var e=`{
  "connect_wallet": {
    "label": "Conectar la billetera",
    "wrong_network": {
      "label": "Red incorrecta"
    }
  },
  "intro": {
    "title": "¿Qué es una billetera?",
    "description": "Una billetera se usa para enviar, recibir, almacenar y mostrar activos digitales. También es una nueva forma de iniciar sesión, sin necesidad de crear nuevas cuentas y contraseñas en cada sitio web.",
    "digital_asset": {
      "title": "Un hogar para tus Activos Digitales",
      "description": "Las carteras se utilizan para enviar, recibir, almacenar y mostrar activos digitales como Ethereum y NFTs."
    },
    "login": {
      "title": "Una nueva forma de iniciar sesión",
      "description": "En lugar de crear nuevas cuentas y contraseñas en cada sitio web, simplemente conecta tu cartera."
    },
    "get": {
      "label": "Obtener una billetera"
    },
    "learn_more": {
      "label": "Obtener más información"
    }
  },
  "sign_in": {
    "label": "Verifica tu cuenta",
    "description": "Para terminar de conectar, debes firmar un mensaje en tu billetera para verificar que eres el propietario de esta cuenta.",
    "message": {
      "send": "Enviar mensaje",
      "preparing": "Preparando mensaje...",
      "cancel": "Cancelar",
      "preparing_error": "Error al preparar el mensaje, ¡intenta de nuevo!"
    },
    "signature": {
      "waiting": "Esperando firma...",
      "verifying": "Verificando firma...",
      "signing_error": "Error al firmar el mensaje, ¡intenta de nuevo!",
      "verifying_error": "Error al verificar la firma, ¡intenta de nuevo!",
      "oops_error": "¡Ups! Algo salió mal."
    }
  },
  "connect": {
    "label": "Conectar",
    "title": "Conectar una billetera",
    "new_to_ethereum": {
      "description": "¿Eres nuevo en las billeteras Ethereum?",
      "learn_more": {
        "label": "Obtener más información"
      }
    },
    "learn_more": {
      "label": "Obtener más información"
    },
    "recent": "Reciente",
    "status": {
      "opening": "Abriendo %{wallet}...",
      "connecting": "Conectando",
      "connect_mobile": "Continuar en %{wallet}",
      "not_installed": "%{wallet} no está instalado",
      "not_available": "%{wallet} no está disponible",
      "confirm": "Confirma la conexión en la extensión",
      "confirm_mobile": "Aceptar la solicitud de conexión en la cartera"
    },
    "secondary_action": {
      "get": {
        "description": "¿No tienes %{wallet}?",
        "label": "OBTENER"
      },
      "install": {
        "label": "INSTALAR"
      },
      "retry": {
        "label": "REINTENTAR"
      }
    },
    "walletconnect": {
      "description": {
        "full": "¿Necesitas el modal oficial de WalletConnect?",
        "compact": "¿Necesitas el modal de WalletConnect?"
      },
      "open": {
        "label": "ABRIR"
      }
    }
  },
  "connect_scan": {
    "title": "Escanea con %{wallet}",
    "fallback_title": "Escanea con tu teléfono"
  },
  "connector_group": {
    "installed": "Instalado",
    "recommended": "Recomendado",
    "other": "Otro",
    "popular": "Popular",
    "more": "Más",
    "others": "Otros"
  },
  "get": {
    "title": "Obtener una billetera",
    "action": {
      "label": "OBTENER"
    },
    "mobile": {
      "description": "Billetera Móvil"
    },
    "extension": {
      "description": "Extensión de navegador"
    },
    "mobile_and_extension": {
      "description": "Billetera móvil y extensión"
    },
    "mobile_and_desktop": {
      "description": "Billetera Móvil y de Escritorio"
    },
    "looking_for": {
      "title": "¿No es lo que estás buscando?",
      "mobile": {
        "description": "Seleccione una billetera en la pantalla principal para comenzar con un proveedor de billetera diferente."
      },
      "desktop": {
        "compact_description": "Seleccione una cartera en la pantalla principal para comenzar con un proveedor de cartera diferente.",
        "wide_description": "Seleccione una cartera a la izquierda para comenzar con un proveedor de cartera diferente."
      }
    }
  },
  "get_options": {
    "title": "Comienza con %{wallet}",
    "short_title": "Obtener %{wallet}",
    "mobile": {
      "title": "%{wallet} para móvil",
      "description": "Use la billetera móvil para explorar el mundo de Ethereum.",
      "download": {
        "label": "Obtener la aplicación"
      }
    },
    "extension": {
      "title": "%{wallet} para %{browser}",
      "description": "Acceda a su billetera directamente desde su navegador web favorito.",
      "download": {
        "label": "Añadir a %{browser}"
      }
    },
    "desktop": {
      "title": "%{wallet} para %{platform}",
      "description": "Acceda a su billetera de forma nativa desde su potente escritorio.",
      "download": {
        "label": "Añadir a %{platform}"
      }
    }
  },
  "get_mobile": {
    "title": "Instalar %{wallet}",
    "description": "Escanee con su teléfono para descargar en iOS o Android",
    "continue": {
      "label": "Continuar"
    }
  },
  "get_instructions": {
    "mobile": {
      "connect": {
        "label": "Conectar"
      },
      "learn_more": {
        "label": "Obtener más información"
      }
    },
    "extension": {
      "refresh": {
        "label": "Actualizar"
      },
      "learn_more": {
        "label": "Obtener más información"
      }
    },
    "desktop": {
      "connect": {
        "label": "Conectar"
      },
      "learn_more": {
        "label": "Obtener más información"
      }
    }
  },
  "chains": {
    "title": "Cambiar redes",
    "wrong_network": "Se detectó la red incorrecta, cambia o desconéctate para continuar.",
    "confirm": "Confirmar en la cartera",
    "switching_not_supported": "Tu cartera no admite cambiar las redes desde %{appName}. Intenta cambiar las redes desde tu cartera.",
    "switching_not_supported_fallback": "Su billetera no admite el cambio de redes desde esta aplicación. Intente cambiar de red desde dentro de su billetera en su lugar.",
    "disconnect": "Desconectar",
    "connected": "Conectado"
  },
  "profile": {
    "disconnect": {
      "label": "Desconectar"
    },
    "copy_address": {
      "label": "Copiar dirección",
      "copied": "¡Copiado!"
    },
    "explorer": {
      "label": "Ver más en el explorador"
    },
    "transactions": {
      "description": "%{appName} transacciones aparecerán aquí...",
      "description_fallback": "Tus transacciones aparecerán aquí...",
      "recent": {
        "title": "Transacciones recientes"
      },
      "clear": {
        "label": "Borrar Todo"
      }
    }
  },
  "wallet_connectors": {
    "argent": {
      "qr_code": {
        "step1": {
          "description": "Coloque Argent en su pantalla de inicio para un acceso más rápido a su billetera.",
          "title": "Abra la aplicación Argent"
        },
        "step2": {
          "description": "Cree una billetera y un nombre de usuario, o importe una billetera existente.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Después de escanear, aparecerá un mensaje de conexión para que conecte su billetera.",
          "title": "Toque el botón Escanear QR"
        }
      }
    },
    "bifrost": {
      "qr_code": {
        "step1": {
          "description": "Recomendamos poner Bifrost Wallet en su pantalla de inicio para un acceso más rápido.",
          "title": "Abra la aplicación Bifrost Wallet"
        },
        "step2": {
          "description": "Cree o importe una billetera usando su frase de recuperación.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Después de escanear, aparecerá un aviso de conexión para que conecte su billetera.",
          "title": "Toque el botón de escaneo"
        }
      }
    },
    "bitget": {
      "qr_code": {
        "step1": {
          "description": "Recomendamos colocar Bitget Wallet en su pantalla de inicio para un acceso más rápido.",
          "title": "Abra la aplicación Bitget Wallet"
        },
        "step2": {
          "description": "Asegúrese de respaldar su billetera utilizando un método seguro. Nunca comparta su frase secreta con nadie.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Después de escanear, aparecerá un aviso de conexión para que pueda conectar su billetera.",
          "title": "Toque el botón de escanear"
        }
      },
      "extension": {
        "step1": {
          "description": "Recomendamos anclar Bitget Wallet a su barra de tareas para un acceso más rápido a su billetera.",
          "title": "Instale la extensión de la Billetera Bitget"
        },
        "step2": {
          "description": "Asegúrate de respaldar tu billetera utilizando un método seguro. Nunca compartas tu frase secreta con nadie.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Una vez que configures tu billetera, haz clic a continuación para refrescar el navegador y cargar la extensión.",
          "title": "Refrescar tu navegador"
        }
      }
    },
    "bitski": {
      "extension": {
        "step1": {
          "description": "Recomendamos anclar Bitski a tu barra de tareas para un acceso más rápido a tu billetera.",
          "title": "Instala la extensión Bitski"
        },
        "step2": {
          "description": "Asegúrate de respaldar tu billetera utilizando un método seguro. Nunca compartas tu frase secreta con nadie.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Una vez que configure su billetera, haga clic abajo para actualizar el navegador y cargar la extensión.",
          "title": "Actualiza tu navegador"
        }
      }
    },
    "bitverse": {
      "qr_code": {
        "step1": {
          "title": "Abra la aplicación Bitverse Wallet",
          "description": "Agregue Bitverse Wallet a su pantalla de inicio para un acceso más rápido a su billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Crea una nueva billetera o importa una existente."
        },
        "step3": {
          "title": "Toque el icono de QR y escanee",
          "description": "Toca el icono QR en tu pantalla de inicio, escanea el código y confirma el prompt para conectar."
        }
      }
    },
    "bloom": {
      "desktop": {
        "step1": {
          "title": "Abra la aplicación Bloom Wallet",
          "description": "Recomendamos colocar Bloom Wallet en su pantalla de inicio para un acceso más rápido."
        },
        "step2": {
          "description": "Cree o importe una billetera usando su frase de recuperación.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Después de tener una billetera, haga clic en Conectar para conectarse a través de Bloom. Aparecerá un aviso de conexión en la aplicación para que confirme la conexión.",
          "title": "Haga clic en Conectar"
        }
      },
      "qr_code": {
        "step1": {
          "title": "Abra la aplicación Bloom Wallet",
          "description": "Recomendamos colocar Bloom Wallet en su pantalla de inicio para un acceso más rápido."
        },
        "step2": {
          "description": "Cree o importe una billetera usando su frase de recuperación.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Después de tener una billetera, haga clic en Conectar para conectarse a través de Bloom. Aparecerá un aviso de conexión en la aplicación para que confirme la conexión.",
          "title": "Haga clic en Conectar"
        }
      }
    },
    "bybit": {
      "qr_code": {
        "step1": {
          "description": "Recomendamos poner Bybit en su pantalla de inicio para un acceso más rápido a su billetera.",
          "title": "Abra la aplicación Bybit"
        },
        "step2": {
          "description": "Puede respaldar fácilmente su billetera utilizando nuestra función de respaldo en su teléfono.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Después de escanear, aparecerá un mensaje de conexión para que conecte su billetera.",
          "title": "Toque el botón de escaneo"
        }
      },
      "extension": {
        "step1": {
          "description": "Haga clic en la parte superior derecha de su navegador y ancle Bybit Wallet para un acceso fácil.",
          "title": "Instale la extensión Bybit Wallet"
        },
        "step2": {
          "description": "Crea una nueva billetera o importa una existente.",
          "title": "Crear o Importar una billetera"
        },
        "step3": {
          "description": "Una vez que haya configurado Bybit Wallet, haga clic a continuación para actualizar el navegador y cargar la extensión.",
          "title": "Refrescar tu navegador"
        }
      }
    },
    "binance": {
      "qr_code": {
        "step1": {
          "description": "Recomendamos poner Binance en tu pantalla de inicio para un acceso más rápido a tu billetera.",
          "title": "Abre la aplicación Binance"
        },
        "step2": {
          "description": "Puede respaldar fácilmente su billetera utilizando nuestra función de respaldo en su teléfono.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Después de escanear, aparecerá un mensaje de conexión para que conecte su billetera.",
          "title": "Toque el botón WalletConnect"
        }
      }
    },
    "coin98": {
      "qr_code": {
        "step1": {
          "description": "Recomendamos poner Coin98 Wallet en la pantalla de inicio para un acceso más rápido a su billetera.",
          "title": "Abra la aplicación Coin98 Wallet"
        },
        "step2": {
          "description": "Puede respaldar fácilmente su billetera utilizando nuestra función de respaldo en su teléfono.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Después de escanear, aparecerá un aviso de conexión para que conecte su billetera.",
          "title": "Toque el botón WalletConnect"
        }
      },
      "extension": {
        "step1": {
          "description": "Haga clic en la parte superior derecha de su navegador y fije Coin98 Wallet para un fácil acceso.",
          "title": "Instale la extensión Coin98 Wallet"
        },
        "step2": {
          "description": "Crea una nueva billetera o importa una existente.",
          "title": "Crear o Importar una billetera"
        },
        "step3": {
          "description": "Una vez que configures Coin98 Wallet, haz clic a continuación para refrescar el navegador y cargar la extensión.",
          "title": "Refresca tu navegador"
        }
      }
    },
    "coinbase": {
      "qr_code": {
        "step1": {
          "description": "Recomendamos poner Coinbase Wallet en tu pantalla de inicio para un acceso más rápido.",
          "title": "Abre la aplicación de la Billetera Coinbase"
        },
        "step2": {
          "description": "Puedes respaldar tu billetera fácilmente utilizando la función de respaldo en la nube.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Después de escanear, aparecerá un aviso de conexión para que conectes tu billetera.",
          "title": "Pulsa el botón de escanear"
        }
      },
      "extension": {
        "step1": {
          "description": "Te recomendamos anclar la Billetera Coinbase a tu barra de tareas para un acceso más rápido a tu billetera.",
          "title": "Instala la extensión de la Billetera Coinbase"
        },
        "step2": {
          "description": "Asegúrate de respaldar tu billetera utilizando un método seguro. Nunca compartas tu frase secreta con nadie.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Una vez que configure su billetera, haga clic abajo para refrescar el navegador y cargar la extensión.",
          "title": "Refresca tu navegador"
        }
      }
    },
    "compass": {
      "extension": {
        "step1": {
          "description": "Recomendamos anclar la Billetera Compass a tu barra de tareas para un acceso más rápido a tu billetera.",
          "title": "Instala la extensión de la Billetera Compass"
        },
        "step2": {
          "description": "Asegúrese de respaldar su billetera utilizando un método seguro. Nunca comparta su frase secreta con nadie.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Una vez que configures tu billetera, haz clic a continuación para refrescar el navegador y cargar la extensión.",
          "title": "Refrescar tu navegador"
        }
      }
    },
    "core": {
      "qr_code": {
        "step1": {
          "description": "Recomendamos poner Core en su pantalla de inicio para un acceso más rápido a su billetera.",
          "title": "Abra la aplicación Core"
        },
        "step2": {
          "description": "Puedes respaldar fácilmente tu billetera utilizando nuestra función de respaldo en tu teléfono.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Después de escanear, aparecerá un aviso de conexión para que conectes tu billetera.",
          "title": "Toque el botón WalletConnect"
        }
      },
      "extension": {
        "step1": {
          "description": "Recomendamos fijar Core a tu barra de tareas para acceder más rápido a tu billetera.",
          "title": "Instala la extensión Core"
        },
        "step2": {
          "description": "Asegúrate de hacer una copia de seguridad de tu billetera utilizando un método seguro. Nunca compartas tu frase secreta con nadie.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Una vez que configures tu billetera, haz clic a continuación para refrescar el navegador y cargar la extensión.",
          "title": "Refresca tu navegador"
        }
      }
    },
    "fox": {
      "qr_code": {
        "step1": {
          "description": "Recomendamos poner FoxWallet en tu pantalla de inicio para un acceso más rápido.",
          "title": "Abre la aplicación FoxWallet"
        },
        "step2": {
          "description": "Asegúrate de respaldar tu billetera utilizando un método seguro. Nunca compartas tu frase secreta con nadie.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Después de escanear, aparecerá una solicitud de conexión para que conectes tu billetera.",
          "title": "Toca el botón de escanear"
        }
      }
    },
    "frontier": {
      "qr_code": {
        "step1": {
          "description": "Recomendamos poner la Billetera Frontier en tu pantalla principal para un acceso más rápido.",
          "title": "Abre la aplicación de la Billetera Frontier"
        },
        "step2": {
          "description": "Asegúrate de respaldar tu billetera utilizando un método seguro. Nunca compartas tu frase secreta con nadie.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Después de escanear, aparecerá un mensaje para que conectes tu billetera.",
          "title": "Haz clic en el botón de escaneo"
        }
      },
      "extension": {
        "step1": {
          "description": "Recomendamos anclar la billetera Frontier a tu barra de tareas para un acceso más rápido a tu billetera.",
          "title": "Instala la extensión de la billetera Frontier"
        },
        "step2": {
          "description": "Asegúrese de hacer una copia de seguridad de su billetera utilizando un método seguro. Nunca comparta su frase secreta con nadie.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Una vez que configure su billetera, haga clic a continuación para actualizar el navegador y cargar la extensión.",
          "title": "Actualizar tu navegador"
        }
      }
    },
    "im_token": {
      "qr_code": {
        "step1": {
          "title": "Abrir la aplicación imToken",
          "description": "Pon la aplicación imToken en tu pantalla de inicio para un acceso más rápido a tu billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Crea una nueva billetera o importa una existente."
        },
        "step3": {
          "title": "Toca el Icono del Escáner en la esquina superior derecha",
          "description": "Elija Nueva Conexión, luego escanee el código QR y confirme el aviso para conectar."
        }
      }
    },
    "kaikas": {
      "extension": {
        "step1": {
          "description": "Recomendamos anclar Kaikas a su barra de tareas para un acceso más rápido a su billetera.",
          "title": "Instale la extensión Kaikas"
        },
        "step2": {
          "description": "Asegúrese de respaldar su billetera utilizando un método seguro. Nunca comparta su frase secreta con nadie.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Una vez que configures tu billetera, haz clic a continuación para refrescar el navegador y cargar la extensión.",
          "title": "Refrescar tu navegador"
        }
      },
      "qr_code": {
        "step1": {
          "title": "Abra la aplicación Kaikas",
          "description": "Ponga la aplicación Kaikas en su pantalla de inicio para un acceso más rápido a su billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Crea una nueva billetera o importa una existente."
        },
        "step3": {
          "title": "Toca el Icono del Escáner en la esquina superior derecha",
          "description": "Elija Nueva Conexión, luego escanee el código QR y confirme el aviso para conectar."
        }
      }
    },
    "kraken": {
      "qr_code": {
        "step1": {
          "title": "Abre la aplicación Kraken Wallet",
          "description": "Agrega la Billetera Kraken a tu pantalla de inicio para un acceso más rápido a tu billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Crea una nueva billetera o importa una existente."
        },
        "step3": {
          "title": "Toque el icono de QR y escanee",
          "description": "Toca el icono QR en tu pantalla de inicio, escanea el código y confirma el prompt para conectar."
        }
      }
    },
    "kresus": {
      "qr_code": {
        "step1": {
          "title": "Abra la aplicación Kresus Wallet",
          "description": "Agregue Kresus Wallet a su pantalla de inicio para un acceso más rápido a su billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Crea una nueva billetera o importa una existente."
        },
        "step3": {
          "title": "Toque el icono de QR y escanee",
          "description": "Toca el icono QR en tu pantalla de inicio, escanea el código y confirma el prompt para conectar."
        }
      }
    },
    "magicEden": {
      "extension": {
        "step1": {
          "title": "Instala la extensión de Magic Eden",
          "description": "Recomendamos anclar Magic Eden a tu barra de tareas para acceder más fácilmente a tu billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrese de respaldar su billetera usando un método seguro. Nunca comparta su frase secreta de recuperación con nadie."
        },
        "step3": {
          "title": "Refrescar tu navegador",
          "description": "Una vez que configures tu billetera, haz clic a continuación para refrescar el navegador y cargar la extensión."
        }
      }
    },
    "metamask": {
      "qr_code": {
        "step1": {
          "title": "Abre la aplicación MetaMask",
          "description": "Recomendamos colocar MetaMask en tu pantalla de inicio para un acceso más rápido."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrate de respaldar tu billetera utilizando un método seguro. Nunca compartas tu frase secreta con nadie."
        },
        "step3": {
          "title": "Toca el botón de escanear",
          "description": "Después de escanear, aparecerá un aviso de conexión para que conectes tu billetera."
        }
      },
      "extension": {
        "step1": {
          "title": "Instala la extensión MetaMask",
          "description": "Recomendamos anclar MetaMask a tu barra de tareas para un acceso más rápido a tu billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrate de hacer una copia de seguridad de tu billetera usando un método seguro. Nunca compartas tu frase secreta con nadie."
        },
        "step3": {
          "title": "Refresca tu navegador",
          "description": "Una vez que configures tu billetera, haz clic abajo para refrescar el navegador y cargar la extensión."
        }
      }
    },
    "nestwallet": {
      "extension": {
        "step1": {
          "title": "Instala la extensión NestWallet",
          "description": "Recomendamos fijar NestWallet a tu barra de tareas para un acceso más rápido a tu billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrese de respaldar su billetera utilizando un método seguro. Nunca comparta su frase secreta con nadie."
        },
        "step3": {
          "title": "Refrescar tu navegador",
          "description": "Una vez que configures tu billetera, haz clic a continuación para refrescar el navegador y cargar la extensión."
        }
      }
    },
    "okx": {
      "qr_code": {
        "step1": {
          "title": "Abre la aplicación OKX Wallet",
          "description": "Recomendamos colocar OKX Wallet en tu pantalla de inicio para un acceso más rápido."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrate de respaldar tu billetera usando un método seguro. Nunca compartas tu frase secreta con nadie."
        },
        "step3": {
          "title": "Toca el botón de escanear",
          "description": "Después de escanear, aparecerá un aviso de conexión para que conectes tu billetera."
        }
      },
      "extension": {
        "step1": {
          "title": "Instala la extensión de Billetera OKX",
          "description": "Recomendamos anclar la Billetera OKX a tu barra de tareas para un acceso más rápido a tu billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrate de respaldar tu billetera usando un método seguro. Nunca compartas tu frase secreta con nadie."
        },
        "step3": {
          "title": "Refresca tu navegador",
          "description": "Una vez que configure su billetera, haga clic abajo para actualizar el navegador y cargar la extensión."
        }
      }
    },
    "omni": {
      "qr_code": {
        "step1": {
          "title": "Abra la aplicación Omni",
          "description": "Agregue Omni a su pantalla de inicio para un acceso más rápido a su billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Crear una nueva billetera o importar una existente."
        },
        "step3": {
          "title": "Toque el icono de QR y escanee",
          "description": "Toca el icono QR en tu pantalla principal, escanea el código y confirma el aviso para conectar."
        }
      }
    },
    "1inch": {
      "qr_code": {
        "step1": {
          "description": "Ponga 1inch Wallet en su pantalla de inicio para un acceso más rápido a su billetera.",
          "title": "Abra la aplicación 1inch Wallet"
        },
        "step2": {
          "description": "Cree una billetera y un nombre de usuario, o importe una billetera existente.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Después de escanear, aparecerá un mensaje de conexión para que conecte su billetera.",
          "title": "Toque el botón Escanear QR"
        }
      }
    },
    "token_pocket": {
      "qr_code": {
        "step1": {
          "title": "Abre la aplicación TokenPocket",
          "description": "Recomendamos colocar TokenPocket en tu pantalla principal para un acceso más rápido."
        },
        "step2": {
          "title": "Crear o importar una Billetera",
          "description": "Asegúrate de respaldar tu billetera utilizando un método seguro. Nunca compartas tu frase secreta con nadie."
        },
        "step3": {
          "title": "Toca el botón de escaneo",
          "description": "Después de escanear, aparecerá una solicitud de conexión para que puedas conectar tu billetera."
        }
      },
      "extension": {
        "step1": {
          "title": "Instala la extensión TokenPocket",
          "description": "Recomendamos anclar TokenPocket a tu barra de tareas para un acceso más rápido a tu billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrate de respaldar tu billetera utilizando un método seguro. Nunca compartas tu frase secreta con nadie."
        },
        "step3": {
          "title": "Actualiza tu navegador",
          "description": "Una vez que configures tu billetera, haz clic a continuación para actualizar el navegador y cargar la extensión."
        }
      }
    },
    "trust": {
      "qr_code": {
        "step1": {
          "title": "Abre la aplicación Trust Wallet",
          "description": "Ubica Trust Wallet en tu pantalla de inicio para un acceso más rápido a tu billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Crea una nueva billetera o importa una existente."
        },
        "step3": {
          "title": "Toca WalletConnect en Configuraciones",
          "description": "Elige Nueva Conexión, luego escanea el código QR y confirma el aviso para conectar."
        }
      },
      "extension": {
        "step1": {
          "title": "Instala la extensión de Trust Wallet",
          "description": "Haz clic en la parte superior derecha de tu navegador y fija Trust Wallet para un fácil acceso."
        },
        "step2": {
          "title": "Crea o Importa una billetera",
          "description": "Crea una nueva billetera o importa una existente."
        },
        "step3": {
          "title": "Refresca tu navegador",
          "description": "Una vez que configures Trust Wallet, haz clic abajo para refrescar el navegador y cargar la extensión."
        }
      }
    },
    "uniswap": {
      "qr_code": {
        "step1": {
          "title": "Abre la aplicación Uniswap",
          "description": "Agrega la billetera Uniswap a tu pantalla de inicio para un acceso más rápido a tu billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Crea una nueva billetera o importa una existente."
        },
        "step3": {
          "title": "Toca el icono QR y escanea",
          "description": "Toca el icono QR en tu pantalla de inicio, escanea el código y confirma el prompt para conectar."
        }
      }
    },
    "zerion": {
      "qr_code": {
        "step1": {
          "title": "Abre la aplicación Zerion",
          "description": "Recomendamos poner Zerion en tu pantalla de inicio para un acceso más rápido."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrate de hacer una copia de seguridad de tu billetera utilizando un método seguro. Nunca compartas tu frase secreta con nadie."
        },
        "step3": {
          "title": "Toca el botón de escanear",
          "description": "Después de escanear, aparecerá un aviso de conexión para que conectes tu billetera."
        }
      },
      "extension": {
        "step1": {
          "title": "Instala la extensión Zerion",
          "description": "Recomendamos anclar Zerion a tu barra de tareas para un acceso más rápido a tu billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrese de respaldar su billetera usando un método seguro. Nunca comparta su frase secreta con nadie."
        },
        "step3": {
          "title": "Actualiza tu navegador",
          "description": "Una vez que configures tu billetera, haz clic a continuación para actualizar el navegador y cargar la extensión."
        }
      }
    },
    "rainbow": {
      "qr_code": {
        "step1": {
          "title": "Abre la aplicación Rainbow",
          "description": "Recomendamos poner Rainbow en tu pantalla de inicio para un acceso más rápido a tu billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Puedes respaldar fácilmente tu billetera usando nuestra función de respaldo en tu teléfono."
        },
        "step3": {
          "title": "Toca el botón de escanear",
          "description": "Después de escanear, aparecerá una solicitud de conexión para que conectes tu billetera."
        }
      }
    },
    "enkrypt": {
      "extension": {
        "step1": {
          "description": "Recomendamos anclar la Billetera Enkrypt a tu barra de tareas para un acceso más rápido a tu billetera.",
          "title": "Instala la extensión de Billetera Enkrypt"
        },
        "step2": {
          "description": "Asegúrate de respaldar tu billetera utilizando un método seguro. Nunca compartas tu frase secreta con nadie.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Una vez que configures tu billetera, haz clic abajo para refrescar el navegador y cargar la extensión.",
          "title": "Refresca tu navegador"
        }
      }
    },
    "frame": {
      "extension": {
        "step1": {
          "description": "Recomendamos anclar Frame a tu barra de tareas para un acceso más rápido a tu billetera.",
          "title": "Instala Frame y la extensión complementaria"
        },
        "step2": {
          "description": "Asegúrate de respaldar tu billetera utilizando un método seguro. Nunca compartas tu frase secreta con nadie.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Una vez que configures tu billetera, haz clic a continuación para refrescar el navegador y cargar la extensión.",
          "title": "Refresca tu navegador"
        }
      }
    },
    "one_key": {
      "extension": {
        "step1": {
          "title": "Instale la extensión de Billetera OneKey",
          "description": "Recomendamos anclar la Billetera OneKey a tu barra de tareas para un acceso más rápido a tu billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrese de respaldar su billetera usando un método seguro. Nunca comparta su frase secreta con nadie."
        },
        "step3": {
          "title": "Actualiza tu navegador",
          "description": "Una vez que configures tu billetera, haz clic a continuación para actualizar el navegador y cargar la extensión."
        }
      }
    },
    "phantom": {
      "extension": {
        "step1": {
          "title": "Instala la extensión Phantom",
          "description": "Recomendamos fijar Phantom a tu barra de tareas para un acceso más fácil a tu billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrese de respaldar su billetera usando un método seguro. Nunca comparta su frase secreta de recuperación con nadie."
        },
        "step3": {
          "title": "Actualiza tu navegador",
          "description": "Una vez que configures tu billetera, haz clic abajo para refrescar el navegador y cargar la extensión."
        }
      }
    },
    "rabby": {
      "extension": {
        "step1": {
          "title": "Instala la extensión Rabby",
          "description": "Recomendamos anclar Rabby a tu barra de tareas para un acceso más rápido a tu billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrate de hacer una copia de seguridad de tu billetera utilizando un método seguro. Nunca compartas tu frase secreta con nadie."
        },
        "step3": {
          "title": "Actualiza tu navegador",
          "description": "Una vez que configures tu billetera, haz clic abajo para actualizar el navegador y cargar la extensión."
        }
      }
    },
    "ronin": {
      "qr_code": {
        "step1": {
          "description": "Recomendamos poner Ronin Wallet en su pantalla de inicio para un acceso más rápido.",
          "title": "Abra la aplicación Ronin Wallet"
        },
        "step2": {
          "description": "Asegúrese de respaldar su billetera utilizando un método seguro. Nunca comparta su frase secreta con nadie.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Después de escanear, aparecerá un mensaje de conexión para que conecte su billetera.",
          "title": "Toque el botón de escaneo"
        }
      },
      "extension": {
        "step1": {
          "description": "Recomendamos anclar Ronin Wallet a su barra de tareas para un acceso más rápido a su billetera.",
          "title": "Instale la extensión Ronin Wallet"
        },
        "step2": {
          "description": "Asegúrese de respaldar su billetera utilizando un método seguro. Nunca comparta su frase secreta con nadie.",
          "title": "Crear o Importar una Billetera"
        },
        "step3": {
          "description": "Una vez que configures tu billetera, haz clic a continuación para refrescar el navegador y cargar la extensión.",
          "title": "Refrescar tu navegador"
        }
      }
    },
    "ramper": {
      "extension": {
        "step1": {
          "title": "Instale la extensión Ramper",
          "description": "Recomendamos anclar Ramper a su barra de tareas para un acceso más fácil a su billetera."
        },
        "step2": {
          "title": "Crea una Cartera",
          "description": "Asegúrese de respaldar su billetera utilizando un método seguro. Nunca comparta su frase secreta con nadie."
        },
        "step3": {
          "title": "Refrescar tu navegador",
          "description": "Una vez que configures tu billetera, haz clic a continuación para refrescar el navegador y cargar la extensión."
        }
      }
    },
    "safeheron": {
      "extension": {
        "step1": {
          "title": "Instala la extensión Core",
          "description": "Recomendamos anclar Safeheron a tu barra de tareas para un acceso más rápido a tu billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrate de respaldar tu billetera utilizando un método seguro. Nunca compartas tu frase secreta con nadie."
        },
        "step3": {
          "title": "Refresca tu navegador",
          "description": "Una vez que configures tu billetera, haz clic abajo para refrescar el navegador y cargar la extensión."
        }
      }
    },
    "taho": {
      "extension": {
        "step1": {
          "title": "Instala la extensión de Taho",
          "description": "Recomendamos anclar Taho a tu barra de tareas para un acceso más rápido a tu billetera."
        },
        "step2": {
          "title": "Crea o Importa una Billetera",
          "description": "Asegúrate de respaldar tu billetera utilizando un método seguro. Nunca compartas tu frase secreta con nadie."
        },
        "step3": {
          "title": "Refresca tu navegador",
          "description": "Una vez que configures tu billetera, haz clic abajo para refrescar el navegador y cargar la extensión."
        }
      }
    },
    "talisman": {
      "extension": {
        "step1": {
          "title": "Instala la extensión de Talisman",
          "description": "Recomendamos anclar Talisman a tu barra de tareas para un acceso más rápido a tu billetera."
        },
        "step2": {
          "title": "Crea o importa una billetera Ethereum",
          "description": "Asegúrate de respaldar tu billetera usando un método seguro. Nunca compartas tu frase de recuperación con nadie."
        },
        "step3": {
          "title": "Recarga tu navegador",
          "description": "Una vez que configures tu billetera, haz clic abajo para refrescar el navegador y cargar la extensión."
        }
      }
    },
    "xdefi": {
      "extension": {
        "step1": {
          "title": "Instala la extensión de la billetera XDEFI",
          "description": "Recomendamos anclar XDEFI Wallet a su barra de tareas para un acceso más rápido a su billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrese de respaldar su billetera utilizando un método seguro. Nunca comparta su frase secreta con nadie."
        },
        "step3": {
          "title": "Actualice su navegador",
          "description": "Una vez que configure su billetera, haga clic abajo para actualizar el navegador y cargar la extensión."
        }
      }
    },
    "zeal": {
      "qr_code": {
        "step1": {
          "title": "Abre la aplicación Zeal",
          "description": "Agrega Zeal Wallet a tu pantalla de inicio para un acceso más rápido a tu billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Crea una nueva billetera o importa una existente."
        },
        "step3": {
          "title": "Toque el icono de QR y escanee",
          "description": "Toca el icono QR en tu pantalla de inicio, escanea el código y confirma el prompt para conectar."
        }
      },
      "extension": {
        "step1": {
          "title": "Instale la extensión Zeal",
          "description": "Recomendamos anclar Zeal a su barra de tareas para un acceso más rápido a su billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrese de respaldar su billetera utilizando un método seguro. Nunca comparta su frase secreta con nadie."
        },
        "step3": {
          "title": "Refrescar tu navegador",
          "description": "Una vez que configures tu billetera, haz clic a continuación para refrescar el navegador y cargar la extensión."
        }
      }
    },
    "safepal": {
      "extension": {
        "step1": {
          "title": "Instale la extensión de la billetera SafePal",
          "description": "Haga clic en la esquina superior derecha de su navegador y ancle SafePal Wallet para un fácil acceso."
        },
        "step2": {
          "title": "Crear o Importar una billetera",
          "description": "Crea una nueva billetera o importa una existente."
        },
        "step3": {
          "title": "Refrescar tu navegador",
          "description": "Una vez que configure la Billetera SafePal, haga clic abajo para refrescar el navegador y cargar la extensión."
        }
      },
      "qr_code": {
        "step1": {
          "title": "Abra la aplicación Billetera SafePal",
          "description": "Coloque la Billetera SafePal en su pantalla de inicio para un acceso más rápido a su billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Crea una nueva billetera o importa una existente."
        },
        "step3": {
          "title": "Toca WalletConnect en Configuraciones",
          "description": "Elija Nueva Conexión, luego escanee el código QR y confirme el aviso para conectar."
        }
      }
    },
    "desig": {
      "extension": {
        "step1": {
          "title": "Instala la extensión Desig",
          "description": "Recomendamos anclar Desig a tu barra de tareas para acceder más fácilmente a tu cartera."
        },
        "step2": {
          "title": "Crea una Cartera",
          "description": "Asegúrese de respaldar su billetera utilizando un método seguro. Nunca comparta su frase secreta con nadie."
        },
        "step3": {
          "title": "Refrescar tu navegador",
          "description": "Una vez que configures tu billetera, haz clic a continuación para refrescar el navegador y cargar la extensión."
        }
      }
    },
    "subwallet": {
      "extension": {
        "step1": {
          "title": "Instala la extensión SubWallet",
          "description": "Recomendamos anclar SubWallet a tu barra de tareas para acceder a tu cartera más rápidamente."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrate de respaldar tu billetera usando un método seguro. Nunca compartas tu frase de recuperación con nadie."
        },
        "step3": {
          "title": "Refrescar tu navegador",
          "description": "Una vez que configures tu billetera, haz clic a continuación para refrescar el navegador y cargar la extensión."
        }
      },
      "qr_code": {
        "step1": {
          "title": "Abre la aplicación SubWallet",
          "description": "Recomendamos colocar SubWallet en tu pantalla principal para un acceso más rápido."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrese de respaldar su billetera utilizando un método seguro. Nunca comparta su frase secreta con nadie."
        },
        "step3": {
          "title": "Toque el botón de escaneo",
          "description": "Después de escanear, aparecerá un mensaje de conexión para que conecte su billetera."
        }
      }
    },
    "clv": {
      "extension": {
        "step1": {
          "title": "Instala la extensión CLV Wallet",
          "description": "Recomendamos anclar la billetera CLV a tu barra de tareas para un acceso más rápido a tu billetera."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrese de respaldar su billetera utilizando un método seguro. Nunca comparta su frase secreta con nadie."
        },
        "step3": {
          "title": "Refrescar tu navegador",
          "description": "Una vez que configures tu billetera, haz clic a continuación para refrescar el navegador y cargar la extensión."
        }
      },
      "qr_code": {
        "step1": {
          "title": "Abra la aplicación CLV Wallet",
          "description": "Recomendamos colocar la billetera CLV en tu pantalla de inicio para un acceso más rápido."
        },
        "step2": {
          "title": "Crear o Importar una Billetera",
          "description": "Asegúrese de respaldar su billetera utilizando un método seguro. Nunca comparta su frase secreta con nadie."
        },
        "step3": {
          "title": "Toque el botón de escaneo",
          "description": "Después de escanear, aparecerá un mensaje de conexión para que conecte su billetera."
        }
      }
    },
    "okto": {
      "qr_code": {
        "step1": {
          "title": "Abra la aplicación Okto",
          "description": "Agrega Okto a tu pantalla de inicio para un acceso rápido"
        },
        "step2": {
          "title": "Crea una billetera MPC",
          "description": "Crea una cuenta y genera una billetera"
        },
        "step3": {
          "title": "Toca WalletConnect en Configuraciones",
          "description": "Toca el icono de Escanear QR en la parte superior derecha y confirma el mensaje para conectar."
        }
      }
    },
    "ledger": {
      "desktop": {
        "step1": {
          "title": "Abra la aplicación Ledger Live",
          "description": "Recomendamos poner Ledger Live en su pantalla de inicio para un acceso más rápido."
        },
        "step2": {
          "title": "Configure su Ledger",
          "description": "Configure un nuevo Ledger o conéctese a uno existente."
        },
        "step3": {
          "title": "Conectar",
          "description": "Después de escanear, aparecerá un aviso de conexión para que conectes tu billetera."
        }
      },
      "qr_code": {
        "step1": {
          "title": "Abra la aplicación Ledger Live",
          "description": "Recomendamos poner Ledger Live en su pantalla de inicio para un acceso más rápido."
        },
        "step2": {
          "title": "Configure su Ledger",
          "description": "Puedes sincronizar con la aplicación de escritorio o conectar tu Ledger."
        },
        "step3": {
          "title": "Escanea el código",
          "description": "Toca WalletConnect y luego cambia a Scanner. Después de escanear, aparecerá un aviso de conexión para que conectes tu billetera."
        }
      }
    }
  }
}
`;export{e as default};
