var u=`{
  "connect_wallet": {
    "label": "지갑 연결",
    "wrong_network": {
      "label": "잘못된 네트워크"
    }
  },
  "intro": {
    "title": "지갑이란 무엇인가요?",
    "description": "지갑은 디지털 자산을 보내고, 받고, 저장하고, 표시하는 데 사용됩니다. 또한, 모든 웹 사이트에서 새 계정과 비밀번호를 생성할 필요 없이 로그인하는 새로운 방법입니다.",
    "digital_asset": {
      "title": "당신의 디지털 자산을 위한 집",
      "description": "지갑은 이더리움 및 NFT와 같은 디지털 자산을 보내고, 받고, 저장하고, 표시하는데 사용됩니다."
    },
    "login": {
      "title": "새로운 로그인 방식",
      "description": "모든 웹사이트에서 새 계정과 비밀번호를 생성하는 대신, 당신의 지갑을 연결하기만 하면 됩니다."
    },
    "get": {
      "label": "지갑 가져오기"
    },
    "learn_more": {
      "label": "더 알아보기"
    }
  },
  "sign_in": {
    "label": "계정을 확인하세요",
    "description": "연결을 완료하려면 이 계정의 소유자임을 확인하기 위해 지갑에 메시지에 서명해야 합니다.",
    "message": {
      "send": "메시지 보내기",
      "preparing": "메시지 준비 중...",
      "cancel": "취소",
      "preparing_error": "메시지 준비 중 오류가 발생했습니다. 다시 시도하세요!"
    },
    "signature": {
      "waiting": "서명을 기다리는 중...",
      "verifying": "서명 검증 중...",
      "signing_error": "메시지 서명 중 오류가 발생했습니다. 다시 시도하세요!",
      "verifying_error": "서명 검증 중 오류가 발생했습니다. 다시 시도하세요!",
      "oops_error": "앗, 문제가 발생했습니다!"
    }
  },
  "connect": {
    "label": "연결",
    "title": "지갑 연결",
    "new_to_ethereum": {
      "description": "이더리움 지갑에 처음 접하시나요?",
      "learn_more": {
        "label": "더 알아보기"
      }
    },
    "learn_more": {
      "label": "더 알아보기"
    },
    "recent": "최근",
    "status": {
      "opening": "%{wallet}열기 ...",
      "connecting": "연결 중",
      "connect_mobile": "%{wallet}에서 계속 진행",
      "not_installed": "%{wallet} 가 설치되어 있지 않습니다",
      "not_available": "%{wallet} 를 사용할 수 없습니다",
      "confirm": "확장 프로그램에서 연결을 확인하세요",
      "confirm_mobile": "지갑에서 연결 요청을 수락하십시오"
    },
    "secondary_action": {
      "get": {
        "description": "%{wallet}가 없나요?",
        "label": "GET"
      },
      "install": {
        "label": "설치"
      },
      "retry": {
        "label": "다시 시도"
      }
    },
    "walletconnect": {
      "description": {
        "full": "공식 WalletConnect 모달이 필요한가요?",
        "compact": "WalletConnect 모달이 필요한가요?"
      },
      "open": {
        "label": "열기"
      }
    }
  },
  "connect_scan": {
    "title": "%{wallet}로 스캔하기",
    "fallback_title": "휴대폰으로 스캔하기"
  },
  "connector_group": {
    "installed": "설치됨",
    "recommended": "추천",
    "other": "기타",
    "popular": "인기",
    "more": "더 보기",
    "others": "다른 지갑들"
  },
  "get": {
    "title": "월렛 받기",
    "action": {
      "label": "받기"
    },
    "mobile": {
      "description": "모바일 월렛"
    },
    "extension": {
      "description": "브라우저 확장 프로그램"
    },
    "mobile_and_extension": {
      "description": "모바일 지갑 및 확장 프로그램"
    },
    "mobile_and_desktop": {
      "description": "모바일 및 데스크톱 지갑"
    },
    "looking_for": {
      "title": "찾고 계신 것이 아닌가요?",
      "mobile": {
        "description": "메인 화면에서 다른 지갑 제공자를 사용하기 위해 지갑을 선택하세요."
      },
      "desktop": {
        "compact_description": "메인 화면에서 다른 지갑 제공자를 사용하기 위해 지갑을 선택하세요.",
        "wide_description": "왼쪽에서 지갑을 선택하여 다른 지갑 제공자를 사용하기 시작하세요."
      }
    }
  },
  "get_options": {
    "title": "%{wallet}로 시작하세요",
    "short_title": "%{wallet}얻기",
    "mobile": {
      "title": "모바일용 %{wallet}",
      "description": "모바일 지갑으로 이더리움 세계를 탐험하세요.",
      "download": {
        "label": "앱 받기"
      }
    },
    "extension": {
      "title": "%{browser}용 %{wallet}",
      "description": "가장 좋아하는 웹 브라우저에서 바로 지갑에 접근하세요.",
      "download": {
        "label": "추가하기 %{browser}"
      }
    },
    "desktop": {
      "title": "%{wallet} 용 %{platform}",
      "description": "강력한 데스크톱에서 네이티브로 지갑에 접근하세요.",
      "download": {
        "label": "%{platform}에 추가"
      }
    }
  },
  "get_mobile": {
    "title": "설치하기 %{wallet}",
    "description": "iOS 또는 Android에서 다운로드하기 위해 휴대폰으로 스캔하세요",
    "continue": {
      "label": "계속"
    }
  },
  "get_instructions": {
    "mobile": {
      "connect": {
        "label": "연결"
      },
      "learn_more": {
        "label": "더 알아보기"
      }
    },
    "extension": {
      "refresh": {
        "label": "새로고침"
      },
      "learn_more": {
        "label": "더 알아보기"
      }
    },
    "desktop": {
      "connect": {
        "label": "연결"
      },
      "learn_more": {
        "label": "더 알아보기"
      }
    }
  },
  "chains": {
    "title": "네트워크 전환",
    "wrong_network": "잘못된 네트워크를 탐지했습니다, 계속하려면 전환하거나 연결을 해제하세요.",
    "confirm": "지갑에서 승인",
    "switching_not_supported": "지갑에서 %{appName}네트워크를 전환하는 것은 지원되지 않습니다. 대신 지갑 내에서 네트워크를 전환해 보세요.",
    "switching_not_supported_fallback": "당신의 지갑은 이 앱에서 네트워크를 바꾸는 것을 지원하지 않습니다. 대신 지갑 내에서 네트워크를 변경해 보세요.",
    "disconnect": "연결 해제",
    "connected": "연결됨"
  },
  "profile": {
    "disconnect": {
      "label": "연결 해제"
    },
    "copy_address": {
      "label": "주소 복사",
      "copied": "복사됨!"
    },
    "explorer": {
      "label": "탐색기에서 더 보기"
    },
    "transactions": {
      "description": "%{appName} 거래가 여기에 나타납니다...",
      "description_fallback": "여기에 트랜잭션이 표시됩니다...",
      "recent": {
        "title": "최근 거래 내역"
      },
      "clear": {
        "label": "모두 지우기"
      }
    }
  },
  "wallet_connectors": {
    "argent": {
      "qr_code": {
        "step1": {
          "description": "지갑에 더 빠르게 액세스하려면 Argent를 홈 화면에 놓으세요.",
          "title": "Argent 앱을 열기"
        },
        "step2": {
          "description": "지갑과 사용자 이름을 생성하거나 기존의 지갑을 가져옵니다.",
          "title": "지갑 생성 또는 가져오기"
        },
        "step3": {
          "description": "스캔 후에 지갑을 연결하기 위한 연결 요청이 표시됩니다.",
          "title": "QR 코드 스캔 버튼을 누르기"
        }
      }
    },
    "bifrost": {
      "qr_code": {
        "step1": {
          "description": "더 빠른 접근을 위해 홈 화면에 Bifrost Wallet을 놓는 것을 권장합니다.",
          "title": "Bifrost 지갑 앱을 열어주세요"
        },
        "step2": {
          "description": "복구 문구를 사용하여 지갑을 생성하거나 가져옵니다.",
          "title": "지갑 생성 또는 가져오기"
        },
        "step3": {
          "description": "스캔 후 연결 프롬프트가 나타나고 지갑을 연결할 수 있습니다.",
          "title": "스캔 버튼을 누릅니다"
        }
      }
    },
    "bitget": {
      "qr_code": {
        "step1": {
          "description": "더 빠른 접근을 위해 Bitget 지갑을 홈 화면에 두는 것을 권장합니다.",
          "title": "Bitget 지갑 앱을 여세요"
        },
        "step2": {
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 절대로 비밀 구문을 누구와도 공유하지 마세요.",
          "title": "지갑 생성 또는 가져오기"
        },
        "step3": {
          "description": "스캔 후, 지갑을 연결하라는 연결 요청 메시지가 나타납니다.",
          "title": "스캔 버튼을 누르세요"
        }
      },
      "extension": {
        "step1": {
          "description": "지갑에 빠르게 액세스하기 위해 Bitget Wallet을 작업 표시줄에 고정하는 것을 권장합니다.",
          "title": "Bitget Wallet 확장 프로그램을 설치하세요"
        },
        "step2": {
          "description": "지갑을 안전한 방법으로 백업하세요. 절대로 비밀 문구를 누구와도 공유하지 마세요.",
          "title": "지갑 생성 또는 가져오기"
        },
        "step3": {
          "description": "지갑 설정을 마친 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요.",
          "title": "브라우저를 새로 고침하세요"
        }
      }
    },
    "bitski": {
      "extension": {
        "step1": {
          "description": "지갑에 더 빠르게 액세스하기 위해 Bitski를 작업 표시줄에 고정하는 것을 권장합니다.",
          "title": "Bitski 확장 프로그램을 설치합니다"
        },
        "step2": {
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 비밀 문구를 누구와도 공유하지 마세요.",
          "title": "지갑 만들기 또는 가져오기"
        },
        "step3": {
          "description": "지갑을 설정한 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요.",
          "title": "브라우저를 새로고침하세요"
        }
      }
    },
    "bitverse": {
      "qr_code": {
        "step1": {
          "title": "Bitverse 지갑 앱을 열어주세요",
          "description": "지갑에 더 빠르게 접근하기 위해 홈 화면에 Bitverse 지갑을 추가하세요."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "새로운 지갑을 만들거나 기존의 지갑을 가져옵니다."
        },
        "step3": {
          "title": "QR 아이콘을 탭하고 스캔하기",
          "description": "홈화면의 QR 아이콘을 누르고 코드를 스캔하고 프롬프트를 확인하여 연결하세요."
        }
      }
    },
    "bloom": {
      "desktop": {
        "step1": {
          "title": "Bloom Wallet 앱을 엽니다",
          "description": "더 빠른 접근을 위해 Bloom Wallet을 홈 화면에 두는 것을 추천합니다."
        },
        "step2": {
          "description": "복구 문구를 사용하여 지갑을 생성하거나 가져옵니다.",
          "title": "지갑 생성 또는 가져오기"
        },
        "step3": {
          "description": "지갑을 갖춘 후, Bloom을 통해 연결하려면 연결하기를 클릭합니다. 앱에서 연결을 확인하는 프롬프트가 나타납니다.",
          "title": "연결하기를 클릭"
        }
      },
      "qr_code": {
        "step1": {
          "title": "Bloom Wallet 앱을 엽니다",
          "description": "더 빠른 접근을 위해 Bloom Wallet을 홈 화면에 두는 것을 추천합니다."
        },
        "step2": {
          "description": "복구 문구를 사용하여 지갑을 생성하거나 가져옵니다.",
          "title": "지갑 생성 또는 가져오기"
        },
        "step3": {
          "description": "지갑을 갖춘 후, Bloom을 통해 연결하려면 연결하기를 클릭합니다. 앱에서 연결을 확인하는 프롬프트가 나타납니다.",
          "title": "연결하기를 클릭"
        }
      }
    },
    "bybit": {
      "qr_code": {
        "step1": {
          "description": "지갑에 더 빠르게 접근하기 위해 홈 화면에 Bybit을 추가하는 것이 좋습니다.",
          "title": "Bybit 앱을 열어주세요"
        },
        "step2": {
          "description": "휴대폰에서 백업 기능을 이용하여 지갑을 쉽게 백업할 수 있습니다.",
          "title": "지갑 생성 또는 가져오기"
        },
        "step3": {
          "description": "스캔 후에 지갑을 연결하기 위한 연결 요청이 표시됩니다.",
          "title": "스캔 버튼을 누릅니다"
        }
      },
      "extension": {
        "step1": {
          "description": "브라우저의 오른쪽 상단에서 클릭하여 Bybit 지갑을 고정시켜 쉽게 접근하세요.",
          "title": "Bybit 지갑 확장 프로그램을 설치하세요"
        },
        "step2": {
          "description": "새로운 지갑을 만들거나 기존의 지갑을 가져옵니다.",
          "title": "지갑을 만들거나 가져옵니다"
        },
        "step3": {
          "description": "Bybit 지갑을 설정한 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요.",
          "title": "브라우저를 새로 고침하세요"
        }
      }
    },
    "binance": {
      "qr_code": {
        "step1": {
          "description": "지갑에 빠르게 액세스하기 위해 홈 화면에 Binance를 두는 것을 권장합니다.",
          "title": "Binance 앱 열기"
        },
        "step2": {
          "description": "휴대폰에서 백업 기능을 이용하여 지갑을 쉽게 백업할 수 있습니다.",
          "title": "지갑 생성 또는 가져오기"
        },
        "step3": {
          "description": "스캔 후에 지갑을 연결하기 위한 연결 요청이 표시됩니다.",
          "title": "WalletConnect 버튼을 누르세요"
        }
      }
    },
    "coin98": {
      "qr_code": {
        "step1": {
          "description": "지갑에 빠르게 액세스하기 위해 Coin98 Wallet을 홈 화면에 두는 것을 권장합니다.",
          "title": "Coin98 Wallet 앱을 열기"
        },
        "step2": {
          "description": "휴대폰에서 백업 기능을 이용하여 지갑을 쉽게 백업할 수 있습니다.",
          "title": "지갑 만들기 또는 가져오기"
        },
        "step3": {
          "description": "스캔한 후 연결 프롬프트가 나타나 지갑을 연결하도록 합니다.",
          "title": "WalletConnect 버튼을 누르세요"
        }
      },
      "extension": {
        "step1": {
          "description": "브라우저 오른쪽 상단을 클릭하고 쉽게 액세스할 수 있도록 Coin98 Wallet을 고정하세요.",
          "title": "Coin98 Wallet 확장 프로그램을 설치하세요"
        },
        "step2": {
          "description": "새로운 지갑을 만들거나 기존의 지갑을 가져옵니다.",
          "title": "지갑을 만들거나 가져옵니다"
        },
        "step3": {
          "description": "Coin98 Wallet을 설정하면 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요.",
          "title": "브라우저를 새로고침 하세요"
        }
      }
    },
    "coinbase": {
      "qr_code": {
        "step1": {
          "description": "더 빠른 액세스를 위해 Coinbase Wallet을 홈 화면에 두는 것을 권장합니다.",
          "title": "Coinbase Wallet 앱을 엽니다"
        },
        "step2": {
          "description": "클라우드 백업 기능을 사용하여 지갑을 쉽게 백업할 수 있습니다.",
          "title": "지갑 생성 또는 가져오기"
        },
        "step3": {
          "description": "스캔한 후에 지갑을 연결하라는 연결 프롬프트가 나타납니다.",
          "title": "스캔 버튼을 탭하세요"
        }
      },
      "extension": {
        "step1": {
          "description": "지갑에 더 빠르게 접근할 수 있도록 Coinbase Wallet을 작업 표시줄에 고정하는 것을 권장합니다.",
          "title": "Coinbase Wallet 확장 프로그램을 설치하세요"
        },
        "step2": {
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 비밀 문구는 절대로 누구와도 공유하지 마세요.",
          "title": "지갑 만들기 또는 가져오기"
        },
        "step3": {
          "description": "지갑을 설정한 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요.",
          "title": "브라우저 새로고침"
        }
      }
    },
    "compass": {
      "extension": {
        "step1": {
          "description": "지갑에 더 빠르게 접근할 수 있도록 Compass Wallet을 작업 표시줄에 고정하는 것을 권장합니다.",
          "title": "Compass Wallet 확장 프로그램을 설치하세요"
        },
        "step2": {
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 절대로 비밀 구문을 누구와도 공유하지 마세요.",
          "title": "지갑 생성 또는 가져오기"
        },
        "step3": {
          "description": "지갑 설정을 마친 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요.",
          "title": "브라우저를 새로 고침하세요"
        }
      }
    },
    "core": {
      "qr_code": {
        "step1": {
          "description": "지갑에 빠르게 액세스할 수 있도록 Core를 홈 화면에 두는 것을 추천드립니다.",
          "title": "Core 앱 열기"
        },
        "step2": {
          "description": "휴대폰에서 우리의 백업 기능을 이용해 지갑을 쉽게 백업할 수 있습니다.",
          "title": "지갑 만들기 또는 가져오기"
        },
        "step3": {
          "description": "스캔 한 후에는 지갑을 연결하라는 연결 요청이 표시됩니다.",
          "title": "WalletConnect 버튼을 누르세요"
        }
      },
      "extension": {
        "step1": {
          "description": "지갑에 더 빠르게 액세스하기 위해 작업 표시줄에 Core를 고정하는 것을 권장합니다.",
          "title": "Core 확장 프로그램을 설치하세요"
        },
        "step2": {
          "description": "안전한 방법을 사용하여 지갑을 백업해야 합니다. 절대로 비밀 문구를 다른 사람과 공유하지 마세요.",
          "title": "지갑 만들기 또는 가져오기"
        },
        "step3": {
          "description": "지갑을 설정한 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요.",
          "title": "브라우저를 새로 고치세요"
        }
      }
    },
    "fox": {
      "qr_code": {
        "step1": {
          "description": "FoxWallet을 홈 화면에 놓는 것을 추천합니다. 이렇게 하면 더 빠르게 접근할 수 있습니다.",
          "title": "FoxWallet 앱을 열어주세요"
        },
        "step2": {
          "description": "지갑을 안전한 방법으로 백업하세요. 절대로 비밀 문구를 다른 사람과 공유하지 마세요.",
          "title": "지갑을 생성하거나 가져오기"
        },
        "step3": {
          "description": "스캔 후, 지갑을 연결하라는 연결 프롬프트가 표시됩니다.",
          "title": "스캔 버튼을 누르세요"
        }
      }
    },
    "frontier": {
      "qr_code": {
        "step1": {
          "description": "Frontier Wallet을 홈 화면에 놓는 것을 추천합니다. 이렇게 하면 더 빠르게 접근할 수 있습니다.",
          "title": "Frontier Wallet 앱을 열어주세요"
        },
        "step2": {
          "description": "지갑을 안전한 방법으로 백업해야 합니다. 비밀 구문을 누구와도 공유하지 마세요.",
          "title": "지갑 생성 또는 가져오기"
        },
        "step3": {
          "description": "스캔 후에 지갑을 연결하라는 연결 프롬프트가 표시됩니다.",
          "title": "스캔 버튼을 누르세요"
        }
      },
      "extension": {
        "step1": {
          "description": "지갑에 더 빠르게 액세스 할 수 있도록 Frontier Wallet을 작업 표시줄에 고정하는 것을 권장합니다.",
          "title": "Frontier Wallet 확장 프로그램 설치"
        },
        "step2": {
          "description": "지갑을 안전한 방법으로 백업해야 합니다. 비밀 구문을 누구와도 공유하지 마세요.",
          "title": "지갑 생성 또는 가져오기"
        },
        "step3": {
          "description": "지갑을 설정한 후에 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요.",
          "title": "브라우저를 새로 고칩니다"
        }
      }
    },
    "im_token": {
      "qr_code": {
        "step1": {
          "title": "imToken 앱을 연다",
          "description": "당신의 지갑에 더 빠르게 접근하기 위해 imToken 앱을 홈 화면에 둡니다."
        },
        "step2": {
          "title": "지갑을 만들거나 불러옵니다",
          "description": "새 지갑을 생성하거나 기존의 것을 가져옵니다."
        },
        "step3": {
          "title": "오른쪽 상단의 스캐너 아이콘을 누릅니다",
          "description": "새 연결을 선택하고 QR 코드를 스캔한 뒤, 연결하려는 프롬프트를 확인합니다."
        }
      }
    },
    "kaikas": {
      "extension": {
        "step1": {
          "description": "지갑에 더 빠르게 접근할 수 있도록 Kaikas Wallet을 작업 표시줄에 고정하는 것을 권장합니다.",
          "title": "Kaikas Wallet 확장 프로그램을 설치하세요"
        },
        "step2": {
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 비밀 문구는 절대로 누구와도 공유하지 마세요.",
          "title": "지갑 만들기 또는 가져오기"
        },
        "step3": {
          "description": "지갑을 설정한 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요.",
          "title": "브라우저 새로고침"
        }
      },
      "qr_code": {
        "step1": {
          "title": "Kaikas 앱을 열어주세요",
          "description": "지갑에 더 빠르게 접근하기 위해 홈 화면에 Kaikas 앱을 추가하세요."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "새로운 지갑을 만들거나 기존의 지갑을 가져옵니다."
        },
        "step3": {
          "title": "오른쪽 상단의 스캐너 아이콘을 누릅니다",
          "description": "새 연결을 선택하고 QR 코드를 스캔한 뒤, 연결하려는 프롬프트를 확인합니다."
        }
      }
    },
    "kraken": {
      "qr_code": {
        "step1": {
          "title": "Kraken Wallet 앱을 여세요",
          "description": "지갑에 빠르게 액세스하기 위해 Kraken Wallet을 홈 화면에 두는 것을 권장합니다."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "새로운 지갑을 만들거나 기존의 지갑을 가져옵니다."
        },
        "step3": {
          "title": "QR 아이콘을 탭하고 스캔하기",
          "description": "홈화면의 QR 아이콘을 누르고 코드를 스캔하고 프롬프트를 확인하여 연결하세요."
        }
      }
    },
    "kresus": {
      "qr_code": {
        "step1": {
          "title": "Kresus Wallet 앱을 엽니다",
          "description": "Kresus 지갑을 홈 화면에 추가하여 지갑에 더 빠르게 접근하세요."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "새로운 지갑을 만들거나 기존의 지갑을 가져옵니다."
        },
        "step3": {
          "title": "QR 아이콘을 탭하고 스캔하기",
          "description": "홈화면의 QR 아이콘을 누르고 코드를 스캔하고 프롬프트를 확인하여 연결하세요."
        }
      }
    },
    "magicEden": {
      "extension": {
        "step1": {
          "title": "Magic Eden 확장 프로그램 설치",
          "description": "지갑에 더 쉽게 접근할 수 있도록 Magic Eden을 작업 표시줄에 고정하는 것을 권장합니다."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 절대로 누구와도 비밀 복구 구문을 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저를 새로 고침하세요",
          "description": "지갑 설정을 마친 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요."
        }
      }
    },
    "metamask": {
      "qr_code": {
        "step1": {
          "title": "MetaMask 앱을 엽니다",
          "description": "빠른 액세스를 위해 MetaMask를 홈 화면에 두는 것을 권장합니다."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "당신의 지갑을 안전한 방법으로 백업하는 것을 잊지 마세요. 절대로 비밀 구절을 공유하지 마세요."
        },
        "step3": {
          "title": "스캔 버튼을 누릅니다",
          "description": "스캔한 후에 지갑을 연결하라는 연결 프롬프트가 나타납니다."
        }
      },
      "extension": {
        "step1": {
          "title": "MetaMask 확장 프로그램을 설치하세요",
          "description": "지갑에 빠르게 접근하기 위해 MetaMask를 작업표시줄에 고정하는 것을 추천합니다."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 결코 비밀 문구를 다른 사람과 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저를 새로 고치세요",
          "description": "지갑 설정을 마친 후에는 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요."
        }
      }
    },
    "nestwallet": {
      "extension": {
        "step1": {
          "title": "NestWallet 확장 프로그램 설치",
          "description": "지갑에 더 빠르게 접근할 수 있도록 NestWallet을 작업 표시줄에 고정하는 것을 권장합니다."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 절대로 비밀 구문을 누구와도 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저를 새로 고침하세요",
          "description": "지갑 설정을 마친 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요."
        }
      }
    },
    "okx": {
      "qr_code": {
        "step1": {
          "title": "OKX Wallet 앱을 열기",
          "description": "더 빠른 접근을 위해 OKX 지갑을 홈 화면에 두는 것을 추천합니다."
        },
        "step2": {
          "title": "지갑 만들기 또는 불러오기",
          "description": "안전한 방법으로 지갑을 백업하세요. 절대 비밀 문구를 다른 사람과 공유하지 마세요."
        },
        "step3": {
          "title": "스캔 버튼을 탭하세요",
          "description": "스캔 후 연결 요청이 나타나며, 이를 통해 지갑을 연결할 수 있습니다."
        }
      },
      "extension": {
        "step1": {
          "title": "OKX 지갑 확장 프로그램 설치하기",
          "description": "지갑에 빠르게 접근할 수 있도록 OKX 지갑을 작업 표시줄에 고정하는 것을 추천합니다."
        },
        "step2": {
          "title": "지갑 만들기 또는 불러오기",
          "description": "당신의 지갑을 안전한 방법으로 백업해야 합니다. 비밀 문구를 절대로 다른 사람과 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저를 새로 고치세요",
          "description": "지갑을 설정한 후, 브라우저를 새로고침하고 확장 프로그램을 로드하기 위해 아래를 클릭하세요."
        }
      }
    },
    "omni": {
      "qr_code": {
        "step1": {
          "title": "Omni 앱을 열기",
          "description": "더 빠른 액세스를 위해 Omni를 홈 스크린에 추가하세요."
        },
        "step2": {
          "title": "지갑 만들기 또는 가져오기",
          "description": "새로운 지갑을 만들거나 기존의 하나를 가져옵니다."
        },
        "step3": {
          "title": "QR 아이콘을 탭하고 스캔하기",
          "description": "홈 화면의 QR 아이콘을 탭하고, 코드를 스캔하고 프롬프트를 확인하여 연결하세요."
        }
      }
    },
    "1inch": {
      "qr_code": {
        "step1": {
          "description": "지갑에 더 빠르게 접근하기 위해 홈 화면에 1inch 지갑을 추가하세요.",
          "title": "1inch 지갑 앱을 열어주세요"
        },
        "step2": {
          "description": "지갑과 사용자 이름을 생성하거나 기존의 지갑을 가져옵니다.",
          "title": "지갑 생성 또는 가져오기"
        },
        "step3": {
          "description": "스캔 후에 지갑을 연결하기 위한 연결 요청이 표시됩니다.",
          "title": "QR 코드 스캔 버튼을 누르기"
        }
      }
    },
    "token_pocket": {
      "qr_code": {
        "step1": {
          "title": "TokenPocket 앱을 열어주세요",
          "description": "빠른 접근을 위해 홈 화면에 TokenPocket을 추가하는 것을 권장합니다."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 절대로 누구에게도 비밀 문구를 공유하지 마세요."
        },
        "step3": {
          "title": "스캔 버튼을 탭하세요",
          "description": "스캔 후에 지갑을 연결하라는 프롬프트가 표시됩니다."
        }
      },
      "extension": {
        "step1": {
          "title": "TokenPocket 확장 프로그램을 설치하세요",
          "description": "지갑에 빠르게 접근하기 위해 TokenPocket를 작업 표시줄에 고정하는 것을 추천합니다."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 절대로 비밀 문구를 다른 사람과 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저 새로고침",
          "description": "지갑을 설정하면 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드합니다."
        }
      }
    },
    "trust": {
      "qr_code": {
        "step1": {
          "title": "Trust Wallet 앱을 열기",
          "description": "지갑에 빠르게 접근하기 위해 Trust Wallet을 홈 스크린에 두세요."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "새로운 지갑을 생성하거나 기존의 것을 가져오세요."
        },
        "step3": {
          "title": "설정에서 WalletConnect를 탭하세요",
          "description": "새 연결을 선택한 다음 QR 코드를 스캔하고, 연결을 확인하는 프롬프트를 확인하세요."
        }
      },
      "extension": {
        "step1": {
          "title": "Trust Wallet 확장 프로그램을 설치하세요",
          "description": "브라우저의 오른쪽 상단을 클릭하고 Trust Wallet을 고정하여 쉽게 접근하세요."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "새로운 지갑을 생성하거나 기존의 것을 가져오세요."
        },
        "step3": {
          "title": "브라우저를 새로고침하세요",
          "description": "Trust Wallet을 설정한 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드합니다."
        }
      }
    },
    "uniswap": {
      "qr_code": {
        "step1": {
          "title": "Uniswap 앱을 엽니다",
          "description": "Uniswap Wallet을 홈 화면에 추가하여 지갑에 더 빠르게 액세스하세요."
        },
        "step2": {
          "title": "지갑을 만들거나 가져오기",
          "description": "새 지갑을 생성하거나 기존의 것을 가져옵니다."
        },
        "step3": {
          "title": "QR 아이콘을 누르고 스캔하기",
          "description": "홈화면의 QR 아이콘을 누르고 코드를 스캔하고 프롬프트를 확인하여 연결하세요."
        }
      }
    },
    "zerion": {
      "qr_code": {
        "step1": {
          "title": "Zerion 앱을 엽니다",
          "description": "더 빠른 접근을 위해 Zerion을 홈 화면에 두는 것을 권장합니다."
        },
        "step2": {
          "title": "지갑 만들기 또는 가져오기",
          "description": "안전한 방법으로 지갑을 백업하세요. 절대로 비밀 구절을 누군가와 공유하지 마세요."
        },
        "step3": {
          "title": "스캔 버튼을 탭하세요",
          "description": "스캔 후 연결 프롬프트가 나타나 지갑을 연결하세요."
        }
      },
      "extension": {
        "step1": {
          "title": "Zerion 확장 프로그램을 설치하세요",
          "description": "지갑에 더 빠르게 접근할 수 있도록 Zerion을 작업 표시줄에 고정하는 것을 권장합니다."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 비밀 구문을 절대로 다른 사람과 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저를 새로 고치세요",
          "description": "지갑을 설정한 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요."
        }
      }
    },
    "rainbow": {
      "qr_code": {
        "step1": {
          "title": "Rainbow 앱 열기",
          "description": "지갑에 더 빠르게 접근하기 위해 홈 화면에 Rainbow를 두는 것을 추천합니다."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "휴대폰에 있는 백업 기능을 사용하여 지갑을 쉽게 백업할 수 있습니다."
        },
        "step3": {
          "title": "스캔 버튼을 누르세요",
          "description": "스캔 후, 지갑을 연결하라는 연결 프롬프트가 나타납니다."
        }
      }
    },
    "enkrypt": {
      "extension": {
        "step1": {
          "description": "지갑에 더 빠르게 접근하기 위해 작업 표시줄에 Enkrypt Wallet를 고정하는 것을 추천합니다.",
          "title": "Enkrypt Wallet 확장 프로그램을 설치하세요"
        },
        "step2": {
          "description": "지갑을 안전한 방법으로 백업하세요. 절대로 비밀 문구를 다른 사람과 공유하지 마세요.",
          "title": "지갑 생성 또는 가져오기"
        },
        "step3": {
          "description": "지갑을 설정한 후에는 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요.",
          "title": "브라우저 새로고침"
        }
      }
    },
    "frame": {
      "extension": {
        "step1": {
          "description": "지갑에 더 빠르게 접근할 수 있도록 Frame을 작업 표시줄에 고정하는 것을 추천합니다.",
          "title": "Frame 및 동반 확장 프로그램 설치"
        },
        "step2": {
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 절대로 비밀 구문을 다른 사람과 공유하지 마세요.",
          "title": "지갑 생성 또는 가져오기"
        },
        "step3": {
          "description": "지갑을 설정한 후에는 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요.",
          "title": "브라우저 새로고침"
        }
      }
    },
    "one_key": {
      "extension": {
        "step1": {
          "title": "OneKey Wallet 확장 프로그램을 설치하세요",
          "description": "지갑에 빠르게 접근할 수 있도록 OneKey Wallet을 작업 표시줄에 고정하는 것을 권장합니다."
        },
        "step2": {
          "title": "지갑 생성 또는 불러오기",
          "description": "지갑을 안전한 방법으로 백업하세요. 절대로 비밀 문구를 다른 사람과 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저를 새로고침 하세요",
          "description": "지갑을 설정한 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요."
        }
      }
    },
    "phantom": {
      "extension": {
        "step1": {
          "title": "Phantom 확장 프로그램을 설치하세요",
          "description": "지갑에 더 쉽게 접근할 수 있도록 Phantom을 작업 표시줄에 고정하는 것을 권장합니다."
        },
        "step2": {
          "title": "지갑 생성 또는 불러오기",
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 절대로 누구와도 비밀 복구 구문을 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저를 새로고침 하세요",
          "description": "지갑을 설정한 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요."
        }
      }
    },
    "rabby": {
      "extension": {
        "step1": {
          "title": "Rabby 확장 프로그램을 설치하세요",
          "description": "지갑에 더 빠르게 액세스할 수 있도록 Rabby를 작업표시줄에 고정하는 것을 권장합니다."
        },
        "step2": {
          "title": "지갑 만들기 또는 가져오기",
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 절대로 누구와도 비밀 구문을 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저를 새로고침 하세요",
          "description": "지갑 설정을 완료하면 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드합니다."
        }
      }
    },
    "ronin": {
      "qr_code": {
        "step1": {
          "description": "Ronin Wallet을 홈 화면에 두어 더 빠른 접근을 추천드립니다.",
          "title": "Ronin Wallet 앱을 열기"
        },
        "step2": {
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 절대로 비밀 구문을 누구와도 공유하지 마세요.",
          "title": "지갑 생성 또는 가져오기"
        },
        "step3": {
          "description": "스캔 후에 지갑을 연결하기 위한 연결 요청이 표시됩니다.",
          "title": "스캔 버튼을 누릅니다"
        }
      },
      "extension": {
        "step1": {
          "description": "작업 표시줄에 Ronin Wallet을 고정하여 지갑에 더 빠르게 접근할 수 있도록 추천합니다.",
          "title": "Ronin Wallet 확장 프로그램 설치하기"
        },
        "step2": {
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 절대로 비밀 구문을 누구와도 공유하지 마세요.",
          "title": "지갑 생성 또는 가져오기"
        },
        "step3": {
          "description": "지갑 설정을 마친 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요.",
          "title": "브라우저를 새로 고침하세요"
        }
      }
    },
    "ramper": {
      "extension": {
        "step1": {
          "title": "Ramper 확장 프로그램 설치하기",
          "description": "작업 표시줄에 Ramper를 고정하여 지갑 접근을 용이하게 할 것을 추천합니다."
        },
        "step2": {
          "title": "지갑 생성",
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 절대로 비밀 구문을 누구와도 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저를 새로 고침하세요",
          "description": "지갑 설정을 마친 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요."
        }
      }
    },
    "safeheron": {
      "extension": {
        "step1": {
          "title": "코어 확장 프로그램 설치",
          "description": "지갑에 빠르게 액세스하기 위해 Safeheron을 작업 표시줄에 고정하는 것을 권장합니다."
        },
        "step2": {
          "title": "지갑 만들기 또는 가져오기",
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 비밀 문구를 절대 다른 사람과 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저 새로고침",
          "description": "지갑 설정을 완료하면 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드합니다."
        }
      }
    },
    "taho": {
      "extension": {
        "step1": {
          "title": "Taho 확장 프로그램 설치",
          "description": "지갑에 더 빠르게 액세스하기 위해 Taho를 작업 표시줄에 고정하는 것을 추천합니다."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 결코 비밀 문구를 누군가와 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저를 새로고침 하세요",
          "description": "지갑을 설정한 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요."
        }
      }
    },
    "talisman": {
      "extension": {
        "step1": {
          "title": "탈리스만 확장 프로그램 설치",
          "description": "지갑에 더 빠르게 접근하기 위해 Talisman을 작업 표시줄에 고정하는 것을 추천합니다."
        },
        "step2": {
          "title": "이더리움 지갑 생성 또는 가져오기",
          "description": "반드시 안전한 방법을 사용하여 지갑을 백업하세요. 복구 문구를 누구와도 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저를 새로고침 하세요",
          "description": "지갑을 설정 한 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요."
        }
      }
    },
    "xdefi": {
      "extension": {
        "step1": {
          "title": "XDEFI 지갑 확장 프로그램을 설치하세요",
          "description": "지갑에 빠르게 액세스하기 위해 작업 표시줄에 XDEFI Wallet을 고정하는 것을 권장합니다."
        },
        "step2": {
          "title": "지갑을 만들거나 가져오기",
          "description": "반드시 안전한 방법을 사용하여 지갑을 백업하세요. 비밀 문구를 누구와도 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저를 새로고침 하세요",
          "description": "지갑을 설정한 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요."
        }
      }
    },
    "zeal": {
      "qr_code": {
        "step1": {
          "title": "Zeal 앱을 엽니다",
          "description": "월렛에 더 빠르게 액세스할 수 있도록 Zeal Wallet을 홈 화면에 두세요."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "새로운 지갑을 만들거나 기존의 지갑을 가져옵니다."
        },
        "step3": {
          "title": "QR 아이콘을 탭하고 스캔하기",
          "description": "홈화면의 QR 아이콘을 누르고 코드를 스캔하고 프롬프트를 확인하여 연결하세요."
        }
      },
      "extension": {
        "step1": {
          "title": "Zeal 확장 프로그램을 설치하세요",
          "description": "월렛에 더 빠르게 액세스할 수 있도록 Zeal을 작업 표시 줄에 고정하는 것을 권장합니다."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 절대로 비밀 구문을 누구와도 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저를 새로 고침하세요",
          "description": "지갑 설정을 마친 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요."
        }
      }
    },
    "safepal": {
      "extension": {
        "step1": {
          "title": "SafePal Wallet 확장 프로그램을 설치하세요",
          "description": "브라우저의 오른쪽 상단에서 클릭하고 SafePal Wallet을 고정하여 쉽게 접근하세요."
        },
        "step2": {
          "title": "지갑을 만들거나 가져옵니다",
          "description": "새로운 지갑을 만들거나 기존의 지갑을 가져옵니다."
        },
        "step3": {
          "title": "브라우저를 새로 고침하세요",
          "description": "SafePal Wallet을 설정한 후에는 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요."
        }
      },
      "qr_code": {
        "step1": {
          "title": "SafePal Wallet 앱을 여세요",
          "description": "월렛에 빠르게 액세스할 수 있도록 SafePal Wallet을 홈 화면에 두세요."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "새로운 지갑을 만들거나 기존의 지갑을 가져옵니다."
        },
        "step3": {
          "title": "설정에서 WalletConnect를 탭하세요",
          "description": "새 연결을 선택하고 QR 코드를 스캔한 뒤, 연결하려는 프롬프트를 확인합니다."
        }
      }
    },
    "desig": {
      "extension": {
        "step1": {
          "title": "Desig 확장 프로그램 설치",
          "description": "당신의 지갑에 더 쉽게 접근하기 위해 작업 표시줄에 Desig을 고정하는 것을 권장합니다."
        },
        "step2": {
          "title": "지갑 생성",
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 절대로 비밀 구문을 누구와도 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저를 새로 고침하세요",
          "description": "지갑 설정을 마친 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요."
        }
      }
    },
    "subwallet": {
      "extension": {
        "step1": {
          "title": "SubWallet 확장 프로그램 설치",
          "description": "당신의 지갑에 더 빠르게 접근하기 위해 작업 표시줄에 SubWallet을 고정하는 것을 권장합니다."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "반드시 안전한 방법을 사용하여 지갑을 백업하세요. 복구 문구를 누구와도 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저를 새로 고침하세요",
          "description": "지갑 설정을 마친 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요."
        }
      },
      "qr_code": {
        "step1": {
          "title": "SubWallet 앱 열기",
          "description": "더 빠른 접근을 위해 SubWallet을 홈 화면에 두는 것을 권장합니다."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 절대로 비밀 구문을 누구와도 공유하지 마세요."
        },
        "step3": {
          "title": "스캔 버튼을 누릅니다",
          "description": "스캔 후에 지갑을 연결하기 위한 연결 요청이 표시됩니다."
        }
      }
    },
    "clv": {
      "extension": {
        "step1": {
          "title": "CLV Wallet 확장 프로그램 설치",
          "description": "당신의 지갑에 더 빠르게 접근하기 위해 작업 표시줄에 CLV Wallet을 고정하는 것을 권장합니다."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 절대로 비밀 구문을 누구와도 공유하지 마세요."
        },
        "step3": {
          "title": "브라우저를 새로 고침하세요",
          "description": "지갑 설정을 마친 후 아래를 클릭하여 브라우저를 새로고침하고 확장 프로그램을 로드하세요."
        }
      },
      "qr_code": {
        "step1": {
          "title": "CLV Wallet 앱을 엽니다",
          "description": "더 빠른 접근을 위해 CLV Wallet을 홈 화면에 놓는 것이 좋습니다."
        },
        "step2": {
          "title": "지갑 생성 또는 가져오기",
          "description": "안전한 방법을 사용하여 지갑을 백업하세요. 절대로 비밀 구문을 누구와도 공유하지 마세요."
        },
        "step3": {
          "title": "스캔 버튼을 누릅니다",
          "description": "스캔 후에 지갑을 연결하기 위한 연결 요청이 표시됩니다."
        }
      }
    },
    "okto": {
      "qr_code": {
        "step1": {
          "title": "Okto 앱을 엽니다",
          "description": "빠른 접근을 위해 Okto를 홈 화면에 추가합니다"
        },
        "step2": {
          "title": "MPC Wallet을 만듭니다",
          "description": "계정을 만들고 지갑을 생성합니다"
        },
        "step3": {
          "title": "설정에서 WalletConnect를 탭하세요",
          "description": "오른쪽 상단의 QR 아이콘을 탭하고 연결하려면 알림을 확인합니다."
        }
      }
    },
    "ledger": {
      "desktop": {
        "step1": {
          "title": "Ledger Live 앱을 엽니다",
          "description": "빠른 접근을 위해 Ledger Live를 홈화면에 두는 것을 권장합니다."
        },
        "step2": {
          "title": "Ledger 설정",
          "description": "새 Ledger를 설정하거나 기존 Ledger에 연결하세요."
        },
        "step3": {
          "title": "연결",
          "description": "스캔 후 연결 요청이 나타나며, 이를 통해 지갑을 연결할 수 있습니다."
        }
      },
      "qr_code": {
        "step1": {
          "title": "Ledger Live 앱을 엽니다",
          "description": "빠른 접근을 위해 Ledger Live를 홈화면에 두는 것을 권장합니다."
        },
        "step2": {
          "title": "Ledger 설정",
          "description": "데스크톱 앱과 동기화하거나 Ledger를 연결할 수 있습니다."
        },
        "step3": {
          "title": "코드를 스캔하세요",
          "description": "WalletConnect를 탭하고 스캐너로 전환합니다. 스캔 후 연결 요청이 나타나며, 이를 통해 지갑을 연결할 수 있습니다."
        }
      }
    }
  }
}
`;export{u as default};
