var n=`{
  "connect_wallet": {
    "label": "Hubungkan Dompet",
    "wrong_network": {
      "label": "Jaringan yang salah"
    }
  },
  "intro": {
    "title": "Apa itu Dompet?",
    "description": "Sebuah dompet digunakan untuk mengirim, menerima, menyimpan, dan menampilkan aset digital. Ini juga cara baru untuk masuk, tanpa perlu membuat akun dan kata sandi baru di setiap situs web.",
    "digital_asset": {
      "title": "Sebuah Rumah untuk Aset Digital Anda",
      "description": "Dompet digunakan untuk mengirim, menerima, menyimpan, dan menampilkan aset digital seperti Ethereum dan NFTs."
    },
    "login": {
      "title": "Cara Baru untuk Masuk",
      "description": "Alih-alih membuat akun dan kata sandi baru di setiap situs web, cukup hubungkan dompet Anda."
    },
    "get": {
      "label": "Dapatkan Dompet"
    },
    "learn_more": {
      "label": "Pelajari lebih lanjut"
    }
  },
  "sign_in": {
    "label": "Verifikasi akun Anda",
    "description": "Untuk menyelesaikan koneksi, Anda harus menandatangani sebuah pesan di dompet Anda untuk memastikan bahwa Anda adalah pemilik dari akun ini.",
    "message": {
      "send": "Kirim pesan",
      "preparing": "Mempersiapkan pesan...",
      "cancel": "Batal",
      "preparing_error": "Kesalahan dalam mempersiapkan pesan, silakan coba lagi!"
    },
    "signature": {
      "waiting": "Menunggu tanda tangan...",
      "verifying": "Memverifikasi tanda tangan...",
      "signing_error": "Kesalahan dalam menandatangani pesan, silakan coba lagi!",
      "verifying_error": "Kesalahan dalam memverifikasi tanda tangan, silakan coba lagi!",
      "oops_error": "Ups, ada yang salah!"
    }
  },
  "connect": {
    "label": "Hubungkan",
    "title": "Hubungkan Dompet",
    "new_to_ethereum": {
      "description": "Baru dalam dompet Ethereum?",
      "learn_more": {
        "label": "Pelajari lebih lanjut"
      }
    },
    "learn_more": {
      "label": "Pelajari lebih lanjut"
    },
    "recent": "Terkini",
    "status": {
      "opening": "Membuka %{wallet}...",
      "connecting": "Menghubungkan",
      "connect_mobile": "Lanjutkan di %{wallet}",
      "not_installed": "%{wallet} tidak terpasang",
      "not_available": "%{wallet} tidak tersedia",
      "confirm": "Konfirmasikan koneksi di ekstensi",
      "confirm_mobile": "Terima permintaan koneksi di dompet"
    },
    "secondary_action": {
      "get": {
        "description": "Tidak memiliki %{wallet}?",
        "label": "DAPATKAN"
      },
      "install": {
        "label": "PASANG"
      },
      "retry": {
        "label": "COBA LAGI"
      }
    },
    "walletconnect": {
      "description": {
        "full": "Perlu modal resmi WalletConnect?",
        "compact": "Perlu modal WalletConnect?"
      },
      "open": {
        "label": "BUKA"
      }
    }
  },
  "connect_scan": {
    "title": "Pindai dengan %{wallet}",
    "fallback_title": "Pindai dengan ponsel Anda"
  },
  "connector_group": {
    "installed": "Terinstal",
    "recommended": "Direkomendasikan",
    "other": "Lainnya",
    "popular": "Populer",
    "more": "Lebih Banyak",
    "others": "Lainnya"
  },
  "get": {
    "title": "Dapatkan Dompet",
    "action": {
      "label": "DAPATKAN"
    },
    "mobile": {
      "description": "Dompet Mobile"
    },
    "extension": {
      "description": "Ekstensi Browser"
    },
    "mobile_and_extension": {
      "description": "Dompet Mobile dan Ekstensi"
    },
    "mobile_and_desktop": {
      "description": "Dompet Seluler dan Desktop"
    },
    "looking_for": {
      "title": "Bukan yang Anda cari?",
      "mobile": {
        "description": "Pilih dompet di layar utama untuk memulai dengan penyedia dompet yang berbeda."
      },
      "desktop": {
        "compact_description": "Pilih dompet di layar utama untuk memulai dengan penyedia dompet yang berbeda.",
        "wide_description": "Pilih dompet di sebelah kiri untuk memulai dengan penyedia dompet yang berbeda."
      }
    }
  },
  "get_options": {
    "title": "Mulai dengan %{wallet}",
    "short_title": "Dapatkan %{wallet}",
    "mobile": {
      "title": "%{wallet} untuk Mobile",
      "description": "Gunakan dompet mobile untuk menjelajahi dunia Ethereum.",
      "download": {
        "label": "Dapatkan aplikasinya"
      }
    },
    "extension": {
      "title": "%{wallet} untuk %{browser}",
      "description": "Akses dompet Anda langsung dari browser web favorit Anda.",
      "download": {
        "label": "Tambahkan ke %{browser}"
      }
    },
    "desktop": {
      "title": "%{wallet} untuk %{platform}",
      "description": "Akses dompet Anda secara native dari desktop yang kuat Anda.",
      "download": {
        "label": "Tambahkan ke %{platform}"
      }
    }
  },
  "get_mobile": {
    "title": "Instal %{wallet}",
    "description": "Pindai dengan ponsel Anda untuk mengunduh di iOS atau Android",
    "continue": {
      "label": "Lanjutkan"
    }
  },
  "get_instructions": {
    "mobile": {
      "connect": {
        "label": "Hubungkan"
      },
      "learn_more": {
        "label": "Pelajari lebih lanjut"
      }
    },
    "extension": {
      "refresh": {
        "label": "Segarkan"
      },
      "learn_more": {
        "label": "Pelajari lebih lanjut"
      }
    },
    "desktop": {
      "connect": {
        "label": "Hubungkan"
      },
      "learn_more": {
        "label": "Pelajari lebih lanjut"
      }
    }
  },
  "chains": {
    "title": "Alihkan Jaringan",
    "wrong_network": "Jaringan yang salah terdeteksi, alihkan atau diskonek untuk melanjutkan.",
    "confirm": "Konfirmasi di Dompet",
    "switching_not_supported": "Dompet Anda tidak mendukung pengalihan jaringan dari %{appName}. Coba alihkan jaringan dari dalam dompet Anda.",
    "switching_not_supported_fallback": "Wallet Anda tidak mendukung penggantian jaringan dari aplikasi ini. Cobalah ganti jaringan dari dalam wallet Anda.",
    "disconnect": "Putuskan koneksi",
    "connected": "Terkoneksi"
  },
  "profile": {
    "disconnect": {
      "label": "Putuskan koneksi"
    },
    "copy_address": {
      "label": "Salin Alamat",
      "copied": "Tersalin!"
    },
    "explorer": {
      "label": "Lihat lebih banyak di penjelajah"
    },
    "transactions": {
      "description": "%{appName} transaksi akan muncul di sini...",
      "description_fallback": "Transaksi Anda akan muncul di sini...",
      "recent": {
        "title": "Transaksi Terbaru"
      },
      "clear": {
        "label": "Hapus Semua"
      }
    }
  },
  "wallet_connectors": {
    "argent": {
      "qr_code": {
        "step1": {
          "description": "Letakkan Argent di layar utama Anda untuk akses lebih cepat ke dompet Anda.",
          "title": "Buka aplikasi Argent"
        },
        "step2": {
          "description": "Buat dompet dan nama pengguna, atau impor dompet yang ada.",
          "title": "Buat atau Impor Dompet"
        },
        "step3": {
          "description": "Setelah Anda memindai, akan muncul petunjuk koneksi untuk Anda menghubungkan dompet Anda.",
          "title": "Tekan tombol Scan QR"
        }
      }
    },
    "bifrost": {
      "qr_code": {
        "step1": {
          "description": "Kami merekomendasikan untuk menempatkan Bifrost Wallet di layar utama anda untuk akses yang lebih cepat.",
          "title": "Buka aplikasi Bifrost Wallet"
        },
        "step2": {
          "description": "Buat atau impor sebuah dompet menggunakan frasa pemulihan Anda.",
          "title": "Buat atau Impor sebuah Wallet"
        },
        "step3": {
          "description": "Setelah Anda memindai, sebuah pesan akan muncul untuk menghubungkan dompet Anda.",
          "title": "Tekan tombol scan"
        }
      }
    },
    "bitget": {
      "qr_code": {
        "step1": {
          "description": "Kami menyarankan untuk meletakkan Bitget Wallet di layar depan Anda untuk akses yang lebih cepat.",
          "title": "Buka aplikasi Bitget Wallet"
        },
        "step2": {
          "description": "Pastikan untuk mencadangkan wallet Anda menggunakan metode yang aman. Jangan pernah berbagi frasa rahasia Anda dengan siapa pun.",
          "title": "Buat atau Impor Wallet"
        },
        "step3": {
          "description": "Setelah Anda pindai, akan muncul petunjuk untuk menghubungkan wallet Anda.",
          "title": "Tekan tombol pindai"
        }
      },
      "extension": {
        "step1": {
          "description": "Kami menyarankan untuk memasang Bitget Wallet ke taskbar Anda untuk akses yang lebih cepat ke wallet Anda.",
          "title": "Instal ekstensi Dompet Bitget"
        },
        "step2": {
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah membagikan frasa rahasia Anda kepada siapa pun.",
          "title": "Buat atau Impor Dompet"
        },
        "step3": {
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi.",
          "title": "Segarkan browser Anda"
        }
      }
    },
    "bitski": {
      "extension": {
        "step1": {
          "description": "Kami merekomendasikan untuk memasang Bitski ke taskbar Anda untuk akses dompet Anda yang lebih cepat.",
          "title": "Pasang ekstensi Bitski"
        },
        "step2": {
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah berbagi frasa rahasia Anda dengan siapa pun.",
          "title": "Buat atau Impor Dompet"
        },
        "step3": {
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi.",
          "title": "Segarkan browser Anda"
        }
      }
    },
    "bitverse": {
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi Bitverse Wallet",
          "description": "Tambahkan Bitverse Wallet ke layar utama Anda untuk akses yang lebih cepat ke dompet Anda."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Buat dompet baru atau impor yang sudah ada."
        },
        "step3": {
          "title": "Ketuk ikon QR dan scan",
          "description": "Ketuk ikon QR di layar utama Anda, pindai kode dan konfirmasi prompt untuk terhubung."
        }
      }
    },
    "bloom": {
      "desktop": {
        "step1": {
          "title": "Buka aplikasi Bloom Wallet",
          "description": "Kami merekomendasikan untuk meletakkan Bloom Wallet di layar utama Anda untuk akses yang lebih cepat."
        },
        "step2": {
          "description": "Buat atau impor sebuah dompet menggunakan frasa pemulihan Anda.",
          "title": "Buat atau Impor Dompet"
        },
        "step3": {
          "description": "Setelah Anda memiliki dompet, klik pada Sambungkan untuk terhubung melalui Bloom. Sebuah permintaan sambungan akan muncul di aplikasi untuk Anda konfirmasi.",
          "title": "Klik pada Sambungkan"
        }
      },
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi Bloom Wallet",
          "description": "Kami merekomendasikan untuk meletakkan Bloom Wallet di layar utama Anda untuk akses yang lebih cepat."
        },
        "step2": {
          "description": "Buat atau impor sebuah dompet menggunakan frasa pemulihan Anda.",
          "title": "Buat atau Impor Dompet"
        },
        "step3": {
          "description": "Setelah Anda memiliki dompet, klik pada Sambungkan untuk terhubung melalui Bloom. Sebuah permintaan sambungan akan muncul di aplikasi untuk Anda konfirmasi.",
          "title": "Klik pada Sambungkan"
        }
      }
    },
    "bybit": {
      "qr_code": {
        "step1": {
          "description": "Kami menyarankan menempatkan Bybit di layar utama Anda untuk akses yang lebih cepat ke dompet Anda.",
          "title": "Buka aplikasi Bybit"
        },
        "step2": {
          "description": "Anda dapat dengan mudah mencadangkan wallet Anda menggunakan fitur cadangan kami di telepon Anda.",
          "title": "Buat atau Impor Dompet"
        },
        "step3": {
          "description": "Setelah Anda memindai, akan muncul petunjuk koneksi untuk Anda menghubungkan dompet Anda.",
          "title": "Tekan tombol scan"
        }
      },
      "extension": {
        "step1": {
          "description": "Klik di pojok kanan atas browser Anda dan sematkan Wallet Bybit untuk akses yang mudah.",
          "title": "Pasang ekstensi Wallet Bybit"
        },
        "step2": {
          "description": "Buat dompet baru atau impor yang sudah ada.",
          "title": "Buat atau Impor sebuah dompet"
        },
        "step3": {
          "description": "Setelah Anda mengatur Wallet Bybit, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi.",
          "title": "Segarkan browser Anda"
        }
      }
    },
    "binance": {
      "qr_code": {
        "step1": {
          "description": "Kami merekomendasikan untuk meletakkan Binance di layar utama Anda untuk akses lebih cepat ke wallet Anda.",
          "title": "Buka aplikasi Binance"
        },
        "step2": {
          "description": "Anda dapat dengan mudah mencadangkan wallet Anda menggunakan fitur cadangan kami di telepon Anda.",
          "title": "Buat atau Impor Dompet"
        },
        "step3": {
          "description": "Setelah Anda memindai, akan muncul petunjuk koneksi untuk Anda menghubungkan dompet Anda.",
          "title": "Ketuk tombol WalletConnect"
        }
      }
    },
    "coin98": {
      "qr_code": {
        "step1": {
          "description": "Kami merekomendasikan untuk menaruh Coin98 Wallet di layar utama Anda untuk akses wallet Anda lebih cepat.",
          "title": "Buka aplikasi Coin98 Wallet"
        },
        "step2": {
          "description": "Anda dapat dengan mudah mencadangkan wallet Anda menggunakan fitur cadangan kami di telepon Anda.",
          "title": "Buat atau Impor Wallet"
        },
        "step3": {
          "description": "Setelah Anda melakukan pemindaian, akan muncul prompt koneksi untuk Anda menghubungkan wallet Anda.",
          "title": "Ketuk tombol WalletConnect"
        }
      },
      "extension": {
        "step1": {
          "description": "Klik di pojok kanan atas browser Anda dan sematkan Coin98 Wallet untuk akses mudah.",
          "title": "Pasang ekstensi Coin98 Wallet"
        },
        "step2": {
          "description": "Buat dompet baru atau impor yang sudah ada.",
          "title": "Buat atau Impor sebuah dompet"
        },
        "step3": {
          "description": "Setelah Anda menyiapkan Coin98 Wallet, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi.",
          "title": "Segarkan browser Anda"
        }
      }
    },
    "coinbase": {
      "qr_code": {
        "step1": {
          "description": "Kami merekomendasikan memasang Coinbase Wallet di layar utama Anda untuk akses yang lebih cepat.",
          "title": "Buka aplikasi Coinbase Wallet"
        },
        "step2": {
          "description": "Anda dapat dengan mudah mencadangkan dompet Anda menggunakan fitur cadangan awan.",
          "title": "Buat atau Impor sebuah Dompet"
        },
        "step3": {
          "description": "Setelah Anda memindai, akan muncul sebuah petunjuk koneksi untuk Anda menyambungkan dompet Anda.",
          "title": "Ketuk tombol pindai"
        }
      },
      "extension": {
        "step1": {
          "description": "Kami merekomendasikan untuk menempel Coinbase Wallet ke taskbar Anda untuk akses lebih cepat ke dompet Anda.",
          "title": "Instal ekstensi Coinbase Wallet"
        },
        "step2": {
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah membagikan frase pemulihan rahasia Anda kepada siapa pun.",
          "title": "Buat atau Import Wallet"
        },
        "step3": {
          "description": "Setelah Anda menyiapkan wallet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi.",
          "title": "Segarkan browser Anda"
        }
      }
    },
    "compass": {
      "extension": {
        "step1": {
          "description": "Kami merekomendasikan untuk menempelkan Compass Wallet ke taskbar Anda untuk akses lebih cepat ke dompet Anda.",
          "title": "Instal ekstensi Compass Wallet"
        },
        "step2": {
          "description": "Pastikan untuk mencadangkan wallet Anda menggunakan metode yang aman. Jangan pernah berbagi frasa rahasia Anda dengan siapa pun.",
          "title": "Buat atau Impor Dompet"
        },
        "step3": {
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi.",
          "title": "Segarkan browser Anda"
        }
      }
    },
    "core": {
      "qr_code": {
        "step1": {
          "description": "Kami merekomendasikan untuk meletakkan Core di layar utama Anda untuk akses lebih cepat ke wallet Anda.",
          "title": "Buka aplikasi Core"
        },
        "step2": {
          "description": "Anda dapat dengan mudah mencadangkan wallet Anda dengan menggunakan fitur cadangan kami di telepon Anda.",
          "title": "Buat atau Import Wallet"
        },
        "step3": {
          "description": "Setelah Anda memindai, akan muncul petunjuk koneksi untuk Anda menyambungkan wallet Anda.",
          "title": "Ketuk tombol WalletConnect"
        }
      },
      "extension": {
        "step1": {
          "description": "Kami merekomendasikan untuk menempelkan Core pada taskbar Anda untuk akses ke dompet Anda lebih cepat.",
          "title": "Pasang ekstensi Core"
        },
        "step2": {
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah membagikan frase rahasia Anda kepada siapa pun.",
          "title": "Buat atau Impor Dompet"
        },
        "step3": {
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi.",
          "title": "Segarkan browser Anda"
        }
      }
    },
    "fox": {
      "qr_code": {
        "step1": {
          "description": "Kami merekomendasikan untuk menaruh FoxWallet pada layar utama Anda untuk akses lebih cepat.",
          "title": "Buka aplikasi FoxWallet"
        },
        "step2": {
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah membagikan frase rahasia Anda kepada siapa pun.",
          "title": "Buat atau Impor Wallet"
        },
        "step3": {
          "description": "Setelah Anda memindai, prompt koneksi akan muncul untuk Anda hubungkan dompet Anda.",
          "title": "Ketuk tombol pindai"
        }
      }
    },
    "frontier": {
      "qr_code": {
        "step1": {
          "description": "Kami merekomendasikan untuk meletakkan Frontier Wallet di layar awal Anda untuk akses yang lebih cepat.",
          "title": "Buka aplikasi Frontier Wallet"
        },
        "step2": {
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah membagikan frase rahasia Anda kepada siapa pun.",
          "title": "Buat atau Impor Wallet"
        },
        "step3": {
          "description": "Setelah Anda memindai, prompt koneksi akan muncul untuk Anda menghubungkan dompet Anda.",
          "title": "Ketuk tombol pindai"
        }
      },
      "extension": {
        "step1": {
          "description": "Kami menyarankan menempelkan Frontier Wallet ke taskbar Anda untuk akses yang lebih cepat ke dompet Anda.",
          "title": "Instal ekstensi Frontier Wallet"
        },
        "step2": {
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah berbagi frasa rahasia Anda dengan siapa pun.",
          "title": "Buat atau Impor Dompet"
        },
        "step3": {
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi.",
          "title": "Segarkan browser Anda"
        }
      }
    },
    "im_token": {
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi imToken",
          "description": "Letakkan aplikasi imToken di layar utama Anda untuk akses yang lebih cepat ke dompet Anda."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Buat dompet baru atau impor yang sudah ada."
        },
        "step3": {
          "title": "Ketuk Ikon Scanner di pojok kanan atas",
          "description": "Pilih Koneksi Baru, lalu pindai kode QR dan konfirmasi petunjuk untuk terhubung."
        }
      }
    },
    "kaikas": {
      "extension": {
        "step1": {
          "description": "Kami menyarankan memasang Kaikas di taskbar Anda untuk akses yang lebih cepat ke dompet Anda.",
          "title": "Pasang ekstensi Kaikas"
        },
        "step2": {
          "description": "Pastikan untuk mencadangkan wallet Anda menggunakan metode yang aman. Jangan pernah berbagi frasa rahasia Anda dengan siapa pun.",
          "title": "Buat atau Impor Dompet"
        },
        "step3": {
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi.",
          "title": "Segarkan browser Anda"
        }
      },
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi Kaikas",
          "description": "Letakkan aplikasi Kaikas di layar utama Anda untuk akses yang lebih cepat ke dompet Anda."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Buat dompet baru atau impor yang sudah ada."
        },
        "step3": {
          "title": "Ketuk Ikon Scanner di pojok kanan atas",
          "description": "Pilih Koneksi Baru, lalu pindai kode QR dan konfirmasi petunjuk untuk terhubung."
        }
      }
    },
    "kraken": {
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi Kraken Wallet",
          "description": "Tambahkan Kraken Wallet ke layar utama Anda untuk akses lebih cepat ke dompet Anda."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Buat dompet baru atau impor yang sudah ada."
        },
        "step3": {
          "title": "Ketuk ikon QR dan scan",
          "description": "Ketuk ikon QR di layar utama Anda, pindai kode dan konfirmasi prompt untuk terhubung."
        }
      }
    },
    "kresus": {
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi Kresus Wallet",
          "description": "Tambahkan Kresus Wallet ke layar utama Anda untuk akses yang lebih cepat ke wallet Anda."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Buat dompet baru atau impor yang sudah ada."
        },
        "step3": {
          "title": "Ketuk ikon QR dan scan",
          "description": "Ketuk ikon QR di layar utama Anda, pindai kode dan konfirmasi prompt untuk terhubung."
        }
      }
    },
    "magicEden": {
      "extension": {
        "step1": {
          "title": "Instal ekstensi Magic Eden",
          "description": "Kami menyarankan untuk menempelkan Magic Eden ke taskbar Anda untuk akses lebih cepat ke dompet Anda."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah membagikan frase pemulihan rahasia Anda kepada siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi."
        }
      }
    },
    "metamask": {
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi MetaMask",
          "description": "Kami merekomendasikan untuk meletakkan MetaMask di layar beranda Anda untuk akses yang lebih cepat."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah membagikan frase rahasia Anda kepada siapa pun."
        },
        "step3": {
          "title": "Ketuk tombol pindai",
          "description": "Setelah Anda memindai, petunjuk koneksi akan muncul untuk Anda menyambungkan dompet Anda."
        }
      },
      "extension": {
        "step1": {
          "title": "Pasang ekstensi MetaMask",
          "description": "Kami menyarankan untuk memasang MetaMask pada taskbar Anda untuk akses wallet lebih cepat."
        },
        "step2": {
          "title": "Buat atau Impor Wallet",
          "description": "Pastikan untuk mencadangkan wallet Anda menggunakan metode yang aman. Jangan pernah membagikan frase rahasia Anda kepada siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda menyiapkan wallet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi."
        }
      }
    },
    "nestwallet": {
      "extension": {
        "step1": {
          "title": "Instal ekstensi NestWallet",
          "description": "Kami menyarankan untuk memasang NestWallet ke taskbar Anda untuk akses dompet yang lebih cepat."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Pastikan untuk mencadangkan wallet Anda menggunakan metode yang aman. Jangan pernah berbagi frasa rahasia Anda dengan siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi."
        }
      }
    },
    "okx": {
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi OKX Wallet",
          "description": "Kami menyarankan untuk menaruh OKX Wallet di layar utama Anda untuk akses lebih cepat."
        },
        "step2": {
          "title": "Buat atau Impor Wallet",
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah membagikan frasa rahasia Anda kepada siapa pun."
        },
        "step3": {
          "title": "Ketuk tombol scan",
          "description": "Setelah Anda memindai, prompt koneksi akan muncul untuk Anda hubungkan dompet Anda."
        }
      },
      "extension": {
        "step1": {
          "title": "Instal ekstensi OKX Wallet",
          "description": "Kami menyarankan untuk menempelkan OKX Wallet ke taskbar Anda untuk akses lebih cepat ke dompet Anda."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah membagikan frasa rahasia Anda kepada siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda mengatur wallet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi."
        }
      }
    },
    "omni": {
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi Omni",
          "description": "Tambahkan Omni ke layar utama Anda untuk akses yang lebih cepat ke wallet Anda."
        },
        "step2": {
          "title": "Buat atau Impor Wallet",
          "description": "Buat wallet baru atau impor yang sudah ada."
        },
        "step3": {
          "title": "Ketuk ikon QR dan scan",
          "description": "Ketuk ikon QR di layar utama Anda, pindai kode dan konfirmasi petunjuk untuk terhubung."
        }
      }
    },
    "1inch": {
      "qr_code": {
        "step1": {
          "description": "Letakkan Wallet 1inch di layar utama Anda untuk akses yang lebih cepat ke dompet Anda.",
          "title": "Buka aplikasi Wallet 1inch"
        },
        "step2": {
          "description": "Buat dompet dan nama pengguna, atau impor dompet yang ada.",
          "title": "Buat atau Impor Dompet"
        },
        "step3": {
          "description": "Setelah Anda memindai, akan muncul petunjuk koneksi untuk Anda menghubungkan dompet Anda.",
          "title": "Tekan tombol Scan QR"
        }
      }
    },
    "token_pocket": {
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi TokenPocket",
          "description": "Kami sarankan meletakkan TokenPocket di layar utama Anda untuk akses yang lebih cepat."
        },
        "step2": {
          "title": "Buat atau impor Dompet",
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah membagikan frase pemulihan rahasia Anda kepada siapa pun."
        },
        "step3": {
          "title": "Ketuk tombol pindai",
          "description": "Setelah Anda memindai, Indikasi sambungan akan muncul untuk Anda menghubungkan dompet Anda."
        }
      },
      "extension": {
        "step1": {
          "title": "Instal ekstensi TokenPocket",
          "description": "Kami merekomendasikan penambatan TokenPocket ke taskbar Anda untuk akses dompet Anda lebih cepat."
        },
        "step2": {
          "title": "Buat atau Impor Wallet",
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah membagi frasa rahasia Anda dengan siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda mengatur dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi."
        }
      }
    },
    "trust": {
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi Trust Wallet",
          "description": "Pasang Trust Wallet di layar utama Anda untuk akses dompet Anda lebih cepat."
        },
        "step2": {
          "title": "Buat atau Impor Wallet",
          "description": "Buat dompet baru atau impor yang sudah ada."
        },
        "step3": {
          "title": "Ketuk WalletConnect di Pengaturan",
          "description": "Pilih Koneksi Baru, kemudian pindai kode QR dan konfirmasi perintah untuk terhubung."
        }
      },
      "extension": {
        "step1": {
          "title": "Instal ekstensi Trust Wallet",
          "description": "Klik di pojok kanan atas browser Anda dan sematkan Trust Wallet untuk akses mudah."
        },
        "step2": {
          "title": "Buat atau Impor dompet",
          "description": "Buat dompet baru atau impor yang sudah ada."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda mengatur Trust Wallet, klik di bawah untuk menyegarkan browser dan memuat ekstensi."
        }
      }
    },
    "uniswap": {
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi Uniswap",
          "description": "Tambahkan Uniswap Wallet ke layar utama Anda untuk akses ke wallet Anda lebih cepat."
        },
        "step2": {
          "title": "Buat atau Impor Wallet",
          "description": "Buat wallet baru atau impor yang sudah ada."
        },
        "step3": {
          "title": "Ketuk ikon QR dan pindai",
          "description": "Ketuk ikon QR di layar utama Anda, pindai kode dan konfirmasi prompt untuk terhubung."
        }
      }
    },
    "zerion": {
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi Zerion",
          "description": "Kami merekomendasikan untuk meletakkan Zerion di layar utama Anda untuk akses lebih cepat."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah membagikan frase pemulihan rahasia Anda kepada siapa pun."
        },
        "step3": {
          "title": "Ketuk tombol scan",
          "description": "Setelah Anda scan, muncul prompt koneksi untuk Anda menghubungkan dompet Anda."
        }
      },
      "extension": {
        "step1": {
          "title": "Instal ekstensi Zerion",
          "description": "Kami menyarankan untuk menempelkan Zerion ke taskbar Anda untuk akses lebih cepat ke dompet Anda."
        },
        "step2": {
          "title": "Buat atau Impor Wallet",
          "description": "Pastikan untuk mencadangkan wallet Anda menggunakan metode yang aman. Jangan pernah berbagi frasa rahasia Anda dengan siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda mengatur wallet Anda, klik di bawah untuk menyegarkan browser dan memuat ekstensi."
        }
      }
    },
    "rainbow": {
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi Rainbow",
          "description": "Kami menyarankan menempatkan Rainbow di layar home Anda untuk akses yang lebih cepat ke wallet Anda."
        },
        "step2": {
          "title": "Buat atau Impor Wallet",
          "description": "Anda dapat dengan mudah mencadangkan wallet Anda menggunakan fitur cadangan kami di telepon Anda."
        },
        "step3": {
          "title": "Tekan tombol scan",
          "description": "Setelah Anda memindai, akan muncul pesan untuk menghubungkan dompet Anda."
        }
      }
    },
    "enkrypt": {
      "extension": {
        "step1": {
          "description": "Kami menyarankan untuk memasang Enkrypt Wallet ke taskbar Anda untuk akses dompet yang lebih cepat.",
          "title": "Instal ekstensi Enkrypt Wallet"
        },
        "step2": {
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah berbagi frase rahasia Anda dengan siapa pun.",
          "title": "Buat atau Impor Dompet"
        },
        "step3": {
          "description": "Setelah Anda menyiapkan dompet, klik di bawah ini untuk memuat ulang peramban dan meload ekstensi.",
          "title": "Segarkan browser Anda"
        }
      }
    },
    "frame": {
      "extension": {
        "step1": {
          "description": "Kami menyarankan untuk memasang Frame ke taskbar Anda untuk akses dompet yang lebih cepat.",
          "title": "Instal Frame & ekstensi pendamping"
        },
        "step2": {
          "description": "Pastikan untuk mencadangkan wallet Anda menggunakan metode yang aman. Jangan pernah membagikan frase rahasia Anda kepada siapa pun.",
          "title": "Buat atau Impor Wallet"
        },
        "step3": {
          "description": "Setelah Anda menyetel wallet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi.",
          "title": "Segarkan browser Anda"
        }
      }
    },
    "one_key": {
      "extension": {
        "step1": {
          "title": "Instal ekstensi OneKey Wallet",
          "description": "Kami menyarankan untuk menempelkan OneKey Wallet ke taskbar Anda untuk akses wallet yang lebih cepat."
        },
        "step2": {
          "title": "Buat atau Impor Wallet",
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah membagikan frase rahasia Anda kepada siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi."
        }
      }
    },
    "phantom": {
      "extension": {
        "step1": {
          "title": "Instal ekstensi Phantom",
          "description": "Kami menyarankan untuk mem-pin Phantom ke taskbar Anda untuk akses dompet yang lebih mudah."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah membagikan frase pemulihan rahasia Anda kepada siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi."
        }
      }
    },
    "rabby": {
      "extension": {
        "step1": {
          "title": "Instal ekstensi Rabby",
          "description": "Kami merekomendasikan menempelkan Rabby ke taskbar Anda untuk akses lebih cepat ke wallet Anda."
        },
        "step2": {
          "title": "Buat atau Impor Wallet",
          "description": "Pastikan untuk mencadangkan wallet Anda dengan metode yang aman. Jangan pernah berbagi frase rahasia Anda dengan siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda menyiapkan wallet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi."
        }
      }
    },
    "ronin": {
      "qr_code": {
        "step1": {
          "description": "Kami merekomendasikan untuk meletakkan Ronin Wallet di layar utama Anda untuk akses yang lebih cepat.",
          "title": "Buka aplikasi Ronin Wallet"
        },
        "step2": {
          "description": "Pastikan untuk mencadangkan wallet Anda menggunakan metode yang aman. Jangan pernah berbagi frasa rahasia Anda dengan siapa pun.",
          "title": "Buat atau Impor Dompet"
        },
        "step3": {
          "description": "Setelah Anda memindai, akan muncul petunjuk koneksi untuk Anda menghubungkan dompet Anda.",
          "title": "Tekan tombol scan"
        }
      },
      "extension": {
        "step1": {
          "description": "Kami merekomendasikan untuk memasang Ronin Wallet di taskbar Anda untuk akses yang lebih cepat ke wallet Anda.",
          "title": "Pasang ekstensi Ronin Wallet"
        },
        "step2": {
          "description": "Pastikan untuk mencadangkan wallet Anda menggunakan metode yang aman. Jangan pernah berbagi frasa rahasia Anda dengan siapa pun.",
          "title": "Buat atau Impor Dompet"
        },
        "step3": {
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi.",
          "title": "Segarkan browser Anda"
        }
      }
    },
    "ramper": {
      "extension": {
        "step1": {
          "title": "Pasang ekstensi Ramper",
          "description": "Kami merekomendasikan untuk memasang Ramper di taskbar Anda untuk akses yang lebih mudah ke wallet Anda."
        },
        "step2": {
          "title": "Buat Dompet",
          "description": "Pastikan untuk mencadangkan wallet Anda menggunakan metode yang aman. Jangan pernah berbagi frasa rahasia Anda dengan siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi."
        }
      }
    },
    "safeheron": {
      "extension": {
        "step1": {
          "title": "Instal ekstensi Core",
          "description": "Kami merekomendasikan menempelkan Safeheron ke taskbar Anda untuk akses lebih cepat ke wallet Anda."
        },
        "step2": {
          "title": "Buat atau Impor Wallet",
          "description": "Pastikan untuk mencadangkan dompet Anda dengan metode yang aman. Jangan pernah berbagi frasa rahasia Anda dengan siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda mengatur dompet Anda, klik di bawah untuk menyegarkan browser dan memuat ekstensi."
        }
      }
    },
    "taho": {
      "extension": {
        "step1": {
          "title": "Instal ekstensi Taho",
          "description": "Kami merekomendasikan pengepinan Taho ke taskbar Anda untuk akses yang lebih cepat ke dompet Anda."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Pastikan untuk mencadangkan dompet Anda dengan metode yang aman. Jangan pernah berbagi frasa rahasia Anda dengan siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi."
        }
      }
    },
    "talisman": {
      "extension": {
        "step1": {
          "title": "Instal ekstensi Talisman",
          "description": "Kami merekomendasikan menempelkan Talisman ke taskbar Anda untuk akses dompet Anda lebih cepat."
        },
        "step2": {
          "title": "Buat atau Impor Dompet Ethereum",
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah berbagi frase pemulihan Anda dengan siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi."
        }
      }
    },
    "xdefi": {
      "extension": {
        "step1": {
          "title": "Instal ekstensi Dompet XDEFI",
          "description": "Kami merekomendasikan menempelkan XDEFI Wallet ke taskbar Anda untuk akses lebih cepat ke dompet Anda."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Pastikan untuk mencadangkan dompet Anda dengan metode yang aman. Jangan pernah berbagi frase rahasia Anda dengan siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi."
        }
      }
    },
    "zeal": {
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi Zeal",
          "description": "Tambahkan Zeal Wallet ke layar utama Anda untuk akses yang lebih cepat ke wallet Anda."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Buat dompet baru atau impor yang sudah ada."
        },
        "step3": {
          "title": "Ketuk ikon QR dan scan",
          "description": "Ketuk ikon QR di layar utama Anda, pindai kode dan konfirmasi prompt untuk terhubung."
        }
      },
      "extension": {
        "step1": {
          "title": "Instal ekstensi Zeal",
          "description": "Kami merekomendasikan untuk mem-pin Zeal ke taskbar Anda untuk akses wallet lebih cepat."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Pastikan untuk mencadangkan wallet Anda menggunakan metode yang aman. Jangan pernah berbagi frasa rahasia Anda dengan siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi."
        }
      }
    },
    "safepal": {
      "extension": {
        "step1": {
          "title": "Pasang ekstensi SafePal Wallet",
          "description": "Klik di pojok kanan atas browser Anda dan pin SafePal Wallet untuk akses mudah."
        },
        "step2": {
          "title": "Buat atau Impor sebuah dompet",
          "description": "Buat dompet baru atau impor yang sudah ada."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda menyiapkan SafePal Wallet, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi."
        }
      },
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi SafePal Wallet",
          "description": "Letakkan SafePal Wallet di layar utama Anda untuk akses yang lebih cepat ke wallet Anda."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Buat dompet baru atau impor yang sudah ada."
        },
        "step3": {
          "title": "Ketuk WalletConnect di Pengaturan",
          "description": "Pilih Koneksi Baru, lalu pindai kode QR dan konfirmasi petunjuk untuk terhubung."
        }
      }
    },
    "desig": {
      "extension": {
        "step1": {
          "title": "Instal ekstensi Desig",
          "description": "Kami merekomendasikan menempelkan Desig ke taskbar Anda untuk akses dompet Anda lebih mudah."
        },
        "step2": {
          "title": "Buat Dompet",
          "description": "Pastikan untuk mencadangkan wallet Anda menggunakan metode yang aman. Jangan pernah berbagi frasa rahasia Anda dengan siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi."
        }
      }
    },
    "subwallet": {
      "extension": {
        "step1": {
          "title": "Instal ekstensi SubWallet",
          "description": "Kami merekomendasikan menempelkan SubWallet ke taskbar Anda untuk akses dompet Anda lebih cepat."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Pastikan untuk mencadangkan dompet Anda menggunakan metode yang aman. Jangan pernah berbagi frase pemulihan Anda dengan siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi."
        }
      },
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi SubWallet",
          "description": "Kami merekomendasikan menaruh SubWallet di layar utama Anda untuk akses lebih cepat."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Pastikan untuk mencadangkan wallet Anda menggunakan metode yang aman. Jangan pernah berbagi frasa rahasia Anda dengan siapa pun."
        },
        "step3": {
          "title": "Tekan tombol scan",
          "description": "Setelah Anda memindai, akan muncul petunjuk koneksi untuk Anda menghubungkan dompet Anda."
        }
      }
    },
    "clv": {
      "extension": {
        "step1": {
          "title": "Instal ekstensi CLV Wallet",
          "description": "Kami merekomendasikan menempelkan CLV Wallet ke taskbar Anda untuk akses dompet Anda lebih cepat."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Pastikan untuk mencadangkan wallet Anda menggunakan metode yang aman. Jangan pernah berbagi frasa rahasia Anda dengan siapa pun."
        },
        "step3": {
          "title": "Segarkan browser Anda",
          "description": "Setelah Anda menyiapkan dompet Anda, klik di bawah ini untuk menyegarkan browser dan memuat ekstensi."
        }
      },
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi CLV Wallet",
          "description": "Kami sarankan untuk menempatkan CLV Wallet di layar utama Anda untuk akses yang lebih cepat."
        },
        "step2": {
          "title": "Buat atau Impor Dompet",
          "description": "Pastikan untuk mencadangkan wallet Anda menggunakan metode yang aman. Jangan pernah berbagi frasa rahasia Anda dengan siapa pun."
        },
        "step3": {
          "title": "Tekan tombol scan",
          "description": "Setelah Anda memindai, akan muncul petunjuk koneksi untuk Anda menghubungkan dompet Anda."
        }
      }
    },
    "okto": {
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi Okto",
          "description": "Tambahkan Okto ke layar utama Anda untuk akses cepat"
        },
        "step2": {
          "title": "Buat Wallet MPC",
          "description": "Buat akun dan generate wallet"
        },
        "step3": {
          "title": "Ketuk WalletConnect di Pengaturan",
          "description": "Ketuk ikon Scan QR di pojok kanan atas dan konfirmasi prompt untuk terhubung."
        }
      }
    },
    "ledger": {
      "desktop": {
        "step1": {
          "title": "Buka aplikasi Ledger Live",
          "description": "Kami merekomendasikan menempatkan Ledger Live di layar utama Anda untuk akses lebih cepat."
        },
        "step2": {
          "title": "Atur Ledger Anda",
          "description": "Atur Ledger baru atau hubungkan ke Ledger yang sudah ada."
        },
        "step3": {
          "title": "Hubungkan",
          "description": "Setelah Anda scan, muncul prompt koneksi untuk Anda menghubungkan dompet Anda."
        }
      },
      "qr_code": {
        "step1": {
          "title": "Buka aplikasi Ledger Live",
          "description": "Kami merekomendasikan menempatkan Ledger Live di layar utama Anda untuk akses lebih cepat."
        },
        "step2": {
          "title": "Atur Ledger Anda",
          "description": "Anda dapat melakukan sinkronisasi dengan aplikasi desktop atau menghubungkan Ledger Anda."
        },
        "step3": {
          "title": "Pindai kode",
          "description": "Ketuk WalletConnect lalu Beralih ke Scanner. Setelah Anda scan, muncul prompt koneksi untuk Anda menghubungkan dompet Anda."
        }
      }
    }
  }
}
`;export{n as default};
