var u=`{
  "connect_wallet": {
    "label": "ウォレットを接続",
    "wrong_network": {
      "label": "ネットワークが間違っています"
    }
  },
  "intro": {
    "title": "ウォレットとは何ですか？",
    "description": "ウォレットは、デジタルアセットを送信、受信、保存、表示するために使用されます。また、各ウェブサイトで新たなアカウントやパスワードを作成する必要なく、ログインする新しい方法でもあります。",
    "digital_asset": {
      "title": "あなたのデジタル資産のための家",
      "description": "ウォレットは、EthereumやNFTのようなデジタル資産を送信、受信、保存、表示するために使用されます。"
    },
    "login": {
      "title": "新しいログイン方法",
      "description": "すべてのウェブサイトで新しいアカウントとパスワードを作成する代わりに、ウォレットを接続します。"
    },
    "get": {
      "label": "ウォレットを取得する"
    },
    "learn_more": {
      "label": "詳しくはこちら"
    }
  },
  "sign_in": {
    "label": "アカウントを確認する",
    "description": "接続を完了するには、このアカウントの所有者であることを証明するためにウォレットでメッセージに署名する必要があります。",
    "message": {
      "send": "メッセージを送信",
      "preparing": "メッセージの準備中...",
      "cancel": "キャンセル",
      "preparing_error": "メッセージの準備中にエラーが発生しました、再試行してください！"
    },
    "signature": {
      "waiting": "署名を待っています...",
      "verifying": "署名を検証中...",
      "signing_error": "メッセージの署名中にエラーが発生しました、再試行してください！",
      "verifying_error": "署名の検証中にエラーが発生しました、再試行してください！",
      "oops_error": "おっと、何かが間違っていました！"
    }
  },
  "connect": {
    "label": "接続",
    "title": "ウォレットを接続する",
    "new_to_ethereum": {
      "description": "Ethereumのウォレットが初めてですか？",
      "learn_more": {
        "label": "詳しくはこちら"
      }
    },
    "learn_more": {
      "label": "詳しくはこちら"
    },
    "recent": "最近利用しました",
    "status": {
      "opening": "%{wallet}を開いています...",
      "connecting": "接続中",
      "connect_mobile": "%{wallet}で続行",
      "not_installed": "%{wallet} はインストールされていません",
      "not_available": "%{wallet} は利用できません",
      "confirm": "エクステンションで接続を確認してください",
      "confirm_mobile": "ウォレットでの接続リクエストを承認する"
    },
    "secondary_action": {
      "get": {
        "description": "%{wallet}がありませんか？",
        "label": "取得"
      },
      "install": {
        "label": "インストール"
      },
      "retry": {
        "label": "再試行"
      }
    },
    "walletconnect": {
      "description": {
        "full": "公式のWalletConnectモーダルが必要ですか？",
        "compact": "WalletConnectモーダルが必要ですか？"
      },
      "open": {
        "label": "開く"
      }
    }
  },
  "connect_scan": {
    "title": "%{wallet}でスキャン",
    "fallback_title": "携帯電話でスキャンしてください"
  },
  "connector_group": {
    "installed": "インストール済み",
    "recommended": "おすすめのウォレット",
    "other": "その他",
    "popular": "人気のウォレット",
    "more": "もっと",
    "others": "その他"
  },
  "get": {
    "title": "ウォレットを取得",
    "action": {
      "label": "取得"
    },
    "mobile": {
      "description": "モバイルウォレット"
    },
    "extension": {
      "description": "ブラウザ拡張"
    },
    "mobile_and_extension": {
      "description": "モバイルウォレットと拡張機能"
    },
    "mobile_and_desktop": {
      "description": "モバイルとデスクトップウォレット"
    },
    "looking_for": {
      "title": "お探しのウォレットがありませんか？",
      "mobile": {
        "description": "メイン画面でウォレットを選択し、異なるウォレットプロバイダーで始めてください。"
      },
      "desktop": {
        "compact_description": "メイン画面でウォレットを選択し、異なるウォレットプロバイダーで始めてください。",
        "wide_description": "左側のウォレットを選択して、別のウォレットプロバイダーで始めてください。"
      }
    }
  },
  "get_options": {
    "title": "%{wallet}で始める",
    "short_title": "%{wallet}を取得する",
    "mobile": {
      "title": "モバイル用 %{wallet}",
      "description": "モバイルウォレットを使用して、イーサリアムの世界を探索します。",
      "download": {
        "label": "アプリを取得"
      }
    },
    "extension": {
      "title": "%{wallet} for %{browser}",
      "description": "お好きなウェブブラウザからウォレットに直接アクセスします。",
      "download": {
        "label": "%{browser}に追加"
      }
    },
    "desktop": {
      "title": "%{wallet} for %{platform}",
      "description": "あなたの強力なデスクトップからネイティブにウォレットにアクセスします。",
      "download": {
        "label": "%{platform}に追加する"
      }
    }
  },
  "get_mobile": {
    "title": "%{wallet}をインストール",
    "description": "iOSまたはAndroidでダウンロードするために電話でスキャン",
    "continue": {
      "label": "続行"
    }
  },
  "get_instructions": {
    "mobile": {
      "connect": {
        "label": "接続"
      },
      "learn_more": {
        "label": "詳しくはこちら"
      }
    },
    "extension": {
      "refresh": {
        "label": "更新"
      },
      "learn_more": {
        "label": "詳しくはこちら"
      }
    },
    "desktop": {
      "connect": {
        "label": "接続"
      },
      "learn_more": {
        "label": "詳しくはこちら"
      }
    }
  },
  "chains": {
    "title": "ネットワークを切り替える",
    "wrong_network": "誤ったネットワークが検出されました、続行するには切り替えるか切断してください。",
    "confirm": "ウォレットで確認する",
    "switching_not_supported": "あなたのウォレットは %{appName}からネットワークを切り替えることをサポートしていません。ウォレット内でネットワークを切り替えてみてください。",
    "switching_not_supported_fallback": "あなたのウォレットは、このアプリからネットワークを切り替えることをサポートしていません。代わりにウォレット内からネットワークを切り替えてみてください。",
    "disconnect": "切断する",
    "connected": "接続しました"
  },
  "profile": {
    "disconnect": {
      "label": "切断する"
    },
    "copy_address": {
      "label": "アドレスをコピーする",
      "copied": "コピーしました！"
    },
    "explorer": {
      "label": "エクスプローラーで詳しく見る"
    },
    "transactions": {
      "description": "%{appName} トランザクションがここに表示されます...",
      "description_fallback": "あなたのトランザクションはここに表示されます...",
      "recent": {
        "title": "最近のトランザクション"
      },
      "clear": {
        "label": "すべてクリア"
      }
    }
  },
  "wallet_connectors": {
    "argent": {
      "qr_code": {
        "step1": {
          "description": "より速くウォレットにアクセスするために、Argentをホーム画面に置いてください。",
          "title": "Argentアプリを開く"
        },
        "step2": {
          "description": "ウォレットとユーザーネームを作成するか、既存のウォレットをインポートします。",
          "title": "ウォレットを作成またはインポート"
        },
        "step3": {
          "description": "スキャン後、ウォレットを接続するための接続プロンプトが表示されます。",
          "title": "「QRをスキャン」ボタンをタップします"
        }
      }
    },
    "bifrost": {
      "qr_code": {
        "step1": {
          "description": "より速くアクセスできるように、Bifrost Walletをホーム画面に置くことをお勧めします。",
          "title": "Bifrost Walletアプリを開きます"
        },
        "step2": {
          "description": "リカバリーフレーズを使用してウォレットを作成またはインポートします。",
          "title": "ウォレットを作成またはインポート"
        },
        "step3": {
          "description": "スキャン後、ウォレットを接続するための接続プロンプトが表示されます。",
          "title": "「スキャン」ボタンをタップします"
        }
      }
    },
    "bitget": {
      "qr_code": {
        "step1": {
          "description": "より迅速なアクセスのために、ホーム画面にBitget Walletを配置することをお勧めします。",
          "title": "Bitget Walletアプリを開く"
        },
        "step2": {
          "description": "ウォレットは安全な方法でバックアップしてください。秘密のフレーズを誰とも共有しないでください。",
          "title": "ウォレットを作成またはインポート"
        },
        "step3": {
          "description": "スキャン後、ウォレットを接続するための接続プロンプトが表示されます。",
          "title": "スキャンボタンをタップする"
        }
      },
      "extension": {
        "step1": {
          "description": "ウォレットへのより迅速なアクセスのためにBitget Walletをタスクバーにピン留めすることをお勧めします。",
          "title": "Bitget Wallet拡張機能をインストールします"
        },
        "step2": {
          "description": "ウォレットを安全な方法でバックアップしてください。秘密のフレーズを誰とも共有しないでください。",
          "title": "ウォレットを作成またはインポートします"
        },
        "step3": {
          "description": "ウォレットを設定したら、以下をクリックしてブラウザを更新し、拡張機能を読み込みます。",
          "title": "ブラウザを更新する"
        }
      }
    },
    "bitski": {
      "extension": {
        "step1": {
          "description": "ウォレットへの素早いアクセスのために、Bitskiをタスクバーにピン留めすることをお勧めします。",
          "title": "Bitskiエクステンションをインストールする"
        },
        "step2": {
          "description": "ウォレットを安全な方法でバックアップしてください。シークレットフレーズは誰とも共有しないでください。",
          "title": "ウォレットを作成するか、インポートする"
        },
        "step3": {
          "description": "ウォレットのセットアップが完了したら、以下をクリックしてブラウザを更新し、エクステンションを読み込みます。",
          "title": "ブラウザを更新する"
        }
      }
    },
    "bitverse": {
      "qr_code": {
        "step1": {
          "title": "Bitverse Walletアプリを開きます",
          "description": "より速くウォレットにアクセスするために、ホーム画面にBitverse Walletを追加してください。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "新しいウォレットを作成するか、既存のものをインポートします。"
        },
        "step3": {
          "title": "QRアイコンをタップしてスキャン",
          "description": "ホーム画面のQRアイコンをタップし、コードをスキャンしてプロンプトを確認して接続します。"
        }
      }
    },
    "bloom": {
      "desktop": {
        "step1": {
          "title": "Bloom Walletアプリを開く",
          "description": "Bloom Walletをホーム画面に置くことをお勧めします。これにより、より迅速にアクセスできます。"
        },
        "step2": {
          "description": "リカバリーフレーズを使用してウォレットを作成またはインポートします。",
          "title": "ウォレットを作成またはインポート"
        },
        "step3": {
          "description": "ウォレットを持った後、Bloomを介して接続するには「Connect」をクリックします。アプリ内で接続を確認するプロンプトが表示されます。",
          "title": "「Connect」をクリック"
        }
      },
      "qr_code": {
        "step1": {
          "title": "Bloom Walletアプリを開く",
          "description": "Bloom Walletをホーム画面に置くことをお勧めします。これにより、より迅速にアクセスできます。"
        },
        "step2": {
          "description": "リカバリーフレーズを使用してウォレットを作成またはインポートします。",
          "title": "ウォレットを作成またはインポート"
        },
        "step3": {
          "description": "ウォレットを持った後、Bloomを介して接続するには「Connect」をクリックします。アプリ内で接続を確認するプロンプトが表示されます。",
          "title": "「Connect」をクリック"
        }
      }
    },
    "bybit": {
      "qr_code": {
        "step1": {
          "description": "より速くウォレットにアクセスするために、ホーム画面にBybitを追加することをお勧めします。",
          "title": "Bybitアプリを開きます"
        },
        "step2": {
          "description": "電話のバックアップ機能を使用して、ウォレットを簡単にバックアップすることができます。",
          "title": "ウォレットを作成またはインポート"
        },
        "step3": {
          "description": "スキャン後、ウォレットを接続するための接続プロンプトが表示されます。",
          "title": "「スキャン」ボタンをタップします"
        }
      },
      "extension": {
        "step1": {
          "description": "ブラウザの右上をクリックして、簡単にアクセスできるようにBybit Walletをピン留めしてください。",
          "title": "Bybit Wallet拡張機能をインストールします"
        },
        "step2": {
          "description": "新しいウォレットを作成するか、既存のものをインポートします。",
          "title": "ウォレットを作成またはインポートする"
        },
        "step3": {
          "description": "Bybit Walletの設定が完了したら、以下をクリックしてブラウザを更新し、拡張機能を読み込んでください。",
          "title": "ブラウザを更新する"
        }
      }
    },
    "binance": {
      "qr_code": {
        "step1": {
          "description": "ウォレットへの迅速なアクセスのため、Binanceをホーム画面に設定することを推奨します。",
          "title": "Binanceアプリを開く"
        },
        "step2": {
          "description": "電話のバックアップ機能を使用して、ウォレットを簡単にバックアップすることができます。",
          "title": "ウォレットを作成またはインポート"
        },
        "step3": {
          "description": "スキャン後、ウォレットを接続するための接続プロンプトが表示されます。",
          "title": "WalletConnectボタンをタップします"
        }
      }
    },
    "coin98": {
      "qr_code": {
        "step1": {
          "description": "Coin98ウォレットをホーム画面に置くことで、ウォレットへのアクセスが高速化されることをお勧めします。",
          "title": "Coin98ウォレットアプリを開きます"
        },
        "step2": {
          "description": "電話のバックアップ機能を使用して、ウォレットを簡単にバックアップすることができます。",
          "title": "ウォレットを作成またはインポートする"
        },
        "step3": {
          "description": "スキャン後、ウォレットへの接続を促すプロンプトが表示されます。",
          "title": "WalletConnectボタンをタップします"
        }
      },
      "extension": {
        "step1": {
          "description": "ブラウザの右上をクリックして、Coin98ウォレットをピン留めして簡単にアクセスできるようにします。",
          "title": "Coin98ウォレットの拡張機能をインストールします"
        },
        "step2": {
          "description": "新しいウォレットを作成するか、既存のものをインポートします。",
          "title": "ウォレットを作成またはインポートする"
        },
        "step3": {
          "description": "Coin98ウォレットをセットアップしたら、下のリンクをクリックしてブラウザを更新し、拡張機能をロードします。",
          "title": "ブラウザを更新する"
        }
      }
    },
    "coinbase": {
      "qr_code": {
        "step1": {
          "description": "より素早くアクセスできるように、Coinbaseウォレットをホームスクリーンに置くことをお勧めします。",
          "title": "Coinbase Walletアプリを開く"
        },
        "step2": {
          "description": "クラウドバックアップ機能を使用して、簡単にウォレットをバックアップできます。",
          "title": "ウォレットを作成またはインポートする"
        },
        "step3": {
          "description": "スキャン後、ウォレットを接続するための接続プロンプトが表示されます。",
          "title": "スキャンボタンをタップする"
        }
      },
      "extension": {
        "step1": {
          "description": "タスクバーにCoinbase Walletをピン留めして、ウォレットにより早くアクセスできるように推奨します。",
          "title": "Coinbase Wallet拡張機能をインストールする"
        },
        "step2": {
          "description": "必ず安全な方法を使用してウォレットをバックアップしてください。秘密のフレーズを誰にも共有しないでください。",
          "title": "ウォレットを作成またはインポート"
        },
        "step3": {
          "description": "ウォレットの設定が完了したら、下のボタンをクリックしてブラウザを更新し、拡張機能をロードします。",
          "title": "ブラウザを更新する"
        }
      }
    },
    "compass": {
      "extension": {
        "step1": {
          "description": "ウォレットへのアクセスをより早くするため、タスクバーにCompass Walletをピン留めすることを推奨します。",
          "title": "Compass Wallet拡張機能をインストールする"
        },
        "step2": {
          "description": "ウォレットは安全な方法でバックアップしてください。秘密のフレーズを誰とも共有しないでください。",
          "title": "ウォレットを作成またはインポート"
        },
        "step3": {
          "description": "ウォレットを設定したら、以下をクリックしてブラウザを更新し、拡張機能を読み込みます。",
          "title": "ブラウザを更新する"
        }
      }
    },
    "core": {
      "qr_code": {
        "step1": {
          "description": "ウォレットへの迅速なアクセスのため、コアをホーム画面に設定することを推奨します。",
          "title": "Coreアプリを開く"
        },
        "step2": {
          "description": "電話のバックアップ機能を使って、簡単にウォレットをバックアップできます。",
          "title": "ウォレットを作成またはインポート"
        },
        "step3": {
          "description": "スキャン後、ウォレットを接続するようにプロンプトが表示されます。",
          "title": "WalletConnectボタンをタップする"
        }
      },
      "extension": {
        "step1": {
          "description": "ウォレットへのより迅速なアクセスのために、タスクバーにCoreをピン留めすることをお勧めします。",
          "title": "Core拡張機能をインストールする"
        },
        "step2": {
          "description": "セキュアな方法を使用してウォレットをバックアップしてください。秘密のフレーズを誰とも共有しないでください。",
          "title": "ウォレットを作成またはインポートする"
        },
        "step3": {
          "description": "ウォレットの設定が完了したら、以下をクリックしてブラウザを更新し、拡張機能をロードします。",
          "title": "ブラウザを更新する"
        }
      }
    },
    "fox": {
      "qr_code": {
        "step1": {
          "description": "より迅速なアクセスのために、ホーム画面にFoxWalletを置くことをお勧めします。",
          "title": "FoxWalletアプリを開く"
        },
        "step2": {
          "description": "セキュアな方法を使用してウォレットをバックアップすることを確認してください。秘密のフレーズは誰とも共有しないでください。",
          "title": "ウォレットを作成またはインポート"
        },
        "step3": {
          "description": "スキャンした後、ウォレットを接続するための接続プロンプトが表示されます。",
          "title": "スキャンボタンをタップします"
        }
      }
    },
    "frontier": {
      "qr_code": {
        "step1": {
          "description": "Frontierウォレットをホーム画面に置くことで、より早くアクセスできることをお勧めします。",
          "title": "Frontierウォレットアプリを開きます"
        },
        "step2": {
          "description": "セキュアな方法を使用してウォレットをバックアップすることを確認してください。秘密のフレーズは誰とも共有しないでください。",
          "title": "ウォレットを作成またはインポート"
        },
        "step3": {
          "description": "スキャン後に、ウォレットの接続を促すメッセージが表示されます。",
          "title": "スキャンボタンをタップします"
        }
      },
      "extension": {
        "step1": {
          "description": "より迅速なウォレットへのアクセスを可能にするために、フロンティアウォレットをタスクバーにピン留めすることを推奨します。",
          "title": "フロンティアウォレットの拡張機能をインストールします"
        },
        "step2": {
          "description": "安全な方法を使用してウォレットをバックアップしてください。秘密のフレーズは決して誰とも共有しないでください。",
          "title": "ウォレットを作成またはインポート"
        },
        "step3": {
          "description": "ウォレットの設定が完了したら、ブラウザを更新して拡張機能を読み込みます。",
          "title": "ブラウザを更新する"
        }
      }
    },
    "im_token": {
      "qr_code": {
        "step1": {
          "title": "imTokenアプリを開く",
          "description": "ウォレットへのアクセスを速くするために、imTokenアプリをホーム画面に置いてください。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "新しいウォレットを作成するか、既存のものをインポートします。"
        },
        "step3": {
          "title": "右上隅のスキャナーアイコンをタップします",
          "description": "新しい接続を選択し、QRコードをスキャンしてプロンプトを確認し接続します。"
        }
      }
    },
    "kaikas": {
      "extension": {
        "step1": {
          "description": "より早くウォレットにアクセスするために、タスクバーにKaikasをピン留めすることをお勧めします。",
          "title": "Kaikas拡張機能をインストールします"
        },
        "step2": {
          "description": "ウォレットは安全な方法でバックアップしてください。秘密のフレーズを誰とも共有しないでください。",
          "title": "ウォレットを作成またはインポート"
        },
        "step3": {
          "description": "ウォレットを設定したら、以下をクリックしてブラウザを更新し、拡張機能を読み込みます。",
          "title": "ブラウザを更新する"
        }
      },
      "qr_code": {
        "step1": {
          "title": "Kaikasアプリを開きます",
          "description": "より速くウォレットにアクセスするために、ホーム画面にKaikasアプリを追加してください。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "新しいウォレットを作成するか、既存のものをインポートします。"
        },
        "step3": {
          "title": "右上隅のスキャナーアイコンをタップします",
          "description": "新しい接続を選択し、QRコードをスキャンしてプロンプトを確認し接続します。"
        }
      }
    },
    "kraken": {
      "qr_code": {
        "step1": {
          "title": "Kraken Walletアプリを開く",
          "description": "ウォレットへのより迅速なアクセスのためにKraken Walletをホーム画面にピン留めすることをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "新しいウォレットを作成するか、既存のものをインポートします。"
        },
        "step3": {
          "title": "QRアイコンをタップしてスキャン",
          "description": "ホーム画面のQRアイコンをタップし、コードをスキャンしてプロンプトを確認して接続します。"
        }
      }
    },
    "kresus": {
      "qr_code": {
        "step1": {
          "title": "Kresus Walletアプリを開く",
          "description": "ウォレットへの迅速なアクセスのため、Kresus Walletをホーム画面に追加してください。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "新しいウォレットを作成するか、既存のものをインポートします。"
        },
        "step3": {
          "title": "QRアイコンをタップしてスキャン",
          "description": "ホーム画面のQRアイコンをタップし、コードをスキャンしてプロンプトを確認して接続します。"
        }
      }
    },
    "magicEden": {
      "extension": {
        "step1": {
          "title": "Magic Eden拡張機能をインストールする",
          "description": "ウォレットへの容易なアクセスのため、Magic Edenをタスクバーにピン留めすることを推奨します。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "安全な方法を使用してウォレットをバックアップしてください。秘密の回復フレーズを誰とも共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新する",
          "description": "ウォレットを設定したら、以下をクリックしてブラウザを更新し、拡張機能を読み込みます。"
        }
      }
    },
    "metamask": {
      "qr_code": {
        "step1": {
          "title": "MetaMaskアプリを開きます",
          "description": "迅速なアクセスのために、MetaMaskをホーム画面に置くことをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポートします",
          "description": "必ず安全な方法を使用してウォレットをバックアップしてください。秘密の回復フレーズを誰にも共有しないでください。"
        },
        "step3": {
          "title": "スキャンボタンをタップします",
          "description": "スキャンすると、ウォレットを接続するための接続プロンプトが表示されます。"
        }
      },
      "extension": {
        "step1": {
          "title": "MetaMaskの拡張機能をインストールします",
          "description": "ウォレットへのより速いアクセスのために、MetaMaskをタスクバーにピン留めすることをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "安全な方法を使用してウォレットをバックアップし、秘密のフレーズを誰とも共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新",
          "description": "ウォレットを設定した後は、下のリンクをクリックしてブラウザを更新し、エクステンションを読み込んでください。"
        }
      }
    },
    "nestwallet": {
      "extension": {
        "step1": {
          "title": "NestWallet拡張機能をインストール",
          "description": "ウォレットへのアクセスをより早くするため、タスクバーにNestWalletをピン留めすることを推奨します。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "ウォレットは安全な方法でバックアップしてください。秘密のフレーズを誰とも共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新する",
          "description": "ウォレットを設定したら、以下をクリックしてブラウザを更新し、拡張機能を読み込みます。"
        }
      }
    },
    "okx": {
      "qr_code": {
        "step1": {
          "title": "OKX Walletアプリを開く",
          "description": "OKX Walletをホーム画面に配置して、より早くアクセスできるようにすることをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "セキュアな方法を使ってウォレットをバックアップしてください。秘密フレーズは誰とも共有しないでください。"
        },
        "step3": {
          "title": "スキャンボタンをタップする",
          "description": "スキャン後、ウォレットを接続するための接続プロンプトが表示されます。"
        }
      },
      "extension": {
        "step1": {
          "title": "OKXウォレット拡張機能をインストールする",
          "description": "ウォレットへの迅速なアクセスのため、OKXウォレットをタスクバーにピン止めすることをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成するか、インポートする",
          "description": "セキュアな方法を使ってウォレットをバックアップしてください。秘密フレーズは誰とも共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新する",
          "description": "ウォレットを設定したら、下をクリックしてブラウザをリフレッシュし、拡張機能を読み込みます。"
        }
      }
    },
    "omni": {
      "qr_code": {
        "step1": {
          "title": "Omniアプリを開く",
          "description": "Omniをホーム画面に追加して、ウォレットへのアクセスを早めます。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "新しいウォレットを作成するか、既存のものをインポートします。"
        },
        "step3": {
          "title": "QRアイコンをタップしてスキャン",
          "description": "ホーム画面のQRアイコンをタップし、コードをスキャンし、プロンプトを確認して接続します。"
        }
      }
    },
    "1inch": {
      "qr_code": {
        "step1": {
          "description": "より速くウォレットにアクセスするために、ホーム画面に1inch Walletを追加してください。",
          "title": "1inch Walletアプリを開きます"
        },
        "step2": {
          "description": "ウォレットとユーザーネームを作成するか、既存のウォレットをインポートします。",
          "title": "ウォレットを作成またはインポート"
        },
        "step3": {
          "description": "スキャン後、ウォレットを接続するための接続プロンプトが表示されます。",
          "title": "「QRをスキャン」ボタンをタップします"
        }
      }
    },
    "token_pocket": {
      "qr_code": {
        "step1": {
          "title": "TokenPocketアプリを開く",
          "description": "より速いアクセスのために、TokenPocketをホーム画面に置くことをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポートする",
          "description": "必ず安全な方法を使用してウォレットをバックアップしてください。秘密の回復フレーズを誰にも共有しないでください。"
        },
        "step3": {
          "title": "スキャンボタンをタップする",
          "description": "スキャン後、ウォレットを接続するための接続プロンプトが表示されます。"
        }
      },
      "extension": {
        "step1": {
          "title": "TokenPocketエクステンションをインストールする",
          "description": "ウォレットへのより早いアクセスのために、TokenPocketをタスクバーにピン留めすることをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "ウォレットを安全な方法でバックアップすることを確認してください。シークレットフレーズを決して他の人と共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新",
          "description": "ウォレットのセットアップが完了したら、以下をクリックしてブラウザを更新し、拡張機能をロードします。"
        }
      }
    },
    "trust": {
      "qr_code": {
        "step1": {
          "title": "Trust Walletアプリを開く",
          "description": "ウォレットへの高速アクセスのために、Trust Walletをホーム画面に置きます。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "新しいウォレットを作成するか、既存のものをインポートします。"
        },
        "step3": {
          "title": "設定でWalletConnectをタップします",
          "description": "新しい接続を選択し、QRコードをスキャンして、プロンプトで接続を確認します。"
        }
      },
      "extension": {
        "step1": {
          "title": "Trust Wallet拡張機能をインストールします",
          "description": "ブラウザの右上をクリックし、Trust Walletをピン留めして簡単にアクセスできるようにします。"
        },
        "step2": {
          "title": "ウォレットを作成するかインポートします",
          "description": "新しいウォレットを作成するか、既存のものをインポートします。"
        },
        "step3": {
          "title": "ブラウザを更新する",
          "description": "Trust Walletの設定が完了したら、以下をクリックしてブラウザを更新し、拡張機能を読み込みます。"
        }
      }
    },
    "uniswap": {
      "qr_code": {
        "step1": {
          "title": "Uniswapアプリを開く",
          "description": "Uniswapウォレットをホーム画面に追加して、ウォレットへのアクセスを高速化します。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポートする",
          "description": "新しいウォレットを作成するか、既存のものをインポートします。"
        },
        "step3": {
          "title": "QRアイコンをタップしてスキャンする",
          "description": "ホーム画面のQRアイコンをタップし、コードをスキャンしてプロンプトを確認して接続します。"
        }
      }
    },
    "zerion": {
      "qr_code": {
        "step1": {
          "title": "Zerionアプリを開く",
          "description": "より速くアクセスするために、Zerionをホーム画面に置くことをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成するか、インポートする",
          "description": "必ず安全な方法を使用してウォレットをバックアップしてください。秘密の回復フレーズを誰にも共有しないでください。"
        },
        "step3": {
          "title": "スキャンボタンを押す",
          "description": "スキャンした後、ウォレットを接続するための接続プロンプトが表示されます。"
        }
      },
      "extension": {
        "step1": {
          "title": "Zerion拡張機能をインストールする",
          "description": "ウォレットへの素早いアクセスのため、Zerionをタスクバーにピン留めすることをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "ウォレットをセキュアな方法でバックアップすることを確認してください。秘密のフレーズを誰とも共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新する",
          "description": "ウォレットをセットアップしたら、下のボタンをクリックしてブラウザを更新し、拡張機能をロードします。"
        }
      }
    },
    "rainbow": {
      "qr_code": {
        "step1": {
          "title": "Rainbowアプリを開く",
          "description": "ウォレットへの早いアクセスのために、Rainbowをホーム画面に置くことをおすすめします。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "電話のバックアップ機能を使用して、簡単にウォレットをバックアップすることができます。"
        },
        "step3": {
          "title": "スキャンボタンをタップする",
          "description": "スキャンした後、ウォレットを接続するための接続プロンプトが表示されます。"
        }
      }
    },
    "enkrypt": {
      "extension": {
        "step1": {
          "description": "ウォレットへのアクセスをより早くするため、タスクバーにEnkrypt Walletをピン留めすることを推奨します。",
          "title": "Enkrypt Wallet拡張機能をインストールしてください"
        },
        "step2": {
          "description": "安全な方法でウォレットのバックアップを必ず取り、秘密のフレーズを誰とも共有しないでください。",
          "title": "ウォレットを作成するか、インポートする"
        },
        "step3": {
          "description": "ウォレットの設定が完了したら、以下をクリックしてブラウザを更新し、拡張機能を読み込みます。",
          "title": "ブラウザを更新する"
        }
      }
    },
    "frame": {
      "extension": {
        "step1": {
          "description": "ウォレットへのアクセスをより早くするため、タスクバーにFrameをピン留めすることを推奨します。",
          "title": "Frameとその付属の拡張機能をインストール"
        },
        "step2": {
          "description": "ウォレットを安全な方法でバックアップしてください。秘密のフレーズを誰とも共有しないでください。",
          "title": "ウォレットを作成、またはインポート"
        },
        "step3": {
          "description": "ウォレットの設定が完了したら、下のリンクをクリックしてブラウザを更新し、拡張機能をロードします。",
          "title": "ブラウザを更新"
        }
      }
    },
    "one_key": {
      "extension": {
        "step1": {
          "title": "OneKey Wallet拡張機能をインストール",
          "description": "ウォレットへのアクセスを素早く行うため、OneKey Walletをタスクバーにピン留めすることをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成、またはインポート",
          "description": "安全な方法を使用してウォレットをバックアップしてください。秘密のフレーズを誰とも共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新する",
          "description": "ウォレットを設定したら、以下をクリックしてブラウザを更新し、拡張機能をロードします。"
        }
      }
    },
    "phantom": {
      "extension": {
        "step1": {
          "title": "Phantom拡張機能をインストールする",
          "description": "ウォレットへの容易なアクセスのため、Phantomをタスクバーにピン留めすることを推奨します。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポートする",
          "description": "安全な方法を使用してウォレットをバックアップしてください。秘密の回復フレーズを誰とも共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新する",
          "description": "ウォレットの設定が完了したら、以下をクリックしてブラウザを更新し、エクステンションを読み込みます。"
        }
      }
    },
    "rabby": {
      "extension": {
        "step1": {
          "title": "Rabbyエクステンションをインストールする",
          "description": "ウォレットへの素早いアクセスのため、タスクバーにRabbyをピン止めすることをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "セキュアな方法を使用してウォレットをバックアップしてください。秘密のフレーズを誰とも共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新",
          "description": "ウォレットの設定が完了したら、以下をクリックしてブラウザを更新し、拡張機能をロードします。"
        }
      }
    },
    "ronin": {
      "qr_code": {
        "step1": {
          "description": "ウォレットへのより速いアクセスのため、Ronin Walletをホーム画面に設定することを推奨します。",
          "title": "Ronin Walletアプリを開く"
        },
        "step2": {
          "description": "ウォレットは安全な方法でバックアップしてください。秘密のフレーズを誰とも共有しないでください。",
          "title": "ウォレットを作成またはインポート"
        },
        "step3": {
          "description": "スキャン後、ウォレットを接続するための接続プロンプトが表示されます。",
          "title": "「スキャン」ボタンをタップします"
        }
      },
      "extension": {
        "step1": {
          "description": "ウォレットへのより速いアクセスのため、タスクバーにRonin Walletをピン留めすることを推奨します。",
          "title": "Ronin Walletの拡張機能をインストールする"
        },
        "step2": {
          "description": "ウォレットは安全な方法でバックアップしてください。秘密のフレーズを誰とも共有しないでください。",
          "title": "ウォレットを作成またはインポート"
        },
        "step3": {
          "description": "ウォレットを設定したら、以下をクリックしてブラウザを更新し、拡張機能を読み込みます。",
          "title": "ブラウザを更新する"
        }
      }
    },
    "ramper": {
      "extension": {
        "step1": {
          "title": "Ramperの拡張機能をインストールする",
          "description": "ウォレットへの容易なアクセスのため、タスクバーにRamperをピン留めすることを推奨します。"
        },
        "step2": {
          "title": "ウォレットを作成",
          "description": "ウォレットは安全な方法でバックアップしてください。秘密のフレーズを誰とも共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新する",
          "description": "ウォレットを設定したら、以下をクリックしてブラウザを更新し、拡張機能を読み込みます。"
        }
      }
    },
    "safeheron": {
      "extension": {
        "step1": {
          "title": "コア拡張機能をインストール",
          "description": "ウォレットへの素早いアクセスのため、タスクバーにSafeheronをピン止めすることをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "確実に安全な方法でウォレットをバックアップしてください。秘密のフレーズは決して誰とも共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新する",
          "description": "ウォレットの設定が完了したら、以下をクリックしてブラウザを更新し、拡張機能をロードします。"
        }
      }
    },
    "taho": {
      "extension": {
        "step1": {
          "title": "Taho拡張機能をインストールする",
          "description": "ウォレットへのより迅速なアクセスのため、Tahoをタスクバーにピン留めすることをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成するか、インポートする",
          "description": "確実に安全な方法でウォレットをバックアップしてください。秘密のフレーズは決して誰とも共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新する",
          "description": "ウォレットの設定が完了したら、下をクリックしてブラウザを更新し、拡張機能をロードします。"
        }
      }
    },
    "talisman": {
      "extension": {
        "step1": {
          "title": "Talisman拡張機能をインストールする",
          "description": "ウォレットへのより早いアクセスのために、Talismanをタスクバーにピン留めすることをお勧めします。"
        },
        "step2": {
          "title": "Ethereumウォレットを作成するか、インポートする",
          "description": "ウォレットを安全な方法でバックアップしておくことを確認してください。リカバリーフレーズを誰とも共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新する",
          "description": "ウォレットの設定が完了したら、下をクリックしてブラウザを更新し、拡張機能をロードします。"
        }
      }
    },
    "xdefi": {
      "extension": {
        "step1": {
          "title": "XDEFI Wallet拡張機能をインストールする",
          "description": "XDEFI Walletをタスクバーにピン留めすることで、ウォレットへのアクセスが速くなることをお勧めします。"
        },
        "step2": {
          "title": "ウォレットの作成またはインポート",
          "description": "ウォレットを安全な方法でバックアップしてください。秘密のフレーズを誰とも共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新する",
          "description": "ウォレットの設定が完了したら、以下をクリックしてブラウザを更新し、拡張機能をロードしてください。"
        }
      }
    },
    "zeal": {
      "qr_code": {
        "step1": {
          "title": "Zealアプリを開く",
          "description": "ウォレットへの素早いアクセスのために、Zeal Walletをホーム画面に追加することをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "新しいウォレットを作成するか、既存のものをインポートします。"
        },
        "step3": {
          "title": "QRアイコンをタップしてスキャン",
          "description": "ホーム画面のQRアイコンをタップし、コードをスキャンしてプロンプトを確認して接続します。"
        }
      },
      "extension": {
        "step1": {
          "title": "Zeal 拡張機能をインストール",
          "description": "ウォレットに素早くアクセスするために、タスクバーに Zeal をピン留めすることをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "ウォレットは安全な方法でバックアップしてください。秘密のフレーズを誰とも共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新する",
          "description": "ウォレットを設定したら、以下をクリックしてブラウザを更新し、拡張機能を読み込みます。"
        }
      }
    },
    "safepal": {
      "extension": {
        "step1": {
          "title": "SafePal Wallet拡張機能をインストールする",
          "description": "ブラウザの右上でクリックし、Easy AccessのためにSafePal Walletをピン留めします。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポートする",
          "description": "新しいウォレットを作成するか、既存のものをインポートします。"
        },
        "step3": {
          "title": "ブラウザを更新する",
          "description": "SafePal Walletのセットアップが完了したら、以下をクリックしてブラウザをリフレッシュし、エクステンションをロードします。"
        }
      },
      "qr_code": {
        "step1": {
          "title": "SafePal Walletアプリを開く",
          "description": "SafePal Walletをホーム画面に置くことで、ウォレットへの素早いアクセスが可能になります。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "新しいウォレットを作成するか、既存のものをインポートします。"
        },
        "step3": {
          "title": "設定でWalletConnectをタップします",
          "description": "新しい接続を選択し、QRコードをスキャンしてプロンプトを確認し接続します。"
        }
      }
    },
    "desig": {
      "extension": {
        "step1": {
          "title": "Desig拡張機能をインストール",
          "description": "あなたのウォレットへの簡単なアクセスのために、Desigをタスクバーにピン留めすることをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成",
          "description": "ウォレットは安全な方法でバックアップしてください。秘密のフレーズを誰とも共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新する",
          "description": "ウォレットを設定したら、以下をクリックしてブラウザを更新し、拡張機能を読み込みます。"
        }
      }
    },
    "subwallet": {
      "extension": {
        "step1": {
          "title": "SubWallet拡張機能をインストール",
          "description": "ウォレットへのより素早いアクセスのため、SubWalletをタスクバーにピン留めすることをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "ウォレットを安全な方法でバックアップしておくことを確認してください。リカバリーフレーズを誰とも共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新する",
          "description": "ウォレットを設定したら、以下をクリックしてブラウザを更新し、拡張機能を読み込みます。"
        }
      },
      "qr_code": {
        "step1": {
          "title": "SubWalletアプリを開く",
          "description": "より迅速なアクセスのために、SubWalletをホーム画面に置くことをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "ウォレットは安全な方法でバックアップしてください。秘密のフレーズを誰とも共有しないでください。"
        },
        "step3": {
          "title": "「スキャン」ボタンをタップします",
          "description": "スキャン後、ウォレットを接続するための接続プロンプトが表示されます。"
        }
      }
    },
    "clv": {
      "extension": {
        "step1": {
          "title": "CLV Wallet拡張機能をインストール",
          "description": "ウォレットへのより素早いアクセスのため、CLV Walletをタスクバーにピン留めすることをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "ウォレットは安全な方法でバックアップしてください。秘密のフレーズを誰とも共有しないでください。"
        },
        "step3": {
          "title": "ブラウザを更新する",
          "description": "ウォレットを設定したら、以下をクリックしてブラウザを更新し、拡張機能を読み込みます。"
        }
      },
      "qr_code": {
        "step1": {
          "title": "CLV Walletアプリを開く",
          "description": "より迅速なアクセスのために、ホーム画面にCLV Walletを置くことをお勧めします。"
        },
        "step2": {
          "title": "ウォレットを作成またはインポート",
          "description": "ウォレットは安全な方法でバックアップしてください。秘密のフレーズを誰とも共有しないでください。"
        },
        "step3": {
          "title": "「スキャン」ボタンをタップします",
          "description": "スキャン後、ウォレットを接続するための接続プロンプトが表示されます。"
        }
      }
    },
    "okto": {
      "qr_code": {
        "step1": {
          "title": "Oktoアプリを開く",
          "description": "素早くアクセスするために、ホーム画面にOktoを追加します"
        },
        "step2": {
          "title": "MPCウォレットを作成する",
          "description": "アカウントを作成し、ウォレットを生成します"
        },
        "step3": {
          "title": "設定でWalletConnectをタップします",
          "description": "右上のScan QRアイコンをタップし、接続するためのプロンプトを確認します。"
        }
      }
    },
    "ledger": {
      "desktop": {
        "step1": {
          "title": "Ledger Liveアプリを開く",
          "description": "より速いアクセスのために、ホーム画面にLedger Liveを置くことを推奨します。"
        },
        "step2": {
          "title": "あなたのLedgerを設定する",
          "description": "新しいLedgerを設定するか、既存のものに接続します。"
        },
        "step3": {
          "title": "接続",
          "description": "スキャン後、ウォレットを接続するための接続プロンプトが表示されます。"
        }
      },
      "qr_code": {
        "step1": {
          "title": "Ledger Liveアプリを開く",
          "description": "より速いアクセスのために、ホーム画面にLedger Liveを置くことを推奨します。"
        },
        "step2": {
          "title": "あなたのLedgerを設定する",
          "description": "デスクトップアプリと同期するか、あなたのLedgerに接続することができます。"
        },
        "step3": {
          "title": "コードをスキャンする",
          "description": "WalletConnectをタップし、スキャナーに切り替えてください。スキャン後、ウォレットを接続するための接続プロンプトが表示されます。"
        }
      }
    }
  }
}
`;export{u as default};
