var u=`{
  "connect_wallet": {
    "label": "اتصال المحفظة",
    "wrong_network": {
      "label": "شبكة خاطئة"
    }
  },
  "intro": {
    "title": "ما هو المحفظة؟",
    "description": "تُستخدم المحفظة لإرسال واستلام وتخزين وعرض الأصول الرقمية. إنها أيضاً طريقة جديدة لتسجيل الدخول، دون الحاجة إلى إنشاء حسابات وكلمات مرور جديدة على كل موقع.",
    "digital_asset": {
      "title": "دار لأصولك الرقمية",
      "description": "تُستخدم المحافظ لإرسال واستلام وتخزين وعرض الأصول الرقمية مثل إيثيريوم والـ NFTs."
    },
    "login": {
      "title": "طريقة جديدة لتسجيل الدخول",
      "description": "بدلاً من إنشاء حسابات وكلمات مرور جديدة على كل موقع، فقط قم بتوصيل محفظتك."
    },
    "get": {
      "label": "احصل على محفظة"
    },
    "learn_more": {
      "label": "تعلم المزيد"
    }
  },
  "sign_in": {
    "label": "تحقق من حسابك",
    "description": "لإنهاء الاتصال، يجب عليك توقيع رسالة في محفظتك للتحقق من أنك صاحب هذا الحساب.",
    "message": {
      "send": "إرسال الرسالة",
      "preparing": "جارٍ تجهيز الرسالة...",
      "cancel": "إلغاء",
      "preparing_error": "خطأ في تجهيز الرسالة، يرجى المحاولة مرة أخرى!"
    },
    "signature": {
      "waiting": "انتظار التوقيع...",
      "verifying": "جار التحقق من التوقيع...",
      "signing_error": "خطأ في توقيع الرسالة، يرجى المحاولة مرة أخرى!",
      "verifying_error": "خطأ في التحقق من التوقيع، يرجى المحاولة مرة أخرى!",
      "oops_error": "عذرًا، حدث خطأ ما!"
    }
  },
  "connect": {
    "label": "اتصل",
    "title": "اتصال بالمحفظة",
    "new_to_ethereum": {
      "description": "جديد في محافظ Ethereum؟",
      "learn_more": {
        "label": "تعلم المزيد"
      }
    },
    "learn_more": {
      "label": "أعرف أكثر"
    },
    "recent": "الأخير",
    "status": {
      "opening": "جار فتح %{wallet}...",
      "connecting": "جارٍ الاتصال",
      "connect_mobile": "استمر في %{wallet}",
      "not_installed": "%{wallet} غير مثبت",
      "not_available": "%{wallet} غير متاح",
      "confirm": "تأكيد الاتصال في الامتداد",
      "confirm_mobile": "قبل طلب الاتصال في المحفظة"
    },
    "secondary_action": {
      "get": {
        "description": "لا يوجد لديك %{wallet}؟",
        "label": "احصل"
      },
      "install": {
        "label": "تثبيت"
      },
      "retry": {
        "label": "أعد المحاولة"
      }
    },
    "walletconnect": {
      "description": {
        "full": "هل تحتاج إلى النافذة الرسمية لـ WalletConnect؟",
        "compact": "هل تحتاج إلى النافذة لـ WalletConnect؟"
      },
      "open": {
        "label": "افتح"
      }
    }
  },
  "connect_scan": {
    "title": "المسح باستخدام %{wallet}",
    "fallback_title": "المسح باستخدام هاتفك"
  },
  "connector_group": {
    "installed": "مُثبّت",
    "recommended": "موصى به",
    "other": "آخر",
    "popular": "شائع",
    "more": "المزيد",
    "others": "الآخرين"
  },
  "get": {
    "title": "احصل على محفظة",
    "action": {
      "label": "احصل"
    },
    "mobile": {
      "description": "محفظة الموبايل"
    },
    "extension": {
      "description": "ملحق المتصفح"
    },
    "mobile_and_extension": {
      "description": "محفظة موبايل وملحق"
    },
    "mobile_and_desktop": {
      "description": "محفظة الموبايل والكمبيوتر"
    },
    "looking_for": {
      "title": "ليست هذه هي ما تبحث عنه؟",
      "mobile": {
        "description": "حدد محفظة على الشاشة الرئيسية للبدء باستخدام موفر محفظة مختلف."
      },
      "desktop": {
        "compact_description": "حدد محفظة على الشاشة الرئيسية للبدء باستخدام موفر محفظة مختلف.",
        "wide_description": "حدد محفظة على اليسار للبدء باستخدام موفر محفظة مختلف."
      }
    }
  },
  "get_options": {
    "title": "ابدأ مع %{wallet}",
    "short_title": "احصل على %{wallet}",
    "mobile": {
      "title": "%{wallet} للجوال",
      "description": "استخدم محفظة الموبايل لاستكشاف عالم Ethereum.",
      "download": {
        "label": "احصل على التطبيق"
      }
    },
    "extension": {
      "title": "%{wallet} لـ %{browser}",
      "description": "وصول لمحفظتك مباشرة من متصفح الويب المفضل لديك.",
      "download": {
        "label": "أضف إلى %{browser}"
      }
    },
    "desktop": {
      "title": "%{wallet} لـ %{platform}",
      "description": "قم بالوصول إلى محفظتك بشكل أصلي من كمبيوترك القوي.",
      "download": {
        "label": "أضف إلى %{platform}"
      }
    }
  },
  "get_mobile": {
    "title": "قم بالتثبيت %{wallet}",
    "description": "استخدم هاتفك للتحميل على iOS أو Android",
    "continue": {
      "label": "استمر"
    }
  },
  "get_instructions": {
    "mobile": {
      "connect": {
        "label": "اتصل"
      },
      "learn_more": {
        "label": "تعلم المزيد"
      }
    },
    "extension": {
      "refresh": {
        "label": "تحديث"
      },
      "learn_more": {
        "label": "تعلم المزيد"
      }
    },
    "desktop": {
      "connect": {
        "label": "اتصل"
      },
      "learn_more": {
        "label": "تعلم المزيد"
      }
    }
  },
  "chains": {
    "title": "تبديل الشبكات",
    "wrong_network": "تم اكتشاف شبكة غير صحيحة، قم بالتبديل أو القطع للمتابعة.",
    "confirm": "التأكيد في المحفظة",
    "switching_not_supported": "محفظتك لا تدعم التبديل بين الشبكات من %{appName}. جرب التبديل بين الشبكات من داخل المحفظة بدلاً من ذلك.",
    "switching_not_supported_fallback": "محفظتك لا تدعم تبديل الشبكات من هذا التطبيق. حاول تبديل الشبكات من داخل المحفظة بدلاً من ذلك.",
    "disconnect": "قطع الاتصال",
    "connected": "متصل"
  },
  "profile": {
    "disconnect": {
      "label": "قطع الاتصال"
    },
    "copy_address": {
      "label": "نسخ العنوان",
      "copied": "تم النسخ!"
    },
    "explorer": {
      "label": "عرض المزيد على المستكشف"
    },
    "transactions": {
      "description": "%{appName} ستظهر المعاملات هنا...",
      "description_fallback": "سوف تظهر معاملاتك هنا...",
      "recent": {
        "title": "المعاملات الأخيرة"
      },
      "clear": {
        "label": "مسح الكل"
      }
    }
  },
  "wallet_connectors": {
    "argent": {
      "qr_code": {
        "step1": {
          "description": "ضع أرجنت على شاشتك الرئيسية للوصول السريع إلى محفظتك.",
          "title": "افتح تطبيق Argent"
        },
        "step2": {
          "description": "أنشئ محفظة واسم مستخدم، أو استورد محفظة موجودة بالفعل.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بعد الفحص، سيظهر لك موجه الاتصال لتوصيل المحفظة الخاصة بك.",
          "title": "اضغط على زر فحص الكود الشريطي"
        }
      }
    },
    "bifrost": {
      "qr_code": {
        "step1": {
          "description": "نوصي بوضع محفظة Bifrost على الشاشة الرئيسية للوصول الأسرع.",
          "title": "افتح تطبيق محفظة Bifrost"
        },
        "step2": {
          "description": "أنشئ أو استورد محفظة باستخدام عبارة الاستعادة الخاصة بك.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بعد الفحص، سيظهر موجه الاتصال لك لتوصيل محفظتك.",
          "title": "اضغط على زر المسح"
        }
      }
    },
    "bitget": {
      "qr_code": {
        "step1": {
          "description": "نوصي بوضع محفظة Bitget على الشاشة الرئيسية للوصول الأسرع.",
          "title": "افتح تطبيق محفظة Bitget"
        },
        "step2": {
          "description": "تأكد من عمل نسخة احتياطية لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أحد.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بعد الفحص، ستظهر لك موجه اتصال لتوصيل محفظتك.",
          "title": "اضغط على زر الفحص"
        }
      },
      "extension": {
        "step1": {
          "description": "نوصي بتثبيت محفظة Bitget على شريط المهام للوصول الأسرع إلى محفظتك.",
          "title": "قم بتثبيت امتداد محفظة Bitget"
        },
        "step2": {
          "description": "تأكد من نسخ محفظتك احتياطيًا باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص.",
          "title": "أنشئ محفظة أو استورد محفظة"
        },
        "step3": {
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الامتداد.",
          "title": "قم بتحديث متصفحك"
        }
      }
    },
    "bitski": {
      "extension": {
        "step1": {
          "description": "نوصي بتثبيت Bitski على شريط المهام الخاص بك للوصول الأسرع إلى محفظتك.",
          "title": "قم بتثبيت امتداد Bitski"
        },
        "step2": {
          "description": "تأكد من الاحتفاظ بنسخة احتياطية من محفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بعد إعداد المحفظة الخاصة بك، انقر أدناه لتحديث المتصفح وتحميل الإضافة.",
          "title": "تحديث المتصفح الخاص بك"
        }
      }
    },
    "bitverse": {
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق محفظة Bitverse",
          "description": "أضف محفظة Bitverse إلى شاشتك الرئيسية للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "أنشئ محفظة جديدة أو استورد واحدة موجودة بالفعل."
        },
        "step3": {
          "title": "اضغط على أيقونة الرمز الاستجابة السريعة وامسحها",
          "description": "اضغط على أيقونة QR على الشاشة الرئيسية، قراءة الرمز وتأكيد الرسالة الموجهة للاتصال."
        }
      }
    },
    "bloom": {
      "desktop": {
        "step1": {
          "title": "افتح تطبيق محفظة Bloom",
          "description": "نوصي بوضع محفظة Bloom على الشاشة الرئيسية للوصول الأسرع."
        },
        "step2": {
          "description": "أنشئ أو استورد محفظة باستخدام عبارة الاستعادة الخاصة بك.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بعد حصولك على محفظة، انقر على Connect للاتصال عبر Bloom. ستظهر رسالة مطالبة بالاتصال في التطبيق لتأكيد الاتصال.",
          "title": "انقر على Connect"
        }
      },
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق محفظة Bloom",
          "description": "نوصي بوضع محفظة Bloom على الشاشة الرئيسية للوصول الأسرع."
        },
        "step2": {
          "description": "أنشئ أو استورد محفظة باستخدام عبارة الاستعادة الخاصة بك.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بعد حصولك على محفظة، انقر على Connect للاتصال عبر Bloom. ستظهر رسالة مطالبة بالاتصال في التطبيق لتأكيد الاتصال.",
          "title": "انقر على Connect"
        }
      }
    },
    "bybit": {
      "qr_code": {
        "step1": {
          "description": "نوصي بوضع Bybit على شاشتك الرئيسية للوصول الأسرع إلى محفظتك.",
          "title": "افتح تطبيق Bybit"
        },
        "step2": {
          "description": "يمكنك بسهولة نسخ محفظتك الاحتياطي باستخدام ميزة النسخ الاحتياطي على هاتفك.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بعد الفحص، سيظهر لك موجه الاتصال لتوصيل المحفظة الخاصة بك.",
          "title": "اضغط على زر المسح"
        }
      },
      "extension": {
        "step1": {
          "description": "انقر في أعلى يمين المتصفح وثبت محفظة Bybit للوصول السهل.",
          "title": "قم بتثبيت امتداد محفظة Bybit"
        },
        "step2": {
          "description": "أنشئ محفظة جديدة أو استورد واحدة موجودة بالفعل.",
          "title": "أنشئ محفظة أو استورد محفظة"
        },
        "step3": {
          "description": "بعد إعداد محفظة Bybit، انقر أدناه لتحديث المتصفح وتحميل الامتداد.",
          "title": "قم بتحديث متصفحك"
        }
      }
    },
    "binance": {
      "qr_code": {
        "step1": {
          "description": "نوصي بوضع Binance على الشاشة الرئيسية للوصول السريع إلى محفظتك.",
          "title": "افتح تطبيق Binance"
        },
        "step2": {
          "description": "يمكنك بسهولة نسخ محفظتك الاحتياطي باستخدام ميزة النسخ الاحتياطي على هاتفك.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بعد الفحص، سيظهر لك موجه الاتصال لتوصيل المحفظة الخاصة بك.",
          "title": "اضغط على زر WalletConnect"
        }
      }
    },
    "coin98": {
      "qr_code": {
        "step1": {
          "description": "نوصي بوضع محفظة Coin98 على الشاشة الرئيسية لسرعة الوصول إلى محفظتك.",
          "title": "افتح تطبيق محفظة Coin98"
        },
        "step2": {
          "description": "يمكنك بسهولة نسخ محفظتك الاحتياطي باستخدام ميزة النسخ الاحتياطي على هاتفك.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بعد الفحص، ستظهر لك مطالبة بالاتصال لتوصيل محفظتك.",
          "title": "اضغط على زر WalletConnect"
        }
      },
      "extension": {
        "step1": {
          "description": "انقر في الجزء العلوي الأيمن من المتصفح وثبت Coin98 Wallet لسهولة الوصول.",
          "title": "قم بتثبيت امتداد Coin98 Wallet"
        },
        "step2": {
          "description": "أنشئ محفظة جديدة أو استورد واحدة موجودة بالفعل.",
          "title": "أنشئ محفظة أو استورد محفظة"
        },
        "step3": {
          "description": "بمجرد إعداد Coin98 Wallet ، انقر أدناه لتحديث المتصفح وتحميل الامتداد.",
          "title": "تحديث المتصفح الخاص بك"
        }
      }
    },
    "coinbase": {
      "qr_code": {
        "step1": {
          "description": "نوصي بوضع Coinbase Wallet على الشاشة الرئيسية لسهولة الوصول.",
          "title": "افتح تطبيق Coinbase Wallet"
        },
        "step2": {
          "description": "يمكنك بسهولة النسخ الاحتياطي لمحفظتك باستخدام ميزة النسخ الاحتياطي السحابي.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بعد الفحص، ستظهر لك مطالبة بالاتصال لتوصيل محفظتك.",
          "title": "اضغط على زر الفحص"
        }
      },
      "extension": {
        "step1": {
          "description": "نوصي بتثبيت محفظة Coinbase على شريط المهام الخاص بك للوصول الأسرع إلى محفظتك.",
          "title": "تثبيت امتداد محفظة Coinbase"
        },
        "step2": {
          "description": "تأكد من النسخ الاحتياطي لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص.",
          "title": "إنشاء أو استيراد المحفظة"
        },
        "step3": {
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الإضافة.",
          "title": "تحديث المتصفح الخاص بك"
        }
      }
    },
    "compass": {
      "extension": {
        "step1": {
          "description": "نوصي بتثبيت محفظة Compass على شريط المهام للوصول الأسرع إلى محفظتك.",
          "title": "تثبيت امتداد محفظة Compass"
        },
        "step2": {
          "description": "تأكد من عمل نسخة احتياطية لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أحد.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الامتداد.",
          "title": "قم بتحديث متصفحك"
        }
      }
    },
    "core": {
      "qr_code": {
        "step1": {
          "description": "نوصي بوضع Core على الشاشة الرئيسية للوصول السريع إلى محفظتك.",
          "title": "افتح تطبيق Core"
        },
        "step2": {
          "description": "يمكنك بسهولة النسخ الاحتياطي لمحفظتك باستخدام ميزة النسخ الاحتياطي على هاتفك.",
          "title": "إنشاء أو استيراد المحفظة"
        },
        "step3": {
          "description": "بعد الفحص، سيظهر لك موجه الاتصال لتوصيل محفظتك.",
          "title": "اضغط على زر WalletConnect"
        }
      },
      "extension": {
        "step1": {
          "description": "نوصي بتثبيت Core على شريط المهام الخاص بك للوصول الأسرع إلى محفظتك.",
          "title": "قم بتثبيت امتداد Core"
        },
        "step2": {
          "description": "تأكد من عمل نسخة احتياطية لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الامتداد.",
          "title": "تحديث متصفحك"
        }
      }
    },
    "fox": {
      "qr_code": {
        "step1": {
          "description": "نوصي بوضع FoxWallet على شاشتك الرئيسية للوصول الأسرع.",
          "title": "افتح تطبيق FoxWallet"
        },
        "step2": {
          "description": "تأكد من الاحتفاظ بنسخة احتياطية من محفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص.",
          "title": "إنشاء محفظة أو استيراد محفظة"
        },
        "step3": {
          "description": "بعد الفحص، ستظهر لك موجه الاتصال لتتمكن من اتصال محفظتك.",
          "title": "اضغط على زر الفحص"
        }
      }
    },
    "frontier": {
      "qr_code": {
        "step1": {
          "description": "نوصي بوضع Frontier Wallet على شاشتك الرئيسية للوصول الأسرع.",
          "title": "افتح تطبيق Frontier Wallet"
        },
        "step2": {
          "description": "تأكد من نسخ محفظتك احتياطيا باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بعد الفحص، ستظهر لك موجه الاتصال لربط محفظتك.",
          "title": "اضغط على زر الفحص"
        }
      },
      "extension": {
        "step1": {
          "description": "نوصي بتثبيت محفظة Frontier على شريط المهام للوصول الأسرع إلى محفظتك.",
          "title": "تثبيت امتداد محفظة Frontier"
        },
        "step2": {
          "description": "تأكد من نسخ محفظتك احتياطيا باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الإضافة.",
          "title": "قم بتحديث المتصفح الخاص بك"
        }
      }
    },
    "im_token": {
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق imToken",
          "description": "ضع تطبيق imToken على الشاشة الرئيسية للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "قم بإنشاء محفظة جديدة أو استيراد واحدة موجودة."
        },
        "step3": {
          "title": "اضغط على أيقونة الماسح الضوئي في الزاوية العليا اليمنى",
          "description": "اختر الاتصال الجديد، ثم امسح الرمز الشريطي وأكد الموجه للاتصال."
        }
      }
    },
    "kaikas": {
      "extension": {
        "step1": {
          "description": "نوصي بتثبيت Kaikas على شريط المهام للوصول الأسرع إلى محفظتك.",
          "title": "قم بتثبيت امتداد Kaikas"
        },
        "step2": {
          "description": "تأكد من عمل نسخة احتياطية لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أحد.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الامتداد.",
          "title": "قم بتحديث متصفحك"
        }
      },
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق Kaikas",
          "description": "ضع تطبيق Kaikas على شاشتك الرئيسية للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "أنشئ محفظة جديدة أو استورد واحدة موجودة بالفعل."
        },
        "step3": {
          "title": "اضغط على أيقونة الماسح الضوئي في الزاوية العليا اليمنى",
          "description": "اختر الاتصال الجديد، ثم امسح الرمز الشريطي وأكد الموجه للاتصال."
        }
      }
    },
    "kraken": {
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق محفظة Kraken",
          "description": "أضف محفظة Kraken إلى شاشتك الرئيسية للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "أنشئ محفظة جديدة أو استورد واحدة موجودة بالفعل."
        },
        "step3": {
          "title": "اضغط على أيقونة الرمز الاستجابة السريعة وامسحها",
          "description": "اضغط على أيقونة QR على الشاشة الرئيسية، قراءة الرمز وتأكيد الرسالة الموجهة للاتصال."
        }
      }
    },
    "kresus": {
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق محفظة Kresus",
          "description": "أضف محفظة Kresus إلى الشاشة الرئيسية للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "أنشئ محفظة جديدة أو استورد واحدة موجودة بالفعل."
        },
        "step3": {
          "title": "اضغط على أيقونة الرمز الاستجابة السريعة وامسحها",
          "description": "اضغط على أيقونة QR على الشاشة الرئيسية، قراءة الرمز وتأكيد الرسالة الموجهة للاتصال."
        }
      }
    },
    "magicEden": {
      "extension": {
        "step1": {
          "title": "قم بتثبيت إضافة Magic Eden",
          "description": "نوصي بتثبيت Magic Eden على شريط المهام للوصول الأسهل إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "تأكد من نسخ محفظتك احتياطيًا باستخدام طريقة آمنة. لا تشارك عبارة الاستعادة السرية الخاصة بك مع أي شخص."
        },
        "step3": {
          "title": "قم بتحديث متصفحك",
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الامتداد."
        }
      }
    },
    "metamask": {
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق MetaMask",
          "description": "نوصي بوضع MetaMask على الشاشة الرئيسية لديك للوصول بشكل أسرع."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "تأكد من نسخ الحفاظ على محفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص."
        },
        "step3": {
          "title": "اضغط على زر المسح",
          "description": "بعد الفحص، ستظهر لك موجه اتصال لتوصيل محفظتك."
        }
      },
      "extension": {
        "step1": {
          "title": "قم بتثبيت امتداد MetaMask",
          "description": "نوصي بتثبيت MetaMask في شريط المهام للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "تأكد من نسخ احتياطي لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص."
        },
        "step3": {
          "title": "تحديث متصفحك",
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الامتداد."
        }
      }
    },
    "nestwallet": {
      "extension": {
        "step1": {
          "title": "قم بتثبيت امتداد NestWallet",
          "description": "نوصي بتثبيت NestWallet على شريط المهام للوصول السريع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "تأكد من عمل نسخة احتياطية لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أحد."
        },
        "step3": {
          "title": "قم بتحديث متصفحك",
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الامتداد."
        }
      }
    },
    "okx": {
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق محفظة OKX",
          "description": "نوصي بوضع محفظة OKX على الشاشة الرئيسية للوصول الأسرع."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "تأكد من نسخ احتياطي لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص."
        },
        "step3": {
          "title": "اضغط على زر المسح",
          "description": "بعد الفحص، ستظهر لك مطالبة بالاتصال لتوصيل محفظتك."
        }
      },
      "extension": {
        "step1": {
          "title": "قم بتثبيت امتداد محفظة OKX",
          "description": "نوصي بتثبيت محفظة OKX على شريط المهام للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "تأكد من حفظ نسخة احتياطية من محفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص."
        },
        "step3": {
          "title": "قم بتحديث المتصفح الخاص بك",
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الإضافة."
        }
      }
    },
    "omni": {
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق Omni",
          "description": "أضف Omni إلى شاشتك الرئيسية للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "إنشاء محفظة جديدة أو استيراد واحدة موجودة."
        },
        "step3": {
          "title": "اضغط على أيقونة الرمز الاستجابة السريعة وامسحها",
          "description": "اضغط على الرمز QR على الشاشة الرئيسية الخاصة بك، امسح الرمز وأكد الموافقة للاتصال."
        }
      }
    },
    "1inch": {
      "qr_code": {
        "step1": {
          "description": "ضع محفظة 1inch على شاشتك الرئيسية للوصول الأسرع إلى محفظتك.",
          "title": "افتح تطبيق محفظة 1inch"
        },
        "step2": {
          "description": "أنشئ محفظة واسم مستخدم، أو استورد محفظة موجودة بالفعل.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بعد الفحص، سيظهر لك موجه الاتصال لتوصيل المحفظة الخاصة بك.",
          "title": "اضغط على زر فحص الكود الشريطي"
        }
      }
    },
    "token_pocket": {
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق TokenPocket",
          "description": "نوصي بوضع TokenPocket على الشاشة الرئيسية للوصول السريع."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "تأكد من نسخ احتياطي لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص."
        },
        "step3": {
          "title": "اضغط على زر المسح",
          "description": "بعد الفحص، ستظهر لك رسالة موجهة للاتصال بمحفظتك."
        }
      },
      "extension": {
        "step1": {
          "title": "قم بتثبيت امتداد TokenPocket",
          "description": "نوصي بتثبيت TokenPocket على شريط المهام الخاص بك للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "قم بإنشاء محفظة أو استيراد محفظة",
          "description": "تأكد من الاحتفاظ بنسخة احتياطية من محفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص."
        },
        "step3": {
          "title": "قم بتحديث المتصفح الخاص بك",
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الإضافة."
        }
      }
    },
    "trust": {
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق Trust Wallet",
          "description": "ضع Trust Wallet على الشاشة الرئيسية للوصول السريع إلى محفظتك."
        },
        "step2": {
          "title": "أنشئ محفظة أو استورد محفظة",
          "description": "أنشئ محفظة جديدة أو استورد واحدة موجودة."
        },
        "step3": {
          "title": "اضغط على WalletConnect في الإعدادات",
          "description": "اختر الاتصال الجديد، ثم امسح الرمز الشريطي QR وأكد الموجه للاتصال."
        }
      },
      "extension": {
        "step1": {
          "title": "قم بتثبيت امتداد Trust Wallet",
          "description": "انقر في الجزء العلوي الأيمن من المتصفح وثبت Trust Wallet للوصول بسهولة."
        },
        "step2": {
          "title": "أنشئ محفظة أو استورد محفظة",
          "description": "أنشئ محفظة جديدة أو استورد واحدة موجودة."
        },
        "step3": {
          "title": "قم بتحديث متصفحك",
          "description": "بمجرد إعداد Trust Wallet، انقر أدناه لتحديث المتصفح وتحميل الإضافة."
        }
      }
    },
    "uniswap": {
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق Uniswap",
          "description": "أضف محفظة Uniswap إلى شاشة الرئيسية للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "قم بإنشاء محفظة جديدة أو استيراد واحدة موجودة."
        },
        "step3": {
          "title": "اضغط على الأيقونة QR واقرأ الرمز",
          "description": "اضغط على أيقونة QR على الشاشة الرئيسية، قراءة الرمز وتأكيد الرسالة الموجهة للاتصال."
        }
      }
    },
    "zerion": {
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق Zerion",
          "description": "نوصي بوضع Zerion على شاشتك الرئيسية للوصول الأسرع."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "تأكد من حفظ نسخة احتياطية من محفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص."
        },
        "step3": {
          "title": "اضغط على زر المسح",
          "description": "بعد المسح، سوف يظهر لك نافذة الاتصال لتوصيل محفظتك."
        }
      },
      "extension": {
        "step1": {
          "title": "تثبيت امتداد Zerion",
          "description": "نوصي بتثبيت Zerion على شريط المهام الخاص بك للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "تأكد من الاحتفاظ بنسخة احتياطية من محفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص."
        },
        "step3": {
          "title": "قم بتحديث المتصفح الخاص بك",
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الإضافة."
        }
      }
    },
    "rainbow": {
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق Rainbow",
          "description": "نوصي بوضع Rainbow على شاشة البداية للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء محفظة أو استيراد محفظة",
          "description": "يمكنك عمل نسخة احتياطية بسهولة لمحفظتك باستخدام ميزة النسخ الاحتياطي على هاتفك."
        },
        "step3": {
          "title": "اضغط على الزر الماسح الضوئي",
          "description": "بعد الفحص، سيظهر لك موجه اتصال لربط محفظتك."
        }
      }
    },
    "enkrypt": {
      "extension": {
        "step1": {
          "description": "نوصي بتثبيت محفظة Enkrypt على شريط المهام الخاص بك للوصول الأسرع إلى محفظتك.",
          "title": "تثبيت امتداد محفظة Enkrypt"
        },
        "step2": {
          "description": "تأكد من عمل نسخة احتياطية لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص.",
          "title": "أنشئ أو استورد محفظة"
        },
        "step3": {
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الإضافة.",
          "title": "حدث المتصفح الخاص بك"
        }
      }
    },
    "frame": {
      "extension": {
        "step1": {
          "description": "نوصي بتعليق Frame على شريط المهام للوصول السريع إلى محفظتك.",
          "title": "ثبت Frame والإضافة المصاحبة"
        },
        "step2": {
          "description": "تأكد من النسخ الاحتياطي لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص.",
          "title": "أنشئ أو استورد محفظة"
        },
        "step3": {
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الإضافة.",
          "title": "حدث المتصفح الخاص بك"
        }
      }
    },
    "one_key": {
      "extension": {
        "step1": {
          "title": "قم بتثبيت امتداد محفظة OneKey",
          "description": "نوصي بتثبيت محفظة OneKey على شريط المهام للوصول السريع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "تأكد من نسخ احتياطي لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص."
        },
        "step3": {
          "title": "تحديث المتصفح الخاص بك",
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الامتداد."
        }
      }
    },
    "phantom": {
      "extension": {
        "step1": {
          "title": "قم بتثبيت امتداد Phantom",
          "description": "نوصي بتثبيت Phantom على شريط المهام للوصول الأسهل إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "تأكد من نسخ محفظتك احتياطيًا باستخدام طريقة آمنة. لا تشارك عبارة الاستعادة السرية الخاصة بك مع أي شخص."
        },
        "step3": {
          "title": "قم بتحديث المتصفح",
          "description": "بمجرد إعداد المحفظة، انقر أدناه لتحديث المتصفح وتحميل الإضافة."
        }
      }
    },
    "rabby": {
      "extension": {
        "step1": {
          "title": "ثبت امتداد Rabby",
          "description": "نوصي بتثبيت Rabby على شريط المهام للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "أنشئ محفظة أو استورد محفظة",
          "description": "تأكد من نسخ محفظتك احتياطيًا باستخدام طريقة آمنة. لا تشارك العبارة السرية مع أي شخص."
        },
        "step3": {
          "title": "قم بتحديث المتصفح",
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الإضافة."
        }
      }
    },
    "ronin": {
      "qr_code": {
        "step1": {
          "description": "نوصي بوضع محفظة Ronin على الشاشة الرئيسية للوصول الأسرع.",
          "title": "افتح تطبيق محفظة Ronin"
        },
        "step2": {
          "description": "تأكد من عمل نسخة احتياطية لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أحد.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بعد الفحص، سيظهر لك موجه الاتصال لتوصيل المحفظة الخاصة بك.",
          "title": "اضغط على زر المسح"
        }
      },
      "extension": {
        "step1": {
          "description": "نوصي بتثبيت محفظة Ronin على شريط المهام للوصول الأسرع إلى محفظتك.",
          "title": "ثبّت امتداد محفظة Ronin"
        },
        "step2": {
          "description": "تأكد من عمل نسخة احتياطية لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أحد.",
          "title": "إنشاء أو استيراد محفظة"
        },
        "step3": {
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الامتداد.",
          "title": "قم بتحديث متصفحك"
        }
      }
    },
    "ramper": {
      "extension": {
        "step1": {
          "title": "ثبّت امتداد Ramper",
          "description": "نوصي بتثبيت Ramper على شريط المهام لسهولة الوصول إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء محفظة",
          "description": "تأكد من عمل نسخة احتياطية لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أحد."
        },
        "step3": {
          "title": "قم بتحديث متصفحك",
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الامتداد."
        }
      }
    },
    "safeheron": {
      "extension": {
        "step1": {
          "title": "قم بتثبيت إضافة النواة",
          "description": "نوصي بتثبيت Safeheron على شريط المهام الخاص بك للوصول السريع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "تأكد من نسخ محفظتك بطريقة آمنة. لا تشارك عبارتك السرية مع أي شخص."
        },
        "step3": {
          "title": "تحديث المتصفح الخاص بك",
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الإضافة."
        }
      }
    },
    "taho": {
      "extension": {
        "step1": {
          "title": "تثبيت إضافة Taho",
          "description": "نوصي بتثبيت Taho على شريط المهام الخاص بك للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء محفظة أو استيراد محفظة",
          "description": "تأكد من النسخ الاحتياطي لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أي شخص."
        },
        "step3": {
          "title": "تحديث المتصفح الخاص بك",
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الإضافة."
        }
      }
    },
    "talisman": {
      "extension": {
        "step1": {
          "title": "تثبيت إضافة Talisman",
          "description": "نوصي بتثبيت Talisman على شريط المهام الخاص بك للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء محفظة Ethereum أو استيرادها",
          "description": "تأكد من النسخ الاحتياطي لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارة الاستعادة الخاصة بك مع أي شخص."
        },
        "step3": {
          "title": "قم بتحديث المستعرض الخاص بك",
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المستعرض وتحميل الإضافة."
        }
      }
    },
    "xdefi": {
      "extension": {
        "step1": {
          "title": "قم بتثبيت إضافة XDEFI Wallet",
          "description": "نوصي بتثبيت XDEFI Wallet على شريط المهام للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "أنشئ محفظة أو استورد محفظة",
          "description": "تأكد من النسخ الاحتياطي لمحفظتك باستخدام طريقة آمنة. لا تشارك العبارة السرية الخاصة بك مع أي شخص."
        },
        "step3": {
          "title": "قم بتحديث المستعرض الخاص بك",
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الإضافة."
        }
      }
    },
    "zeal": {
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق Zeal",
          "description": "أضف محفظة Zeal إلى الشاشة الرئيسية للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "أنشئ محفظة جديدة أو استورد واحدة موجودة بالفعل."
        },
        "step3": {
          "title": "اضغط على أيقونة الرمز الاستجابة السريعة وامسحها",
          "description": "اضغط على أيقونة QR على الشاشة الرئيسية، قراءة الرمز وتأكيد الرسالة الموجهة للاتصال."
        }
      },
      "extension": {
        "step1": {
          "title": "قم بتثبيت امتداد Zeal",
          "description": "نوصي بتثبيت Zeal في شريط المهام الخاص بك للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "تأكد من عمل نسخة احتياطية لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أحد."
        },
        "step3": {
          "title": "قم بتحديث متصفحك",
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الامتداد."
        }
      }
    },
    "safepal": {
      "extension": {
        "step1": {
          "title": "قم بتثبيت صيغة SafePal Wallet",
          "description": "انقر في أعلى يمين المتصفح وثبت صيغة SafePal Wallet لسهولة الوصول."
        },
        "step2": {
          "title": "أنشئ محفظة أو استورد محفظة",
          "description": "أنشئ محفظة جديدة أو استورد واحدة موجودة بالفعل."
        },
        "step3": {
          "title": "قم بتحديث متصفحك",
          "description": "بمجرد إعداد محفظة SafePal، انقر أدناه لتحديث المتصفح وتحميل الإضافة."
        }
      },
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق محفظة SafePal",
          "description": "ضع محفظة SafePal على شاشة الرئيسية لسهولة الوصول إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "أنشئ محفظة جديدة أو استورد واحدة موجودة بالفعل."
        },
        "step3": {
          "title": "اضغط على WalletConnect في الإعدادات",
          "description": "اختر الاتصال الجديد، ثم امسح الرمز الشريطي وأكد الموجه للاتصال."
        }
      }
    },
    "desig": {
      "extension": {
        "step1": {
          "title": "قم بتثبيت إضافة Desig",
          "description": "نوصي بتثبيت Desig على شريط المهام الخاص بك للوصول الأسهل إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء محفظة",
          "description": "تأكد من عمل نسخة احتياطية لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أحد."
        },
        "step3": {
          "title": "قم بتحديث متصفحك",
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الامتداد."
        }
      }
    },
    "subwallet": {
      "extension": {
        "step1": {
          "title": "قم بتثبيت إضافة SubWallet",
          "description": "نوصي بتثبيت SubWallet على شريط المهام الخاص بك للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "تأكد من النسخ الاحتياطي لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارة الاستعادة الخاصة بك مع أي شخص."
        },
        "step3": {
          "title": "قم بتحديث متصفحك",
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الامتداد."
        }
      },
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق SubWallet",
          "description": "نوصي بوضع SubWallet على شاشة الرئيسية الخاصة بك للوصول الأسرع."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "تأكد من عمل نسخة احتياطية لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أحد."
        },
        "step3": {
          "title": "اضغط على زر المسح",
          "description": "بعد الفحص، سيظهر لك موجه الاتصال لتوصيل المحفظة الخاصة بك."
        }
      }
    },
    "clv": {
      "extension": {
        "step1": {
          "title": "قم بتثبيت إضافة CLV Wallet",
          "description": "نوصي بتثبيت CLV Wallet على شريط المهام الخاص بك للوصول الأسرع إلى محفظتك."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "تأكد من عمل نسخة احتياطية لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أحد."
        },
        "step3": {
          "title": "قم بتحديث متصفحك",
          "description": "بمجرد إعداد محفظتك، انقر أدناه لتحديث المتصفح وتحميل الامتداد."
        }
      },
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق محفظة CLV",
          "description": "نوصي بوضع محفظة CLV على الشاشة الرئيسية للوصول الأسرع."
        },
        "step2": {
          "title": "إنشاء أو استيراد محفظة",
          "description": "تأكد من عمل نسخة احتياطية لمحفظتك باستخدام طريقة آمنة. لا تشارك عبارتك السرية مع أحد."
        },
        "step3": {
          "title": "اضغط على زر المسح",
          "description": "بعد الفحص، سيظهر لك موجه الاتصال لتوصيل المحفظة الخاصة بك."
        }
      }
    },
    "okto": {
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق Okto",
          "description": "أضف Okto إلى الشاشة الرئيسية للوصول السريع"
        },
        "step2": {
          "title": "أنشئ محفظة MPC",
          "description": "أنشئ حسابًا وقم بإنشاء محفظة"
        },
        "step3": {
          "title": "اضغط على WalletConnect في الإعدادات",
          "description": "اضغط على أيقونة فحص الشاشة في الجهة العليا اليمنى وأكد الإدخال للاتصال."
        }
      }
    },
    "ledger": {
      "desktop": {
        "step1": {
          "title": "افتح تطبيق Ledger Live",
          "description": "نوصي بوضع Ledger Live على شاشة الرئيسية لديك لسرعة الوصول."
        },
        "step2": {
          "title": "قم بإعداد Ledger الخاص بك",
          "description": "قم بإعداد Ledger جديد أو قم بالاتصال بواحد موجود ."
        },
        "step3": {
          "title": "اتصل",
          "description": "بعد المسح، سوف يظهر لك نافذة الاتصال لتوصيل محفظتك."
        }
      },
      "qr_code": {
        "step1": {
          "title": "افتح تطبيق Ledger Live",
          "description": "نوصي بوضع Ledger Live على شاشة الرئيسية لديك لسرعة الوصول."
        },
        "step2": {
          "title": "قم بإعداد Ledger الخاص بك",
          "description": "يمكنك إما المزامنة مع تطبيق سطح المكتب أو توصيل Ledger الخاص بك."
        },
        "step3": {
          "title": "مسح الرمز",
          "description": "اضغط على WalletConnect ثم انتقل إلى الفحص. بعد المسح، سوف يظهر لك نافذة الاتصال لتوصيل محفظتك."
        }
      }
    }
  }
}
`;export{u as default};
