var u=`{
  "connect_wallet": {
    "label": "連接錢包",
    "wrong_network": {
      "label": "錯誤的網絡"
    }
  },
  "intro": {
    "title": "錢包是什麼？",
    "description": "錢包可以用來發送、接收、存儲和顯示數字資產。這也是一種新的登錄方式，不需要在每個網站上創建新的賬號和密碼。",
    "digital_asset": {
      "title": "您的數字資產之家",
      "description": "錢包可用於發送、接收、存儲和顯示數字資產，例如以太坊和NFT。"
    },
    "login": {
      "title": "一種新的登錄方式",
      "description": "無需在每個網站上創建新的賬號和密碼，只需連接您的錢包。"
    },
    "get": {
      "label": "獲取錢包"
    },
    "learn_more": {
      "label": "了解更多"
    }
  },
  "sign_in": {
    "label": "驗證你的賬戶",
    "description": "要完成連接，你必須在錢包中簽署一條消息，以驗證你是這個賬戶的擁有者。",
    "message": {
      "send": "簽署消息",
      "preparing": "正在準備消息...",
      "cancel": "取消",
      "preparing_error": "準備消息時出錯，請重試！"
    },
    "signature": {
      "waiting": "等待簽名...",
      "verifying": "驗證簽名中...",
      "signing_error": "簽署消息時出錯，請重試！",
      "verifying_error": "驗證簽名時出錯，請重試！",
      "oops_error": "哦，出了點問題！"
    }
  },
  "connect": {
    "label": "連接",
    "title": "連接錢包",
    "new_to_ethereum": {
      "description": "新手入門以太坊錢包？",
      "learn_more": {
        "label": "了解更多"
      }
    },
    "learn_more": {
      "label": "了解更多"
    },
    "recent": "最近",
    "status": {
      "opening": "正在開啟%{wallet}...",
      "connecting": "連接中",
      "connect_mobile": "繼續在 %{wallet} 中操作",
      "not_installed": "%{wallet} 尚未安裝",
      "not_available": "%{wallet} 不可用",
      "confirm": "在擴展程序中確認連接",
      "confirm_mobile": "在錢包中接受連接請求"
    },
    "secondary_action": {
      "get": {
        "description": "沒有%{wallet}？",
        "label": "獲取"
      },
      "install": {
        "label": "安裝"
      },
      "retry": {
        "label": "重試"
      }
    },
    "walletconnect": {
      "description": {
        "full": "需要官方的WalletConnect模態框嗎？",
        "compact": "需要WalletConnect模態框嗎？"
      },
      "open": {
        "label": "開啟"
      }
    }
  },
  "connect_scan": {
    "title": "用 %{wallet} 掃描",
    "fallback_title": "用你的手機掃描"
  },
  "connector_group": {
    "installed": "已安裝",
    "recommended": "推荐",
    "other": "其他",
    "popular": "流行",
    "more": "更多",
    "others": "其他"
  },
  "get": {
    "title": "獲取錢包",
    "action": {
      "label": "獲取"
    },
    "mobile": {
      "description": "手機錢包"
    },
    "extension": {
      "description": "瀏覽器擴展"
    },
    "mobile_and_extension": {
      "description": "手機錢包和擴展"
    },
    "mobile_and_desktop": {
      "description": "行動裝置和桌面錢包"
    },
    "looking_for": {
      "title": "找不到你想要的？",
      "mobile": {
        "description": "在主屏幕上選擇一個錢包，以開始使用不同的錢包提供商。"
      },
      "desktop": {
        "compact_description": "在主屏幕上選擇一個錢包，以開始使用不同的錢包提供商。",
        "wide_description": "在左邊選擇一個錢包，以開始使用不同的錢包提供商。"
      }
    }
  },
  "get_options": {
    "title": "開始使用%{wallet}",
    "short_title": "獲取%{wallet}",
    "mobile": {
      "title": "%{wallet} 手機版",
      "description": "使用手機錢包探索以太坊的世界。",
      "download": {
        "label": "獲取應用"
      }
    },
    "extension": {
      "title": "%{wallet} 適用於 %{browser}",
      "description": "直接從您喜愛的網頁瀏覽器中訪問您的錢包。",
      "download": {
        "label": "添加到%{browser}"
      }
    },
    "desktop": {
      "title": "%{wallet} 用於 %{platform}",
      "description": "從強大的桌面上本地訪問你的錢包。",
      "download": {
        "label": "添加到 %{platform}"
      }
    }
  },
  "get_mobile": {
    "title": "安裝%{wallet}",
    "description": "用你的手機掃描以下載iOS或Android版本",
    "continue": {
      "label": "繼續"
    }
  },
  "get_instructions": {
    "mobile": {
      "connect": {
        "label": "連接"
      },
      "learn_more": {
        "label": "了解更多"
      }
    },
    "extension": {
      "refresh": {
        "label": "刷新"
      },
      "learn_more": {
        "label": "了解更多"
      }
    },
    "desktop": {
      "connect": {
        "label": "連接"
      },
      "learn_more": {
        "label": "了解更多"
      }
    }
  },
  "chains": {
    "title": "切換網絡",
    "wrong_network": "檢測到錯誤的網絡，請切換或斷開連接以繼續。",
    "confirm": "在錢包中確認",
    "switching_not_supported": "您的錢包不支持從 %{appName} 切換網絡。請嘗試在您的錢包內切換網絡。",
    "switching_not_supported_fallback": "您的錢包不支持從此應用切換網絡。請嘗試在您的錢包內切換網絡。",
    "disconnect": "斷開連接",
    "connected": "已連接"
  },
  "profile": {
    "disconnect": {
      "label": "斷開連接"
    },
    "copy_address": {
      "label": "複製地址",
      "copied": "已複製!"
    },
    "explorer": {
      "label": "在探勘器查看更多"
    },
    "transactions": {
      "description": "%{appName} 的交易將會顯示在這裡...",
      "description_fallback": "您的交易將會顯示在這裡...",
      "recent": {
        "title": "最近的交易"
      },
      "clear": {
        "label": "清除所有"
      }
    }
  },
  "wallet_connectors": {
    "argent": {
      "qr_code": {
        "step1": {
          "description": "將 Argent 加到你的主畫面以快速訪問你的錢包。",
          "title": "打開 Argent 應用程式"
        },
        "step2": {
          "description": "創建一個錢包和用戶名，或導入現有的錢包。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。",
          "title": "點擊掃瞄 QR 按鈕"
        }
      }
    },
    "bifrost": {
      "qr_code": {
        "step1": {
          "description": "我們建議將 Bifrost Wallet 加到你的主畫面，以便更快訪問。",
          "title": "打開 Bifrost Wallet 應用程式"
        },
        "step2": {
          "description": "使用你的恢覆短語創建或導入錢包。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。",
          "title": "點擊掃描按鈕"
        }
      }
    },
    "bitget": {
      "qr_code": {
        "step1": {
          "description": "我們建議將 Bitget Wallet 加到你的主畫面，以便更快訪問。",
          "title": "打開 Bitget Wallet 應用程式"
        },
        "step2": {
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。",
          "title": "點擊掃描按鈕"
        }
      },
      "extension": {
        "step1": {
          "description": "我們建議將 Bitget Wallet 固定到你的任務欄上，以便更快訪問你的錢包。",
          "title": "安裝 Bitget Wallet 擴展"
        },
        "step2": {
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。",
          "title": "刷新你的瀏覽器"
        }
      }
    },
    "bitski": {
      "extension": {
        "step1": {
          "description": "我們建議將 Bitski 固定到你的任務欄上，以便更快訪問你的錢包。",
          "title": "安裝 Bitski 擴展"
        },
        "step2": {
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。",
          "title": "刷新你的瀏覽器"
        }
      }
    },
    "bitverse": {
      "qr_code": {
        "step1": {
          "title": "開啟 Bitverse Wallet 應用程式",
          "description": "新增 Bitverse Wallet 至你的主畫面，便可以更快存取你的電子錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "創建新的錢包或導入現有的錢包。"
        },
        "step3": {
          "title": "點擊二維碼圖示並掃描",
          "description": "點擊主畫面上的二維碼圖示，掃描代碼並確認提示以連接。"
        }
      }
    },
    "bloom": {
      "desktop": {
        "step1": {
          "title": "打開 Bloom Wallet 應用程式",
          "description": "我們建議將 Bloom Wallet 放置在你的主畫面，以便更快地訪問。"
        },
        "step2": {
          "description": "使用你的恢覆短語創建或導入錢包。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "擁有錢包後，點擊連接以通過 Bloom 連接。應用程式中將會出現一個連接提示讓你確認連接。",
          "title": "點擊連接"
        }
      },
      "qr_code": {
        "step1": {
          "title": "打開 Bloom Wallet 應用程式",
          "description": "我們建議將 Bloom Wallet 放置在你的主畫面，以便更快地訪問。"
        },
        "step2": {
          "description": "使用你的恢覆短語創建或導入錢包。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "擁有錢包後，點擊連接以通過 Bloom 連接。應用程式中將會出現一個連接提示讓你確認連接。",
          "title": "點擊連接"
        }
      }
    },
    "bybit": {
      "qr_code": {
        "step1": {
          "description": "我們建議將 Bybit 放在主畫面，便可以更快存取你的電子錢包。",
          "title": "開啟 Bybit 應用程式"
        },
        "step2": {
          "description": "你可以使用我們的備份功能在手機上輕鬆備份你的錢包。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。",
          "title": "點擊掃描按鈕"
        }
      },
      "extension": {
        "step1": {
          "description": "點擊瀏覽器右上角，並將 Bybit Wallet 釘起來，以便輕鬆存取。",
          "title": "安裝 Bybit Wallet 擴充功能"
        },
        "step2": {
          "description": "創建新的錢包或導入現有的錢包。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "設置 Bybit Wallet 後，點擊下方刷新瀏覽器，並加載擴充功能。",
          "title": "刷新你的瀏覽器"
        }
      }
    },
    "binance": {
      "qr_code": {
        "step1": {
          "description": "我們建議將 Binance 放在主畫面，便可以更快存取你的電子錢包。",
          "title": "開啟 Binance 應用程式"
        },
        "step2": {
          "description": "你可以使用我們的備份功能在手機上輕鬆備份你的錢包。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。",
          "title": "點擊 WalletConnect 按鈕"
        }
      }
    },
    "coin98": {
      "qr_code": {
        "step1": {
          "description": "我們建議將 Coin98 Wallet 加到你的主畫面，以便更快訪問你的錢包。",
          "title": "打開 Coin98 Wallet 應用程式"
        },
        "step2": {
          "description": "你可以使用我們的備份功能在手機上輕鬆備份你的錢包。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。",
          "title": "點擊 WalletConnect 按鈕"
        }
      },
      "extension": {
        "step1": {
          "description": "點擊瀏覽器右上角並固定 Coin98 Wallet 以便訪問。",
          "title": "安裝 Coin98 Wallet 擴展"
        },
        "step2": {
          "description": "創建新的錢包或導入現有的錢包。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "設置好 Coin98 Wallet 後，點擊下方按鈕刷新瀏覽器並載入擴展。",
          "title": "刷新你的瀏覽器"
        }
      }
    },
    "coinbase": {
      "qr_code": {
        "step1": {
          "description": "我們建議將 Coinbase Wallet 加到你的主畫面，以便更快訪問。",
          "title": "打開 Coinbase Wallet 應用程式"
        },
        "step2": {
          "description": "你可以使用雲端備份功能輕鬆備份你的錢包。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。",
          "title": "點擊掃描按鈕"
        }
      },
      "extension": {
        "step1": {
          "description": "我們建議將 Coinbase Wallet 固定到你的任務欄上，以便更快訪問你的錢包。",
          "title": "安裝 Coinbase Wallet 擴展"
        },
        "step2": {
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。",
          "title": "刷新你的瀏覽器"
        }
      }
    },
    "compass": {
      "extension": {
        "step1": {
          "description": "我們建議將 Compass Wallet 釘在工作列上，便可以更快存取你的電子錢包。",
          "title": "安裝 Compass Wallet 擴充功能"
        },
        "step2": {
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。",
          "title": "刷新你的瀏覽器"
        }
      }
    },
    "core": {
      "qr_code": {
        "step1": {
          "description": "我們建議將 Core 加到你的主畫面，以便更快訪問你的錢包。",
          "title": "打開 Core 應用程式"
        },
        "step2": {
          "description": "你可以使用我們的備份功能在手機上輕鬆備份你的錢包。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。",
          "title": "點擊 WalletConnect 按鈕"
        }
      },
      "extension": {
        "step1": {
          "description": "我們建議將 Core 釘在你的工作列，以便更快捷地存取你的錢包。",
          "title": "安裝 Core 擴充套件"
        },
        "step2": {
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。",
          "title": "刷新你的瀏覽器"
        }
      }
    },
    "fox": {
      "qr_code": {
        "step1": {
          "description": "我們建議將 FoxWallet 放在你的主畫面上，以方便更快地存取。",
          "title": "打開 FoxWallet 應用程式"
        },
        "step2": {
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。",
          "title": "點擊掃描按鈕"
        }
      }
    },
    "frontier": {
      "qr_code": {
        "step1": {
          "description": "我們建議將 Frontier Wallet 放在你的主畫面上，以便更快捷地存取。",
          "title": "打開 Frontier Wallet 應用程式"
        },
        "step2": {
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。",
          "title": "點擊掃描按鈕"
        }
      },
      "extension": {
        "step1": {
          "description": "我們建議將 Frontier Wallet 釘在你的工作列，以便更快捷地存取你的錢包。",
          "title": "安裝 Frontier Wallet 擴充套件"
        },
        "step2": {
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。",
          "title": "刷新你的瀏覽器"
        }
      }
    },
    "im_token": {
      "qr_code": {
        "step1": {
          "title": "打開 imToken 應用程式",
          "description": "將 imToken 應用程式放在你的主畫面上，以便更快捷地存取你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "創建新的錢包或導入現有的錢包。"
        },
        "step3": {
          "title": "點擊右上角的掃描圖示",
          "description": "選擇新連接，然後掃描二維碼並確認提示以連接。"
        }
      }
    },
    "iopay": {
      "qr_code": {
        "step1": {
          "description": "我們建議將 ioPay 放在主畫面，便可以更快存取你的電子錢包。",
          "title": "開啟 ioPay 應用程式"
        },
        "step2": {
          "description": "你可以使用我們的備份功能在手機上輕鬆備份你的錢包。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。",
          "title": "點擊 WalletConnect 按鈕"
        }
      }
    },
    "kaikas": {
      "extension": {
        "step1": {
          "description": "我們建議將 Kaikas 釘在工作列上，便可以更快存取你的電子錢包。",
          "title": "安裝 Kaikas 擴充功能"
        },
        "step2": {
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。",
          "title": "刷新你的瀏覽器"
        }
      },
      "qr_code": {
        "step1": {
          "title": "開啟 Kaikas 應用程式",
          "description": "將 Kaikas 應用程式放在主畫面，便可以更快存取你的電子錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "創建新的錢包或導入現有的錢包。"
        },
        "step3": {
          "title": "點擊右上角的掃描圖示",
          "description": "選擇新連接，然後掃描二維碼並確認提示以連接。"
        }
      }
    },
    "kaia": {
      "extension": {
        "step1": {
          "description": "我們建議將 Kaia 釘在工作列上，便可以更快存取你的電子錢包。",
          "title": "安裝 Kaia 擴充功能"
        },
        "step2": {
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。",
          "title": "刷新你的瀏覽器"
        }
      },
      "qr_code": {
        "step1": {
          "title": "打開 Kaia 應用程式",
          "description": "將 Kaia 應用程式放在主畫面，以便更快訪問你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "創建新的錢包或導入現有的錢包。"
        },
        "step3": {
          "title": "點擊右上角的掃描圖示",
          "description": "選擇新連接，然後掃描二維碼並確認提示以連接。"
        }
      }
    },
    "kraken": {
      "qr_code": {
        "step1": {
          "title": "開啟 Kraken Wallet 應用程式",
          "description": "新增 Kraken Wallet 至你的主畫面，便可以更快存取你的電子錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "創建新的錢包或導入現有的錢包。"
        },
        "step3": {
          "title": "點擊二維碼圖示並掃描",
          "description": "點擊主畫面上的二維碼圖示，掃描代碼並確認提示以連接。"
        }
      }
    },
    "kresus": {
      "qr_code": {
        "step1": {
          "title": "開啟 Kresus Wallet 應用程式",
          "description": "新增 Kresus Wallet 至你的主畫面，便可以更快存取你的電子錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "創建新的錢包或導入現有的錢包。"
        },
        "step3": {
          "title": "點擊二維碼圖示並掃描",
          "description": "點擊主畫面上的二維碼圖示，掃描代碼並確認提示以連接。"
        }
      }
    },
    "magicEden": {
      "extension": {
        "step1": {
          "title": "安裝 Magic Eden 擴充功能",
          "description": "我們建議將 Magic Eden 釘在工作列上，便可以更容易存取你的電子錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保用安全的方法備份你的錢包。絕不與任何人分享你的秘密恢復詞。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      }
    },
    "metamask": {
      "qr_code": {
        "step1": {
          "title": "打開 MetaMask 應用程式",
          "description": "我們建議將 MetaMask 放在你的主畫面上，以便更快捷地存取。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "點擊掃描按鈕",
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。"
        }
      },
      "extension": {
        "step1": {
          "title": "安裝 MetaMask 擴充套件",
          "description": "我們建議將 MetaMask 釘在你的工作列，以便更快捷地存取你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      }
    },
    "nestwallet": {
      "extension": {
        "step1": {
          "title": "安裝 NestWallet 擴充功能",
          "description": "我們建議將 NestWallet 釘在工作列上，便可以更快存取你的電子錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      }
    },
    "okx": {
      "qr_code": {
        "step1": {
          "title": "打開 OKX Wallet 應用程式",
          "description": "我們建議將 OKX Wallet 放在你的主畫面上，以便更快捷地存取。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "點擊掃描按鈕",
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。"
        }
      },
      "extension": {
        "step1": {
          "title": "安裝 OKX Wallet 擴充套件",
          "description": "我們建議將 OKX Wallet 釘在你的工作列，以便更快捷地存取你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      }
    },
    "omni": {
      "qr_code": {
        "step1": {
          "title": "打開 Omni 應用程式",
          "description": "將 Omni 加到你的主畫面上，以便更快捷地存取你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "創建新的錢包或導入現有的錢包。"
        },
        "step3": {
          "title": "點擊二維碼圖示並掃描",
          "description": "點擊主畫面上的二維碼圖示，掃描代碼並確認提示以連接。"
        }
      }
    },
    "1inch": {
      "qr_code": {
        "step1": {
          "description": "將 1inch Wallet 放在主畫面，便可以更快存取你的電子錢包。",
          "title": "開啟 1inch Wallet 應用程式"
        },
        "step2": {
          "description": "創建一個錢包和用戶名，或導入現有的錢包。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。",
          "title": "點擊掃瞄 QR 按鈕"
        }
      }
    },
    "token_pocket": {
      "qr_code": {
        "step1": {
          "title": "打開 TokenPocket 應用程式",
          "description": "我們建議將 TokenPocket 放在你的主畫面上，以便更快捷地存取。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "點擊掃描按鈕",
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。"
        }
      },
      "extension": {
        "step1": {
          "title": "安裝 TokenPocket 擴充套件",
          "description": "我們建議將 TokenPocket 釘在你的工作列，以便更快捷地存取你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      }
    },
    "trust": {
      "qr_code": {
        "step1": {
          "title": "打開 Trust Wallet 應用程式",
          "description": "將 Trust Wallet 放在你的主畫面上，以便更快捷地存取你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "創建新的錢包或導入現有的錢包。"
        },
        "step3": {
          "title": "在設定中點擊 WalletConnect",
          "description": "選擇新連接，然後掃描二維碼並確認提示以連接。"
        }
      },
      "extension": {
        "step1": {
          "title": "安裝 Trust Wallet 擴充套件",
          "description": "點擊瀏覽器右上角，然後釘上 Trust Wallet 以便輕鬆存取。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "創建新的錢包或導入現有的錢包。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設定 Trust Wallet 後，點擊下方以重新整理瀏覽器並加載擴充套件。"
        }
      }
    },
    "uniswap": {
      "qr_code": {
        "step1": {
          "title": "打開 Uniswap 應用程式",
          "description": "將 Uniswap Wallet 加到你的主畫面上，以便更快捷地存取你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "創建新的錢包或導入現有的錢包。"
        },
        "step3": {
          "title": "點擊二維碼圖示並掃描",
          "description": "點擊主畫面上的二維碼圖示，掃描代碼並確認提示以連接。"
        }
      }
    },
    "zerion": {
      "qr_code": {
        "step1": {
          "title": "打開 Zerion 應用程式",
          "description": "我們建議把 Zerion 放在主頁上以便更快捷地進入。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "點擊掃描按鈕",
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。"
        }
      },
      "extension": {
        "step1": {
          "title": "安裝 Zerion 擴充功能",
          "description": "我們建議把 Zerion 釘在工作列上，以便更快捷地進入你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      }
    },
    "rainbow": {
      "qr_code": {
        "step1": {
          "title": "打開 Rainbow 應用程式",
          "description": "我們建議把 Rainbow 放在主頁上以便更快捷地進入你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "你可以使用我們的備份功能在手機上輕鬆備份你的錢包。"
        },
        "step3": {
          "title": "點擊掃描按鈕",
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。"
        }
      }
    },
    "enkrypt": {
      "extension": {
        "step1": {
          "description": "我們建議把 Enkrypt Wallet 釘在工作列上，以便更快捷地進入你的錢包。",
          "title": "安裝 Enkrypt Wallet 擴充功能"
        },
        "step2": {
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。",
          "title": "刷新你的瀏覽器"
        }
      }
    },
    "frame": {
      "extension": {
        "step1": {
          "description": "我們建議把 Frame 釘在工作列上，以便更快捷地進入你的錢包。",
          "title": "安裝 Frame 和配套擴充功能"
        },
        "step2": {
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。",
          "title": "刷新你的瀏覽器"
        }
      }
    },
    "one_key": {
      "extension": {
        "step1": {
          "title": "安裝 OneKey Wallet 擴充功能",
          "description": "我們建議把 OneKey Wallet 釘在工作列上，以便更快捷地進入你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      }
    },
    "phantom": {
      "extension": {
        "step1": {
          "title": "安裝 Phantom 擴充功能",
          "description": "我們建議把 Phantom 釘在工作列上，以便更容易地進入你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保用安全的方法備份你的錢包。絕不與任何人分享你的秘密恢復詞。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      }
    },
    "rabby": {
      "extension": {
        "step1": {
          "title": "安裝 Rabby 擴充功能",
          "description": "我們建議把 Rabby 釘在工作列上，以便更快捷地進入你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      }
    },
    "ronin": {
      "qr_code": {
        "step1": {
          "description": "我們建議將 Ronin Wallet 放在主畫面，便可以更快存取你的電子錢包。",
          "title": "開啟 Ronin Wallet 應用程式"
        },
        "step2": {
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。",
          "title": "點擊掃描按鈕"
        }
      },
      "extension": {
        "step1": {
          "description": "我們建議將 Ronin Wallet 釘在工作列上，便可以更快存取你的電子錢包。",
          "title": "安裝 Ronin Wallet 擴充功能"
        },
        "step2": {
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。",
          "title": "創建或導入錢包"
        },
        "step3": {
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。",
          "title": "刷新你的瀏覽器"
        }
      }
    },
    "ramper": {
      "extension": {
        "step1": {
          "title": "安裝 Ramper 擴充功能",
          "description": "我們建議將 Ramper 釘在工作列上，便可以更容易存取你的電子錢包。"
        },
        "step2": {
          "title": "建立錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      }
    },
    "safeheron": {
      "extension": {
        "step1": {
          "title": "安裝 Core 擴充套件",
          "description": "我們建議把 Safeheron 釘在工作列上，以便更快捷地進入你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      }
    },
    "taho": {
      "extension": {
        "step1": {
          "title": "安裝 Taho 擴充功能",
          "description": "我們建議把 Taho 釘在工作列上，以便更快捷地進入你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      }
    },
    "talisman": {
      "extension": {
        "step1": {
          "title": "安裝 Talisman 擴充功能",
          "description": "我們建議把 Talisman 釘在工作列上，以便更快捷地進入你的錢包。"
        },
        "step2": {
          "title": "建立或導入以太坊錢包",
          "description": "請確保用安全的方法備份你的錢包。絕不與任何人分享你的恢復詞。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      }
    },
    "xdefi": {
      "extension": {
        "step1": {
          "title": "安裝 XDEFI Wallet 擴充功能",
          "description": "我們建議把 XDEFI Wallet 釘在工作列上，以便更快捷地進入你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      }
    },
    "zeal": {
      "qr_code": {
        "step1": {
          "title": "開啟 Zeal 應用程式",
          "description": "新增 Zeal Wallet 至你的主畫面，便可以更快存取你的電子錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "創建新的錢包或導入現有的錢包。"
        },
        "step3": {
          "title": "點擊二維碼圖示並掃描",
          "description": "點擊主畫面上的二維碼圖示，掃描代碼並確認提示以連接。"
        }
      },
      "extension": {
        "step1": {
          "title": "安裝 Zeal 擴充功能",
          "description": "我們建議把 Zeal 釘在工作列上，以便更快捷地進入你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      }
    },
    "safepal": {
      "extension": {
        "step1": {
          "title": "安裝 SafePal Wallet 擴充功能",
          "description": "點擊瀏覽器右上方並把 SafePal Wallet 釘起來，以便容易進入。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "創建新的錢包或導入現有的錢包。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設定好 SafePal Wallet 後，點擊下方以更新瀏覽器並加載擴充功能。"
        }
      },
      "qr_code": {
        "step1": {
          "title": "打開 SafePal Wallet 應用程式",
          "description": "把 SafePal Wallet 放在主頁上以便更快捷地進入你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "創建新的錢包或導入現有的錢包。"
        },
        "step3": {
          "title": "在設定中點擊 WalletConnect",
          "description": "選擇新連接，然後掃描二維碼並確認提示以連接。"
        }
      }
    },
    "desig": {
      "extension": {
        "step1": {
          "title": "安裝 Desig 擴充功能",
          "description": "我們建議把 Desig 釘在工作列上以便更容易地進入你的錢包。"
        },
        "step2": {
          "title": "建立錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      }
    },
    "subwallet": {
      "extension": {
        "step1": {
          "title": "安裝 SubWallet 擴充功能",
          "description": "我們建議將 SubWallet 固定到你的任務欄，以便更快地訪問你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保用安全的方法備份你的錢包。絕不與任何人分享你的恢復詞。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      },
      "qr_code": {
        "step1": {
          "title": "打開 SubWallet 應用程式",
          "description": "我們建議將 SubWallet 放置在你的主畫面，以便更快地訪問。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "點擊掃描按鈕",
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。"
        }
      }
    },
    "clv": {
      "extension": {
        "step1": {
          "title": "安裝 CLV Wallet 擴展",
          "description": "我們建議將 CLV Wallet 固定到你的任務欄，以便更快地訪問你的錢包。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "刷新你的瀏覽器",
          "description": "設置你的錢包後，點擊下方按鈕刷新瀏覽器並載入擴展。"
        }
      },
      "qr_code": {
        "step1": {
          "title": "打開 CLV Wallet 應用程式",
          "description": "我們建議將 CLV Wallet 放置在你的主畫面，以便更快地訪問。"
        },
        "step2": {
          "title": "創建或導入錢包",
          "description": "請確保使用安全方法備份你的錢包，絕不要與任何人分享你的秘密短語。"
        },
        "step3": {
          "title": "點擊掃描按鈕",
          "description": "掃描後，將會出現連接提示，讓你連接你的錢包。"
        }
      }
    },
    "okto": {
      "qr_code": {
        "step1": {
          "title": "打開 Okto 應用程式",
          "description": "將 Okto 添加到你的主畫面，以便快速訪問"
        },
        "step2": {
          "title": "創建 MPC 錢包",
          "description": "創建賬戶並生成錢包"
        },
        "step3": {
          "title": "在設定中點擊 WalletConnect",
          "description": "點擊右上角的掃描 QR 圖示，並確認提示以連接。"
        }
      }
    },
    "ledger": {
      "desktop": {
        "step1": {
          "title": "打開 Ledger Live 應用程式",
          "description": "我們建議將 Ledger Live 放置在你的主畫面，以便更快地訪問。"
        },
        "step2": {
          "title": "設置你的 Ledger",
          "description": "設置一個新的 Ledger 或連接到現有的 Ledger。"
        },
        "step3": {
          "title": "連接",
          "description": "將會出現一個連接提示，以便你連接錢包。"
        }
      },
      "qr_code": {
        "step1": {
          "title": "打開 Ledger Live 應用程式",
          "description": "我們建議將 Ledger Live 放置在你的主畫面，以便更快地訪問。"
        },
        "step2": {
          "title": "設置你的 Ledger",
          "description": "你可以同步桌面應用程式或連接你的 Ledger。"
        },
        "step3": {
          "title": "掃描代碼",
          "description": "點擊 WalletConnect 並切換到掃描器。掃描後，將會出現一個連接提示，以便你連接錢包。"
        }
      }
    }
  }
}
`;export{u as default};
