var u=`{
  "connect_wallet": {
    "label": "连接钱包",
    "wrong_network": {
      "label": "错误的网络"
    }
  },
  "intro": {
    "title": "什么是钱包？",
    "description": "钱包用于发送、接收、存储和显示数字资产。它也是一种新型的登录方式，无需在每个网站上创建新账户和密码。",
    "digital_asset": {
      "title": "您的数字资产之家",
      "description": "钱包用于发送、接收、存储和显示像以太坊和NFT这样的数字资产。"
    },
    "login": {
      "title": "一种新的登录方式",
      "description": "而不是在每个网站上创建新的账户和密码，只需连接您的钱包。"
    },
    "get": {
      "label": "获取钱包"
    },
    "learn_more": {
      "label": "了解更多"
    }
  },
  "sign_in": {
    "label": "验证您的账户",
    "description": "为了完成连接，您必须在钱包中签署一条消息，以验证您是此账户的所有者。",
    "message": {
      "send": "发送消息",
      "preparing": "准备消息中...",
      "cancel": "取消",
      "preparing_error": "准备消息时出错，请重试！"
    },
    "signature": {
      "waiting": "等待签名...",
      "verifying": "正在验证签名...",
      "signing_error": "签署消息时出错，请重试！",
      "verifying_error": "验证签名时出错，请重试！",
      "oops_error": "哎呀，出了点问题！"
    }
  },
  "connect": {
    "label": "连接",
    "title": "连接钱包",
    "new_to_ethereum": {
      "description": "对以太坊钱包不熟悉？",
      "learn_more": {
        "label": "了解更多"
      }
    },
    "learn_more": {
      "label": "了解更多"
    },
    "recent": "近期",
    "status": {
      "opening": "正在打开 %{wallet}...",
      "connecting": "正在连接",
      "connect_mobile": "在 %{wallet}中继续",
      "not_installed": "%{wallet} 尚未安装",
      "not_available": "%{wallet} 不可用",
      "confirm": "在扩展中确认连接",
      "confirm_mobile": "在钱包中接受连接请求"
    },
    "secondary_action": {
      "get": {
        "description": "没有 %{wallet}吗？",
        "label": "获取"
      },
      "install": {
        "label": "安装"
      },
      "retry": {
        "label": "重试"
      }
    },
    "walletconnect": {
      "description": {
        "full": "需要官方的 WalletConnect 弹窗吗？",
        "compact": "需要 WalletConnect 弹窗吗？"
      },
      "open": {
        "label": "打开"
      }
    }
  },
  "connect_scan": {
    "title": "使用 %{wallet}扫描",
    "fallback_title": "使用您的手机扫描"
  },
  "connector_group": {
    "installed": "已安装",
    "recommended": "推荐",
    "other": "其他",
    "popular": "流行",
    "more": "更多",
    "others": "其他的"
  },
  "get": {
    "title": "获取一个钱包",
    "action": {
      "label": "获取"
    },
    "mobile": {
      "description": "移动钱包"
    },
    "extension": {
      "description": "浏览器扩展"
    },
    "mobile_and_extension": {
      "description": "移动钱包和扩展"
    },
    "mobile_and_desktop": {
      "description": "移动和桌面钱包"
    },
    "looking_for": {
      "title": "不是你要找的吗？",
      "mobile": {
        "description": "在主屏幕上选择一个钱包，以开始使用不同的钱包提供商。"
      },
      "desktop": {
        "compact_description": "在主屏幕上选择一个钱包，以开始使用不同的钱包提供商。",
        "wide_description": "在左侧选择一个钱包，以开始使用不同的钱包提供商。"
      }
    }
  },
  "get_options": {
    "title": "开始使用 %{wallet}",
    "short_title": "获取 %{wallet}",
    "mobile": {
      "title": "%{wallet} 用于移动",
      "description": "使用移动钱包探索以太坊的世界。",
      "download": {
        "label": "获取应用"
      }
    },
    "extension": {
      "title": "%{wallet} 为 %{browser}",
      "description": "从您最喜欢的网络浏览器直接访问您的钱包。",
      "download": {
        "label": "添加到 %{browser}"
      }
    },
    "desktop": {
      "title": "%{wallet} 对于 %{platform}",
      "description": "从您强大的桌面原生访问您的钱包。",
      "download": {
        "label": "添加到 %{platform}"
      }
    }
  },
  "get_mobile": {
    "title": "安装 %{wallet}",
    "description": "用手机扫描下载 iOS 或 Android",
    "continue": {
      "label": "继续"
    }
  },
  "get_instructions": {
    "mobile": {
      "connect": {
        "label": "连接"
      },
      "learn_more": {
        "label": "了解更多"
      }
    },
    "extension": {
      "refresh": {
        "label": "刷新"
      },
      "learn_more": {
        "label": "了解更多"
      }
    },
    "desktop": {
      "connect": {
        "label": "连接"
      },
      "learn_more": {
        "label": "了解更多"
      }
    }
  },
  "chains": {
    "title": "切换网络",
    "wrong_network": "检测到错误的网络，请切换或断开连接以继续。",
    "confirm": "在钱包中确认",
    "switching_not_supported": "您的钱包不支持从 %{appName}切换网络。请尝试从您的钱包内部切换网络。",
    "switching_not_supported_fallback": "您的钱包不支持从此应用切换网络。尝试从您的钱包内切换网络。",
    "disconnect": "断开连接",
    "connected": "已连接"
  },
  "profile": {
    "disconnect": {
      "label": "断开连接"
    },
    "copy_address": {
      "label": "复制地址",
      "copied": "已复制！"
    },
    "explorer": {
      "label": "在浏览器上查看更多"
    },
    "transactions": {
      "description": "%{appName} 交易将会出现在这里...",
      "description_fallback": "您的交易将会出现在这里...",
      "recent": {
        "title": "最近交易"
      },
      "clear": {
        "label": "清除全部"
      }
    }
  },
  "wallet_connectors": {
    "argent": {
      "qr_code": {
        "step1": {
          "description": "将 Argent 放到您的主屏幕上，以便更快地访问您的钱包。",
          "title": "打开 Argent 应用"
        },
        "step2": {
          "description": "创建钱包和用户名，或导入现有钱包。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "在您扫描后，将出现连接提示，供您连接您的钱包。",
          "title": "点击扫描二维码按钮"
        }
      }
    },
    "bifrost": {
      "qr_code": {
        "step1": {
          "description": "我们建议将Bifrost Wallet放在您的主屏幕上，以便更快地访问。",
          "title": "打开 Bifrost Wallet 应用"
        },
        "step2": {
          "description": "使用恢复短语创建或导入钱包。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "在您扫描后，将出现连接提示，供您连接您的钱包。",
          "title": "点击扫描按钮"
        }
      }
    },
    "bitget": {
      "qr_code": {
        "step1": {
          "description": "我们建议您将Bitget钱包添加到主屏幕，以便更快地访问。",
          "title": "打开Bitget钱包应用程序"
        },
        "step2": {
          "description": "务必使用安全的方法备份您的钱包。决不与任何人分享您的秘密短语。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "扫描后，将出现一个连接提示，供您连接您的钱包。",
          "title": "点击扫描按钮"
        }
      },
      "extension": {
        "step1": {
          "description": "我们建议您将Bitget钱包固定在任务栏，以便更快地访问您的钱包。",
          "title": "安装Bitget Wallet扩展"
        },
        "step2": {
          "description": "确保使用安全的方式备份您的钱包。绝不与任何人分享您的秘密短语。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "设置钱包后，点击下方刷新浏览器并加载扩展。",
          "title": "刷新您的浏览器"
        }
      }
    },
    "bitski": {
      "extension": {
        "step1": {
          "description": "我们建议您将Bitski固定在任务栏上，以便更快地访问您的钱包。",
          "title": "安装Bitski扩展"
        },
        "step2": {
          "description": "请确保用安全的方法备份您的钱包。绝不与任何人共享您的秘密短语。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "设置完您的钱包后，点击下方以刷新浏览器并加载扩展程序。",
          "title": "刷新您的浏览器"
        }
      }
    },
    "bitverse": {
      "qr_code": {
        "step1": {
          "title": "打开 Bitverse Wallet 应用",
          "description": "将 Bitverse Wallet 添加到您的主屏幕上，以便更快访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "创建新钱包或导入现有钱包。"
        },
        "step3": {
          "title": "点击QR图标并扫描",
          "description": "在您的主屏幕上点击QR图标，扫描代码并确认提示以进行连接。"
        }
      }
    },
    "bloom": {
      "desktop": {
        "step1": {
          "title": "打开 Bloom 钱包应用",
          "description": "我们建议将 Bloom 钱包添加到主屏幕上，以便更快地访问。"
        },
        "step2": {
          "description": "使用恢复短语创建或导入钱包。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "拥有钱包后，点击连接以通过 Bloom 连接。应用中会出现一个连接提示，供您确认连接。",
          "title": "点击连接"
        }
      },
      "qr_code": {
        "step1": {
          "title": "打开 Bloom 钱包应用",
          "description": "我们建议将 Bloom 钱包添加到主屏幕上，以便更快地访问。"
        },
        "step2": {
          "description": "使用恢复短语创建或导入钱包。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "拥有钱包后，点击连接以通过 Bloom 连接。应用中会出现一个连接提示，供您确认连接。",
          "title": "点击连接"
        }
      }
    },
    "bybit": {
      "qr_code": {
        "step1": {
          "description": "我们建议将 Bybit 添加到您的主屏幕上，以便更快访问您的钱包。",
          "title": "打开 Bybit 应用"
        },
        "step2": {
          "description": "您可以使用我们的手机上的备份功能轻松备份您的钱包。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "在您扫描后，将出现连接提示，供您连接您的钱包。",
          "title": "点击扫描按钮"
        }
      },
      "extension": {
        "step1": {
          "description": "点击浏览器右上角并固定 Bybit Wallet，便于快速访问。",
          "title": "安装 Bybit Wallet 扩展程序"
        },
        "step2": {
          "description": "创建新钱包或导入现有钱包。",
          "title": "创建或导入钱包。"
        },
        "step3": {
          "description": "设置 Bybit Wallet 后，点击下方刷新浏览器并加载扩展程序。",
          "title": "刷新您的浏览器"
        }
      }
    },
    "binance": {
      "qr_code": {
        "step1": {
          "description": "我们建议将Binance放在您的主屏幕上，以便更快地访问您的钱包。",
          "title": "打开 Binance 应用"
        },
        "step2": {
          "description": "您可以使用我们的手机上的备份功能轻松备份您的钱包。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "在您扫描后，将出现连接提示，供您连接您的钱包。",
          "title": "点击WalletConnect按钮"
        }
      }
    },
    "coin98": {
      "qr_code": {
        "step1": {
          "description": "我们建议将Coin98钱包放在您的主屏幕上，以便更快地访问您的钱包。",
          "title": "打开Coin98钱包应用程序"
        },
        "step2": {
          "description": "您可以使用我们的手机上的备份功能轻松备份您的钱包。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "扫描后，将出现一个连接提示，让您连接您的钱包。",
          "title": "点击WalletConnect按钮"
        }
      },
      "extension": {
        "step1": {
          "description": "点击浏览器右上角并固定Coin98钱包，以便轻松访问。",
          "title": "安装Coin98钱包扩展"
        },
        "step2": {
          "description": "创建新钱包或导入现有钱包。",
          "title": "创建或导入钱包。"
        },
        "step3": {
          "description": "设置完成Coin98 钱包后，单击下方以刷新浏览器并加载扩展程序。",
          "title": "刷新您的浏览器"
        }
      }
    },
    "coinbase": {
      "qr_code": {
        "step1": {
          "description": "我们建议您把Coinbase钱包放到主屏幕上，以便更快地访问。",
          "title": "打开Coinbase钱包应用"
        },
        "step2": {
          "description": "您可以轻松地使用云备份功能备份您的钱包。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "扫描后，将出现连接提示，供您连接您的钱包。",
          "title": "点击扫描按钮"
        }
      },
      "extension": {
        "step1": {
          "description": "我们建议您将Coinbase钱包固定在任务栏上，以便更快地访问您的钱包。",
          "title": "安装Coinbase钱包扩展"
        },
        "step2": {
          "description": "务必使用安全的方法备份您的钱包。永远不要与任何人分享您的秘密短语。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "设置好钱包后，点击下方以刷新浏览器并加载扩展。",
          "title": "刷新您的浏览器"
        }
      }
    },
    "compass": {
      "extension": {
        "step1": {
          "description": "我们建议将Compass Wallet固定在任务栏上，以便更快地访问您的钱包。",
          "title": "安装Compass Wallet扩展"
        },
        "step2": {
          "description": "务必使用安全的方法备份您的钱包。决不与任何人分享您的秘密短语。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "设置钱包后，点击下方刷新浏览器并加载扩展。",
          "title": "刷新您的浏览器"
        }
      }
    },
    "core": {
      "qr_code": {
        "step1": {
          "description": "我们建议您将Core添加到主屏幕，以便更快地访问您的钱包。",
          "title": "打开Core应用程序"
        },
        "step2": {
          "description": "您可以使用我们的手机备份功能轻松备份您的钱包。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "扫描后，将出现连接提示，让您连接您的钱包。",
          "title": "点击WalletConnect按钮"
        }
      },
      "extension": {
        "step1": {
          "description": "我们建议将 Core 固定到任务栏，以便更快地访问您的钱包。",
          "title": "安装 Core 扩展"
        },
        "step2": {
          "description": "一定要使用安全的方法备份您的钱包。切勿与任何人分享您的秘密短语。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "设置好钱包后，点击下方以刷新浏览器并加载扩展。",
          "title": "刷新你的浏览器"
        }
      }
    },
    "fox": {
      "qr_code": {
        "step1": {
          "description": "我们建议您将 FoxWallet 放到主屏幕上，以便更快的访问。",
          "title": "打开 FoxWallet 应用"
        },
        "step2": {
          "description": "确保使用安全的方法备份您的钱包。永远不要与任何人共享您的秘密短语。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "扫描后，将出现连接提示，让您连接您的钱包。",
          "title": "点击扫描按钮"
        }
      }
    },
    "frontier": {
      "qr_code": {
        "step1": {
          "description": "我们建议将 Frontier 钱包放在您的主屏幕上，以便更快地访问。",
          "title": "打开 Frontier 钱包应用"
        },
        "step2": {
          "description": "确保使用安全的方法备份您的钱包。永远不要与任何人共享您的秘密短语。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "扫描后，将出现连接提示，让您连接您的钱包。",
          "title": "点击扫描按钮"
        }
      },
      "extension": {
        "step1": {
          "description": "我们建议您将Frontier钱包固定到任务栏，以便更快地访问您的钱包。",
          "title": "安装Frontier钱包扩展"
        },
        "step2": {
          "description": "确保使用安全的方法备份您的钱包。永远不要与任何人分享您的秘密短语。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "设置完成钱包后，点击下方刷新浏览器并加载扩展。",
          "title": "刷新你的浏览器"
        }
      }
    },
    "im_token": {
      "qr_code": {
        "step1": {
          "title": "打开imToken应用",
          "description": "将imToken应用放在您的主屏幕上，以更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "创建新钱包或导入已有的钱包。"
        },
        "step3": {
          "title": "点击右上角的扫描图标",
          "description": "选择新连接，然后扫描二维码并确认提示以进行连接。"
        }
      }
    },
    "iopay": {
      "qr_code": {
        "step1": {
          "description": "我们建议您将ioPay添加到主屏幕，以便更快地访问您的钱包。",
          "title": "打开ioPay应用"
        },
        "step2": {
          "description": "您可以使用我们的手机上的备份功能轻松备份您的钱包。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "在您扫描后，将出现连接提示，供您连接您的钱包。",
          "title": "点击WalletConnect按钮"
        }
      }
    },
    "kaikas": {
      "extension": {
        "step1": {
          "description": "我们建议将 Kaikas 固定到任务栏上，以便更快访问您的钱包。",
          "title": "安装 Kaikas 扩展程序"
        },
        "step2": {
          "description": "务必使用安全的方法备份您的钱包。决不与任何人分享您的秘密短语。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "设置钱包后，点击下方刷新浏览器并加载扩展。",
          "title": "刷新您的浏览器"
        }
      },
      "qr_code": {
        "step1": {
          "title": "打开 Kaikas 应用",
          "description": "将 Kaikas 应用添加到您的主屏幕上，以便更快访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "创建新钱包或导入现有钱包。"
        },
        "step3": {
          "title": "点击右上角的扫描图标",
          "description": "选择新连接，然后扫描二维码并确认提示以进行连接。"
        }
      }
    },
    "kaia": {
      "extension": {
        "step1": {
          "description": "我们建议将Kaia固定在您的任务栏上，以便更快地访问您的钱包。",
          "title": "安装Kaia扩展程序"
        },
        "step2": {
          "description": "务必使用安全的方法备份您的钱包。决不与任何人分享您的秘密短语。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "设置钱包后，点击下方刷新浏览器并加载扩展。",
          "title": "刷新您的浏览器"
        }
      },
      "qr_code": {
        "step1": {
          "title": "打开Kaia应用",
          "description": "将Kaia应用放在您的主屏幕上，以更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "创建新钱包或导入现有钱包。"
        },
        "step3": {
          "title": "点击右上角的扫描图标",
          "description": "选择新连接，然后扫描二维码并确认提示以进行连接。"
        }
      }
    },
    "kraken": {
      "qr_code": {
        "step1": {
          "title": "打开Kraken Wallet应用程序",
          "description": "将Kraken Wallet添加到您的主屏幕，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "创建新钱包或导入现有钱包。"
        },
        "step3": {
          "title": "点击QR图标并扫描",
          "description": "在您的主屏幕上点击QR图标，扫描代码并确认提示以进行连接。"
        }
      }
    },
    "kresus": {
      "qr_code": {
        "step1": {
          "title": "打开 Kresus 钱包应用",
          "description": "将Kresus钱包添加到主屏幕，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "创建新钱包或导入现有钱包。"
        },
        "step3": {
          "title": "点击QR图标并扫描",
          "description": "在您的主屏幕上点击QR图标，扫描代码并确认提示以进行连接。"
        }
      }
    },
    "magicEden": {
      "extension": {
        "step1": {
          "title": "安装 Magic Eden 扩展程序",
          "description": "我们建议将 Magic Eden 固定到任务栏，以便更轻松地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "确保使用安全的方法备份您的钱包。切勿与任何人分享您的秘密恢复短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "设置钱包后，点击下方刷新浏览器并加载扩展。"
        }
      }
    },
    "metamask": {
      "qr_code": {
        "step1": {
          "title": "打开 MetaMask 应用",
          "description": "我们建议将 MetaMask 放在您的主屏幕上，以便更快地访问。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "确保使用安全的方法备份您的钱包。永远不要与任何人分享你的秘密短语。"
        },
        "step3": {
          "title": "点击扫描按钮",
          "description": "扫描后，将出现连接提示，以便你连接你的钱包。"
        }
      },
      "extension": {
        "step1": {
          "title": "安装 MetaMask 扩展",
          "description": "我们建议将MetaMask固定在您的任务栏上，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "请务必使用安全的方法备份您的钱包。切勿与任何人分享您的秘密短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "一旦您设置好您的钱包，点击下面刷新浏览器并加载扩展。"
        }
      }
    },
    "nestwallet": {
      "extension": {
        "step1": {
          "title": "安装 NestWallet 扩展程序",
          "description": "我们建议将NestWallet固定到任务栏，以便更快速地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "务必使用安全的方法备份您的钱包。决不与任何人分享您的秘密短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "设置钱包后，点击下方刷新浏览器并加载扩展。"
        }
      }
    },
    "okx": {
      "qr_code": {
        "step1": {
          "title": "打开OKX钱包应用程序",
          "description": "我们建议将OKX钱包放在您的主屏幕上，以便更快地访问。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "务必使用安全的方法备份您的钱包。千万不要与任何人分享您的秘密短语。"
        },
        "step3": {
          "title": "点击扫描按钮",
          "description": "扫描后，将出现一个连接提示，让您连接您的钱包。"
        }
      },
      "extension": {
        "step1": {
          "title": "安装 OKX 钱包扩展",
          "description": "我们建议将 OKX 钱包固定到您的任务栏，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "务必使用安全的方法备份您的钱包。千万不要与任何人分享您的秘密短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "一旦你设置好你的钱包，点击下方刷新浏览器并加载扩展。"
        }
      }
    },
    "omni": {
      "qr_code": {
        "step1": {
          "title": "打开Omni应用",
          "description": "将Omni添加到你的主屏幕，以便更快地访问你的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "创建新的钱包或导入现有的钱包。"
        },
        "step3": {
          "title": "点击QR图标并扫描",
          "description": "点击首页的二维码图标，扫描代码并确认提示以连接。"
        }
      }
    },
    "1inch": {
      "qr_code": {
        "step1": {
          "description": "将 1inch Wallet 添加到您的主屏幕上，以便更快访问您的钱包。",
          "title": "打开 1inch Wallet 应用"
        },
        "step2": {
          "description": "创建钱包和用户名，或导入现有钱包。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "在您扫描后，将出现连接提示，供您连接您的钱包。",
          "title": "点击扫描二维码按钮"
        }
      }
    },
    "token_pocket": {
      "qr_code": {
        "step1": {
          "title": "打开TokenPocket应用",
          "description": "我们建议将TokenPocket放在您的主屏幕上以便更快的访问。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "一定要使用安全的方法备份您的钱包。切勿与任何人分享您的秘密短语。"
        },
        "step3": {
          "title": "点击扫描按钮",
          "description": "扫描后，将出现连接提示，供您连接钱包。"
        }
      },
      "extension": {
        "step1": {
          "title": "安装TokenPocket扩展",
          "description": "我们建议将TokenPocket固定到任务栏，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入一个钱包",
          "description": "一定要使用安全的方法备份您的钱包。绝对不要与任何人分享您的秘密短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "设置好您的钱包后，点击下面刷新浏览器并加载扩展。"
        }
      }
    },
    "trust": {
      "qr_code": {
        "step1": {
          "title": "打开Trust Wallet应用",
          "description": "将Trust Wallet放在主屏幕上，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入一个钱包",
          "description": "创建新的钱包或导入现有的钱包。"
        },
        "step3": {
          "title": "在设置中点击WalletConnect",
          "description": "选择新的连接，然后扫描二维码并确认提示以进行连接。"
        }
      },
      "extension": {
        "step1": {
          "title": "安装Trust Wallet扩展程序",
          "description": "在浏览器的右上角点击并固定Trust Wallet以便于访问。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "创建新的钱包或导入现有的钱包。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "设置Trust Wallet后，点击下面以刷新浏览器并加载扩展程序。"
        }
      }
    },
    "uniswap": {
      "qr_code": {
        "step1": {
          "title": "打开Uniswap应用",
          "description": "将Uniswap钱包添加到您的主屏幕，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "创建新钱包或导入现有钱包。"
        },
        "step3": {
          "title": "点击QR图标并扫描",
          "description": "在您的主屏幕上点击QR图标，扫描代码并确认提示以进行连接。"
        }
      }
    },
    "zerion": {
      "qr_code": {
        "step1": {
          "title": "打开Zerion应用",
          "description": "我们建议将Zerion放在您的主屏幕上以便更快地访问。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "确保使用安全的方式备份你的钱包。绝对不要与任何人分享你的私人密语。"
        },
        "step3": {
          "title": "点击扫描按钮",
          "description": "你扫描后，会出现一个连接提示让你连接你的钱包。"
        }
      },
      "extension": {
        "step1": {
          "title": "安装 Zerion 扩展",
          "description": "我们建议将 Zerion 固定在你的任务栏以便更快访问你的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "确保使用安全的方法备份你的钱包。永远不要与任何人分享你的秘密短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "设置您的钱包后，点击下面以刷新浏览器并加载扩展程序。"
        }
      }
    },
    "rainbow": {
      "qr_code": {
        "step1": {
          "title": "打开 Rainbow 应用",
          "description": "我们建议将 Rainbow 放在您的主屏幕上，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "您可以使用我们的备份功能在您的手机上轻松备份你的钱包。"
        },
        "step3": {
          "title": "点击扫描按钮",
          "description": "扫描后，将出现连接提示，让您连接您的钱包。"
        }
      }
    },
    "enkrypt": {
      "extension": {
        "step1": {
          "description": "我们建议将Enkrypt Wallet固定到任务栏，以便更快地访问您的钱包。",
          "title": "安装Enkrypt Wallet扩展"
        },
        "step2": {
          "description": "请确保使用安全方法备份您的钱包。永远不要与任何人分享您的秘密短语。",
          "title": "创建钱包或导入钱包"
        },
        "step3": {
          "description": "设置钱包后，点击下面刷新浏览器并加载扩展。",
          "title": "刷新您的浏览器"
        }
      }
    },
    "frame": {
      "extension": {
        "step1": {
          "description": "我们建议将Frame固定到任务栏，以便更快地访问您的钱包。",
          "title": "安装Frame及其配套扩展"
        },
        "step2": {
          "description": "务必使用安全的方法备份您的钱包。决不与任何人分享您的秘密短语。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "设置钱包后，点击下方以刷新浏览器并加载扩展。",
          "title": "刷新你的浏览器"
        }
      }
    },
    "one_key": {
      "extension": {
        "step1": {
          "title": "安装OneKey Wallet扩展",
          "description": "我们建议将OneKey Wallet固定到任务栏，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "确保使用安全的方法备份您的钱包。切勿与任何人分享您的秘密短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "设置您的钱包后，点击下方以刷新浏览器并加载扩展程序。"
        }
      }
    },
    "phantom": {
      "extension": {
        "step1": {
          "title": "安装 Phantom 扩展程序",
          "description": "我们建议将 Phantom 固定到您的任务栏，以便更容易访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "确保使用安全的方法备份您的钱包。切勿与任何人分享您的秘密恢复短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "设置好您的钱包后，点击下方以刷新浏览器并加载扩展程序。"
        }
      }
    },
    "rabby": {
      "extension": {
        "step1": {
          "title": "安装 Rabby 扩展程序",
          "description": "我们建议将 Rabby 固定在您的任务栏，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "一定要使用安全的方法备份您的钱包。切勿与任何人分享您的密钥短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "一旦您设置好您的钱包，点击以下以刷新浏览器并加载扩展程序。"
        }
      }
    },
    "ronin": {
      "qr_code": {
        "step1": {
          "description": "我们建议您将Ronin钱包添加到主屏幕，以便更快地访问。",
          "title": "打开Ronin钱包应用"
        },
        "step2": {
          "description": "务必使用安全的方法备份您的钱包。决不与任何人分享您的秘密短语。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "在您扫描后，将出现连接提示，供您连接您的钱包。",
          "title": "点击扫描按钮"
        }
      },
      "extension": {
        "step1": {
          "description": "我们建议您将Ronin钱包固定到任务栏，以便更快地访问您的钱包。",
          "title": "安装Ronin钱包扩展"
        },
        "step2": {
          "description": "务必使用安全的方法备份您的钱包。决不与任何人分享您的秘密短语。",
          "title": "创建或导入钱包"
        },
        "step3": {
          "description": "设置钱包后，点击下方刷新浏览器并加载扩展。",
          "title": "刷新您的浏览器"
        }
      }
    },
    "ramper": {
      "extension": {
        "step1": {
          "title": "安装Ramper扩展",
          "description": "我们建议您将Ramper固定到任务栏，以便更容易地访问您的钱包。"
        },
        "step2": {
          "title": "创建一个钱包",
          "description": "务必使用安全的方法备份您的钱包。决不与任何人分享您的秘密短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "设置钱包后，点击下方刷新浏览器并加载扩展。"
        }
      }
    },
    "safeheron": {
      "extension": {
        "step1": {
          "title": "安装 Core 扩展",
          "description": "我们建议将 Safeheron 固定在您的任务栏，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "确保使用安全的方法备份您的钱包。切勿与任何人分享您的秘密短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "设置好您的钱包后，点击下方以刷新浏览器并加载扩展程序。"
        }
      }
    },
    "taho": {
      "extension": {
        "step1": {
          "title": "安装Taho扩展程序",
          "description": "我们建议将Taho固定在您的任务栏上，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "确保使用安全的方法备份您的钱包。切勿与任何人分享您的秘密短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "设置好您的钱包后，点击下方以刷新浏览器并加载扩展程序。"
        }
      }
    },
    "talisman": {
      "extension": {
        "step1": {
          "title": "安装 Talisman 扩展程序",
          "description": "我们建议将 Talisman 固定在任务栏上，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入以太坊钱包",
          "description": "确保使用安全的方法备份您的钱包。永远不要与任何人分享您的恢复短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "设置好您的钱包后，点击下方以刷新浏览器并加载扩展程序。"
        }
      }
    },
    "xdefi": {
      "extension": {
        "step1": {
          "title": "安装 XDEFI 钱包扩展程序",
          "description": "我们建议将XDEFI钱包固定到您的任务栏，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "确保使用安全的方法备份您的钱包。永远不要与任何人共享您的秘密短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "一旦你设置好你的钱包，点击下面刷新浏览器和加载扩展。"
        }
      }
    },
    "zeal": {
      "qr_code": {
        "step1": {
          "title": "打开 Zeal 应用",
          "description": "将Zeal钱包添加到您的主屏幕，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "创建新钱包或导入现有钱包。"
        },
        "step3": {
          "title": "点击QR图标并扫描",
          "description": "在您的主屏幕上点击QR图标，扫描代码并确认提示以进行连接。"
        }
      },
      "extension": {
        "step1": {
          "title": "安装Zeal扩展程序",
          "description": "我们建议将Zeal固定在您的任务栏上，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "务必使用安全的方法备份您的钱包。决不与任何人分享您的秘密短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "设置钱包后，点击下方刷新浏览器并加载扩展。"
        }
      }
    },
    "safepal": {
      "extension": {
        "step1": {
          "title": "安装SafePal Wallet扩展程序",
          "description": "点击浏览器右上角并固定SafePal Wallet以便于快速访问。"
        },
        "step2": {
          "title": "创建或导入钱包。",
          "description": "创建新钱包或导入现有钱包。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "一旦设置了SafePal钱包，点击下方刷新浏览器并加载扩展程序。"
        }
      },
      "qr_code": {
        "step1": {
          "title": "打开SafePal钱包应用程序",
          "description": "将SafePal钱包放在主屏幕上以更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "创建新钱包或导入现有钱包。"
        },
        "step3": {
          "title": "在设置中点击WalletConnect",
          "description": "选择新连接，然后扫描二维码并确认提示以进行连接。"
        }
      }
    },
    "desig": {
      "extension": {
        "step1": {
          "title": "安装 Desig 扩展",
          "description": "我们建议将 Desig 固定到任务栏，以便更轻松地访问您的钱包。"
        },
        "step2": {
          "title": "创建一个钱包",
          "description": "务必使用安全的方法备份您的钱包。决不与任何人分享您的秘密短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "设置钱包后，点击下方刷新浏览器并加载扩展。"
        }
      }
    },
    "subwallet": {
      "extension": {
        "step1": {
          "title": "安装 SubWallet 扩展",
          "description": "我们建议将 SubWallet 固定到任务栏，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "确保使用安全的方法备份您的钱包。永远不要与任何人分享您的恢复短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "设置钱包后，点击下方刷新浏览器并加载扩展。"
        }
      },
      "qr_code": {
        "step1": {
          "title": "打开 SubWallet 应用",
          "description": "我们建议将 SubWallet 放置在主屏幕上，以便更快地访问。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "务必使用安全的方法备份您的钱包。决不与任何人分享您的秘密短语。"
        },
        "step3": {
          "title": "点击扫描按钮",
          "description": "在您扫描后，将出现连接提示，供您连接您的钱包。"
        }
      }
    },
    "clv": {
      "extension": {
        "step1": {
          "title": "安装 CLV Wallet 扩展",
          "description": "我们建议将 CLV Wallet 固定到任务栏，以便更快地访问您的钱包。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "务必使用安全的方法备份您的钱包。决不与任何人分享您的秘密短语。"
        },
        "step3": {
          "title": "刷新您的浏览器",
          "description": "设置钱包后，点击下方刷新浏览器并加载扩展。"
        }
      },
      "qr_code": {
        "step1": {
          "title": "打开 CLV 钱包应用",
          "description": "我们建议将 CLV 钱包添加到您的主屏幕，以便更快地访问。"
        },
        "step2": {
          "title": "创建或导入钱包",
          "description": "务必使用安全的方法备份您的钱包。决不与任何人分享您的秘密短语。"
        },
        "step3": {
          "title": "点击扫描按钮",
          "description": "在您扫描后，将出现连接提示，供您连接您的钱包。"
        }
      }
    },
    "okto": {
      "qr_code": {
        "step1": {
          "title": "打开 Okto 应用",
          "description": "将 Okto 添加到您的主屏幕以便快速访问"
        },
        "step2": {
          "title": "创建一个 MPC 钱包",
          "description": "创建一个账户并生成一个钱包"
        },
        "step3": {
          "title": "在设置中点击WalletConnect",
          "description": "点击右上角的扫描二维码图标，并确认提示以连接。"
        }
      }
    },
    "ledger": {
      "desktop": {
        "step1": {
          "title": "打开Ledger Live应用",
          "description": "我们建议将Ledger Live放在您的主屏幕上，以便更快地访问。"
        },
        "step2": {
          "title": "设置您的Ledger",
          "description": "设置一个新的Ledger或连接到一个现有的。"
        },
        "step3": {
          "title": "连接",
          "description": "你扫描后，会出现一个连接提示让你连接你的钱包。"
        }
      },
      "qr_code": {
        "step1": {
          "title": "打开Ledger Live应用",
          "description": "我们建议将Ledger Live放在您的主屏幕上，以便更快地访问。"
        },
        "step2": {
          "title": "设置您的Ledger",
          "description": "您可以同步桌面应用程式，或连接您的Ledger。"
        },
        "step3": {
          "title": "扫描代码",
          "description": "点击 WalletConnect 然后切换到扫描器。你扫描后，会出现一个连接提示让你连接你的钱包。"
        }
      }
    }
  }
}
`;export{u as default};
