var E=`{
  "connect_wallet": {
    "label": "เชื่อมต่อกระเป๋าเงิน",
    "wrong_network": {
      "label": "เครือข่ายไม่ถูกต้อง"
    }
  },
  "intro": {
    "title": "อะไรคือกระเป๋าเงิน?",
    "description": "กระเป๋าเงินใช้ในการส่ง, รับ, เก็บ, และแสดงสินทรัพย์ดิจิทัล มันยังเป็นวิธีใหม่ในการเข้าสู่ระบบ, โดยไม่จำเป็นต้องสร้างบัญชีและรหัสผ่านใหม่ในทุกเว็บไซต์.",
    "digital_asset": {
      "title": "บ้านสำหรับสินทรัพย์ดิจิทัลของคุณ",
      "description": "กระเป๋าเงินถูกใช้เพื่อส่ง, รับ, เก็บ, แสดงสินทรัพย์ดิจิทัล เช่น Ethereum และ NFTs."
    },
    "login": {
      "title": "วิธีใหม่ในการเข้าสู่ระบบ",
      "description": "แทนที่จะสร้างบัญชีและรหัสผ่านใหม่ในทุกเว็บไซต์, แค่เชื่อมต่อกระเป๋าของคุณ."
    },
    "get": {
      "label": "รับกระเป๋าเงิน"
    },
    "learn_more": {
      "label": "เรียนรู้เพิ่มเติม"
    }
  },
  "sign_in": {
    "label": "ยืนยันบัญชีของคุณ",
    "description": "เพื่อการเชื่อมต่อที่สมบูรณ์, คุณต้องลงนามในข้อความในกระเป๋าเงินของคุณเพื่อยืนยันว่าคุณเป็นเจ้าของบัญชีนี้",
    "message": {
      "send": "ส่งข้อความ",
      "preparing": "กำลังเตรียมข้อความ...",
      "cancel": "ยกเลิก",
      "preparing_error": "เกิดข้อผิดพลาดในการเตรียมข้อความ โปรดลองใหม่!"
    },
    "signature": {
      "waiting": "รอการลงนาม...",
      "verifying": "กำลังตรวจสอบลายเซ็น...",
      "signing_error": "เกิดข้อผิดพลาดในการลงนามในข้อความ โปรดลองใหม่!",
      "verifying_error": "เกิดข้อผิดพลาดในการตรวจสอบลายเซ็น โปรดลองใหม่!",
      "oops_error": "อ๊ะ, เกิดข้อผิดพลาดบางอย่าง!"
    }
  },
  "connect": {
    "label": "เชื่อมต่อ",
    "title": "เชื่อมต่อกระเป๋าเงิน",
    "new_to_ethereum": {
      "description": "ใหม่กับกระเป๋า Ethereum หรือไม่?",
      "learn_more": {
        "label": "เรียนรู้เพิ่มเติม"
      }
    },
    "learn_more": {
      "label": "เรียนรู้เพิ่มเติม"
    },
    "recent": "ล่าสุด",
    "status": {
      "opening": "กำลังเปิด %{wallet}...",
      "connecting": "กำลังเชื่อมต่อ",
      "connect_mobile": "ดำเนินการต่อใน %{wallet}",
      "not_installed": "%{wallet} ไม่ได้ติดตั้ง",
      "not_available": "%{wallet} ไม่สามารถใช้ได้",
      "confirm": "ยืนยันการเชื่อมต่อในส่วนขยาย",
      "confirm_mobile": "ยอมรับคำขอเชื่อมต่อในกระเป๋าเงิน"
    },
    "secondary_action": {
      "get": {
        "description": "ไม่มี %{wallet}?",
        "label": "รับ"
      },
      "install": {
        "label": "ติดตั้ง"
      },
      "retry": {
        "label": "ลองใหม่"
      }
    },
    "walletconnect": {
      "description": {
        "full": "ต้องการ modal อย่างเป็นทางการจาก WalletConnect หรือไม่?",
        "compact": "ต้องการ modal จาก WalletConnect หรือไม่?"
      },
      "open": {
        "label": "เปิด"
      }
    }
  },
  "connect_scan": {
    "title": "สแกนด้วย %{wallet}",
    "fallback_title": "สแกนด้วยโทรศัพท์ของคุณ"
  },
  "connector_group": {
    "installed": "ติดตั้งแล้ว",
    "recommended": "แนะนำ",
    "other": "อื่น ๆ",
    "popular": "ยอดนิยม",
    "more": "เพิ่มเติม",
    "others": "อื่น ๆ"
  },
  "get": {
    "title": "รับ Wallet",
    "action": {
      "label": "รับ"
    },
    "mobile": {
      "description": "Wallet บนมือถือ"
    },
    "extension": {
      "description": "ส่วนขยายบราวเซอร์"
    },
    "mobile_and_extension": {
      "description": "กระเป๋าเงินมือถือและส่วนขยาย"
    },
    "mobile_and_desktop": {
      "description": "กระเป๋าเงินบนมือถือและคอมพิวเตอร์"
    },
    "looking_for": {
      "title": "ไม่ใช่สิ่งที่คุณกำลังหาหรือไม่?",
      "mobile": {
        "description": "เลือกกระเป๋าเงินบนหน้าจอหลักเพื่อเริ่มต้นใช้งานกับผู้ให้บริการกระเป๋าเงินที่แตกต่างกัน"
      },
      "desktop": {
        "compact_description": "เลือกกระเป๋าเงินบนหน้าจอหลักเพื่อเริ่มต้นใช้งานกับผู้ให้บริการกระเป๋าเงินที่แตกต่างกัน",
        "wide_description": "เลือกกระเป๋าเงินที่อยู่ทางซ้ายเพื่อเริ่มต้นใช้งานกับผู้ให้บริการกระเป๋าเงินที่แตกต่างกัน"
      }
    }
  },
  "get_options": {
    "title": "เริ่มต้นกับ %{wallet}",
    "short_title": "รับ %{wallet}",
    "mobile": {
      "title": "%{wallet} สำหรับมือถือ",
      "description": "ใช้กระเป๋าระบบมือถือในการสำรวจโลกของ Ethereum.",
      "download": {
        "label": "รับแอป"
      }
    },
    "extension": {
      "title": "%{wallet} สำหรับ %{browser}",
      "description": "เข้าถึงกระเป๋าเงินของคุณได้โดยตรงจากบราวเซอร์ที่คุณชื่นชอบ.",
      "download": {
        "label": "เพิ่มไปยัง %{browser}"
      }
    },
    "desktop": {
      "title": "%{wallet} สำหรับ %{platform}",
      "description": "เข้าถึงกระเป๋าเงินของคุณโดยตรงจากคอมพิวเตอร์ที่มีประสิทธิภาพของคุณ",
      "download": {
        "label": "เพิ่มไปยัง %{platform}"
      }
    }
  },
  "get_mobile": {
    "title": "ติดตั้ง %{wallet}",
    "description": "สแกนด้วยโทรศัพท์ของคุณเพื่อดาวน์โหลดบน iOS หรือ Android",
    "continue": {
      "label": "ดำเนินการต่อ"
    }
  },
  "get_instructions": {
    "mobile": {
      "connect": {
        "label": "เชื่อมต่อ"
      },
      "learn_more": {
        "label": "เรียนรู้เพิ่มเติม"
      }
    },
    "extension": {
      "refresh": {
        "label": "รีเฟรช"
      },
      "learn_more": {
        "label": "เรียนรู้เพิ่มเติม"
      }
    },
    "desktop": {
      "connect": {
        "label": "เชื่อมต่อ"
      },
      "learn_more": {
        "label": "เรียนรู้เพิ่มเติม"
      }
    }
  },
  "chains": {
    "title": "เปลี่ยนเครือข่าย",
    "wrong_network": "ตรวจสอบพบเครือข่ายที่ไม่ถูกต้อง สลับหรือตัดการเชื่อมต่อเพื่อดำเนินการต่อ.",
    "confirm": "ยืนยันใน Wallet",
    "switching_not_supported": "กระเป๋าสตางค์ของคุณไม่สนับสนุนการเปลี่ยนเครือข่ายจาก %{appName}ลองเปลี่ยนเครือข่ายจากภายในกระเป๋าสตางค์ของคุณแทน",
    "switching_not_supported_fallback": "กระเป๋าสตางค์ของคุณไม่สนับสนุนการสลับเครือข่ายจากแอปนี้ ลองสลับเครือข่ายจากภายในกระเป๋าสตางค์ของคุณแทน",
    "disconnect": "ตัดการเชื่อมต่อ",
    "connected": "เชื่อมต่อแล้ว"
  },
  "profile": {
    "disconnect": {
      "label": "ตัดการเชื่อมต่อ"
    },
    "copy_address": {
      "label": "คัดลอกที่อยู่",
      "copied": "คัดลอกแล้ว!"
    },
    "explorer": {
      "label": "ดูเพิ่มเติมบน explorer"
    },
    "transactions": {
      "description": "%{appName} รายการจะปรากฎที่นี่...",
      "description_fallback": "การทำธุรกรรมของคุณจะปรากฎที่นี่...",
      "recent": {
        "title": "ธุรกรรมล่าสุด"
      },
      "clear": {
        "label": "ลบทั้งหมด"
      }
    }
  },
  "wallet_connectors": {
    "argent": {
      "qr_code": {
        "step1": {
          "description": "วาง Argent บนหน้าจอหลักของคุณเพื่อเข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น",
          "title": "เปิดแอป Argent"
        },
        "step2": {
          "description": "สร้างกระเป๋าเงินและชื่อผู้ใช้หรือนำเข้ากระเป๋าเงินที่มีอยู่แล้ว",
          "title": "สร้างหรือนำเข้า Wallet"
        },
        "step3": {
          "description": "หลังจากคุณสแกน จะปรากฏหน้าต่างเชื่อมต่อให้คุณเชื่อมต่อกระเป๋าเงินของคุณ",
          "title": "แตะที่คุ่มุ่งสแกน QR"
        }
      }
    },
    "bifrost": {
      "qr_code": {
        "step1": {
          "description": "เราขอแนะนำให้คุณวาง Bifrost Wallet บนหน้าจอหลักของคุณเพื่อเข้าถึงได้เร็วขึ้น",
          "title": "เปิดแอพฯ Bifrost Wallet"
        },
        "step2": {
          "description": "สร้างหรือนำเข้ากระเป๋าเงินด้วย recovery phrase ของคุณ",
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน"
        },
        "step3": {
          "description": "หลังจากที่คุณสแกนแล้วยินยันการเชื่อมต่อกับกระเป๋าเงินของคุณ",
          "title": "แตะปุ่มสแกน"
        }
      }
    },
    "bitget": {
      "qr_code": {
        "step1": {
          "description": "เราขอแนะนำให้วาง Bitget Wallet บนหน้าจอหน้าแรกของคุณเพื่อการเข้าถึงที่รวดเร็วขึ้น.",
          "title": "เปิดแอพ Bitget Wallet"
        },
        "step2": {
          "description": "ตรวจสอบการสำรองข้อมูลกระเป๋าสตางค์ของคุณให้แน่นอนโดยใช้วิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณกับใครเป็นอันขาด.",
          "title": "สร้างหรือนำเข้า Wallet"
        },
        "step3": {
          "description": "หลังจากที่คุณสแกน จะมีข้อความขอเชื่อมต่อที่จะปรากฏขึ้นให้คุณเชื่อมต่อกระเป๋าสตางค์ของคุณ.",
          "title": "แตะปุ่มสแกน"
        }
      },
      "extension": {
        "step1": {
          "description": "เราแนะนำให้คุณปัก Bitget Wallet ไว้บนแถบงานของคุณเพื่อเข้าถึงกระเป๋าสตางค์ได้เร็วขึ้น",
          "title": "ติดตั้งส่วนเสริม Bitget Wallet"
        },
        "step2": {
          "description": "โปรดแน่ใจว่าคุณได้สำรองข้อมูลกระเป๋าเงินของคุณโดยใช้วิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณกับบุคคลใดๆ",
          "title": "สร้างหรือนำเข้า Wallet"
        },
        "step3": {
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้วคลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนเสริม",
          "title": "รีเฟรชเบราว์เซอร์ของคุณ"
        }
      }
    },
    "bitski": {
      "extension": {
        "step1": {
          "description": "เราแนะนำให้ทำปัก Bitski ไว้ที่แถบงานของคุณเพื่อเข้าถึงกระเป๋าเงินได้โดยไม่ต้องรอ",
          "title": "ติดตั้งส่วนขยาย Bitski"
        },
        "step2": {
          "description": "ควรสำรองกระเป๋าเงินของคุณโดยใช้วิธีที่ปลอดภัย อย่าเปิดเผยคำลับของคุณให้ใครทราบ",
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน"
        },
        "step3": {
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้ว คลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนขยาย",
          "title": "รีเฟรชเบราว์เซอร์ของคุณ"
        }
      }
    },
    "bitverse": {
      "qr_code": {
        "step1": {
          "title": "เปิดแอพฯ Bitverse Wallet",
          "description": "เพิ่ม Bitverse Wallet ลงบนหน้าจอหลักของคุณเพื่อการเข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "สร้างกระเป๋าเงินใหม่หรือนำเข้าที่มีอยู่แล้ว."
        },
        "step3": {
          "title": "แตะที่ไอคอน QR แล้วสแกน",
          "description": "แตะที่ไอคอน QR บนหน้าจอหลักของคุณ สแกนรหัสและยืนยันการเชื่อมต่อ"
        }
      }
    },
    "bloom": {
      "desktop": {
        "step1": {
          "title": "เปิดแอพ Bloom Wallet",
          "description": "เราแนะนำให้วาง Bloom Wallet ไว้บนหน้าจอหลักเพื่อการเข้าถึงที่เร็วขึ้น"
        },
        "step2": {
          "description": "สร้างหรือนำเข้ากระเป๋าเงินด้วย recovery phrase ของคุณ",
          "title": "สร้างหรือนำเข้า Wallet"
        },
        "step3": {
          "description": "หลังจากที่คุณมีกระเป๋าเงินแล้ว คลิกที่ 'Connect' เพื่อเชื่อมต่อผ่าน Bloom จะมีหน้าต่างแจ้งเตือนการเชื่อมต่อปรากฏขึ้นในแอพเพื่อให้คุณยืนยันการเชื่อมต่อ",
          "title": "คลิกที่ 'Connect'"
        }
      },
      "qr_code": {
        "step1": {
          "title": "เปิดแอพ Bloom Wallet",
          "description": "เราแนะนำให้วาง Bloom Wallet ไว้บนหน้าจอหลักเพื่อการเข้าถึงที่เร็วขึ้น"
        },
        "step2": {
          "description": "สร้างหรือนำเข้ากระเป๋าเงินด้วย recovery phrase ของคุณ",
          "title": "สร้างหรือนำเข้า Wallet"
        },
        "step3": {
          "description": "หลังจากที่คุณมีกระเป๋าเงินแล้ว คลิกที่ 'Connect' เพื่อเชื่อมต่อผ่าน Bloom จะมีหน้าต่างแจ้งเตือนการเชื่อมต่อปรากฏขึ้นในแอพเพื่อให้คุณยืนยันการเชื่อมต่อ",
          "title": "คลิกที่ 'Connect'"
        }
      }
    },
    "bybit": {
      "qr_code": {
        "step1": {
          "description": "เราแนะนำให้คุณตั้ง Bybit ไว้บนหน้าจอหลักเพื่อการเข้าถึงกระเป๋าเงินได้เร็วขึ้น",
          "title": "เปิดแอพฯ Bybit"
        },
        "step2": {
          "description": "คุณสามารถสำรองข้อมูลกระเป๋าเงินของคุณได้ง่ายๆ ด้วยฟีเจอร์สำรองข้อมูลบนโทรศัพท์ของคุณ.",
          "title": "สร้างหรือนำเข้า Wallet"
        },
        "step3": {
          "description": "หลังจากคุณสแกน จะปรากฏหน้าต่างเชื่อมต่อให้คุณเชื่อมต่อกระเป๋าเงินของคุณ",
          "title": "แตะปุ่มสแกน"
        }
      },
      "extension": {
        "step1": {
          "description": "คลิกที่มุมขวาบนของเบราว์เซอร์ของคุณและปักหมุด Bybit Wallet เพื่อการเข้าถึงได้ง่าย",
          "title": "ติดตั้งส่วนขยาย Bybit Wallet"
        },
        "step2": {
          "description": "สร้างกระเป๋าเงินใหม่หรือนำเข้าที่มีอยู่แล้ว.",
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน"
        },
        "step3": {
          "description": "เมื่อคุณตั้งค่า Bybit Wallet เสร็จสมบูรณ์แล้ว คลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนขยาย",
          "title": "รีเฟรชเบราว์เซอร์ของคุณ"
        }
      }
    },
    "binance": {
      "qr_code": {
        "step1": {
          "description": "เราขอแนะนำให้คุณวาง Binance อยู่บนหน้าจอหลักของคุณเพื่อให้เข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น",
          "title": "เปิดแอป Binance"
        },
        "step2": {
          "description": "คุณสามารถสำรองข้อมูลกระเป๋าเงินของคุณได้ง่ายๆ ด้วยฟีเจอร์สำรองข้อมูลบนโทรศัพท์ของคุณ.",
          "title": "สร้างหรือนำเข้า Wallet"
        },
        "step3": {
          "description": "หลังจากคุณสแกน จะปรากฏหน้าต่างเชื่อมต่อให้คุณเชื่อมต่อกระเป๋าเงินของคุณ",
          "title": "แตะที่ปุ่ม WalletConnect"
        }
      }
    },
    "coin98": {
      "qr_code": {
        "step1": {
          "description": "เราขอแนะนำให้คุณวาง Coin98 Wallet บนหน้าจอหลักของคุณ เพื่อให้เข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น.",
          "title": "เปิดแอพ Coin98 Wallet"
        },
        "step2": {
          "description": "คุณสามารถสำรองข้อมูลกระเป๋าเงินของคุณได้ง่ายๆ ด้วยฟีเจอร์สำรองข้อมูลบนโทรศัพท์ของคุณ.",
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน"
        },
        "step3": {
          "description": "หลังจากคุณสแกน จะมีเตือนการเชื่อมต่อที่ปรากฏขึ้นให้คุณเชื่อมต่อกระเป๋าเงินของคุณ.",
          "title": "แตะที่ปุ่ม WalletConnect"
        }
      },
      "extension": {
        "step1": {
          "description": "คลิกที่ด้านบนขวาของเบราว์เซอร์ของคุณและปัก Coin98 Wallet ไว้เพื่อให้เข้าถึงได้ง่าย.",
          "title": "ติดตั้งส่วนขยาย Coin98 Wallet"
        },
        "step2": {
          "description": "สร้างกระเป๋าเงินใหม่หรือนำเข้าที่มีอยู่แล้ว.",
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน"
        },
        "step3": {
          "description": "เมื่อคุณตั้งค่า Coin98 Wallet แล้ว คลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนขยายขึ้นมา.",
          "title": "รีเฟรชเบราว์เซอร์ของคุณ"
        }
      }
    },
    "coinbase": {
      "qr_code": {
        "step1": {
          "description": "เราแนะนำให้วาง Coinbase Wallet ไว้ที่หน้าจอหลักของคุณเพื่อให้เข้าถึงได้เร็วขึ้น.",
          "title": "เปิดแอป Coinbase Wallet"
        },
        "step2": {
          "description": "คุณสามารถสำรองข้อมูลกระเป๋าสตางค์ของคุณได้ง่ายๆ โดยใช้ฟีเจอร์การสำรองข้อมูลด้วยคลาวด์",
          "title": "สร้างหรือนำเข้ากระเป๋าสตางค์"
        },
        "step3": {
          "description": "หลังจากที่คุณสแกนแล้ว จะมีการแสดงขอ้มูลเพื่อให้คุณเชื่อมต่อกระเป๋าสตางค์ของคุณ",
          "title": "แตะที่ปุ่มสแกน"
        }
      },
      "extension": {
        "step1": {
          "description": "เราแนะนำให้คุณยัด Coinbase Wallet ไว้ที่แถบงานของคุณเพื่อให้สามารถเข้าถึงกระเป๋าสตางค์ของคุณได้เร็วขึ้น",
          "title": "ติดตั้งส่วนขยาย Coinbase Wallet"
        },
        "step2": {
          "description": "ตรวจสอบให้แน่ใจว่าคุณได้สำรองข้อมูลกระเป๋าเงินของคุณโดยใช้วิธีที่ปลอดภัย อย่าเปิดเผยประโยคลับของคุณให้กับใครเลย",
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน"
        },
        "step3": {
          "description": "เมื่อคุณได้ตั้งค่ากระเป๋าเงินของคุณแล้ว คลิกด้านล่างเพื่อเรียกดูเบราว์เซอร์ใหม่และโหลดส่วนขยาย",
          "title": "รีเฟรชเบราว์เซอร์ของคุณ"
        }
      }
    },
    "compass": {
      "extension": {
        "step1": {
          "description": "เราแนะนำให้คุณปัก Compass Wallet ไว้ที่แถบงานของคุณเพื่อเข้าถึงกระเป๋าสตางค์ของคุณได้เร็วขึ้น",
          "title": "ติดตั้งส่วนขยาย Compass Wallet"
        },
        "step2": {
          "description": "ตรวจสอบการสำรองข้อมูลกระเป๋าสตางค์ของคุณให้แน่นอนโดยใช้วิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณกับใครเป็นอันขาด.",
          "title": "สร้างหรือนำเข้า Wallet"
        },
        "step3": {
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้วคลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนเสริม",
          "title": "รีเฟรชเบราว์เซอร์ของคุณ"
        }
      }
    },
    "core": {
      "qr_code": {
        "step1": {
          "description": "เราแนะนำให้คุณวาง Core ลงสนามหลักเพื่อให้เข้าถึงกระเป๋าเงินได้เร็วขึ้น",
          "title": "เปิดแอปเครื่องมือช่วยอีเกิร์น"
        },
        "step2": {
          "description": "คุณสามารถสำรองกระเป๋าเงินของคุณได้ง่ายๆ โดยใช้ฟีเจอร์สำรองของเราบนโทรศัพท์ของคุณ",
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน"
        },
        "step3": {
          "description": "หลังจากที่คุณสแกนแล้ว จะมีการแจ้งเตือนเพื่อให้คุณเชื่อมต่อกับกระเป๋าสตางค์ของคุณ",
          "title": "แตะปุ่ม WalletConnect"
        }
      },
      "extension": {
        "step1": {
          "description": "เราขอแนะนำให้คุณปัก Core ไว้ที่แถบงานของคุณเพื่อเข้าถึงกระเป๋าสตางค์ของคุณได้อย่างรวดเร็ว",
          "title": "ติดตั้งส่วนขยาย Core"
        },
        "step2": {
          "description": "โปรดแน่ใจว่าคุณได้สำรองกระเป๋าสตางค์ของคุณใช้วิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณกับใคร",
          "title": "สร้างหรือนำเข้า Wallet"
        },
        "step3": {
          "description": "เมื่อคุณตั้งค่ากระเป๋าสตางค์ของคุณแล้ว คลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนขยาย",
          "title": "รีเฟรชเบราว์เซอร์ของคุณ"
        }
      }
    },
    "fox": {
      "qr_code": {
        "step1": {
          "description": "เราขอแนะนำให้คุณวาง FoxWallet บนหน้าจอหลักเพื่อให้เข้าถึงได้เร็วขึ้น",
          "title": "เปิดแอป FoxWallet"
        },
        "step2": {
          "description": "ตรวจสอบที่จะสำรองข้อมูลกระเป๋าเงินของคุณโดยใช้วิธีที่ปลอดภัย จงอย่าเปิดเผยประโยคลับลับของคุณให้ผู้อื่นรู้",
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน"
        },
        "step3": {
          "description": "หลังจากที่คุณสแกน จะมีการเชื่อมต่อที่แสดงให้คุณเชื่อมต่อกระเป๋าเงินของคุณ",
          "title": "แตะปุ่มสแกน"
        }
      }
    },
    "frontier": {
      "qr_code": {
        "step1": {
          "description": "เราขอแนะนำให้คุณวาง Frontier Wallet บนหน้าจอหลักเพื่อให้เข้าถึงได้เร็วขึ้น",
          "title": "เปิดแอป Frontier Wallet"
        },
        "step2": {
          "description": "ตรวจสอบให้แน่ใจว่าคุณได้สำรองข้อมูลกระเป๋าสตางค์ของคุณโดยใช้วิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณกับใคร",
          "title": "สร้างหรือนำเข้ากระเป๋าสตางค์"
        },
        "step3": {
          "description": "หลังจากที่คุณสแกนแล้ว จะมีการแสดงข้อมูลเพื่อให้คุณเชื่อมต่อกับกระเป๋าสตางค์ของคุณ",
          "title": "แตะปุ่มสแกน"
        }
      },
      "extension": {
        "step1": {
          "description": "เราแนะนำให้คุณปักหมุด Frontier Wallet ไว้ที่แถบงานของคุณเพื่อเข้าถึงกระเป๋าสตางค์ของคุณได้ง่ายขึ้น",
          "title": "ติดตั้งส่วนเสริม Frontier Wallet"
        },
        "step2": {
          "description": "ตรวจสอบให้แน่ใจว่าคุณได้สำรองข้อมูลกระเป๋าสตางค์ของคุณโดยใช้วิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณกับใคร",
          "title": "สร้างหรือนำเข้ากระเป๋าสตางค์"
        },
        "step3": {
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้ว คลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนขยาย",
          "title": "รีเฟรชเบราว์เซอร์ของคุณ"
        }
      }
    },
    "im_token": {
      "qr_code": {
        "step1": {
          "title": "เปิดแอพ imToken",
          "description": "ใส่แอพ imToken ไว้ที่หน้าจอหลักเพื่อเข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น."
        },
        "step2": {
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน",
          "description": "สร้างกระเป๋าเงินใหม่หรือนำเข้ากระเป๋าเงินที่มีอยู่แล้ว"
        },
        "step3": {
          "title": "แตะไอคอนสแกนเนอร์ในมุมบนขวา",
          "description": "เลือก New Connection, แล้วสแกน QR code และยืนยันการรับรองสำหรับการเชื่อมต่อ"
        }
      }
    },
    "kaikas": {
      "extension": {
        "step1": {
          "description": "เราแนะนำให้คุณปักหมุด Kaikas ไว้ที่แถบงานเพื่อการเข้าถึงกระเป๋าเงินได้เร็วขึ้น",
          "title": "ติดตั้งส่วนขยาย Kaikas"
        },
        "step2": {
          "description": "ตรวจสอบการสำรองข้อมูลกระเป๋าสตางค์ของคุณให้แน่นอนโดยใช้วิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณกับใครเป็นอันขาด.",
          "title": "สร้างหรือนำเข้า Wallet"
        },
        "step3": {
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้วคลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนเสริม",
          "title": "รีเฟรชเบราว์เซอร์ของคุณ"
        }
      },
      "qr_code": {
        "step1": {
          "title": "เปิดแอพฯ Kaikas",
          "description": "วางแอพฯ Kaikas ไว้บนหน้าจอหลักเพื่อการเข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "สร้างกระเป๋าเงินใหม่หรือนำเข้าที่มีอยู่แล้ว."
        },
        "step3": {
          "title": "แตะไอคอนสแกนเนอร์ในมุมบนขวา",
          "description": "เลือก New Connection, แล้วสแกน QR code และยืนยันการรับรองสำหรับการเชื่อมต่อ"
        }
      }
    },
    "kraken": {
      "qr_code": {
        "step1": {
          "title": "เปิดแอพ Kraken Wallet",
          "description": "เพิ่ม Kraken Wallet ไปยังหน้าจอหลักของคุณเพื่อเข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "สร้างกระเป๋าเงินใหม่หรือนำเข้าที่มีอยู่แล้ว."
        },
        "step3": {
          "title": "แตะที่ไอคอน QR แล้วสแกน",
          "description": "แตะที่ไอคอน QR บนหน้าจอหลักของคุณ สแกนรหัสและยืนยันการเชื่อมต่อ"
        }
      }
    },
    "kresus": {
      "qr_code": {
        "step1": {
          "title": "เปิดแอพ Kresus Wallet",
          "description": "เพิ่มกระเป๋าเงิน Kresus ลงบนหน้าจอหลักเพื่อการเข้าถึงกระเป๋าเงินของคุณได้เร็วยิ่งขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "สร้างกระเป๋าเงินใหม่หรือนำเข้าที่มีอยู่แล้ว."
        },
        "step3": {
          "title": "แตะที่ไอคอน QR แล้วสแกน",
          "description": "แตะที่ไอคอน QR บนหน้าจอหลักของคุณ สแกนรหัสและยืนยันการเชื่อมต่อ"
        }
      }
    },
    "magicEden": {
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนขยาย Magic Eden",
          "description": "เราแนะนำให้คุณปัก Magic Eden ไว้ที่แถบงานของคุณเพื่อเข้าถึงกระเป๋าเงินของคุณได้ง่ายขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "แน่ใจว่าคุณได้สำรองกระเป๋าเงินของคุณโดยใช้วิธีที่ปลอดภัย อย่าเปิดเผยข้อความลับสำหรับการกู้คืนของคุณกับบุคคลใด ๆ"
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้วคลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนเสริม"
        }
      }
    },
    "metamask": {
      "qr_code": {
        "step1": {
          "title": "เปิดแอป MetaMask",
          "description": "เราขอแนะนำให้วาง MetaMask บนหน้าจอหลักของคุณเพื่อเข้าถึงได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "ตรวจสอบว่าได้สำรองกระเป๋าเงินของคุณโดยใช้วิธีที่ปลอดภัย อย่าเปิดเผยวลีลับของคุณให้กับใคร"
        },
        "step3": {
          "title": "แตะที่ปุ่มสแกน",
          "description": "หลังจากการสแกน, จะปรากฏข้อความเชื่อมต่อสำหรับคุณเพื่อเชื่อมต่อกับกระเป๋าเงินของคุณ"
        }
      },
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนขยาย MetaMask",
          "description": "เราขอแนะนำให้คุณปัก MetaMask ไว้ที่แถบงานของคุณเพื่อเข้าถึงกระเป๋าเงินของคุณได้รวดเร็ว"
        },
        "step2": {
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน",
          "description": "อย่างแน่นอนให้สำรองข้อมูลกระเป๋าเงินของคุณโดยใช้วิธีที่ปลอดภัย อย่าแชร์ประโยคลับของคุณกับใครเลย"
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้ว คลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนขยาย"
        }
      }
    },
    "nestwallet": {
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนขยาย NestWallet",
          "description": "เราแนะนำให้คุณตรึง NestWallet ไว้ที่แถบงานของคุณเพื่อให้เข้าถึงกระเป๋าเงินของคุณได้ง่ายขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "ตรวจสอบการสำรองข้อมูลกระเป๋าสตางค์ของคุณให้แน่นอนโดยใช้วิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณกับใครเป็นอันขาด."
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้วคลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนเสริม"
        }
      }
    },
    "okx": {
      "qr_code": {
        "step1": {
          "title": "เปิดแอพ OKX Wallet",
          "description": "เราแนะนำให้วาง OKX Wallet บนหน้าจอหลักของคุณเพื่อให้เข้าถึงได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "จงแน่ใจว่าคุณได้สำรองข้อมูล wallet ของคุณด้วยวิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณให้คนอื่น"
        },
        "step3": {
          "title": "แตะปุ่มสแกน",
          "description": "หลังจากคุณสแกน จะมีการแสดงข้อมูลเพื่อให้คุณเชื่อมต่อ wallet ของคุณ"
        }
      },
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนเสริม OKX Wallet",
          "description": "เราแนะนำให้ยึด OKX Wallet ไว้ที่แถบงานของคุณเพื่อให้เข้าถึง wallet ของคุณได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "โปรดแน่ใจว่าคุณได้สำรองกระเป๋าสตางค์ของคุณด้วยวิธีที่ปลอดภัย อย่าเปิดเผยประโยคลับของคุณให้ใครทราบ"
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่ากระเป๋าสตางค์ของคุณแล้ว คลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนขยาย"
        }
      }
    },
    "omni": {
      "qr_code": {
        "step1": {
          "title": "เปิดแอป Omni",
          "description": "เพิ่ม Omni ไปยังหน้าจอแรกเพื่อเข้าถึงกระเป๋าสตางค์ของคุณได้รวดเร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้ากระเป๋าสตางค์",
          "description": "สร้างกระเป๋าสตางค์ใหม่หรือนำเข้ากระเป๋าสตางค์ที่มีอยู่"
        },
        "step3": {
          "title": "แตะที่ไอคอน QR แล้วสแกน",
          "description": "แตะที่ไอคอน QR บนหน้าจอหน้าแรกของคุณ, สแกนรหัสและยืนยันการเตือนเพื่อเชื่อมต่อ."
        }
      }
    },
    "1inch": {
      "qr_code": {
        "step1": {
          "description": "วาง 1inch Wallet ไว้บนหน้าจอหลักเพื่อการเข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น",
          "title": "เปิดแอพฯ 1inch Wallet"
        },
        "step2": {
          "description": "สร้างกระเป๋าเงินและชื่อผู้ใช้หรือนำเข้ากระเป๋าเงินที่มีอยู่แล้ว",
          "title": "สร้างหรือนำเข้า Wallet"
        },
        "step3": {
          "description": "หลังจากคุณสแกน จะปรากฏหน้าต่างเชื่อมต่อให้คุณเชื่อมต่อกระเป๋าเงินของคุณ",
          "title": "แตะที่คุ่มุ่งสแกน QR"
        }
      }
    },
    "token_pocket": {
      "qr_code": {
        "step1": {
          "title": "เปิดแอป TokenPocket",
          "description": "เราแนะนำให้วาง TokenPocket บนหน้าจอหน้าแรกของคุณเพื่อเข้าถึงได้เร็วขึ้น."
        },
        "step2": {
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน",
          "description": "ตรวจสอบว่าได้สำรองกระเป๋าเงินของคุณโดยใช้วิธีที่ปลอดภัย อย่าเปิดเผยวลีลับของคุณให้ผู้อื่นทราบในทางใดทางหนึ่ง."
        },
        "step3": {
          "title": "แตะปุ่มสแกน",
          "description": "หลังจากที่คุณสแกนแล้ว จะมีการเรียกให้เชื่อมต่อกับกระเป๋าเงินของคุณ"
        }
      },
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนขยาย TokenPocket",
          "description": "เราขอแนะนำให้คุณปัก TokenPocket ไว้ที่แถบงานเพื่อทำให้สามารถเข้าถึงกระเป๋าเงินของคุณได้ง่ายขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน",
          "description": "ตรวจสอบให้แน่ใจว่าคุณได้สำรองข้อมูลกระเป๋าเงินของคุณด้วยวิธีที่ปลอดภัย อย่าทำการแชร์ประโยคลับด้วยความลับของคุณกับใคร"
        },
        "step3": {
          "title": "รีเฟรชบราวเซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้ว คลิกด้านล่างเพื่อรีเฟรชบราวเซอร์และโหลดส่วนขยาย"
        }
      }
    },
    "trust": {
      "qr_code": {
        "step1": {
          "title": "เปิดแอพ Trust Wallet",
          "description": "วาง Trust Wallet ที่หน้าจอหลักของคุณเพื่อเข้าถึงกระเป๋าเงินของคุณได้รวดเร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "สร้าง wallet ใหม่หรือนำเข้า wallet ที่มีอยู่แล้ว"
        },
        "step3": {
          "title": "แตะ WalletConnect ในการตั้งค่า",
          "description": "เลือก New Connection จากนั้นสแกน QR code และยืนยันการแจ้งเตือนเพื่อเชื่อมต่อ"
        }
      },
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนขยาย Trust Wallet",
          "description": "คลิกที่มุมบนขวาของเบราว์เซอร์ของคุณและปัก Trust Wallet เพื่อเข้าถึงได้ง่าย"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า wallet",
          "description": "สร้าง wallet ใหม่หรือนำเข้า wallet ที่มีอยู่แล้ว"
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่า Trust Wallet แล้ว คลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนขยายขึ้นมา"
        }
      }
    },
    "uniswap": {
      "qr_code": {
        "step1": {
          "title": "เปิดแอป Uniswap",
          "description": "เพิ่ม Uniswap Wallet ไปยังหน้าจอหลักของคุณเพื่อเข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "สร้างกระเป๋าเงินใหม่หรือนำเข้ากระเป๋าเงินที่มีอยู่แล้ว"
        },
        "step3": {
          "title": "แตะที่ไอคอน QR และสแกน",
          "description": "แตะที่ไอคอน QR บนหน้าจอหลักของคุณ สแกนรหัสและยืนยันการเชื่อมต่อ"
        }
      }
    },
    "zerion": {
      "qr_code": {
        "step1": {
          "title": "เปิดแอป Zerion",
          "description": "เราแนะนำให้คุณวาง Zerion บนหน้าจอหลักของคุณเพื่อเข้าถึงได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "ลองทำสำเนาข้อมูล wallet ของคุณไว้ในช่องทางที่ปลอดภัย อย่าเปิดเผยวลีลับของคุณให้กับผู้อื่น"
        },
        "step3": {
          "title": "แตะที่ปุ่มสแกน",
          "description": "หลังจากสแกน จะมีหน้าต่างแสดงคำสั่งเชื่อมต่อให้คุณเชื่อมต่อ wallet ของคุณ"
        }
      },
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนขยาย Zerion",
          "description": "เราแนะนำให้คุณติด Zerion บนแถบงานของคุณเพื่อเข้าถึง wallet ของคุณได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน",
          "description": "ตรวจสอบให้แน่ใจว่าคุณได้สำรองข้อมูลกระเป๋าเงินของคุณโดยวิธีที่ปลอดภัย อย่าเปิดเผยประโยคลับลับของคุณให้ใครทราบครับ"
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้ว คลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนขยาย"
        }
      }
    },
    "rainbow": {
      "qr_code": {
        "step1": {
          "title": "เปิดแอป Rainbow",
          "description": "เราขอแนะนำให้คุณวาง Rainbow อยู่บนหน้าจอหลักของคุณเพื่อรับผิดชอบจากกระเป๋าสตางค์ของคุณอย่างรวดเร็ว"
        },
        "step2": {
          "title": "สร้างหรือนำเข้ากระเป๋าสตางค์",
          "description": "คุณสามารถสำรองข้อมูลกระเป๋าสตางค์ของคุณได้ง่ายๆ ด้วยฟีเจอร์สำรองข้อมูลบนโทรศัพท์ของคุณ"
        },
        "step3": {
          "title": "แตะปุ่มสแกน",
          "description": "หลังจากสแกนแล้ว จะแสดงข้อความขอเชื่อมต่อเพื่อให้คุณเชื่อมต่อกระเป๋าสตางค์ของคุณ"
        }
      }
    },
    "enkrypt": {
      "extension": {
        "step1": {
          "description": "เราขอแนะนำให้คุณปัก Enkrypt Wallet ไว้ที่แทบงานของคุณเพื่อให้สามารถเข้าถึงกระเป๋าสตางค์ของคุณได้เร็วขึ้น",
          "title": "ติดตั้งส่วนขยาย Enkrypt Wallet"
        },
        "step2": {
          "description": "ตรวจสอบให้แน่ใจว่าคุณได้สำรองกระเป๋าสตางค์ของคุณโดยใช้วิธีที่ปลอดภัย ห้ามแชร์วลีลับของคุณให้กับใคร",
          "title": "สร้างหรือนำเข้า Wallet"
        },
        "step3": {
          "description": "เมื่อคุณตั้งค่า wallet ของคุณแล้ว คลิกด้านล่างเพื่อรีเฟรช browser และโหลดขึ้น extension",
          "title": "รีเฟรช browser ของคุณ"
        }
      }
    },
    "frame": {
      "extension": {
        "step1": {
          "description": "เราแนะนำให้หมุน Frame ไว้บน taskbar ของคุณเพื่อให้เข้าถึง wallet ได้เร็วขึ้น",
          "title": "ติดตั้ง Frame และ extension ที่เป็นคู่"
        },
        "step2": {
          "description": "ตรวจสอบว่าได้สำรอง wallet ของคุณโดยใช้วิธีการที่ปลอดภัย อย่าเปิดเผยวลีลับของคุณให้กับใคร",
          "title": "สร้างหรือนำเข้า Wallet"
        },
        "step3": {
          "description": "เมื่อคุณตั้งค่า wallet ของคุณแล้ว คลิกด้านล่างเพื่อรีเฟรช browser และโหลดขึ้น extension",
          "title": "รีเฟรช browser ของคุณ"
        }
      }
    },
    "one_key": {
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนเสริม OneKey Wallet",
          "description": "เราแนะนำการปัก OneKey Wallet ไว้บนแทบงานของคุณเพื่อเข้าถึงกระเป๋าเงินได้ง่ายขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน",
          "description": "อย่าลืมสำรองกระเป๋าเงินของคุณด้วยวิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณกับใคร"
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้ว คลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนเสริม"
        }
      }
    },
    "phantom": {
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนเสริม Phantom",
          "description": "เราแนะนำการปัก Phantom ไว้บนแทบงานของคุณเพื่อเข้าถึงกระเป๋าเงินได้ง่ายขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน",
          "description": "แน่ใจว่าคุณได้สำรองกระเป๋าเงินของคุณโดยใช้วิธีที่ปลอดภัย อย่าเปิดเผยข้อความลับสำหรับการกู้คืนของคุณกับบุคคลใด ๆ"
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินเรียบร้อยแล้ว, คลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนขยาย"
        }
      }
    },
    "rabby": {
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนขยาย Rabby",
          "description": "เราแนะนำให้คุณปัก Rabby ไว้ที่แถบงานเพื่อให้เข้าถึงกระเป๋าเงินของคุณได้รวดเร็วขึ้น."
        },
        "step2": {
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน",
          "description": "แน่ใจว่าคุณได้สำรองกระเป๋าเงินของคุณโดยใช้วิธีที่ปลอดภัย อย่าแชร์ข้อความลับของคุณกับบุคคลอื่น"
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้ว คลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนขยาย"
        }
      }
    },
    "ronin": {
      "qr_code": {
        "step1": {
          "description": "เราแนะนำให้คุณวางกระเป๋าเงิน Ronin บนหน้าจอหลักเพื่อการเข้าถึงที่รวดเร็วยิ่งขึ้น",
          "title": "เปิดแอปกระเป๋าเงิน Ronin"
        },
        "step2": {
          "description": "ตรวจสอบการสำรองข้อมูลกระเป๋าสตางค์ของคุณให้แน่นอนโดยใช้วิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณกับใครเป็นอันขาด.",
          "title": "สร้างหรือนำเข้า Wallet"
        },
        "step3": {
          "description": "หลังจากคุณสแกน จะปรากฏหน้าต่างเชื่อมต่อให้คุณเชื่อมต่อกระเป๋าเงินของคุณ",
          "title": "แตะปุ่มสแกน"
        }
      },
      "extension": {
        "step1": {
          "description": "เราแนะนำให้คุณปักหมุดกระเป๋าเงิน Ronin ไว้ที่แถบงานเพื่อการเข้าถึงกระเป๋าเงินของคุณได้เร็วยิ่งขึ้น",
          "title": "ติดตั้งส่วนขยายกระเป๋าเงิน Ronin"
        },
        "step2": {
          "description": "ตรวจสอบการสำรองข้อมูลกระเป๋าสตางค์ของคุณให้แน่นอนโดยใช้วิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณกับใครเป็นอันขาด.",
          "title": "สร้างหรือนำเข้า Wallet"
        },
        "step3": {
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้วคลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนเสริม",
          "title": "รีเฟรชเบราว์เซอร์ของคุณ"
        }
      }
    },
    "ramper": {
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนขยาย Ramper",
          "description": "เราแนะนำให้คุณปักหมุด Ramper ไว้ที่แถบงานเพื่อการเข้าถึงกระเป๋าเงินของคุณได้ง่ายยิ่งขึ้น"
        },
        "step2": {
          "title": "สร้างกระเป๋าเงิน",
          "description": "ตรวจสอบการสำรองข้อมูลกระเป๋าสตางค์ของคุณให้แน่นอนโดยใช้วิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณกับใครเป็นอันขาด."
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้วคลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนเสริม"
        }
      }
    },
    "safeheron": {
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนขยาย Core",
          "description": "เราขอแนะนำให้คุณปัก Safeheron ไว้ที่แถบงานเพื่อเข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน",
          "description": "อย่าลืมสำรองกระเป๋าเงินของคุณโดยใช้วิธีที่ปลอดภัย อย่าเปิดเผยประโยคลับของคุณให้ผู้อื่นทราบ"
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้ว คลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนขยาย"
        }
      }
    },
    "taho": {
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนขยาย Taho",
          "description": "เราแนะนำให้คุณปัก Taho ไว้ที่แถบงานของคุณเพื่อเข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน",
          "description": "โปรดแน่ใจว่าคุณได้สำรองกระเป๋าเงินของคุณโดยใช้วิธีที่ปลอดภัย อย่าแชร์ประโยคลับคุณกับผู้อื่น"
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้ว คลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนขยาย"
        }
      }
    },
    "talisman": {
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนขยาย Talisman",
          "description": "เราแนะนำให้คุณปัก Talisman ไว้ที่แถบงานของคุณเพื่อเข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน Ethereum",
          "description": "ให้แน่ใจว่าคุณได้สำรองกระเป๋าเงินของคุณโดยใช้วิธีที่ปลอดภัย อย่าเปิดเผยวลีการกู้คืนของคุณให้ใครทราบเด็ดขาด"
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้ว คลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนขยาย"
        }
      }
    },
    "xdefi": {
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนขยาย XDEFI Wallet",
          "description": "เราแนะนำให้คุณตรา XDEFI Wallet ไว้ที่แถบงานเพื่อเข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน",
          "description": "ให้แน่ใจว่าคุณได้สำรองกระเป๋าเงินของคุณโดยใช้วิธีที่ปลอดภัย อย่าเปิดเผยวลีลับของคุณให้ใครทราบเด็ดขาด"
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "หลังจากที่คุณตั้งค่ากระเป๋าสตางค์ของคุณแล้ว คลิกด้านล่างเพื่อรีเฟรชบราวเซอร์และโหลดส่วนเสริม."
        }
      }
    },
    "zeal": {
      "qr_code": {
        "step1": {
          "title": "เปิดแอป Zeal",
          "description": "เพิ่ม Zeal Wallet ไปยังหน้าจอหลักของคุณเพื่อให้เข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "สร้างกระเป๋าเงินใหม่หรือนำเข้าที่มีอยู่แล้ว."
        },
        "step3": {
          "title": "แตะที่ไอคอน QR แล้วสแกน",
          "description": "แตะที่ไอคอน QR บนหน้าจอหลักของคุณ สแกนรหัสและยืนยันการเชื่อมต่อ"
        }
      },
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนขยาย Zeal",
          "description": "เราแนะนำให้ปัก Zeal ไว้ที่แถบงานของคุณเพื่อเข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "ตรวจสอบการสำรองข้อมูลกระเป๋าสตางค์ของคุณให้แน่นอนโดยใช้วิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณกับใครเป็นอันขาด."
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้วคลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนเสริม"
        }
      }
    },
    "safepal": {
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนขยาย SafePal Wallet",
          "description": "คลิกที่มุมบนขวาของเบราว์เซอร์ของคุณและปักมุม SafePal Wallet เพื่อที่จะเข้าถึงได้ง่าย"
        },
        "step2": {
          "title": "สร้างหรือนำเข้ากระเป๋าเงิน",
          "description": "สร้างกระเป๋าเงินใหม่หรือนำเข้าที่มีอยู่แล้ว."
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "หลังจากคุณตั้งค่า SafePal Wallet เรียบร้อยแล้ว คลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนขยาย"
        }
      },
      "qr_code": {
        "step1": {
          "title": "เปิดแอป SafePal Wallet",
          "description": "วาง SafePal Wallet ที่หน้าจอหลักของคุณเพื่อเข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "สร้างกระเป๋าเงินใหม่หรือนำเข้าที่มีอยู่แล้ว."
        },
        "step3": {
          "title": "แตะ WalletConnect ในการตั้งค่า",
          "description": "เลือก New Connection, แล้วสแกน QR code และยืนยันการรับรองสำหรับการเชื่อมต่อ"
        }
      }
    },
    "desig": {
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนขยาย Desig",
          "description": "เราขอแนะนำให้คุณตรึง Desig ไว้ที่แถบงานของคุณเพื่อให้เข้าถึงกระเป๋าเงินของคุณได้ง่ายขึ้น"
        },
        "step2": {
          "title": "สร้างกระเป๋าเงิน",
          "description": "ตรวจสอบการสำรองข้อมูลกระเป๋าสตางค์ของคุณให้แน่นอนโดยใช้วิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณกับใครเป็นอันขาด."
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้วคลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนเสริม"
        }
      }
    },
    "subwallet": {
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนขยาย SubWallet",
          "description": "เราขอแนะนำให้คุณตรึง SubWallet ไว้ที่แถบงานของคุณเพื่อเข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "ให้แน่ใจว่าคุณได้สำรองกระเป๋าเงินของคุณโดยใช้วิธีที่ปลอดภัย อย่าเปิดเผยวลีการกู้คืนของคุณให้ใครทราบเด็ดขาด"
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้วคลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนเสริม"
        }
      },
      "qr_code": {
        "step1": {
          "title": "เปิดแอพ SubWallet",
          "description": "เราขอแนะนำให้วาง SubWallet ไว้ที่หน้าจอหลักของคุณเพื่อเข้าถึงได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "ตรวจสอบการสำรองข้อมูลกระเป๋าสตางค์ของคุณให้แน่นอนโดยใช้วิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณกับใครเป็นอันขาด."
        },
        "step3": {
          "title": "แตะปุ่มสแกน",
          "description": "หลังจากคุณสแกน จะปรากฏหน้าต่างเชื่อมต่อให้คุณเชื่อมต่อกระเป๋าเงินของคุณ"
        }
      }
    },
    "clv": {
      "extension": {
        "step1": {
          "title": "ติดตั้งส่วนขยาย CLV Wallet",
          "description": "เราขอแนะนำให้คุณตรึง CLV Wallet ไว้ที่แถบงานของคุณเพื่อเข้าถึงกระเป๋าเงินของคุณได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "ตรวจสอบการสำรองข้อมูลกระเป๋าสตางค์ของคุณให้แน่นอนโดยใช้วิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณกับใครเป็นอันขาด."
        },
        "step3": {
          "title": "รีเฟรชเบราว์เซอร์ของคุณ",
          "description": "เมื่อคุณตั้งค่ากระเป๋าเงินของคุณแล้วคลิกด้านล่างเพื่อรีเฟรชเบราว์เซอร์และโหลดส่วนเสริม"
        }
      },
      "qr_code": {
        "step1": {
          "title": "เปิดแอพ CLV Wallet",
          "description": "เราแนะนำให้คุณวาง CLV Wallet บนหน้าจอหลักเพื่อให้สามารถเข้าถึงได้เร็วขึ้น"
        },
        "step2": {
          "title": "สร้างหรือนำเข้า Wallet",
          "description": "ตรวจสอบการสำรองข้อมูลกระเป๋าสตางค์ของคุณให้แน่นอนโดยใช้วิธีที่ปลอดภัย อย่าแชร์วลีลับของคุณกับใครเป็นอันขาด."
        },
        "step3": {
          "title": "แตะปุ่มสแกน",
          "description": "หลังจากคุณสแกน จะปรากฏหน้าต่างเชื่อมต่อให้คุณเชื่อมต่อกระเป๋าเงินของคุณ"
        }
      }
    },
    "okto": {
      "qr_code": {
        "step1": {
          "title": "เปิดแอพ Okto",
          "description": "เพิ่ม Okto ไปยังหน้าจอหลักของคุณเพื่อเข้าถึงได้เร็ว"
        },
        "step2": {
          "title": "สร้างกระเป๋าเงิน MPC",
          "description": "สร้างบัญชีและสร้างกระเป๋าเงิน"
        },
        "step3": {
          "title": "แตะ WalletConnect ในการตั้งค่า",
          "description": "แตะที่ไอคอน Scan QR ที่บริเวณมุมบนขวาและยืนยันข้อความเพื่อเชื่อมต่อ."
        }
      }
    },
    "ledger": {
      "desktop": {
        "step1": {
          "title": "เปิดแอป Ledger Live",
          "description": "เราแนะนำให้คุณวาง Ledger Live บนหน้าจอหลักเพื่อให้สามารถเข้าถึงได้เร็วขึ้น"
        },
        "step2": {
          "title": "ตั้งค่า Ledger ของคุณ",
          "description": "ตั้งค่า Ledger ใหม่หรือเชื่อมต่อกับ Ledger ที่มีอยู่แล้ว"
        },
        "step3": {
          "title": "เชื่อมต่อ",
          "description": "หลังจากที่คุณสแกนแล้ว จะมีการเรียกให้เชื่อมต่อกับกระเป๋าเงินของคุณ"
        }
      },
      "qr_code": {
        "step1": {
          "title": "เปิดแอป Ledger Live",
          "description": "เราแนะนำให้วาง Ledger Live บนหน้าจอหลักของคุณเพื่อการเข้าถึงที่รวดเร็วขึ้น"
        },
        "step2": {
          "title": "ตั้งค่า Ledger ของคุณ",
          "description": "คุณสามารถซิงค์กับแอพพลิเคชันบนเดสก์ท็อปหรือเชื่อมต่อ Ledger ของคุณ"
        },
        "step3": {
          "title": "สแกนรหัส",
          "description": "แตะ WalletConnect แล้วเปลี่ยนไปที่ Scanner. หลังจากที่คุณสแกนแล้ว จะมีการเรียกให้เชื่อมต่อกับกระเป๋าเงินของคุณ"
        }
      }
    }
  }
}
`;export{E as default};
