var u=`{
  "connect_wallet": {
    "label": "Cüzdanı Bağla",
    "wrong_network": {
      "label": "Yanlış ağ"
    }
  },
  "intro": {
    "title": "Cüzdan nedir?",
    "description": "Bir cüzdan, dijital varlıkları göndermek, almak, saklamak ve görüntülemek için kullanılır. Aynı zamanda her web sitesinde yeni hesaplar ve şifreler oluşturmanıza gerek kalmadan oturum açmanın yeni bir yoludur.",
    "digital_asset": {
      "title": "Dijital Varlıklarınız İçin Bir Ev",
      "description": "Cüzdanlar, Ethereum ve NFT'ler gibi dijital varlıkları göndermek, almak, depolamak ve görüntülemek için kullanılır."
    },
    "login": {
      "title": "Yeni Bir Giriş Yolu",
      "description": "Her web sitesinde yeni hesap ve parolalar oluşturmak yerine, sadece cüzdanınızı bağlayın."
    },
    "get": {
      "label": "Bir Cüzdan Edinin"
    },
    "learn_more": {
      "label": "Daha fazla bilgi edinin"
    }
  },
  "sign_in": {
    "label": "Hesabınızı doğrulayın",
    "description": "Bağlantıyı tamamlamak için, bu hesabın sahibi olduğunuzu doğrulamak için cüzdanınızdaki bir mesaja imza atmalısınız.",
    "message": {
      "send": "Mesajı gönder",
      "preparing": "Mesaj hazırlanıyor...",
      "cancel": "İptal",
      "preparing_error": "Mesajı hazırlarken hata oluştu, lütfen tekrar deneyin!"
    },
    "signature": {
      "waiting": "İmza bekleniyor...",
      "verifying": "İmza doğrulanıyor...",
      "signing_error": "Mesajı imzalarken hata oluştu, lütfen tekrar deneyin!",
      "verifying_error": "İmza doğrulanırken hata oluştu, lütfen tekrar deneyin!",
      "oops_error": "Hata, bir şeyler yanlış gitti!"
    }
  },
  "connect": {
    "label": "Bağlan",
    "title": "Bir Cüzdanı Bağla",
    "new_to_ethereum": {
      "description": "Ethereum cüzdanlarına yeni misiniz?",
      "learn_more": {
        "label": "Daha fazla bilgi edinin"
      }
    },
    "learn_more": {
      "label": "Daha fazla bilgi edinin"
    },
    "recent": "Son",
    "status": {
      "opening": "%{wallet}açılıyor...",
      "connecting": "Bağlanıyor",
      "connect_mobile": "%{wallet}'da devam edin",
      "not_installed": "%{wallet} yüklü değil",
      "not_available": "%{wallet} kullanılabilir değil",
      "confirm": "Bağlantıyı eklentide onaylayın",
      "confirm_mobile": "Cüzdanında bağlantı isteğini kabul et"
    },
    "secondary_action": {
      "get": {
        "description": "%{wallet}yok mu?",
        "label": "AL"
      },
      "install": {
        "label": "YÜKLE"
      },
      "retry": {
        "label": "YENİDEN DENE"
      }
    },
    "walletconnect": {
      "description": {
        "full": "Resmi WalletConnect modalına mı ihtiyacınız var?",
        "compact": "WalletConnect modalına mı ihtiyacınız var?"
      },
      "open": {
        "label": "AÇ"
      }
    }
  },
  "connect_scan": {
    "title": "%{wallet}ile tarama yapın",
    "fallback_title": "Telefonunuzla tarama yapın"
  },
  "connector_group": {
    "installed": "Yüklendi",
    "recommended": "Tavsiye Edilen",
    "other": "Diğer",
    "popular": "Popüler",
    "more": "Daha Fazla",
    "others": "Diğerleri"
  },
  "get": {
    "title": "Bir Cüzdan Edinin",
    "action": {
      "label": "AL"
    },
    "mobile": {
      "description": "Mobil Cüzdan"
    },
    "extension": {
      "description": "Tarayıcı Eklentisi"
    },
    "mobile_and_extension": {
      "description": "Mobil Cüzdan ve Eklenti"
    },
    "mobile_and_desktop": {
      "description": "Mobil ve Masaüstü Cüzdan"
    },
    "looking_for": {
      "title": "Aradığınız şey bu değil mi?",
      "mobile": {
        "description": "Ana ekranda başka bir cüzdan sağlayıcısıyla başlamak için bir cüzdan seçin."
      },
      "desktop": {
        "compact_description": "Ana ekranda başka bir cüzdan sağlayıcısıyla başlamak için bir cüzdan seçin.",
        "wide_description": "Başka bir cüzdan sağlayıcısıyla başlamak için sol tarafta bir cüzdan seçin."
      }
    }
  },
  "get_options": {
    "title": "%{wallet}ile başlayın",
    "short_title": "%{wallet}Edinin",
    "mobile": {
      "title": "%{wallet} Mobil İçin",
      "description": "Mobil cüzdanı kullanarak Ethereum dünyasını keşfedin.",
      "download": {
        "label": "Uygulamayı alın"
      }
    },
    "extension": {
      "title": "%{wallet} için %{browser}",
      "description": "Cüzdanınıza favori web tarayıcınızdan doğrudan erişin.",
      "download": {
        "label": "%{browser}'e ekle"
      }
    },
    "desktop": {
      "title": "%{wallet} için %{platform}",
      "description": "Güçlü masaüstünüzden cüzdanınıza yerel olarak erişin.",
      "download": {
        "label": "%{platform}ekleyin"
      }
    }
  },
  "get_mobile": {
    "title": "%{wallet}'i yükleyin",
    "description": "iOS veya Android'de indirmek için telefonunuzla tarayın",
    "continue": {
      "label": "Devam et"
    }
  },
  "get_instructions": {
    "mobile": {
      "connect": {
        "label": "Bağlan"
      },
      "learn_more": {
        "label": "Daha fazla bilgi edinin"
      }
    },
    "extension": {
      "refresh": {
        "label": "Yenile"
      },
      "learn_more": {
        "label": "Daha fazla bilgi edinin"
      }
    },
    "desktop": {
      "connect": {
        "label": "Bağlan"
      },
      "learn_more": {
        "label": "Daha fazla bilgi edinin"
      }
    }
  },
  "chains": {
    "title": "Ağları Değiştir",
    "wrong_network": "Yanlış ağ algılandı, devam etmek için bağlantıyı kesin veya değiştirin.",
    "confirm": "Cüzdanında Onayla",
    "switching_not_supported": "Cüzdanınız %{appName}. ağları değiştirmeyi desteklemiyor. Bunun yerine cüzdanınızdan ağları değiştirmeyi deneyin.",
    "switching_not_supported_fallback": "Cüzdanınız bu uygulamadan ağları değiştirmeyi desteklemiyor. Bunun yerine cüzdanınızdaki ağları değiştirmeyi deneyin.",
    "disconnect": "Bağlantıyı Kes",
    "connected": "Bağlı"
  },
  "profile": {
    "disconnect": {
      "label": "Bağlantıyı Kes"
    },
    "copy_address": {
      "label": "Adresi Kopyala",
      "copied": "Kopyalandı!"
    },
    "explorer": {
      "label": "Explorer üzerinde daha fazlasını görün"
    },
    "transactions": {
      "description": "%{appName} işlem burada görünecek...",
      "description_fallback": "İşlemleriniz burada görünecek...",
      "recent": {
        "title": "Son İşlemler"
      },
      "clear": {
        "label": "Hepsini Temizle"
      }
    }
  },
  "wallet_connectors": {
    "argent": {
      "qr_code": {
        "step1": {
          "description": "Cüzdanınıza daha hızlı erişim için Argent'i ana ekranınıza koyun.",
          "title": "Argent uygulamasını açın"
        },
        "step2": {
          "description": "Bir cüzdan ve kullanıcı adı oluşturun veya mevcut bir cüzdanı içe aktarın.",
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar"
        },
        "step3": {
          "description": "Taradıktan sonra, cüzdanınızı bağlamak için bir bağlantı istemi görünecektir.",
          "title": "QR tarayıcı düğmesine dokunun"
        }
      }
    },
    "bifrost": {
      "qr_code": {
        "step1": {
          "description": "Daha hızlı erişim için Bifrost Cüzdan'ı ana ekranınıza koymanızı öneririz.",
          "title": "Bifrost Cüzdan uygulamasını açın"
        },
        "step2": {
          "description": "Kurtarma ifadenizle bir cüzdan oluşturun veya içe aktarın.",
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar"
        },
        "step3": {
          "description": "Tarama işlemi sonrasında, cüzdanınızı bağlamak için bir bağlantı istemi gözükecektir.",
          "title": "Tarayıcı düğmesine dokunun"
        }
      }
    },
    "bitget": {
      "qr_code": {
        "step1": {
          "description": "Daha hızlı erişim için Bitget Cüzdanınızı ana ekranınıza koymanızı öneririz.",
          "title": "Bitget Cüzdan uygulamasını açın"
        },
        "step2": {
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklemeye emin olun. Gizli ifadenizi asla kimseyle paylaşmayın.",
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar"
        },
        "step3": {
          "description": "Tarama yaptıktan sonra, cüzdanınızı bağlamak için bir bağlantı istemi görünecektir.",
          "title": "Tarama düğmesine dokunun"
        }
      },
      "extension": {
        "step1": {
          "description": "Cüzdanınıza daha hızlı erişim için Bitget Cüzdanını görev çubuğunuza sabitlemenizi öneririz.",
          "title": "Bitget Cüzdan eklentisini yükleyin"
        },
        "step2": {
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklemekten emin olun. Gizli ifadenizi hiç kimseyle paylaşmayın.",
          "title": "Bir Cüzdan Oluşturun veya İçe Aktarın"
        },
        "step3": {
          "description": "Cüzdanınızı kurduktan sonra, aşağıya tıklayın ve tarayıcıyı yenileyin ve eklentiyi yükleyin.",
          "title": "Tarayıcınızı yenileyin"
        }
      }
    },
    "bitski": {
      "extension": {
        "step1": {
          "description": "Cüzdanınıza daha hızlı erişim için Bitski'yi görev çubuğunuza sabitlemenizi öneririz.",
          "title": "Bitski eklentisini yükleyin"
        },
        "step2": {
          "description": "Cüzdanınızı güvenli bir yöntem kullanarak yedeklediğinizden emin olun. Gizli ifadenizi kimseyle paylaşmayın.",
          "title": "Bir Cüzdan Oluşturun veya İçe Aktarın"
        },
        "step3": {
          "description": "Cüzdanınızı kurduktan sonra, tarayıcıyı yenilemek ve eklentiyi yüklemek için aşağıya tıklayın.",
          "title": "Tarayıcınızı yenileyin"
        }
      }
    },
    "bitverse": {
      "qr_code": {
        "step1": {
          "title": "Bitverse Cüzdan uygulamasını açın",
          "description": "Cüzdanınıza daha hızlı erişim için Bitverse Cüzdan'ı ana ekranınıza ekleyin."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar",
          "description": "Yeni bir cüzdan oluşturun veya mevcut birini içe aktarın."
        },
        "step3": {
          "title": "QR simgesine dokunun ve tarayın",
          "description": "Ana ekranınızdaki QR simgesine dokunun, kodu tarayın ve bağlanmayı onaylamak için istemi kabul edin."
        }
      }
    },
    "bloom": {
      "desktop": {
        "step1": {
          "title": "Bloom Cüzdan uygulamasını açın",
          "description": "Daha hızlı erişim için Bloom Cüzdan'ı ana ekranınıza koymayı öneririz."
        },
        "step2": {
          "description": "Kurtarma ifadenizle bir cüzdan oluşturun veya içe aktarın.",
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar"
        },
        "step3": {
          "description": "Bir cüzdanınız olduktan sonra, Bloom üzerinden bağlanmak için Bağlan'a tıklayın. Uygulamada bağlantıyı onaylamanız için bir bağlantı istemi belirecektir.",
          "title": "Bağlan'a tıklayın"
        }
      },
      "qr_code": {
        "step1": {
          "title": "Bloom Cüzdan uygulamasını açın",
          "description": "Daha hızlı erişim için Bloom Cüzdan'ı ana ekranınıza koymayı öneririz."
        },
        "step2": {
          "description": "Kurtarma ifadenizle bir cüzdan oluşturun veya içe aktarın.",
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar"
        },
        "step3": {
          "description": "Bir cüzdanınız olduktan sonra, Bloom üzerinden bağlanmak için Bağlan'a tıklayın. Uygulamada bağlantıyı onaylamanız için bir bağlantı istemi belirecektir.",
          "title": "Bağlan'a tıklayın"
        }
      }
    },
    "bybit": {
      "qr_code": {
        "step1": {
          "description": "Cüzdanınıza daha hızlı erişim için Bybit'i ana ekranınıza koymayı öneririz.",
          "title": "Bybit uygulamasını açın"
        },
        "step2": {
          "description": "Telefonunuzdaki yedekleme özelliğimizi kullanarak cüzdanınızı kolayca yedekleyebilirsiniz.",
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar"
        },
        "step3": {
          "description": "Taradıktan sonra, cüzdanınızı bağlamak için bir bağlantı istemi görünecektir.",
          "title": "Tarayıcı düğmesine dokunun"
        }
      },
      "extension": {
        "step1": {
          "description": "Tarayıcınızın sağ üst köşesine tıklayın ve kolay erişim için Bybit Cüzdan'ı sabitleyin.",
          "title": "Bybit Cüzdan uzantısını yükleyin"
        },
        "step2": {
          "description": "Yeni bir cüzdan oluşturun veya mevcut birini içe aktarın.",
          "title": "Bir cüzdan oluşturun veya içe aktarın"
        },
        "step3": {
          "description": "Bybit Cüzdan'ı ayarladıktan sonra, tarayıcıyı yenilemek ve uzantıyı yüklemek için aşağıdaki butona tıklayın.",
          "title": "Tarayıcınızı yenileyin"
        }
      }
    },
    "binance": {
      "qr_code": {
        "step1": {
          "description": "Cüzdanınıza daha hızlı erişim için Binance'u ana ekranınıza koymanızı öneririz.",
          "title": "Binance uygulamasını açın"
        },
        "step2": {
          "description": "Telefonunuzdaki yedekleme özelliğimizi kullanarak cüzdanınızı kolayca yedekleyebilirsiniz.",
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar"
        },
        "step3": {
          "description": "Taradıktan sonra, cüzdanınızı bağlamak için bir bağlantı istemi görünecektir.",
          "title": "CüzdanBağlantısı düğmesine dokunun"
        }
      }
    },
    "coin98": {
      "qr_code": {
        "step1": {
          "description": "Cüzdanınıza daha hızlı erişim için Coin98 Cüzdanınızı ana ekranınıza koymanızı öneririz.",
          "title": "Coin98 Cüzdan uygulamasını açın"
        },
        "step2": {
          "description": "Telefonunuzdaki yedekleme özelliğimizi kullanarak cüzdanınızı kolayca yedekleyebilirsiniz.",
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar"
        },
        "step3": {
          "description": "Tarama işlemi yaptıktan sonra, cüzdanınızı bağlamak için bir bağlantı istemi görünecektir.",
          "title": "CüzdanBağlantısı düğmesine dokunun"
        }
      },
      "extension": {
        "step1": {
          "description": "Tarayıcınızın sağ üst köşesinde tıklayın ve Coin98 Cüzdanınızı kolay erişim için sabitleyin.",
          "title": "Coin98 Cüzdan eklentisini yükleyin"
        },
        "step2": {
          "description": "Yeni bir cüzdan oluşturun veya mevcut birini içe aktarın.",
          "title": "Bir cüzdan oluşturun veya içe aktarın"
        },
        "step3": {
          "description": "Coin98 Cüzdan'ı kurduktan sonra, tarayıcıyı yenilemek ve eklentiyi yüklemek için aşağıya tıklayın.",
          "title": "Tarayıcınızı yenileyin"
        }
      }
    },
    "coinbase": {
      "qr_code": {
        "step1": {
          "description": "Coinbase Cüzdan'ı ana ekranınıza koymanızı öneririz, böylece daha hızlı erişim sağlanır.",
          "title": "Coinbase Wallet uygulamasını açın"
        },
        "step2": {
          "description": "Cüzdanınızı bulut yedekleme özelliğini kullanarak kolayca yedekleyebilirsiniz.",
          "title": "Bir Cüzdan Oluşturun veya İçe Aktarın"
        },
        "step3": {
          "description": "Tarama yaptıktan sonra, cüzdanınızı bağlamanız için bir bağlantı istemi belirecektir.",
          "title": "Tarama düğmesine dokunun"
        }
      },
      "extension": {
        "step1": {
          "description": "Cüzdanınıza daha hızlı erişim için Coinbase Wallet'ı görev çubuğunuza sabitlemenizi öneririz.",
          "title": "Coinbase Wallet uzantısını yükleyin"
        },
        "step2": {
          "description": "Cüzdanınızı güvenli bir yöntem kullanarak yedekleyin. Gizli ifadenizi asla başkalarıyla paylaşmayın.",
          "title": "Cüzdan Oluştur veya İçe Aktar"
        },
        "step3": {
          "description": "Cüzdanınızı kurduktan sonra, tarayıcıyı yenilemek ve eklentiyi yüklemek için aşağıya tıklayın.",
          "title": "Tarayıcınızı yenileyin"
        }
      }
    },
    "compass": {
      "extension": {
        "step1": {
          "description": "Cüzdanınıza daha hızlı erişim için Compass Wallet'ı görev çubuğunuza sabitlemenizi öneririz.",
          "title": "Compass Wallet uzantısını yükleyin"
        },
        "step2": {
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklemeye emin olun. Gizli ifadenizi asla kimseyle paylaşmayın.",
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar"
        },
        "step3": {
          "description": "Cüzdanınızı kurduktan sonra, aşağıya tıklayın ve tarayıcıyı yenileyin ve eklentiyi yükleyin.",
          "title": "Tarayıcınızı yenileyin"
        }
      }
    },
    "core": {
      "qr_code": {
        "step1": {
          "description": "Cüzdanınıza daha hızlı erişim için Core'u ana ekranınıza koymanızı öneririz.",
          "title": "Core uygulamasını açın"
        },
        "step2": {
          "description": "Cüzdanınızın yedeğini telefonunuzda bulunan yedekleme özelliğimizi kullanarak kolayca alabilirsiniz.",
          "title": "Cüzdan Oluştur veya İçe Aktar"
        },
        "step3": {
          "description": "Tarama yaptıktan sonra, cüzdanınızı bağlamak üzere bir bağlantı istemi görünecektir.",
          "title": "WalletConnect düğmesine dokunun"
        }
      },
      "extension": {
        "step1": {
          "description": "Cüzdanınıza daha hızlı erişim için Core'u görev çubuğunuza sabitlemenizi öneririz.",
          "title": "Core eklentisini yükleyin"
        },
        "step2": {
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklemeye dikkat edin. Gizli ifadenizi asla kimseyle paylaşmayın.",
          "title": "Bir Cüzdan Oluşturun veya İçe Aktarın"
        },
        "step3": {
          "description": "Cüzdanınızı kurduktan sonra, aşağıya tıklayarak tarayıcıyı yenileyin ve eklentiyi yükleyin.",
          "title": "Tarayıcınızı yenileyin"
        }
      }
    },
    "fox": {
      "qr_code": {
        "step1": {
          "description": "Daha hızlı erişim için FoxWallet'ı ana ekranınıza koymanızı öneririz.",
          "title": "FoxWallet uygulamasını açın"
        },
        "step2": {
          "description": "Cüzdanınızı güvenli bir yöntem kullanarak yedeklediğinizden emin olun. Gizli ifadenizi asla kimseyle paylaşmayın.",
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar"
        },
        "step3": {
          "description": "Tarama yaptıktan sonra cüzdanınızı bağlamanız için bir bağlantı istemi belirecektir.",
          "title": "Tarama düğmesine dokunun"
        }
      }
    },
    "frontier": {
      "qr_code": {
        "step1": {
          "description": "Daha hızlı erişim için Frontier Cüzdanını ana ekranınıza koymanızı öneririz.",
          "title": "Frontier Cüzdan uygulamasını açın"
        },
        "step2": {
          "description": "Cüzdanınızı güvenli bir yöntem kullanarak yedeklediğinizden emin olun. Gizli ifadenizi asla kimseyle paylaşmayın.",
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar"
        },
        "step3": {
          "description": "Taramadan sonra, cüzdanınızı bağlamak için bir bağlantı istemi görünecektir.",
          "title": "Tarama düğmesine dokunun"
        }
      },
      "extension": {
        "step1": {
          "description": "Cüzdanınıza daha hızlı erişim için Frontier Cüzdanını görev çubuğunuza sabitlemenizi öneririz.",
          "title": "Frontier Cüzdan eklentisini yükleyin"
        },
        "step2": {
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklediğinizden emin olun. Gizli ifadenizi hiç kimseyle paylaşmayın.",
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar"
        },
        "step3": {
          "description": "Cüzdanınızı ayarladıktan sonra, tarayıcıyı yenilemeye ve eklentiyi yüklemeye başlamak için aşağıya tıklayın.",
          "title": "Tarayıcınızı Yenileyin"
        }
      }
    },
    "im_token": {
      "qr_code": {
        "step1": {
          "title": "imToken uygulamasını açın",
          "description": "Cüzdanınıza daha hızlı erişim için imToken uygulamasını ana ekranınıza koyun."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar",
          "description": "Yeni bir cüzdan oluşturun veya mevcut bir cüzdanı içe aktarın."
        },
        "step3": {
          "title": "Sağ üst köşede Tarayıcı Simgesine dokunun",
          "description": "Yeni Bağlantı'yı seçin, ardından QR kodunu tarayın ve bağlantıyı onaylamak için istemi onaylayın."
        }
      }
    },
    "kaikas": {
      "extension": {
        "step1": {
          "description": "Cüzdanınıza daha hızlı erişim için Kaikas'ı görev çubuğunuza sabitlemeyi öneririz.",
          "title": "Kaikas uzantısını yükleyin"
        },
        "step2": {
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklemeye emin olun. Gizli ifadenizi asla kimseyle paylaşmayın.",
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar"
        },
        "step3": {
          "description": "Cüzdanınızı kurduktan sonra, aşağıya tıklayın ve tarayıcıyı yenileyin ve eklentiyi yükleyin.",
          "title": "Tarayıcınızı yenileyin"
        }
      },
      "qr_code": {
        "step1": {
          "title": "Kaikas uygulamasını açın",
          "description": "Cüzdanınıza daha hızlı erişim için Kaikas uygulamasını ana ekranınıza koyun."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar",
          "description": "Yeni bir cüzdan oluşturun veya mevcut birini içe aktarın."
        },
        "step3": {
          "title": "Sağ üst köşede Tarayıcı Simgesine dokunun",
          "description": "Yeni Bağlantı'yı seçin, ardından QR kodunu tarayın ve bağlantıyı onaylamak için istemi onaylayın."
        }
      }
    },
    "kraken": {
      "qr_code": {
        "step1": {
          "title": "Kraken Wallet uygulamasını açın",
          "description": "Cüzdanınıza daha hızlı erişim için Kraken Wallet'ı ana ekranınıza koymanızı öneririz."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar",
          "description": "Yeni bir cüzdan oluşturun veya mevcut birini içe aktarın."
        },
        "step3": {
          "title": "QR simgesine dokunun ve tarayın",
          "description": "Ana ekranınızdaki QR simgesine dokunun, kodu tarayın ve bağlanmayı onaylamak için istemi kabul edin."
        }
      }
    },
    "kresus": {
      "qr_code": {
        "step1": {
          "title": "Kresus Cüzdan uygulamasını açın",
          "description": "Cüzdanınıza daha hızlı erişim için Kresus Cüzdanını ana ekranınıza ekleyin."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar",
          "description": "Yeni bir cüzdan oluşturun veya mevcut birini içe aktarın."
        },
        "step3": {
          "title": "QR simgesine dokunun ve tarayın",
          "description": "Ana ekranınızdaki QR simgesine dokunun, kodu tarayın ve bağlanmayı onaylamak için istemi kabul edin."
        }
      }
    },
    "magicEden": {
      "extension": {
        "step1": {
          "title": "Magic Eden eklentisini yükleyin",
          "description": "Cüzdanınıza daha kolay erişim sağlamak için Magic Eden'i görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar",
          "description": "Cüzdanınızı güvenli bir yöntem kullanarak yedeklediğinizden emin olun. Gizli kurtarma ifadenizi kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Cüzdanınızı kurduktan sonra, aşağıya tıklayın ve tarayıcıyı yenileyin ve eklentiyi yükleyin."
        }
      }
    },
    "metamask": {
      "qr_code": {
        "step1": {
          "title": "MetaMask uygulamasını açın",
          "description": "Daha hızlı erişim için MetaMask'ı ana ekranınıza koymanızı öneririz."
        },
        "step2": {
          "title": "Bir Cüzdan Oluşturun veya İçe Aktarın",
          "description": "Cüzdanınızı güvenli bir yöntem kullanarak yedekleyin. Gizli kurtarma ifadenizi asla başkalarıyla paylaşmayın."
        },
        "step3": {
          "title": "Tarama düğmesine dokunun",
          "description": "Taramayı yaptıktan sonra, cüzdanınızı bağlamak için bir bağlantı istemi belirecektir."
        }
      },
      "extension": {
        "step1": {
          "title": "MetaMask eklentisini yükleyin",
          "description": "Cüzdanınıza daha hızlı erişim için MetaMask'i görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Bir Cüzdan Oluşturun veya İçe Aktarın",
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklediğinizden emin olun. Gizli ifadenizi hiç kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı Yenileyin",
          "description": "Cüzdanınızı ayarladıktan sonra, tarayıcıyı yenilemek ve eklentiyi yüklemek için aşağıya tıklayın."
        }
      }
    },
    "nestwallet": {
      "extension": {
        "step1": {
          "title": "NestWallet eklentisini yükleyin",
          "description": "Cüzdanınıza daha hızlı erişim sağlamak için NestWallet'i görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar",
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklemeye emin olun. Gizli ifadenizi asla kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Cüzdanınızı kurduktan sonra, aşağıya tıklayın ve tarayıcıyı yenileyin ve eklentiyi yükleyin."
        }
      }
    },
    "okx": {
      "qr_code": {
        "step1": {
          "title": "OKX Wallet uygulamasını açın",
          "description": "Daha hızlı erişim için OKX Wallet'ı ana ekranınıza koymanızı öneririz."
        },
        "step2": {
          "title": "Bir Cüzdan Oluşturun veya İçe Aktarın",
          "description": "Cüzdanınızı güvenli bir yöntem kullanarak yedeklediğinizden emin olun. Gizli cümlenizi asla kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarama düğmesine dokunun",
          "description": "Tarama yaptıktan sonra, cüzdanınızı bağlama istemi görünecektir."
        }
      },
      "extension": {
        "step1": {
          "title": "OKX Cüzdan eklentisini yükleyin",
          "description": "Cüzdanınıza daha hızlı erişim için OKX Cüzdan'ı görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Cüzdan Oluşturun veya İçe Aktarın",
          "description": "Cüzdanınızı güvenli bir yöntem kullanarak yedeklediğinizden emin olun. Gizli cümlenizi asla kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Cüzdanınızı kurduktan sonra, tarayıcıyı yenilemek ve eklentiyi yüklemek için aşağıya tıklayın."
        }
      }
    },
    "omni": {
      "qr_code": {
        "step1": {
          "title": "Omni uygulamasını açın",
          "description": "Cüzdanınıza daha hızlı erişim için Omni'yi ana ekranınıza ekleyin."
        },
        "step2": {
          "title": "Bir Cüzdan Oluşturun ya da İçe Aktarın",
          "description": "Yeni bir cüzdan oluşturun veya mevcut birini içe aktarın."
        },
        "step3": {
          "title": "QR simgesine dokunun ve tarayın",
          "description": "Ana ekranınızdaki QR simgesine dokunun, kodu tarayın ve bağlanmak için istemi onaylayın."
        }
      }
    },
    "1inch": {
      "qr_code": {
        "step1": {
          "description": "Cüzdanınıza daha hızlı erişim için 1inch Cüzdan'ı ana ekranınıza koyun.",
          "title": "1inch Cüzdan uygulamasını açın"
        },
        "step2": {
          "description": "Bir cüzdan ve kullanıcı adı oluşturun veya mevcut bir cüzdanı içe aktarın.",
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar"
        },
        "step3": {
          "description": "Taradıktan sonra, cüzdanınızı bağlamak için bir bağlantı istemi görünecektir.",
          "title": "QR tarayıcı düğmesine dokunun"
        }
      }
    },
    "token_pocket": {
      "qr_code": {
        "step1": {
          "title": "TokenPocket uygulamasını açın",
          "description": "Daha hızlı erişim için TokenPocket'ı ana ekranınıza koymanızı öneririz."
        },
        "step2": {
          "title": "Bir Cüzdan Oluşturun veya Cüzdanı İçe Aktarın",
          "description": "Cüzdanınızı güvenli bir yöntem kullanarak yedekleyin. Gizli ifadenizi asla başkalarıyla paylaşmayın."
        },
        "step3": {
          "title": "Tarama düğmesine dokunun",
          "description": "Taramayı yaptıktan sonra, cüzdanınızı bağlamak için bir bağlantı istemi belirecektir."
        }
      },
      "extension": {
        "step1": {
          "title": "TokenPocket eklentisini yükleyin",
          "description": "Cüzdanınıza daha hızlı erişim için TokenPocket'i görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar",
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklediğinizden emin olun. Gizli cümlenizi asla başkalarıyla paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Cüzdanınızı ayarladıktan sonra, tarayıcıyı yenilemekte ve eklentiyi yüklemek için aşağıya tıklayın."
        }
      }
    },
    "trust": {
      "qr_code": {
        "step1": {
          "title": "Trust Wallet uygulamasını açın",
          "description": "Cüzdanınıza daha hızlı erişim için Trust Wallet'ı ana ekranınıza koyun."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar",
          "description": "Yeni bir cüzdan oluşturun veya mevcut bir tane içe aktarın."
        },
        "step3": {
          "title": "Ayarlar'da WalletConnect'e dokunun",
          "description": "Yeni Bağlantı'yı seçin, ardından QR kodunu tarayın ve bağlanmak için istemi onaylayın."
        }
      },
      "extension": {
        "step1": {
          "title": "Trust Wallet eklentisini yükleyin",
          "description": "Tarayıcınızın sağ üst köşesine tıklayın ve kolay erişim için Trust Wallet'i sabitleyin."
        },
        "step2": {
          "title": "Bir cüzdan oluşturun veya içe aktarın",
          "description": "Yeni bir cüzdan oluşturun veya mevcut bir tane içe aktarın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Trust Wallet'ı kurduktan sonra, tarayıcıyı yenilemek ve eklentiyi yüklemek için aşağıya tıklayın."
        }
      }
    },
    "uniswap": {
      "qr_code": {
        "step1": {
          "title": "Uniswap uygulamasını açın",
          "description": "Cüzdanınıza daha hızlı erişim için Uniswap Cüzdanınızı ana ekranınıza ekleyin."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya İçe Aktar",
          "description": "Yeni bir cüzdan oluşturun veya mevcut birini içe aktarın."
        },
        "step3": {
          "title": "QR ikonuna dokunun ve tarama yapın",
          "description": "Ana ekranınızdaki QR simgesine dokunun, kodu tarayın ve bağlanmayı onaylamak için istemi kabul edin."
        }
      }
    },
    "zerion": {
      "qr_code": {
        "step1": {
          "title": "Zerion uygulamasını açın",
          "description": "Daha hızlı erişim için Zerion'un ana ekranınıza konumlandırmanızı öneririz."
        },
        "step2": {
          "title": "Bir Cüzdan Oluşturun veya İçe Aktarın",
          "description": "Cüzdanınızı güvenli bir yöntem kullanarak yedekleyin. Gizli ifadenizi asla başkalarıyla paylaşmayın."
        },
        "step3": {
          "title": "Tarama düğmesine basın",
          "description": "Taramadan sonra, cüzdanınızı bağlamak için bir bağlantı istemi belirecektir."
        }
      },
      "extension": {
        "step1": {
          "title": "Zerion eklentisini yükleyin",
          "description": "Cüzdanınıza daha hızlı erişim için Zerion'u görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya İçe Aktar",
          "description": "Cüzdanınızı güvenli bir yöntem kullanarak yedeklemeye emin olun. Gizli ifadenizi asla başkalarıyla paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Cüzdanınızı ayarladıktan sonra, tarayıcıyı yenilemek ve eklentiyi yüklemek için aşağıya tıklayın."
        }
      }
    },
    "rainbow": {
      "qr_code": {
        "step1": {
          "title": "Rainbow uygulamasını açın",
          "description": "Cüzdanınıza daha hızlı erişim için Rainbow'u ana ekranınıza koymanızı öneririz."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya İçe Aktar",
          "description": "Telefonunuzdaki yedekleme özelliğimizi kullanarak cüzdanınızı kolayca yedekleyebilirsiniz."
        },
        "step3": {
          "title": "Tarama düğmesine dokunun",
          "description": "Tarama yaptıktan sonra, cüzdanınızı bağlamanız için bir bağlantı istemi belirecektir."
        }
      }
    },
    "enkrypt": {
      "extension": {
        "step1": {
          "description": "Cüzdanınıza daha hızlı erişim sağlamak için Enkrypt Cüzdan'ı görev çubuğunuza sabitlemenizi öneririz.",
          "title": "Enkrypt Cüzdan eklentisini yükleyin"
        },
        "step2": {
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklediğinizden emin olun. Gizli ifadenizi hiç kimseyle paylaşmayın.",
          "title": "Bir Cüzdan Oluşturun veya İçe Aktarın"
        },
        "step3": {
          "description": "Cüzdanınızı kurduktan sonra, tarayıcıyı yenilemek ve eklentiyi yüklemek için aşağıya tıklayın.",
          "title": "Tarayıcınızı yenileyin"
        }
      }
    },
    "frame": {
      "extension": {
        "step1": {
          "description": "Cüzdanınıza daha hızlı erişim sağlamak için Frame'ı görev çubuğunuza sabitlemenizi öneririz.",
          "title": "Frame ve eşlik eden uzantıyı yükleyin"
        },
        "step2": {
          "description": "Cüzdanınızı güvenli bir yöntem kullanarak yedeklediğinizden emin olun. Gizli ifadenizi asla başkasıyla paylaşmayın.",
          "title": "Cüzdan Oluştur veya İçe Aktar"
        },
        "step3": {
          "description": "Cüzdanınızı ayarladıktan sonra, tarayıcıyı yenilemek ve uzantıyı yüklemek için aşağıya tıklayın.",
          "title": "Tarayıcınızı yenileyin"
        }
      }
    },
    "one_key": {
      "extension": {
        "step1": {
          "title": "OneKey Wallet uzantısını yükleyin",
          "description": "Cüzdanınıza daha hızlı erişim için OneKey Wallet'ı görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya İçe Aktar",
          "description": "Cüzdanınızı güvenli bir yöntem kullanarak yedeklediğinizden emin olun. Gizli ifadenizi kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Cüzdanınızı kurduktan sonra, tarayıcıyı yenilemek ve eklentiyi yüklemek için aşağıya tıklayın."
        }
      }
    },
    "phantom": {
      "extension": {
        "step1": {
          "title": "Phantom eklentisini yükleyin",
          "description": "Cüzdanınıza daha kolay erişim sağlamak için Phantom'u görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Bir Cüzdan Oluşturun veya İçe Aktarın",
          "description": "Cüzdanınızı güvenli bir yöntem kullanarak yedeklediğinizden emin olun. Gizli kurtarma ifadenizi kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Cüzdanınızı ayarladıktan sonra, tarayıcıyı yenilemek ve eklentiyi yüklemek için aşağıya tıklayın."
        }
      }
    },
    "rabby": {
      "extension": {
        "step1": {
          "title": "Rabby eklentisini yükleyin",
          "description": "Cüzdanınıza daha hızlı erişim için Rabby'yi görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya İçe Aktar",
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklediğinizden emin olun. Gizli ifadenizi asla başkalarıyla paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Cüzdanınızı kurduktan sonra, tarayıcıyı yenilemek ve eklentiyi yüklemek için aşağıdaki düğmeye tıklayın."
        }
      }
    },
    "ronin": {
      "qr_code": {
        "step1": {
          "description": "Cüzdanınıza daha hızlı erişim için Ronin Cüzdanını ana ekranınıza koymayı öneririz.",
          "title": "Ronin Cüzdan uygulamasını açın"
        },
        "step2": {
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklemeye emin olun. Gizli ifadenizi asla kimseyle paylaşmayın.",
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar"
        },
        "step3": {
          "description": "Taradıktan sonra, cüzdanınızı bağlamak için bir bağlantı istemi görünecektir.",
          "title": "Tarayıcı düğmesine dokunun"
        }
      },
      "extension": {
        "step1": {
          "description": "Cüzdanınıza daha hızlı erişim için Ronin Cüzdanını görev çubuğunuza sabitlemenizi öneririz.",
          "title": "Ronin Cüzdan eklentisini yükleyin"
        },
        "step2": {
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklemeye emin olun. Gizli ifadenizi asla kimseyle paylaşmayın.",
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar"
        },
        "step3": {
          "description": "Cüzdanınızı kurduktan sonra, aşağıya tıklayın ve tarayıcıyı yenileyin ve eklentiyi yükleyin.",
          "title": "Tarayıcınızı yenileyin"
        }
      }
    },
    "ramper": {
      "extension": {
        "step1": {
          "title": "Ramper eklentisini yükleyin",
          "description": "Cüzdanınıza daha kolay erişim için Ramper'ı görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Bir Cüzdan Oluşturun",
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklemeye emin olun. Gizli ifadenizi asla kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Cüzdanınızı kurduktan sonra, aşağıya tıklayın ve tarayıcıyı yenileyin ve eklentiyi yükleyin."
        }
      }
    },
    "safeheron": {
      "extension": {
        "step1": {
          "title": "Core eklentisini yükleyin",
          "description": "Cüzdanınıza daha hızlı erişim için Safeheron'u görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya İçe Aktar",
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklediğinizden emin olun. Gizli ifadenizi hiç kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Cüzdanınızı ayarladıktan sonra, tarayıcıyı yenilemek ve eklentiyi yüklemek için aşağıya tıklayın."
        }
      }
    },
    "taho": {
      "extension": {
        "step1": {
          "title": "Taho uzantısını yükleyin",
          "description": "Cüzdanınıza daha hızlı erişim için Taho'yu görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Bir Cüzdan Oluşturun veya İçe Aktarın",
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklediğinizden emin olun. Gizli ifadenizi hiç kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Cüzdanınızı ayarladıktan sonra, tarayıcıyı yenilemek ve eklentiyi yüklemek için aşağıya tıklayın."
        }
      }
    },
    "talisman": {
      "extension": {
        "step1": {
          "title": "Talisman eklentisini yükleyin",
          "description": "Cüzdanınıza daha hızlı erişim için Talisman'ı görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Ethereum Cüzdanı Oluşturun veya İçe Aktarın",
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklediğinizden emin olun. Kurtarma ifadenizi hiç kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Cüzdanınızı ayarladıktan sonra, tarayıcıyı yenilemek ve eklentiyi yüklemek için aşağıya tıklayın."
        }
      }
    },
    "xdefi": {
      "extension": {
        "step1": {
          "title": "XDEFI Cüzdan eklentisini yükleyin",
          "description": "Cüzdanınıza daha hızlı erişim için XDEFI Wallet'ı görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Bir Cüzdan Oluşturun veya İçe Aktarın",
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklediğinizden emin olun. Gizli ifadenizi hiç kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Cüzdanınızı ayarladıktan sonra, tarayıcıyı yenilemek ve eklentiyi yüklemek için aşağıya tıklayın."
        }
      }
    },
    "zeal": {
      "qr_code": {
        "step1": {
          "title": "Zeal uygulamasını açın",
          "description": "Cüzdanınıza daha hızlı erişim için Zeal Cüzdanı ana ekranınıza ekleyin."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar",
          "description": "Yeni bir cüzdan oluşturun veya mevcut birini içe aktarın."
        },
        "step3": {
          "title": "QR simgesine dokunun ve tarayın",
          "description": "Ana ekranınızdaki QR simgesine dokunun, kodu tarayın ve bağlanmayı onaylamak için istemi kabul edin."
        }
      },
      "extension": {
        "step1": {
          "title": "Zeal eklentisini yükleyin",
          "description": "Cüzdanınıza daha hızlı erişim için Zeal'ı görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar",
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklemeye emin olun. Gizli ifadenizi asla kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Cüzdanınızı kurduktan sonra, aşağıya tıklayın ve tarayıcıyı yenileyin ve eklentiyi yükleyin."
        }
      }
    },
    "safepal": {
      "extension": {
        "step1": {
          "title": "SafePal Wallet eklentisini yükleyin",
          "description": "Tarayıcınızın sağ üst köşesine tıklayın ve kolay erişim için SafePal Wallet'ı sabitleyin."
        },
        "step2": {
          "title": "Bir cüzdan oluşturun veya içe aktarın",
          "description": "Yeni bir cüzdan oluşturun veya mevcut birini içe aktarın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "SafePal Cüzdan'ı kurduktan sonra, tarayıcıyı yenilemek ve eklentiyi yüklemek için aşağıya tıklayın."
        }
      },
      "qr_code": {
        "step1": {
          "title": "SafePal Cüzdan uygulamasını açın",
          "description": "SafePal Cüzdan'ı ana ekranınıza koyun, cüzdanınıza daha hızlı erişim için."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar",
          "description": "Yeni bir cüzdan oluşturun veya mevcut birini içe aktarın."
        },
        "step3": {
          "title": "Ayarlar'da WalletConnect'e dokunun",
          "description": "Yeni Bağlantı'yı seçin, ardından QR kodunu tarayın ve bağlantıyı onaylamak için istemi onaylayın."
        }
      }
    },
    "desig": {
      "extension": {
        "step1": {
          "title": "Desig eklentisini yükleyin",
          "description": "Cüzdanınıza daha kolay erişim sağlamak için Desig'i görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Bir Cüzdan Oluşturun",
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklemeye emin olun. Gizli ifadenizi asla kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Cüzdanınızı kurduktan sonra, aşağıya tıklayın ve tarayıcıyı yenileyin ve eklentiyi yükleyin."
        }
      }
    },
    "subwallet": {
      "extension": {
        "step1": {
          "title": "SubWallet eklentisini yükleyin",
          "description": "Cüzdanınıza daha hızlı erişim için SubWallet'ı görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar",
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklediğinizden emin olun. Kurtarma ifadenizi hiç kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Cüzdanınızı kurduktan sonra, aşağıya tıklayın ve tarayıcıyı yenileyin ve eklentiyi yükleyin."
        }
      },
      "qr_code": {
        "step1": {
          "title": "SubWallet uygulamasını açın",
          "description": "Daha hızlı erişim için SubWallet'ı ana ekranınıza koymenizi öneririz."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar",
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklemeye emin olun. Gizli ifadenizi asla kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcı düğmesine dokunun",
          "description": "Taradıktan sonra, cüzdanınızı bağlamak için bir bağlantı istemi görünecektir."
        }
      }
    },
    "clv": {
      "extension": {
        "step1": {
          "title": "CLV Cüzdanı eklentisini yükleyin",
          "description": "Cüzdanınıza daha hızlı erişim için CLV Cüzdanını görev çubuğunuza sabitlemenizi öneririz."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar",
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklemeye emin olun. Gizli ifadenizi asla kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcınızı yenileyin",
          "description": "Cüzdanınızı kurduktan sonra, aşağıya tıklayın ve tarayıcıyı yenileyin ve eklentiyi yükleyin."
        }
      },
      "qr_code": {
        "step1": {
          "title": "CLV Cüzdan uygulamasını açın",
          "description": "Daha hızlı erişim için CLV Cüzdanını ana ekranınıza koymanızı öneririz."
        },
        "step2": {
          "title": "Cüzdan Oluştur veya Cüzdanı İçe Aktar",
          "description": "Cüzdanınızı güvenli bir yöntemle yedeklemeye emin olun. Gizli ifadenizi asla kimseyle paylaşmayın."
        },
        "step3": {
          "title": "Tarayıcı düğmesine dokunun",
          "description": "Taradıktan sonra, cüzdanınızı bağlamak için bir bağlantı istemi görünecektir."
        }
      }
    },
    "okto": {
      "qr_code": {
        "step1": {
          "title": "Okto uygulamasını açın",
          "description": "Hızlı erişim için Okto'yu ana ekranınıza ekleyin"
        },
        "step2": {
          "title": "MPC Cüzdanı oluşturun",
          "description": "Bir hesap oluşturun ve bir cüzdan oluşturun"
        },
        "step3": {
          "title": "Ayarlar'da WalletConnect'e dokunun",
          "description": "Sağ üstteki Tarama QR simgesine dokunun ve bağlanmak için istemi onaylayın."
        }
      }
    },
    "ledger": {
      "desktop": {
        "step1": {
          "title": "Ledger Live uygulamasını açın",
          "description": "Daha hızlı erişim için Ledger Live'ı ana ekranınıza koymanızı öneririz."
        },
        "step2": {
          "title": "Ledger'ınızı kurun",
          "description": "Yeni bir Ledger kurun veya mevcut birine bağlanın."
        },
        "step3": {
          "title": "Bağlan",
          "description": "Cüzdanınızı bağlamak için bir bağlantı istemi belirecektir."
        }
      },
      "qr_code": {
        "step1": {
          "title": "Ledger Live uygulamasını açın",
          "description": "Daha hızlı erişim için Ledger Live'ı ana ekranınıza koymanızı öneririz."
        },
        "step2": {
          "title": "Ledger'ınızı kurun",
          "description": "Masaüstü uygulama ile senkronize olabilir veya Ledger'ınızı bağlayabilirsiniz."
        },
        "step3": {
          "title": "Kodu tarayın",
          "description": "WalletConnect'e dokunun ve ardından Tarayıcı'ya geçin. Taramadan sonra, cüzdanınızı bağlamak için bir bağlantı istemi belirecektir."
        }
      }
    }
  }
}
`;export{u as default};
