var u=`{
  "connect_wallet": {
    "label": "वॉलेट को कनेक्ट करें",
    "wrong_network": {
      "label": "गलत नेटवर्क"
    }
  },
  "intro": {
    "title": "वॉलेट क्या है?",
    "description": "एक वॉलेट का उपयोग डिजिटल संपत्तियों को भेजने, प्राप्त करने, संग्रहित करने और प्रदर्शित करने के लिए किया जाता है। यह एक नया तरीका भी है लॉग इन करने का, हर वेबसाइट पर नए खाते और पासवर्ड बनाने की जरूरत के बिना।",
    "digital_asset": {
      "title": "अपने डिजिटल संपत्तियों के लिए एक घर",
      "description": "वॉलेट का उपयोग Ethereum और NFTs जैसी डिजिटल संपत्तियों को भेजने, प्राप्त करने, संग्रहित करने और प्रदर्शित करने के लिए किया जाता है."
    },
    "login": {
      "title": "लॉग इन करने का एक नया तरीका",
      "description": "हर वेबसाइट पर नए खाते और पासवर्ड बनाने की बजाय, बस अपना वॉलेट कनेक्ट करें."
    },
    "get": {
      "label": "एक वॉलेट प्राप्त करें"
    },
    "learn_more": {
      "label": "और जानें"
    }
  },
  "sign_in": {
    "label": "अपने खाते की पुष्टि करें",
    "description": "जुड़ने को पूरा करने के लिए, आपको अपने बटुए में एक संदेश पर हस्ताक्षर करना होगा ताकि पुष्टि हो सके कि आप इस खाते के मालिक हैं।",
    "message": {
      "send": "संदेश भेजें",
      "preparing": "संदेश तैयार कर रहा है...",
      "cancel": "रद्द करें",
      "preparing_error": "संदेश तैयार करते समय त्रुटि, कृपया पुनः प्रयास करें!"
    },
    "signature": {
      "waiting": "हस्ताक्षर का इंतजार कर रहा है...",
      "verifying": "हस्ताक्षर की पुष्टि की जा रही है...",
      "signing_error": "संदेश पर हस्ताक्षर करते समय त्रुटि, कृपया पुनः प्रयास करें!",
      "verifying_error": "हस्ताक्षर की पुष्टि में त्रुटि, कृपया पुनः प्रयास करें!",
      "oops_error": "ओह, कुछ गलत हो गया!"
    }
  },
  "connect": {
    "label": "कनेक्ट करें",
    "title": "वॉलेट को कनेक्ट करें",
    "new_to_ethereum": {
      "description": "Ethereum वॉलेट्स में नए हैं?",
      "learn_more": {
        "label": "और जानें"
      }
    },
    "learn_more": {
      "label": "और जानें।"
    },
    "recent": "हाल ही में",
    "status": {
      "opening": "%{wallet}खोल रहा है...",
      "connecting": "जोड़ रहा है",
      "connect_mobile": "जारी रखें %{wallet}",
      "not_installed": "%{wallet} स्थापित नहीं है",
      "not_available": "%{wallet} उपलब्ध नहीं है",
      "confirm": "एक्सटेंशन में कनेक्शन की पुष्टि करें",
      "confirm_mobile": "वॉलेट में कनेक्शन अनुरोध स्वीकार करें"
    },
    "secondary_action": {
      "get": {
        "description": "क्या आपके पास %{wallet}नहीं है ?",
        "label": "प्राप्त करें"
      },
      "install": {
        "label": "स्थापित करें"
      },
      "retry": {
        "label": "पुनः प्रयास करें"
      }
    },
    "walletconnect": {
      "description": {
        "full": "क्या आपको आधिकारिक WalletConnect मोडल की आवश्यकता है?",
        "compact": "क्या आपको WalletConnect मोडल की आवश्यकता है?"
      },
      "open": {
        "label": "खोलें"
      }
    }
  },
  "connect_scan": {
    "title": "स्कैन करें विथ %{wallet}",
    "fallback_title": "अपने फोन से स्कैन करें"
  },
  "connector_group": {
    "installed": "स्थापित",
    "recommended": "अनुशंसित",
    "other": "अन्य",
    "popular": "लोकप्रिय",
    "more": "अधिक",
    "others": "अन्य लोग"
  },
  "get": {
    "title": "एक वॉलेट प्राप्त करें",
    "action": {
      "label": "प्राप्त करें"
    },
    "mobile": {
      "description": "मोबाइल वॉलेट"
    },
    "extension": {
      "description": "ब्राउज़र एक्सटेंशन"
    },
    "mobile_and_extension": {
      "description": "मोबाइल वॉलेट और एक्सटेंशन"
    },
    "mobile_and_desktop": {
      "description": "मोबाइल और डेस्कटॉप वॉलेट"
    },
    "looking_for": {
      "title": "क्या आपको जो चाहिए वह नहीं मिल रहा है?",
      "mobile": {
        "description": "मुख्य स्क्रीन पर एक बटुआ चुनें ताकि आप एक अलग बटुआ प्रदाता के साथ शुरू कर सकें।"
      },
      "desktop": {
        "compact_description": "मुख्य स्क्रीन पर एक बटुआ चुनें ताकि आप एक अलग बटुआ प्रदाता के साथ शुरू कर सकें।",
        "wide_description": "बाएं एक बटुआ चुनें ताकि आप एक अलग बटुआ प्रदाता के साथ शुरू कर सकें।"
      }
    }
  },
  "get_options": {
    "title": "%{wallet}के साथ शुरू करें",
    "short_title": "%{wallet}प्राप्त करें",
    "mobile": {
      "title": "मोबाइल के लिए %{wallet}",
      "description": "मोबाइल वॉलेट का उपयोग करके Ethereum की दुनिया का अन्वेषण करें।",
      "download": {
        "label": "ऐप प्राप्त करें"
      }
    },
    "extension": {
      "title": "%{wallet} के लिए %{browser}",
      "description": "अपने पसंदीदा वेब ब्राउज़र से अपने वॉलेट तक पहुंचें।",
      "download": {
        "label": "करें जोड़ें %{browser}"
      }
    },
    "desktop": {
      "title": "%{wallet} के लिए %{platform}",
      "description": "अपने शक्तिशाली डेस्कटॉप से आपके वॉलेट की स्वतंत्रता द्वारा पहुंच।",
      "download": {
        "label": "को जोड़ें %{platform}"
      }
    }
  },
  "get_mobile": {
    "title": "स्थापित करें %{wallet}",
    "description": "iOS या Android पर डाउनलोड करने के लिए अपने फोन से स्कैन करें",
    "continue": {
      "label": "जारी रखें"
    }
  },
  "get_instructions": {
    "mobile": {
      "connect": {
        "label": "जोड़ें"
      },
      "learn_more": {
        "label": "और जानें"
      }
    },
    "extension": {
      "refresh": {
        "label": "ताज़ा करें"
      },
      "learn_more": {
        "label": "और जानें"
      }
    },
    "desktop": {
      "connect": {
        "label": "कनेक्ट करें"
      },
      "learn_more": {
        "label": "और जानें"
      }
    }
  },
  "chains": {
    "title": "नेटवर्क स्विच करें",
    "wrong_network": "गलत नेटवर्क का पता चला, जारी रखने के लिए स्विच करें या कनेक्ट करें।",
    "confirm": "वॉलेट में पुष्टि करें",
    "switching_not_supported": "आपका वॉलेट नेटवर्क्स को %{appName}से स्विच करना समर्थन नहीं करता . बजाय अपने वॉलेट के भीतर से नेटवर्क स्विच करने का प्रयास करें।",
    "switching_not_supported_fallback": "आपका वॉलेट इस एप से नेटवर्क्स स्विच करने का समर्थन नहीं करता। बजाय उसके, अपना वॉलेट द्वारा नेटवर्क्स स्विच करने की कोशिश करें।",
    "disconnect": "डिकनेक्ट",
    "connected": "कनेक्ट किया गया"
  },
  "profile": {
    "disconnect": {
      "label": "डिकनेक्ट"
    },
    "copy_address": {
      "label": "पता कॉपी करें",
      "copied": "कॉपी कर दिया गया!"
    },
    "explorer": {
      "label": "एक्सप्लोरर पर अधिक देखें"
    },
    "transactions": {
      "description": "%{appName} लेन - देन यहां दिखाई देंगे...",
      "description_fallback": "आपके लेन-देन यहां दिखाई देंगे...",
      "recent": {
        "title": "हाल के लेन - देन"
      },
      "clear": {
        "label": "सभी को हटाएं"
      }
    }
  },
  "wallet_connectors": {
    "argent": {
      "qr_code": {
        "step1": {
          "description": "अपने वॉलेट को जल्दी से एक्सेस करने के लिए आपके होम स्क्रीन पर Argent डालें।",
          "title": "Argent ऐप खोलें"
        },
        "step2": {
          "description": "वॉलेट और उपयोगकर्ता नाम बनाएं, या मौजूदा वॉलेट को आयात करें।",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "जैसे ही आप स्कैन करेंगे, एक कनेक्शन संकेत आपके वॉलेट को कनेक्ट करने के लिए प्रकट होगा।",
          "title": "QR स्कैन बटन को टैप करें"
        }
      }
    },
    "bifrost": {
      "qr_code": {
        "step1": {
          "description": "हम आपको सलाह देते हैं कि Bifrost Wallet को अपने होम स्क्रीन पर लगाएं, ताकि त्वरित एक्सेस को सुनिश्चित किया जा सके।",
          "title": "Bifrost Wallet ऐप को खोलें"
        },
        "step2": {
          "description": "अपने रिकवरी फ़्रेज़ का उपयोग करके एक वॉलेट बनाएं या इंपोर्ट करें।",
          "title": "वॉलेट बनाएं या इंपोर्ट करें"
        },
        "step3": {
          "description": "स्कैन करने के बाद, आपके वॉलेट को कनेक्ट करने के लिए एक कनेक्शन संकेत दिखाई देगा।",
          "title": "स्कैन बटन को टैप करें"
        }
      }
    },
    "bitget": {
      "qr_code": {
        "step1": {
          "description": "हम इसे सुझाव देते हैं कि आप अपने होम स्क्रीन पर Bitget वॉलेट को रखें ताकि जल्दी एक्सेस कर सकें।",
          "title": "Bitget वॉलेट एप को खोलें"
        },
        "step2": {
          "description": "अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेने के लिए सुनिश्चित करें। किसी के साथ भी अपना गुप्त वाक्यांश साझा न करें।",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "स्कैन करने के बाद, आपके वॉलेट को कनेक्ट करने का एक संकेत दिखाई देगा।",
          "title": "स्कैन बटन पर टैप करें"
        }
      },
      "extension": {
        "step1": {
          "description": "हम इसे सुझाव देते हैं कि आप Bitget वॉलेट को आपके टास्कबार में पिन करें ताकि आपके वॉलेट तक जल्दी पहुंच सकें।",
          "title": "Bitget Wallet एक्सटेंशन स्थापित करें"
        },
        "step2": {
          "description": "सुनिश्चित करें कि आप अपने वॉलेट का बैकअप किसी सुरक्षित तरीके से ले रहे हैं। अपनी गुप्त वाक्यांश को कभी किसी के साथ साझा न करें।",
          "title": "एक वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "एक बार जब आप अपना वॉलेट सेटअप कर लेते हैं, तो नीचे क्लिक करें ताकि ब्राउज़र को ताज़ा करें और एक्सटेंशन लोड करें।",
          "title": "अपने ब्राउज़र को ताज़ा करें"
        }
      }
    },
    "bitski": {
      "extension": {
        "step1": {
          "description": "हम आपको अपने वॉलेट तक जल्दी पहुंचने के लिए Bitski को अपने टास्कबार में पिन करने की सलाह देते हैं।",
          "title": "Bitski एक्सटेंशन स्थापित करें"
        },
        "step2": {
          "description": "सुनिश्चित करें कि आप एक सुरक्षित तरीके से अपने वॉलेट का बैकअप बना रहे हैं। कभी भी किसी के साथ अपने गोपनीय वाक्यांश को साझा न करें।",
          "title": "एक वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "एक बार जब आप अपना वॉलेट सेट कर लेते हैं, तो ब्राउज़र को ताज़ा करने और एक्सटेंशन को लोड करने के लिए नीचे क्लिक करें।",
          "title": "अपने ब्राउज़र को ताज़ा करें"
        }
      }
    },
    "bitverse": {
      "qr_code": {
        "step1": {
          "title": "Bitverse Wallet ऐप को खोलें",
          "description": "अपने वॉलेट तक तेजी से पहुँचने के लिए Bitverse Wallet को अपनी होम स्क्रीन पर जोड़ें।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "नया बटुआ बनाएं या मौजूदा को आयात करें।"
        },
        "step3": {
          "title": "QR आइकन पर टैप करें और स्कैन करें",
          "description": "अपने होमस्क्रीन पर QR आइकन पर टैप करें, कोड स्कैन करें और प्रम्प्ट को कनेक्ट करने की पुष्टि करें।"
        }
      }
    },
    "bloom": {
      "desktop": {
        "step1": {
          "title": "Bloom वॉलेट ऐप खोलें",
          "description": "आपकी सुविधा के लिए हम Bloom वॉलेट को होम स्क्रीन पर रखने की सलाह देते हैं।"
        },
        "step2": {
          "description": "अपने रिकवरी फ़्रेज़ का उपयोग करके एक वॉलेट बनाएं या इंपोर्ट करें।",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "जब आपके पास वॉलेट हो, तो Bloom के माध्यम से जुड़ने के लिए Connect पर क्लिक करें। ऐप में एक कनेक्शन प्रॉम्प्ट दिखाई देगा जिसे आपको कनेक्शन की पुष्टि करनी होगी।",
          "title": "Connect पर क्लिक करें"
        }
      },
      "qr_code": {
        "step1": {
          "title": "Bloom वॉलेट ऐप खोलें",
          "description": "आपकी सुविधा के लिए हम Bloom वॉलेट को होम स्क्रीन पर रखने की सलाह देते हैं।"
        },
        "step2": {
          "description": "अपने रिकवरी फ़्रेज़ का उपयोग करके एक वॉलेट बनाएं या इंपोर्ट करें।",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "जब आपके पास वॉलेट हो, तो Bloom के माध्यम से जुड़ने के लिए Connect पर क्लिक करें। ऐप में एक कनेक्शन प्रॉम्प्ट दिखाई देगा जिसे आपको कनेक्शन की पुष्टि करनी होगी।",
          "title": "Connect पर क्लिक करें"
        }
      }
    },
    "bybit": {
      "qr_code": {
        "step1": {
          "description": "हम आपके वॉलेट तक तेजी से पहुँचने के लिए Bybit को आपकी होम स्क्रीन पर रखने की सलाह देते हैं।",
          "title": "Bybit ऐप को खोलें"
        },
        "step2": {
          "description": "आप अपने फोन पर हमारे बैकअप फीचर का उपयोग करके आसानी से अपने वॉलेट का बैकअप कर सकते हैं।",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "जैसे ही आप स्कैन करेंगे, एक कनेक्शन संकेत आपके वॉलेट को कनेक्ट करने के लिए प्रकट होगा।",
          "title": "स्कैन बटन को टैप करें"
        }
      },
      "extension": {
        "step1": {
          "description": "अपने ब्राउज़र के ऊपरी दाएँ कोने पर क्लिक करें और आसान पहुँच के लिए Bybit Wallet को पिन करें।",
          "title": "Bybit Wallet एक्सटेंशन को इंस्टॉल करें"
        },
        "step2": {
          "description": "नया बटुआ बनाएं या मौजूदा को आयात करें।",
          "title": "एक बटुआ बनाएं या आयात करें"
        },
        "step3": {
          "description": "Bybit Wallet सेट अप करने के बाद, ब्राउज़र को रिफ्रेश करने के लिए नीचे क्लिक करें और एक्सटेंशन को लोड करें।",
          "title": "अपने ब्राउज़र को ताज़ा करें"
        }
      }
    },
    "binance": {
      "qr_code": {
        "step1": {
          "description": "हम अपने वॉलेट के तेज एक्सेस के लिए Binance को अपने होम स्क्रीन पर रखने की सलाह देते हैं।",
          "title": "Binance ऐप को खोलें"
        },
        "step2": {
          "description": "आप अपने फोन पर हमारे बैकअप फीचर का उपयोग करके आसानी से अपने वॉलेट का बैकअप कर सकते हैं।",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "जैसे ही आप स्कैन करेंगे, एक कनेक्शन संकेत आपके वॉलेट को कनेक्ट करने के लिए प्रकट होगा।",
          "title": "WalletConnect बटन पर टैप करें"
        }
      }
    },
    "coin98": {
      "qr_code": {
        "step1": {
          "description": "हम आपके वॉलेट तक तेजी से पहुंचने के लिए अपने होम स्क्रीन पर Coin98 वॉलेट रखने की सलाह देते हैं।",
          "title": "Coin98 वॉलेट ऐप को खोलें"
        },
        "step2": {
          "description": "आप अपने फोन पर हमारे बैकअप फीचर का उपयोग करके आसानी से अपने वॉलेट का बैकअप कर सकते हैं।",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "स्कैन करने के बाद, आपके वॉलेट को कनेक्ट करने के लिए एक कनेक्शन प्रांप्ट दिखाई देगा।",
          "title": "WalletConnect बटन पर टैप करें"
        }
      },
      "extension": {
        "step1": {
          "description": "अपने ब्राउज़र के ऊपरी दाएं हिस्से पर क्लिक करें और आसानी से पहुंच के लिए Coin98 वॉलेट को पिन करें।",
          "title": "Coin98 वॉलेट एक्सटेंशन स्थापित करें"
        },
        "step2": {
          "description": "नया बटुआ बनाएं या मौजूदा को आयात करें।",
          "title": "एक बटुआ बनाएं या आयात करें"
        },
        "step3": {
          "description": "एक बार जब आप Coin98 वॉलेट सेट करते हैं, तो नीचे क्लिक करके ब्राउजर को ताजा करें और एक्सटेंशन को लोड करें।",
          "title": "अपने ब्राउज़र को ताज़ा करें"
        }
      }
    },
    "coinbase": {
      "qr_code": {
        "step1": {
          "description": "हम आपको सलाह देते हैं कि आपकी मुख्य बिल्ड स्क्रीन पर Coinbase वॉलेट को रखें जिससे आपकी पहुंच तेज हो।",
          "title": "Coinbase वॉलेट ऐप खोलें"
        },
        "step2": {
          "description": "आप बादल बैकअप सुविधा का उपयोग करके आसानी से अपने वॉलेट का बैकअप ले सकते हैं।",
          "title": "एक वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "जैसे ही आप स्कैन करते हैं, आपको अपने वॉलेट से कनेक्ट करने के लिए एक कनेक्शन संकेत दिखाई देगा।",
          "title": "स्कैन बटन को छूना"
        }
      },
      "extension": {
        "step1": {
          "description": "हमारा सिफारिश है कि आप अपने वॉलेट तक जल्दी पहुंचने के लिए Coinbase वॉलेट को अपने टास्कबार पर पिन पर रखें।",
          "title": "Coinbase वॉलेट एक्सटेंशन स्थापित करें"
        },
        "step2": {
          "description": "सुरक्षित विधि का उपयोग करके अपने बटुए का बैकअप लेना सुनिश्चित करें। अपना गुप्त पुनर्प्राप्ति वाक्यांश कभी भी किसी के साथ साझा न करें।",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "एक बार जब आप अपना वॉलेट सेट अप करते हैं, तो ब्राउज़र को ताजगी देने और एक्सटेंशन को लोड करने के लिए नीचे क्लिक करें.",
          "title": "अपना ब्राउज़र ताजा करें"
        }
      }
    },
    "compass": {
      "extension": {
        "step1": {
          "description": "हम अपने वॉलेट तक त्वरित पहुंच के लिए Compass Wallet को अपने कार्यपट्टी में पिन करने की सलाह देते हैं।",
          "title": "Compass Wallet एक्सटेंशन स्थापित करें"
        },
        "step2": {
          "description": "अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेने के लिए सुनिश्चित करें। किसी के साथ भी अपना गुप्त वाक्यांश साझा न करें।",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "एक बार जब आप अपना वॉलेट सेटअप कर लेते हैं, तो नीचे क्लिक करें ताकि ब्राउज़र को ताज़ा करें और एक्सटेंशन लोड करें।",
          "title": "अपने ब्राउज़र को ताज़ा करें"
        }
      }
    },
    "core": {
      "qr_code": {
        "step1": {
          "description": "हम आपकी वॉलेट के तेज एक्सेस के लिए Core को आपके होम स्क्रीन पर डालने की सलाह देते हैं.",
          "title": "Core एप खोलें"
        },
        "step2": {
          "description": "आप आसानी से अपने फ़ोन पर हमारे बैकअप फीचर का उपयोग करके अपना वॉलेट बैकअप कर सकते हैं.",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "स्कैन करने के बाद, आपके वॉलेट को कनेक्ट करने के लिए आपके लिए कनेक्शन प्राम्प्ट प्रकट होगा.",
          "title": "WalletConnect बटन को छूने के साथ"
        }
      },
      "extension": {
        "step1": {
          "description": "हम अपने वॉलेट के लिए तेज एक्सेस के लिए कोर को अपने टास्कबार में पिन करने की सिफारिश करते हैं।",
          "title": "कोर एक्सटेंशन स्थापित करें"
        },
        "step2": {
          "description": "सुनिश्चित करें कि आप अपने वॉलेट का बैकअप एक सुरक्षित तरीके से ले। कभी भी किसी के साथ अपनी गुप्त वाक्यांश साझा न करें।",
          "title": "एक वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "एक बार जब आप अपने वॉलेट की स्थापना कर लें, तो नीचे क्लिक करें ताकि ब्राउज़र को ताज़ा कर सकें और एक्सटेंशन को लोड कर सकें।",
          "title": "अपने ब्राउज़र को ताज़ा करें"
        }
      }
    },
    "fox": {
      "qr_code": {
        "step1": {
          "description": "हम FoxWallet को अपने होम स्क्रीन पर रखने की सिफारिश करते हैं ताकि त्वरित एक्सेस मिल सके।",
          "title": "FoxWallet ऐप खोलें"
        },
        "step2": {
          "description": "सुनिश्चित करें कि आप एक सुरक्षित तरीके का उपयोग करके अपने वॉलेट का बैकअप ले रहे हैं। कभी भी किसी के साथ अपना गुप्त वाक्यांश साझा न करें।",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "जब आप स्कैन करेंगे, तो आपके वॉलेट को कनेक्ट करने के लिए एक कनेक्शन संकेत प्रकट होगा।",
          "title": "स्कैन बटन पर टैप करें"
        }
      }
    },
    "frontier": {
      "qr_code": {
        "step1": {
          "description": "हमारी सिफारिश है कि आप अपने होम स्क्रीन पर फ्रंटियर वॉलेट रखें जिससे कि आपको त्वरित पहुंच मिले।",
          "title": "फ्रंटियर वॉलेट ऐप को खोलें"
        },
        "step2": {
          "description": "सुनिश्चित करें कि आप एक सुरक्षित तरीके का उपयोग करके अपने वॉलेट का बैकअप ले रहे हैं। कभी भी किसी के साथ अपना गुप्त वाक्यांश साझा न करें।",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "जब आप स्कैन करते हैं, तो आपके वॉलेट को कनेक्ट करने के लिए एक कनेक्शन संकेत प्रकट होगा।",
          "title": "स्कैन बटन को टैप करें"
        }
      },
      "extension": {
        "step1": {
          "description": "हम आपके वॉलेट की तेजी से पहुंच के लिए Frontier Wallet को अपने टास्कबार में पिन करने की सिफारिश करते हैं।",
          "title": "Frontier Wallet एक्सटेंशन इंस्टॉल करें"
        },
        "step2": {
          "description": "सुनिश्चित करें कि आप एक सुरक्षित तरीके से अपना वॉलेट बैकअप कर रहे हैं। कभी भी किसी के साथ अपना गुप्त वाक्यांश साझा न करें।",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "वॉलेट सेटअप होने के बाद, ब्राउज़र को रिफ्रेश करने के लिए नीचे क्लिक करें और एक्सटेंशन लोड करें।",
          "title": "अपना ब्राउज़र रिफ्रेश करें"
        }
      }
    },
    "im_token": {
      "qr_code": {
        "step1": {
          "title": "imToken ऐप खोलें",
          "description": "अपने वॉलेट के तेजी से पहुँच के लिए imToken एप्लीकेशन को अपने होम स्क्रीन पर रखें।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "एक नया वॉलेट बनाएं या मौजूदा एक को आयात करें।"
        },
        "step3": {
          "title": "ऊपरी दाएं कोने में स्कैनर आइकॉन पर टैप करें",
          "description": "नया कनेक्शन चुनें, फिर QR कोड स्कैन करें और कनेक्ट करने के लिए प्रॉम्प्ट की पुष्टि करें।"
        }
      }
    },
    "kaikas": {
      "extension": {
        "step1": {
          "description": "हम आपके वॉलेट तक जल्दी पहुँचने के लिए Kaikas को आपके टास्कबार पर पिन करने की सलाह देते हैं।",
          "title": "Kaikas एक्सटेंशन को इंस्टॉल करें"
        },
        "step2": {
          "description": "अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेने के लिए सुनिश्चित करें। किसी के साथ भी अपना गुप्त वाक्यांश साझा न करें।",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "एक बार जब आप अपना वॉलेट सेटअप कर लेते हैं, तो नीचे क्लिक करें ताकि ब्राउज़र को ताज़ा करें और एक्सटेंशन लोड करें।",
          "title": "अपने ब्राउज़र को ताज़ा करें"
        }
      },
      "qr_code": {
        "step1": {
          "title": "Kaikas ऐप को खोलें",
          "description": "अपने वॉलेट तक तेजी से पहुँचने के लिए Kaikas ऐप को अपनी होम स्क्रीन पर रखें।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "नया बटुआ बनाएं या मौजूदा को आयात करें।"
        },
        "step3": {
          "title": "ऊपरी दाएं कोने में स्कैनर आइकॉन पर टैप करें",
          "description": "नया कनेक्शन चुनें, फिर QR कोड स्कैन करें और कनेक्ट करने के लिए प्रॉम्प्ट की पुष्टि करें।"
        }
      }
    },
    "kraken": {
      "qr_code": {
        "step1": {
          "title": "Kraken Wallet ऐप खोलें",
          "description": "हम आपके वॉलेट तक तेजी से पहुंचने के लिए अपने होम स्क्रीन पर Kraken Wallet रखने की सलाह देते हैं।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "नया बटुआ बनाएं या मौजूदा को आयात करें।"
        },
        "step3": {
          "title": "QR आइकन पर टैप करें और स्कैन करें",
          "description": "अपने होमस्क्रीन पर QR आइकन पर टैप करें, कोड स्कैन करें और प्रम्प्ट को कनेक्ट करने की पुष्टि करें।"
        }
      }
    },
    "kresus": {
      "qr_code": {
        "step1": {
          "title": "Kresus वॉलेट ऐप खोलें",
          "description": "अपने वॉलेट तक तेज़ी से पहुँचने के लिए Kresus Wallet को अपने होम स्क्रीन पर जोड़ें।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "नया बटुआ बनाएं या मौजूदा को आयात करें।"
        },
        "step3": {
          "title": "QR आइकन पर टैप करें और स्कैन करें",
          "description": "अपने होमस्क्रीन पर QR आइकन पर टैप करें, कोड स्कैन करें और प्रम्प्ट को कनेक्ट करने की पुष्टि करें।"
        }
      }
    },
    "magicEden": {
      "extension": {
        "step1": {
          "title": "Magic Eden एक्सटेंशन स्थापित करें",
          "description": "हम आपके वॉलेट के आसान उपयोग के लिए Magic Eden को अपने टास्कबार में पिन करने की सलाह देते हैं।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "सुनिश्चित करें कि आप अपने वॉलेट का बैकअप एक सुरक्षित तरीके से ले रहे हैं। अपना गुप्त वसूली वाक्यांश किसी के साथ भी साझा न करें।"
        },
        "step3": {
          "title": "अपने ब्राउज़र को ताज़ा करें",
          "description": "एक बार जब आप अपना वॉलेट सेटअप कर लेते हैं, तो नीचे क्लिक करें ताकि ब्राउज़र को ताज़ा करें और एक्सटेंशन लोड करें।"
        }
      }
    },
    "metamask": {
      "qr_code": {
        "step1": {
          "title": "MetaMask ऐप को खोलें",
          "description": "हम आपको MetaMask को आपकी होम स्क्रीन पर रखने की सलाह देते हैं, इससे आपको त्वरित पहुँच मिलेगी।"
        },
        "step2": {
          "title": "एक वॉलेट बनाएं या इम्पोर्ट करें",
          "description": "सुरक्षित विधि का उपयोग करके अपने बटुए का बैकअप लेना सुनिश्चित करें। अपना गुप्त वाक्यांश कभी भी किसी के साथ साझा न करें।"
        },
        "step3": {
          "title": "स्कैन बटन पर टैप करें",
          "description": "स्कैन करने के बाद, आपके वॉलेट को कनेक्ट करने के लिए एक कनेक्शन प्रॉम्प्ट दिखाई देगा।"
        }
      },
      "extension": {
        "step1": {
          "title": "MetaMask एक्सटेंशन स्थापित करें",
          "description": "हम अपने वॉलेट तक जल्दी से पहुँचने के लिए MetaMask को अपने टास्कबार में पिन करने की सलाह देते हैं।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेना सुनिश्चित करें। अपनी गुप्त वाक्यांश को किसी के साथ शेयर न करें।"
        },
        "step3": {
          "title": "अपना ब्राउज़र ताज़ा करें",
          "description": "एक बार जब आप अपना वॉलेट सेट अप करते हैं, तो ब्राउजर को ताज़ा करने और एक्सटेंशन को लोड करने के लिए नीचे क्लिक करें।"
        }
      }
    },
    "nestwallet": {
      "extension": {
        "step1": {
          "title": "NestWallet एक्सटेंशन स्थापित करें",
          "description": "हम आपके वॉलेट के तेज एक्सेस के लिए NestWallet को आपके टास्कबार में पिन करने की सलाह देते हैं।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेने के लिए सुनिश्चित करें। किसी के साथ भी अपना गुप्त वाक्यांश साझा न करें।"
        },
        "step3": {
          "title": "अपने ब्राउज़र को ताज़ा करें",
          "description": "एक बार जब आप अपना वॉलेट सेटअप कर लेते हैं, तो नीचे क्लिक करें ताकि ब्राउज़र को ताज़ा करें और एक्सटेंशन लोड करें।"
        }
      }
    },
    "okx": {
      "qr_code": {
        "step1": {
          "title": "OKX Wallet ऐप खोलें",
          "description": "हम आपको OKX Wallet को अपने होम स्क्रीन पर रखने की सलाह देते हैं, जिससे आप जल्दी से पहुंच सकें।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेने का यकीन करें। कभी भी किसी के साथ अपने गुप्त वाक्यांश साझा न करें।"
        },
        "step3": {
          "title": "स्कैन बटन पर टैप करें",
          "description": "जब आप स्कैन करते हैं, तो आपके वॉलेट को कनेक्ट करने के लिए एक कनेक्शन संकेत प्रकट होगा।"
        }
      },
      "extension": {
        "step1": {
          "title": "OKX वॉलेट एक्सटेंशन स्थापित करें",
          "description": "हम अपने वॉलेट तक तेज़ी से पहुंचने के लिए आपको OKX वॉलेट को अपने कार्यपट्टी में पिन करने की सलाह देते हैं।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेने का यकीन करें। कभी भी किसी के साथ अपने गुप्त वाक्यांश साझा न करें।"
        },
        "step3": {
          "title": "अपने ब्राउज़र को ताज़ा करें",
          "description": "जब आप अपना वॉलेट सेट अप कर लेते हैं, तो नीचे क्लिक करके ब्राउज़र को ताजा करें और एक्सटेंशन को लोड करें।"
        }
      }
    },
    "omni": {
      "qr_code": {
        "step1": {
          "title": "Omni ऐप को खोलें",
          "description": "अपने वॉलेट तक अधिक जल्दी पहुंचने के लिए Omni को अपने होम स्क्रीन पर जोड़ें।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "एक नया वॉलेट बनाएं या मौजूदा एक को आयात करें।"
        },
        "step3": {
          "title": "QR आइकन पर टैप करें और स्कैन करें",
          "description": "अपने होम स्क्रीन पर QR आइकन पर टैप करें, कोड स्कैन करें और कनेक्ट करने के लिए प्रॉम्प्ट की पुष्टि करें।"
        }
      }
    },
    "1inch": {
      "qr_code": {
        "step1": {
          "description": "अपने वॉलेट तक तेजी से पहुँचने के लिए 1inch Wallet को अपनी होम स्क्रीन पर रखें।",
          "title": "1inch Wallet ऐप को खोलें"
        },
        "step2": {
          "description": "वॉलेट और उपयोगकर्ता नाम बनाएं, या मौजूदा वॉलेट को आयात करें।",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "जैसे ही आप स्कैन करेंगे, एक कनेक्शन संकेत आपके वॉलेट को कनेक्ट करने के लिए प्रकट होगा।",
          "title": "QR स्कैन बटन को टैप करें"
        }
      }
    },
    "token_pocket": {
      "qr_code": {
        "step1": {
          "title": "TokenPocket ऐप को खोलें",
          "description": "हम आपको TokenPocket को अपने होम स्क्रीन पर रखने की सलाह देते हैं ताकि आपको तेज एक्सेस मिल सके।"
        },
        "step2": {
          "title": "एक वॉलेट बनाएँ या आयात करें",
          "description": "सुरक्षित विधि का उपयोग करके अपने बटुए का बैकअप लेना सुनिश्चित करें। अपना गुप्त वाक्यांश कभी भी किसी के साथ साझा न करें।"
        },
        "step3": {
          "title": "स्कैन बटन पर टैप करें",
          "description": "एक बार स्कैन करने के बाद, आपके लिए एक कनेक्शन प्रॉम्प्ट प्रकट होगा ताकि आप अपने वॉलेट को कनेक्ट कर सकें।"
        }
      },
      "extension": {
        "step1": {
          "title": "TokenPocket एक्सटेंशन स्थापित करें",
          "description": "हम अपने वॉलेट तक त्वरित पहुंच के लिए TokenPocket को अपने taskbar पर pin करने की सिफारिश करते हैं।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "सुनिश्चित करें कि आप अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेते हैं। कभी किसी के साथ अपना गुप्त वाक्यांश साझा न करें।"
        },
        "step3": {
          "title": "अपना ब्राउज़र ताज़ा करें",
          "description": "एक बार जब आप अपना वॉलेट सेटअप कर लेते हैं, तो नीचे क्लिक करें ताज़ा ब्राउज़र  लोड करें और एक्सटेंशन अप करें।"
        }
      }
    },
    "trust": {
      "qr_code": {
        "step1": {
          "title": "Trust Wallet ऐप खोलें",
          "description": "अपने वॉलेट तक तेज़ी से पहुंचने के लिए Trust Wallet को अपने होम स्क्रीन पर रखें।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "एक नया वॉलेट बनाएं या मौजूदा वॉलेट आयात करें।"
        },
        "step3": {
          "title": "सेटिंग्स में WalletConnect को टैप करें",
          "description": "नया कनेक्शन चुनें, फिर QR कोड स्कैन करें और प्रम्प्ट की पुष्टि करें।"
        }
      },
      "extension": {
        "step1": {
          "title": "Trust Wallet एक्सटेंशन को इंस्टॉल करें",
          "description": "अपने ब्राउज़र के ऊपरी दाएं कोने पर क्लिक करें और Trust Wallet को आसानी से प्रवेश के लिए पिन करें।"
        },
        "step2": {
          "title": "एक वॉलेट बनाएं या आयात करें",
          "description": "एक नया वॉलेट बनाएं या मौजूदा वॉलेट आयात करें।"
        },
        "step3": {
          "title": "अपने ब्राउज़र को ताज़ा करें",
          "description": "एक बार Trust Wallet सेट अप करने के बाद, नीचे क्लिक करें ब्राउज़र को ताज़ा करने और एक्सटेंशन लोड करने के लिए।"
        }
      }
    },
    "uniswap": {
      "qr_code": {
        "step1": {
          "title": "Uniswap ऐप को खोलें",
          "description": "अपने होम स्क्रीन पर Uniswap वॉलेट जोड़ें, इससे आपके वॉलेट तक तेजी से पहुंचने की सुविधा होगी।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "एक नया वॉलेट बनाएं या मौजूदा वॉलेट को आयात करें।"
        },
        "step3": {
          "title": "QR आइकन पर टैप करें और स्कैन करें",
          "description": "अपने होमस्क्रीन पर QR आइकन पर टैप करें, कोड स्कैन करें और प्रम्प्ट को कनेक्ट करने की पुष्टि करें।"
        }
      }
    },
    "zerion": {
      "qr_code": {
        "step1": {
          "title": "Zerion ऐप को खोलें",
          "description": "हम सलाह देते हैं कि आप Zerion को अपने होम स्क्रीन पर रखें, इससे तेजी से एक्सेस करने में आसानी होगी।"
        },
        "step2": {
          "title": "एक वॉलेट बनाएं या आयात करें",
          "description": "सुरक्षित विधि का उपयोग करके अपने बटुए का बैकअप लेना सुनिश्चित करें। अपना गुप्त वाक्यांश कभी भी किसी के साथ साझा न करें।"
        },
        "step3": {
          "title": "स्कैन बटन को टैप करें",
          "description": "आप स्कैन करने के बाद, एक कनेक्शन प्रोम्प्ट आपके बटुए को कनेक्ट करने के लिए प्रकट होगा।"
        }
      },
      "extension": {
        "step1": {
          "title": "Zerion एक्सटेंशन स्थापित करें",
          "description": "हमारी सिफारिश है कि आप अपने वॉलेट तक जल्दी पहुँचने के लिए Zerion को अपने टास्कबार में पिन करें।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "सुनिश्चित करें कि आप एक सुरक्षित विधि का उपयोग करके अपने वॉलेट का बैकअप ले रहे हैं। अपना गुप्त वाक्य कभी किसी के साथ साझा न करें।"
        },
        "step3": {
          "title": "अपना ब्राउज़र ताज़ा करें",
          "description": "एक बार जब आप अपने वॉलेट की स्थापना कर लें, तो ब्राउज़र को ताज़ा करने और एक्सटेंशन को लोड करने के लिए नीचे क्लिक करें।"
        }
      }
    },
    "rainbow": {
      "qr_code": {
        "step1": {
          "title": "Rainbow ऐप को खोलें",
          "description": "हम अपने वॉलेट के तेज एक्सेस के लिए Rainbow को अपने होम स्क्रीन पर रखने की सलाह देते हैं।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "आप अपने फ़ोन पर हमारे बैकअप फीचर का उपयोग करके अपने वॉलेट का बैकअप आसानी से ले सकते हैं।"
        },
        "step3": {
          "title": "स्कैन बटन पर टैप करें",
          "description": "जब आप स्कैन करते हैं, तो आपकी वॉलेट से कनेक्ट करने के लिए एक कनेक्शन संकेत दिखाई देगा।"
        }
      }
    },
    "enkrypt": {
      "extension": {
        "step1": {
          "description": "हम अपनी वॉलेट तक तेज़ी से पहुँच के लिए Enkrypt वॉलेट को अपने टास्कबार में पिन करने की सलाह देते हैं।",
          "title": "Enkrypt वॉलेट एक्सटेंशन स्थापित करें"
        },
        "step2": {
          "description": "सुनिश्चित करें कि आप अपनी वॉलेट का बैकअप एक सुरक्षित तरीके से ले। अपनी गुप्त वाक्यांश को कभी भी किसी के साथ साझा न करें।",
          "title": "एक वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "एक बार जब आप अपनी वॉलेट सेट कर लें, तो नीचे क्लिक करें ब्राउज़र को ताज़ा करने और एक्सटेंशन लोड करने के लिए।",
          "title": "अपने ब्राउज़र को ताज़ा करें"
        }
      }
    },
    "frame": {
      "extension": {
        "step1": {
          "description": "हम अपनी वॉलेट तक तेज़ी से पहुँच के लिए Frame को अपने टास्कबार में पिन करने की सलाह देते हैं।",
          "title": "Frame और साथी एक्सटेंशन स्थापित करें"
        },
        "step2": {
          "description": "अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेना सुनिश्चित करें। कभी भी अपनी गुप्त वाक्यांश को किसी के साथ साझा न करें।",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "एक बार जब आप अपने वॉलेट की सेटअप कर लेते हैं, तो नीचे क्लिक करके ब्राउज़र को ताज़ा करें और एक्सटेंशन को लोड करें।",
          "title": "अपना ब्राउज़र ताज़ा करें"
        }
      }
    },
    "one_key": {
      "extension": {
        "step1": {
          "title": "OneKey Wallet एक्सटेंशन स्थापित करें",
          "description": "हम आपको अपने वॉलेट की तेज एक्सेस के लिए OneKey Wallet को अपने टास्कबार में पिन करने की सलाह देते हैं।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "सुनिश्चित करें कि आप अपने वॉलेट का बैकअप एक सुरक्षित तरीके से ले रहे हैं। अपना गुप्त वाक्यांश किसी के साथ भी साझा न करें।"
        },
        "step3": {
          "title": "अपने ब्राउज़र को ताज़ा करें",
          "description": "एक बार जब आप अपना वॉलेट सेट अप कर लेते हैं, तो ब्राउज़र को ताज़ा करने और एक्सटेंशन को लोड करने के लिए नीचे क्लिक करें।"
        }
      }
    },
    "phantom": {
      "extension": {
        "step1": {
          "title": "फैंटम एक्सटेंशन स्थापित करें",
          "description": "हम आपके वॉलेट के आसान उपयोग के लिए फैंटम को अपने टास्कबार में पिन करने की सलाह देते हैं।"
        },
        "step2": {
          "title": "एक वॉलेट बनाएं या आयात करें",
          "description": "सुनिश्चित करें कि आप अपने वॉलेट का बैकअप एक सुरक्षित तरीके से ले रहे हैं। अपना गुप्त वसूली वाक्यांश किसी के साथ भी साझा न करें।"
        },
        "step3": {
          "title": "अपने ब्राउज़र को ताज़ा करें",
          "description": "एक बार जब आप अपना वॉलेट सेट कर लें, तो ब्राउज़र को ताजगी देने और एक्सटेंशन को लोड करने के लिए नीचे क्लिक करें।"
        }
      }
    },
    "rabby": {
      "extension": {
        "step1": {
          "title": "Rabby एक्सटेंशन स्थापित करें",
          "description": "हम आपको सलाह देते हैं कि अपने वॉलेट की जल्दी से पहुँच के लिए Rabby को अपने टास्कबार में पिन करें।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "सुनिश्चित करें कि आप अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेते हैं। कभी भी किसी के साथ अपना गुप्त वाक्यांश साझा न करें।"
        },
        "step3": {
          "title": "अपना ब्राउज़र ताज़ा करें",
          "description": "जब आप अपना वॉलेट सेट अप कर लेते हैं, तो ब्राउज़र को ताज़ा करने और एक्सटेंशन लोड करने के लिए नीचे क्लिक करें।"
        }
      }
    },
    "ronin": {
      "qr_code": {
        "step1": {
          "description": "हम आपके वॉलेट तक जल्दी पहुँच के लिए Ronin Wallet को आपके होम स्क्रीन पर डालने की सलाह देते हैं।",
          "title": "Ronin Wallet ऐप खोलें"
        },
        "step2": {
          "description": "अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेने के लिए सुनिश्चित करें। किसी के साथ भी अपना गुप्त वाक्यांश साझा न करें।",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "जैसे ही आप स्कैन करेंगे, एक कनेक्शन संकेत आपके वॉलेट को कनेक्ट करने के लिए प्रकट होगा।",
          "title": "स्कैन बटन को टैप करें"
        }
      },
      "extension": {
        "step1": {
          "description": "अपने वॉलेट तक जल्दी पहुँच के लिए हम Ronin Wallet को आपके टास्कबार पर पिन करने की सलाह देते हैं।",
          "title": "Ronin Wallet एक्सटेंशन इंस्टॉल करें"
        },
        "step2": {
          "description": "अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेने के लिए सुनिश्चित करें। किसी के साथ भी अपना गुप्त वाक्यांश साझा न करें।",
          "title": "वॉलेट बनाएं या आयात करें"
        },
        "step3": {
          "description": "एक बार जब आप अपना वॉलेट सेटअप कर लेते हैं, तो नीचे क्लिक करें ताकि ब्राउज़र को ताज़ा करें और एक्सटेंशन लोड करें।",
          "title": "अपने ब्राउज़र को ताज़ा करें"
        }
      }
    },
    "ramper": {
      "extension": {
        "step1": {
          "title": "Ramper एक्सटेंशन इंस्टॉल करें",
          "description": "अपने वॉलेट तक आसान पहुँच के लिए हम Ramper को आपके टास्कबार पर पिन करने की सलाह देते हैं।"
        },
        "step2": {
          "title": "एक वॉलेट बनाएँ",
          "description": "अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेने के लिए सुनिश्चित करें। किसी के साथ भी अपना गुप्त वाक्यांश साझा न करें।"
        },
        "step3": {
          "title": "अपने ब्राउज़र को ताज़ा करें",
          "description": "एक बार जब आप अपना वॉलेट सेटअप कर लेते हैं, तो नीचे क्लिक करें ताकि ब्राउज़र को ताज़ा करें और एक्सटेंशन लोड करें।"
        }
      }
    },
    "safeheron": {
      "extension": {
        "step1": {
          "title": "कोर एक्सटेंशन स्थापित करें",
          "description": "हम आपको सलाह देते हैं कि अपने वॉलेट की जल्दी से पहुँच के लिए Safeheron को अपने टास्कबार में पिन करें।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "सुनिश्चित करें कि आप एक सुरक्षित तरीके से अपना वॉलेट बैकअप कर रहे हैं। कभी भी किसी के साथ अपने गुप्त वाक्यांश को साझा न करें।"
        },
        "step3": {
          "title": "अपने ब्राउज़र को ताज़ा करें",
          "description": "एक बार जब आप अपने वॉलेट को सेट अप करते हैं, तो नीचे क्लिक करें ताकि ब्राउज़र को ताज़ा करें और एक्सटेंशन को लोड करें।"
        }
      }
    },
    "taho": {
      "extension": {
        "step1": {
          "title": "ताहो एक्सटेंशन स्थापित करें",
          "description": "हम आपके वॉलेट तक त्वरित पहुँच के लिए ताहो को अपने टास्कबार में पिन करने की सलाह देते हैं।"
        },
        "step2": {
          "title": "एक वॉलेट बनाएँ या आयात करें",
          "description": "सुनिश्चित करें कि आप एक सुरक्षित तरीके से अपना वॉलेट बैकअप कर रहे हैं। कभी भी किसी के साथ अपने गुप्त वाक्यांश को साझा न करें।"
        },
        "step3": {
          "title": "अपने ब्राउज़र को ताज़ा करें",
          "description": "एक बार जब आप अपना बटुआ सेट कर लेते हैं, तो नीचे क्लिक करके ब्राउज़र को ताज़ा करें और एक्सटेंशन को लोड करें।"
        }
      }
    },
    "talisman": {
      "extension": {
        "step1": {
          "title": "तालिसमान एक्सटेंशन स्थापित करें",
          "description": "हम आपके बटुए के त्वरित पहुँच के लिए तालिसमान को अपने टास्कबार में पिन करने की सिफारिश करते हैं।"
        },
        "step2": {
          "title": "एक ईथेरियम बटुए बनाएं या आयात करें",
          "description": "अपने बटुए का बैकअप एक सुरक्षित तरीके से लेने का ध्यान रखें। कभी भी अपनी वसूली वाक्यांश को किसी के साथ साझा न करें।"
        },
        "step3": {
          "title": "अपने ब्राउज़र को ताज़ा करें",
          "description": "एक बार जब आप अपना बटुआ सेट कर लेते हैं, तो नीचे क्लिक करके ब्राउज़र को ताज़ा करें और एक्सटेंशन को लोड करें।"
        }
      }
    },
    "xdefi": {
      "extension": {
        "step1": {
          "title": "XDEFI वॉलेट एक्सटेंशन स्थापित करें",
          "description": "हम आपकी वॉलेट की जल्दी से पहुँच के लिए XDEFI Wallet को अपने टास्कबार में पिन करने की सलाह देते हैं।"
        },
        "step2": {
          "title": "एक वॉलेट बनाएं या आयात करें",
          "description": "निश्चित रूप से अपने वॉलेट का बैकअप किसी सुरक्षित तरीके से लें। अपनी गोपनीय वाक्यांश को किसी के साथ शेयर ना करें।"
        },
        "step3": {
          "title": "अपने ब्राउज़र को ताज़ा करें",
          "description": "एक बार जब आपने अपनी वॉलेट सेट अप कर ली हो, तो ब्राउज़र को ताज़ा करने और एक्सटेंशन को लोड करने के लिए नीचे क्लिक करें।"
        }
      }
    },
    "zeal": {
      "qr_code": {
        "step1": {
          "title": "Zeal ऐप को खोलें",
          "description": "अपने वॉलेट तक तेजी से पहुंचने के लिए अपने होम स्क्रीन पर Zeal वॉलेट जोड़ें।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "नया बटुआ बनाएं या मौजूदा को आयात करें।"
        },
        "step3": {
          "title": "QR आइकन पर टैप करें और स्कैन करें",
          "description": "अपने होमस्क्रीन पर QR आइकन पर टैप करें, कोड स्कैन करें और प्रम्प्ट को कनेक्ट करने की पुष्टि करें।"
        }
      },
      "extension": {
        "step1": {
          "title": "Zeal एक्सटेंशन स्थापित करें",
          "description": "हम आपको अपने वॉलेट तक जल्दी पहुँचने के लिए Zeal को अपने टास्कबार में पिन करने की सलाह देते हैं।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेने के लिए सुनिश्चित करें। किसी के साथ भी अपना गुप्त वाक्यांश साझा न करें।"
        },
        "step3": {
          "title": "अपने ब्राउज़र को ताज़ा करें",
          "description": "एक बार जब आप अपना वॉलेट सेटअप कर लेते हैं, तो नीचे क्लिक करें ताकि ब्राउज़र को ताज़ा करें और एक्सटेंशन लोड करें।"
        }
      }
    },
    "safepal": {
      "extension": {
        "step1": {
          "title": "SafePal Wallet एक्सटेंशन स्थापित करें",
          "description": "अपने ब्राउज़र के शीर्ष दाएं में क्लिक करें और SafePal Wallet को आसानी से पहुंच के लिए पिन करें।"
        },
        "step2": {
          "title": "एक बटुआ बनाएं या आयात करें",
          "description": "नया बटुआ बनाएं या मौजूदा को आयात करें।"
        },
        "step3": {
          "title": "अपने ब्राउज़र को ताज़ा करें",
          "description": "एक बार जब आप SafePal वॉलेट सेट अप कर लेते हैं, तो नीचे क्लिक करें ताकि ब्राउज़र को रिफ्रेश करें और एक्सटेंशन लोड करें।"
        }
      },
      "qr_code": {
        "step1": {
          "title": "SafePal वॉलेट ऐप खोलें",
          "description": "अपने वॉलेट तक जल्दी पहुंचने के लिए SafePal वॉलेट को अपनी होम स्क्रीन पर रखें।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "नया बटुआ बनाएं या मौजूदा को आयात करें।"
        },
        "step3": {
          "title": "सेटिंग्स में WalletConnect को टैप करें",
          "description": "नया कनेक्शन चुनें, फिर QR कोड स्कैन करें और कनेक्ट करने के लिए प्रॉम्प्ट की पुष्टि करें।"
        }
      }
    },
    "desig": {
      "extension": {
        "step1": {
          "title": "Desig एक्सटेंशन स्थापित करें",
          "description": "हम आपको अपने वॉलेट के लिए आसानी से पहुंच पाने के लिए Desig को अपने टास्कबार में पिन करने की सलाह देते हैं।"
        },
        "step2": {
          "title": "एक वॉलेट बनाएँ",
          "description": "अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेने के लिए सुनिश्चित करें। किसी के साथ भी अपना गुप्त वाक्यांश साझा न करें।"
        },
        "step3": {
          "title": "अपने ब्राउज़र को ताज़ा करें",
          "description": "एक बार जब आप अपना वॉलेट सेटअप कर लेते हैं, तो नीचे क्लिक करें ताकि ब्राउज़र को ताज़ा करें और एक्सटेंशन लोड करें।"
        }
      }
    },
    "subwallet": {
      "extension": {
        "step1": {
          "title": "SubWallet एक्सटेंशन स्थापित करें",
          "description": "हम आपको अपने वॉलेट तक तेजी से पहुंचने के लिए SubWallet को अपने टास्कबार में पिन करने की सलाह देते हैं।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "अपने बटुए का बैकअप एक सुरक्षित तरीके से लेने का ध्यान रखें। कभी भी अपनी वसूली वाक्यांश को किसी के साथ साझा न करें।"
        },
        "step3": {
          "title": "अपने ब्राउज़र को ताज़ा करें",
          "description": "एक बार जब आप अपना वॉलेट सेटअप कर लेते हैं, तो नीचे क्लिक करें ताकि ब्राउज़र को ताज़ा करें और एक्सटेंशन लोड करें।"
        }
      },
      "qr_code": {
        "step1": {
          "title": "SubWallet ऐप खोलें",
          "description": "हम आपको तेजी से पहुंचने के लिए SubWallet को अपने होम स्क्रीन पर रखने की सलाह देते हैं।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेने के लिए सुनिश्चित करें। किसी के साथ भी अपना गुप्त वाक्यांश साझा न करें।"
        },
        "step3": {
          "title": "स्कैन बटन को टैप करें",
          "description": "जैसे ही आप स्कैन करेंगे, एक कनेक्शन संकेत आपके वॉलेट को कनेक्ट करने के लिए प्रकट होगा।"
        }
      }
    },
    "clv": {
      "extension": {
        "step1": {
          "title": "CLV Wallet एक्सटेंशन स्थापित करें",
          "description": "हम आपको अपने वॉलेट तक तेजी से पहुंचने के लिए CLV Wallet को अपने टास्कबार में पिन करने की सलाह देते हैं।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेने के लिए सुनिश्चित करें। किसी के साथ भी अपना गुप्त वाक्यांश साझा न करें।"
        },
        "step3": {
          "title": "अपने ब्राउज़र को ताज़ा करें",
          "description": "एक बार जब आप अपना वॉलेट सेटअप कर लेते हैं, तो नीचे क्लिक करें ताकि ब्राउज़र को ताज़ा करें और एक्सटेंशन लोड करें।"
        }
      },
      "qr_code": {
        "step1": {
          "title": "CLV वॉलेट ऐप खोलें",
          "description": "हम तीव्र पहुंच के लिए आपके होम स्क्रीन पर CLV वॉलेट रखने की सलाह देते हैं।"
        },
        "step2": {
          "title": "वॉलेट बनाएं या आयात करें",
          "description": "अपने वॉलेट का बैकअप एक सुरक्षित तरीके से लेने के लिए सुनिश्चित करें। किसी के साथ भी अपना गुप्त वाक्यांश साझा न करें।"
        },
        "step3": {
          "title": "स्कैन बटन को टैप करें",
          "description": "जैसे ही आप स्कैन करेंगे, एक कनेक्शन संकेत आपके वॉलेट को कनेक्ट करने के लिए प्रकट होगा।"
        }
      }
    },
    "okto": {
      "qr_code": {
        "step1": {
          "title": "Okto ऐप को खोलें",
          "description": "त्वरित पहुंच के लिए अपने होम स्क्रीन पर Okto जोड़ें"
        },
        "step2": {
          "title": "एक MPC वॉलेट बनाएं",
          "description": "एक खाता बनाएं और वॉलेट उत्पन्न करें"
        },
        "step3": {
          "title": "सेटिंग्स में WalletConnect को टैप करें",
          "description": "ऊपरी दाएँ में स्कैन QR आइकन को टैप करें और कनेक्ट करने के लिए संकेत दें।"
        }
      }
    },
    "ledger": {
      "desktop": {
        "step1": {
          "title": "लेजर लाइव ऐप खोलें",
          "description": "हम तेज एक्सेस के लिए अपने होम स्क्रीन पर Ledger Live डालने की सिफारिश करते हैं।"
        },
        "step2": {
          "title": "अपना लेजर सेट करें",
          "description": "एक नया लेजर सेट अप करें या मौजूदा वाले से कनेक्ट करें।"
        },
        "step3": {
          "title": "कनेक्ट करें",
          "description": "स्कैन करने के बाद, आपके वॉलेट को कनेक्ट करने के लिए एक कनेक्शन प्रॉम्प्ट दिखाई देगा।"
        }
      },
      "qr_code": {
        "step1": {
          "title": "लेजर लाइव ऐप खोलें",
          "description": "हम तेज एक्सेस के लिए अपने होम स्क्रीन पर Ledger Live डालने की सिफारिश करते हैं।"
        },
        "step2": {
          "title": "अपना लेजर सेट करें",
          "description": "आप डेस्कटॉप ऐप के साथ सिंक कर सकते हैं या अपने Ledger को कनेक्ट कर सकते हैं।"
        },
        "step3": {
          "title": "कोड स्कैन करें",
          "description": "WalletConnect पर टैप करें फिर स्कैनर पर स्विच करें। जब आप स्कैन करेंगे, तो आपके वॉलेट को कनेक्ट करने के लिए एक कनेक्शन संकेत प्रकट होगा।"
        }
      }
    }
  }
}
`;export{u as default};
