var e=`{
  "connect_wallet": {
    "label": "Connecter le portefeuille",
    "wrong_network": {
      "label": "Réseau incorrect"
    }
  },
  "intro": {
    "title": "Qu'est-ce qu'un portefeuille?",
    "description": "Un portefeuille est utilisé pour envoyer, recevoir, stocker et afficher des actifs numériques. C'est aussi une nouvelle façon de se connecter, sans avoir besoin de créer de nouveaux comptes et mots de passe sur chaque site.",
    "digital_asset": {
      "title": "Un foyer pour vos actifs numériques",
      "description": "Les portefeuilles sont utilisés pour envoyer, recevoir, stocker et afficher des actifs numériques comme Ethereum et les NFTs."
    },
    "login": {
      "title": "Une nouvelle façon de se connecter",
      "description": "Au lieu de créer de nouveaux comptes et mots de passe sur chaque site Web, connectez simplement votre portefeuille."
    },
    "get": {
      "label": "Obtenir un portefeuille"
    },
    "learn_more": {
      "label": "En savoir plus"
    }
  },
  "sign_in": {
    "label": "Vérifiez votre compte",
    "description": "Pour terminer la connexion, vous devez signer un message dans votre portefeuille pour vérifier que vous êtes le propriétaire de ce compte.",
    "message": {
      "send": "Envoyer le message",
      "preparing": "Préparation du message...",
      "cancel": "Annuler",
      "preparing_error": "Erreur lors de la préparation du message, veuillez réessayer!"
    },
    "signature": {
      "waiting": "En attente de la signature...",
      "verifying": "Vérification de la signature...",
      "signing_error": "Erreur lors de la signature du message, veuillez réessayer!",
      "verifying_error": "Erreur lors de la vérification de la signature, veuillez réessayer!",
      "oops_error": "Oups, quelque chose a mal tourné!"
    }
  },
  "connect": {
    "label": "Connecter",
    "title": "Connecter un portefeuille",
    "new_to_ethereum": {
      "description": "Nouveau aux portefeuilles Ethereum?",
      "learn_more": {
        "label": "En savoir plus"
      }
    },
    "learn_more": {
      "label": "En savoir plus"
    },
    "recent": "Récents",
    "status": {
      "opening": "Ouverture %{wallet}...",
      "connecting": "Connect :)ing",
      "connect_mobile": "Continuer dans %{wallet}",
      "not_installed": "%{wallet} n'est pas installé",
      "not_available": "%{wallet} n'est pas disponible",
      "confirm": "Confirmez la connexion dans l'extension",
      "confirm_mobile": "Accepter la demande de connexion dans le portefeuille"
    },
    "secondary_action": {
      "get": {
        "description": "Vous n'avez pas de %{wallet}?",
        "label": "OBTENIR"
      },
      "install": {
        "label": "INSTALLER"
      },
      "retry": {
        "label": "RÉESSAYER"
      }
    },
    "walletconnect": {
      "description": {
        "full": "Vous avez besoin du modal officiel de WalletConnect ?",
        "compact": "Besoin du modal de WalletConnect ?"
      },
      "open": {
        "label": "OUVRIR"
      }
    }
  },
  "connect_scan": {
    "title": "Scannez avec %{wallet}",
    "fallback_title": "Scannez avec votre téléphone"
  },
  "connector_group": {
    "installed": "Installé",
    "recommended": "Recommandé",
    "other": "Autre",
    "popular": "Populaire",
    "more": "Plus",
    "others": "Autres"
  },
  "get": {
    "title": "Obtenez un portefeuille",
    "action": {
      "label": "OBTENIR"
    },
    "mobile": {
      "description": "Portefeuille mobile"
    },
    "extension": {
      "description": "Extension de navigateur"
    },
    "mobile_and_extension": {
      "description": "Portefeuille mobile et extension"
    },
    "mobile_and_desktop": {
      "description": "Portefeuille mobile et de bureau"
    },
    "looking_for": {
      "title": "Ce n'est pas ce que vous cherchez ?",
      "mobile": {
        "description": "Sélectionnez un portefeuille sur l'écran principal pour commencer avec un autre fournisseur de portefeuille."
      },
      "desktop": {
        "compact_description": "Sélectionnez un portefeuille sur l'écran principal pour commencer avec un autre fournisseur de portefeuille.",
        "wide_description": "Sélectionnez un portefeuille sur la gauche pour commencer avec un autre fournisseur de portefeuille."
      }
    }
  },
  "get_options": {
    "title": "Commencez avec %{wallet}",
    "short_title": "Obtenez %{wallet}",
    "mobile": {
      "title": "%{wallet} pour mobile",
      "description": "Utilisez le portefeuille mobile pour explorer le monde d'Ethereum.",
      "download": {
        "label": "Obtenez l'application"
      }
    },
    "extension": {
      "title": "%{wallet} pour %{browser}",
      "description": "Accédez à votre portefeuille directement depuis votre navigateur web préféré.",
      "download": {
        "label": "Ajouter à %{browser}"
      }
    },
    "desktop": {
      "title": "%{wallet} pour %{platform}",
      "description": "Accédez à votre portefeuille nativement depuis votre puissant ordinateur de bureau.",
      "download": {
        "label": "Ajouter à %{platform}"
      }
    }
  },
  "get_mobile": {
    "title": "Installer %{wallet}",
    "description": "Scannez avec votre téléphone pour télécharger sur iOS ou Android",
    "continue": {
      "label": "Continuer"
    }
  },
  "get_instructions": {
    "mobile": {
      "connect": {
        "label": "Connecter"
      },
      "learn_more": {
        "label": "En savoir plus"
      }
    },
    "extension": {
      "refresh": {
        "label": "Rafraîchir"
      },
      "learn_more": {
        "label": "En savoir plus"
      }
    },
    "desktop": {
      "connect": {
        "label": "Connecter"
      },
      "learn_more": {
        "label": "En savoir plus"
      }
    }
  },
  "chains": {
    "title": "Changer de réseau",
    "wrong_network": "Mauvais réseau détecté, changez ou déconnectez-vous pour continuer.",
    "confirm": "Confirmer dans le portefeuille",
    "switching_not_supported": "Votre portefeuille ne supporte pas le changement de réseau depuis %{appName}. Essayez de changer de réseau depuis votre portefeuille.",
    "switching_not_supported_fallback": "Votre portefeuille ne prend pas en charge le changement de réseau à partir de cette application. Essayez de changer de réseau à partir de votre portefeuille à la place.",
    "disconnect": "Déconnecter",
    "connected": "Connecté"
  },
  "profile": {
    "disconnect": {
      "label": "Déconnecter"
    },
    "copy_address": {
      "label": "Copier l'adresse",
      "copied": "Copié !"
    },
    "explorer": {
      "label": "Voir plus sur l'explorateur"
    },
    "transactions": {
      "description": "%{appName} transactions apparaîtront ici...",
      "description_fallback": "Vos transactions apparaîtront ici...",
      "recent": {
        "title": "Transactions Récentes"
      },
      "clear": {
        "label": "Tout supprimer"
      }
    }
  },
  "wallet_connectors": {
    "argent": {
      "qr_code": {
        "step1": {
          "description": "Mettez Argent sur votre écran d'accueil pour un accès plus rapide à votre portefeuille.",
          "title": "Ouvrez l'application Argent"
        },
        "step2": {
          "description": "Créez un portefeuille et un nom d'utilisateur, ou importez un portefeuille existant.",
          "title": "Créer ou Importer un Portefeuille"
        },
        "step3": {
          "description": "Après avoir numérisé, une invite de connexion apparaîtra pour vous permettre de connecter votre portefeuille.",
          "title": "Appuyez sur le bouton Scan QR"
        }
      }
    },
    "bifrost": {
      "qr_code": {
        "step1": {
          "description": "Nous vous recommandons de mettre le portefeuille Bifrost sur votre écran d'accueil pour un accès plus rapide.",
          "title": "Ouvrez l'application Bifrost Wallet"
        },
        "step2": {
          "description": "Créez ou importez un portefeuille en utilisant votre phrase de récupération.",
          "title": "Créer ou Importer un portefeuille"
        },
        "step3": {
          "description": "Après votre scan, une invite de connexion apparaîtra pour vous permettre de connecter votre portefeuille.",
          "title": "Appuyez sur le bouton de scan"
        }
      }
    },
    "bitget": {
      "qr_code": {
        "step1": {
          "description": "Nous vous recommandons de placer Bitget Wallet sur votre écran d'accueil pour un accès plus rapide.",
          "title": "Ouvrez l'application Bitget Wallet"
        },
        "step2": {
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quiconque.",
          "title": "Créer ou Importer un portefeuille"
        },
        "step3": {
          "description": "Après le scan, une incitation de connexion apparaîtra pour vous permettre de connecter votre portefeuille.",
          "title": "Appuyez sur le bouton de scan"
        }
      },
      "extension": {
        "step1": {
          "description": "Nous vous recommandons d'épingler Bitget Wallet à votre barre des tâches pour un accès plus rapide à votre portefeuille.",
          "title": "Installez l'extension de portefeuille Bitget"
        },
        "step2": {
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec personne.",
          "title": "Créez ou Importez un portefeuille"
        },
        "step3": {
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour actualiser le navigateur et charger l'extension.",
          "title": "Rafraîchissez votre navigateur"
        }
      }
    },
    "bitski": {
      "extension": {
        "step1": {
          "description": "Nous recommandons d'épingler Bitski à votre barre des tâches pour un accès plus rapide à votre portefeuille.",
          "title": "Installez l'extension Bitski"
        },
        "step2": {
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec qui que ce soit.",
          "title": "Créer ou Importer un portefeuille"
        },
        "step3": {
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour rafraîchir le navigateur et charger l'extension.",
          "title": "Rafraîchissez votre navigateur"
        }
      }
    },
    "bitverse": {
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application Bitverse Wallet",
          "description": "Ajoutez Bitverse Wallet à votre écran d'accueil pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un Portefeuille",
          "description": "Créez un nouveau portefeuille ou importez-en un existant."
        },
        "step3": {
          "title": "Touchez l'icône QR et scannez",
          "description": "Touchez l'icône QR sur votre écran d'accueil, scannez le code et confirmez l'invite pour vous connecter."
        }
      }
    },
    "bloom": {
      "desktop": {
        "step1": {
          "title": "Ouvrez l'application Bloom Wallet",
          "description": "Nous recommandons de placer Bloom Wallet sur votre écran d'accueil pour un accès plus rapide."
        },
        "step2": {
          "description": "Créez ou importez un portefeuille en utilisant votre phrase de récupération.",
          "title": "Créer ou Importer un Portefeuille"
        },
        "step3": {
          "description": "Après avoir obtenu un portefeuille, cliquez sur Connecter pour vous connecter via Bloom. Une invite de connexion apparaîtra dans l'application pour que vous confirmiez la connexion.",
          "title": "Cliquez sur Connecter"
        }
      },
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application Bloom Wallet",
          "description": "Nous recommandons de placer Bloom Wallet sur votre écran d'accueil pour un accès plus rapide."
        },
        "step2": {
          "description": "Créez ou importez un portefeuille en utilisant votre phrase de récupération.",
          "title": "Créer ou Importer un Portefeuille"
        },
        "step3": {
          "description": "Après avoir obtenu un portefeuille, cliquez sur Connecter pour vous connecter via Bloom. Une invite de connexion apparaîtra dans l'application pour que vous confirmiez la connexion.",
          "title": "Cliquez sur Connecter"
        }
      }
    },
    "bybit": {
      "qr_code": {
        "step1": {
          "description": "Nous recommandons de placer Bybit sur votre écran d'accueil pour un accès plus rapide à votre portefeuille.",
          "title": "Ouvrez l'application Bybit"
        },
        "step2": {
          "description": "Vous pouvez facilement sauvegarder votre portefeuille en utilisant notre fonction de sauvegarde sur votre téléphone.",
          "title": "Créer ou Importer un Portefeuille"
        },
        "step3": {
          "description": "Après avoir numérisé, une invite de connexion apparaîtra pour vous permettre de connecter votre portefeuille.",
          "title": "Appuyez sur le bouton de scan"
        }
      },
      "extension": {
        "step1": {
          "description": "Cliquez en haut à droite de votre navigateur et épinglez le portefeuille Bybit pour un accès facile.",
          "title": "Installez l'extension Bybit Wallet"
        },
        "step2": {
          "description": "Créez un nouveau portefeuille ou importez-en un existant.",
          "title": "Créer ou Importer un portefeuille"
        },
        "step3": {
          "description": "Une fois que vous avez configuré Bybit Wallet, cliquez ci-dessous pour rafraîchir le navigateur et charger l'extension.",
          "title": "Rafraîchissez votre navigateur"
        }
      }
    },
    "binance": {
      "qr_code": {
        "step1": {
          "description": "Nous vous recommandons de mettre Binance sur votre écran d'accueil pour un accès plus rapide à votre portefeuille.",
          "title": "Ouvrez l'application Binance"
        },
        "step2": {
          "description": "Vous pouvez facilement sauvegarder votre portefeuille en utilisant notre fonction de sauvegarde sur votre téléphone.",
          "title": "Créer ou Importer un Portefeuille"
        },
        "step3": {
          "description": "Après avoir numérisé, une invite de connexion apparaîtra pour vous permettre de connecter votre portefeuille.",
          "title": "Appuyez sur le bouton WalletConnect"
        }
      }
    },
    "coin98": {
      "qr_code": {
        "step1": {
          "description": "Nous vous recommandons de placer Coin98 Wallet sur votre écran d'accueil pour un accès plus rapide à votre portefeuille.",
          "title": "Ouvrez l'application Coin98 Wallet"
        },
        "step2": {
          "description": "Vous pouvez facilement sauvegarder votre portefeuille en utilisant notre fonction de sauvegarde sur votre téléphone.",
          "title": "Créer ou Importer un portefeuille"
        },
        "step3": {
          "description": "Après que vous ayez scanné, une invite de connexion apparaîtra pour vous permettre de connecter votre portefeuille.",
          "title": "Appuyez sur le bouton WalletConnect"
        }
      },
      "extension": {
        "step1": {
          "description": "Cliquez en haut à droite de votre navigateur et épinglez Coin98 Wallet pour un accès facile.",
          "title": "Installez l'extension Coin98 Wallet"
        },
        "step2": {
          "description": "Créez un nouveau portefeuille ou importez-en un existant.",
          "title": "Créer ou Importer un portefeuille"
        },
        "step3": {
          "description": "Une fois que vous avez configuré Coin98 Wallet, cliquez ci-dessous pour actualiser le navigateur et charger l'extension.",
          "title": "Rafraîchissez votre navigateur"
        }
      }
    },
    "coinbase": {
      "qr_code": {
        "step1": {
          "description": "Nous recommandons de placer Coinbase Wallet sur votre écran d'accueil pour un accès plus rapide.",
          "title": "Ouvrez l'application Coinbase Wallet"
        },
        "step2": {
          "description": "Vous pouvez facilement sauvegarder votre portefeuille en utilisant la fonction de sauvegarde cloud.",
          "title": "Créer ou Importer un portefeuille"
        },
        "step3": {
          "description": "Après avoir scanné, une invite de connexion s'affichera pour que vous puissiez connecter votre portefeuille.",
          "title": "Appuyez sur le bouton de scan"
        }
      },
      "extension": {
        "step1": {
          "description": "Nous recommandons d'épingler Coinbase Wallet à votre barre des tâches pour un accès plus rapide à votre portefeuille.",
          "title": "Installez l'extension Coinbase Wallet"
        },
        "step2": {
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sûre. Ne partagez jamais votre phrase secrète avec quiconque.",
          "title": "Créer ou Importer un portefeuille"
        },
        "step3": {
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour actualiser le navigateur et charger l'extension.",
          "title": "Actualisez votre navigateur"
        }
      }
    },
    "compass": {
      "extension": {
        "step1": {
          "description": "Nous vous recommandons d'épingler Compass Wallet à votre barre des tâches pour un accès plus rapide à votre portefeuille.",
          "title": "Installez l'extension Compass Wallet"
        },
        "step2": {
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quiconque.",
          "title": "Créer ou Importer un Portefeuille"
        },
        "step3": {
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour actualiser le navigateur et charger l'extension.",
          "title": "Rafraîchissez votre navigateur"
        }
      }
    },
    "core": {
      "qr_code": {
        "step1": {
          "description": "Nous recommandons de placer Core sur votre écran d'accueil pour un accès plus rapide à votre portefeuille.",
          "title": "Ouvrez l'application Core"
        },
        "step2": {
          "description": "Vous pouvez facilement sauvegarder votre portefeuille en utilisant notre fonction de sauvegarde sur votre téléphone.",
          "title": "Créer ou Importer un portefeuille"
        },
        "step3": {
          "description": "Après avoir scanné, une invite de connexion apparaîtra pour vous permettre de connecter votre portefeuille.",
          "title": "Appuyez sur le bouton WalletConnect"
        }
      },
      "extension": {
        "step1": {
          "description": "Nous recommandons d'épingler Core à votre barre des tâches pour un accès plus rapide à votre portefeuille.",
          "title": "Installez l'extension Core"
        },
        "step2": {
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quiconque.",
          "title": "Créez ou Importer un Portefeuille"
        },
        "step3": {
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour rafraîchir le navigateur et charger l'extension.",
          "title": "Rafraîchissez votre navigateur"
        }
      }
    },
    "fox": {
      "qr_code": {
        "step1": {
          "description": "Nous recommandons de mettre FoxWallet sur votre écran d'accueil pour un accès plus rapide.",
          "title": "Ouvrez l'application FoxWallet"
        },
        "step2": {
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec personne.",
          "title": "Créer ou Importer un portefeuille"
        },
        "step3": {
          "description": "Après avoir scanné, une invitation à la connexion apparaîtra pour vous permettre de connecter votre portefeuille.",
          "title": "Appuyez sur le bouton de scan"
        }
      }
    },
    "frontier": {
      "qr_code": {
        "step1": {
          "description": "Nous vous recommandons de placer le portefeuille Frontier sur votre écran d'accueil pour un accès plus rapide.",
          "title": "Ouvrez l'application Frontier Wallet"
        },
        "step2": {
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec personne.",
          "title": "Créer ou Importer un portefeuille"
        },
        "step3": {
          "description": "Après avoir scanné, une invite de connexion apparaîtra pour vous permettre de connecter votre portefeuille.",
          "title": "Appuyez sur le bouton de scan"
        }
      },
      "extension": {
        "step1": {
          "description": "Nous recommandons d'épingler Frontier Wallet à votre barre des tâches pour un accès plus rapide à votre portefeuille.",
          "title": "Installez l'extension Frontier Wallet"
        },
        "step2": {
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec personne.",
          "title": "Créez ou importez un portefeuille"
        },
        "step3": {
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour actualiser le navigateur et charger l'extension.",
          "title": "Rafraîchissez votre navigateur"
        }
      }
    },
    "im_token": {
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application imToken",
          "description": "Placez l'application imToken sur votre écran d'accueil pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créez ou importez un portefeuille",
          "description": "Créez un nouveau portefeuille ou importez-en un existant ."
        },
        "step3": {
          "title": "Appuyez sur l'icône du scanner dans le coin supérieur droit",
          "description": "Choisissez Nouvelle Connexion, puis scannez le code QR et confirmez l'invite pour vous connecter."
        }
      }
    },
    "kaikas": {
      "extension": {
        "step1": {
          "description": "Nous recommandons d'épingler Kaikas à votre barre des tâches pour un accès plus rapide à votre portefeuille.",
          "title": "Installez l'extension Kaikas"
        },
        "step2": {
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quiconque.",
          "title": "Créer ou Importer un Portefeuille"
        },
        "step3": {
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour actualiser le navigateur et charger l'extension.",
          "title": "Rafraîchissez votre navigateur"
        }
      },
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application Kaikas",
          "description": "Placez l'application Kaikas sur votre écran d'accueil pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un Portefeuille",
          "description": "Créez un nouveau portefeuille ou importez-en un existant."
        },
        "step3": {
          "title": "Appuyez sur l'icône du scanner dans le coin supérieur droit",
          "description": "Choisissez Nouvelle Connexion, puis scannez le code QR et confirmez l'invite pour vous connecter."
        }
      }
    },
    "kraken": {
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application Kraken Wallet",
          "description": "Ajoutez Kraken Wallet à votre écran d'accueil pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un Portefeuille",
          "description": "Créez un nouveau portefeuille ou importez-en un existant."
        },
        "step3": {
          "title": "Touchez l'icône QR et scannez",
          "description": "Touchez l'icône QR sur votre écran d'accueil, scannez le code et confirmez l'invite pour vous connecter."
        }
      }
    },
    "kresus": {
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application Kresus Wallet",
          "description": "Ajoutez Kresus Wallet sur votre écran d'accueil pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un Portefeuille",
          "description": "Créez un nouveau portefeuille ou importez-en un existant."
        },
        "step3": {
          "title": "Touchez l'icône QR et scannez",
          "description": "Touchez l'icône QR sur votre écran d'accueil, scannez le code et confirmez l'invite pour vous connecter."
        }
      }
    },
    "magicEden": {
      "extension": {
        "step1": {
          "title": "Installez l'extension Magic Eden",
          "description": "Nous vous recommandons d'épingler Magic Eden à votre barre des tâches pour un accès plus facile à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un Portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase de récupération secrète avec personne."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour actualiser le navigateur et charger l'extension."
        }
      }
    },
    "metamask": {
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application MetaMask",
          "description": "Nous vous recommandons de mettre MetaMask sur votre écran d'accueil pour un accès plus rapide."
        },
        "step2": {
          "title": "Créer ou Importer un Portefeuille",
          "description": "Veillez à sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec qui que ce soit."
        },
        "step3": {
          "title": "Appuyez sur le bouton de scan",
          "description": "Après avoir scanné, une invite de connexion apparaîtra pour vous permettre de connecter votre portefeuille."
        }
      },
      "extension": {
        "step1": {
          "title": "Installez l’extension de MetaMask",
          "description": "Nous recommandons d'épingler MetaMask à votre barre des tâches pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quiconque."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour rafraîchir le navigateur et charger l'extension."
        }
      }
    },
    "nestwallet": {
      "extension": {
        "step1": {
          "title": "Installez l'extension NestWallet",
          "description": "Nous vous recommandons d'épingler NestWallet à votre barre des tâches pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un Portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quiconque."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour actualiser le navigateur et charger l'extension."
        }
      }
    },
    "okx": {
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application OKX Wallet",
          "description": "Nous recommandons de mettre OKX Wallet sur votre écran d'accueil pour un accès plus rapide."
        },
        "step2": {
          "title": "Créer ou Importer un portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quiconque."
        },
        "step3": {
          "title": "Appuyez sur le bouton de numérisation",
          "description": "Après avoir numérisé, une invite de connexion apparaîtra pour vous permettre de connecter votre portefeuille."
        }
      },
      "extension": {
        "step1": {
          "title": "Installez l'extension de portefeuille OKX",
          "description": "Nous vous recommandons d'épingler le portefeuille OKX à votre barre des tâches pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quiconque."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour actualiser le navigateur et charger l'extension."
        }
      }
    },
    "omni": {
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application Omni",
          "description": "Ajoutez Omni à votre écran d'accueil pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un Portefeuille",
          "description": "Créez un nouveau portefeuille ou importez-en un existant."
        },
        "step3": {
          "title": "Touchez l'icône QR et scannez",
          "description": "Appuyez sur l'icône QR sur votre écran d'accueil, scannez le code et confirmez l'invite pour vous connecter."
        }
      }
    },
    "1inch": {
      "qr_code": {
        "step1": {
          "description": "Placez 1inch Wallet sur votre écran d'accueil pour un accès plus rapide à votre portefeuille.",
          "title": "Ouvrez l'application 1inch Wallet"
        },
        "step2": {
          "description": "Créez un portefeuille et un nom d'utilisateur, ou importez un portefeuille existant.",
          "title": "Créer ou Importer un Portefeuille"
        },
        "step3": {
          "description": "Après avoir numérisé, une invite de connexion apparaîtra pour vous permettre de connecter votre portefeuille.",
          "title": "Appuyez sur le bouton Scan QR"
        }
      }
    },
    "token_pocket": {
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application TokenPocket",
          "description": "Nous vous recommandons de mettre TokenPocket sur votre écran d'accueil pour un accès plus rapide."
        },
        "step2": {
          "title": "Créez ou Importer un portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille à l'aide d'une méthode sécurisée. Ne partagez jamais votre phrase secrète avec qui que ce soit."
        },
        "step3": {
          "title": "Appuyez sur le bouton de scan",
          "description": "Après votre scan, une invite de connexion apparaîtra pour vous permettre de connecter votre portefeuille."
        }
      },
      "extension": {
        "step1": {
          "title": "Installez l'extension TokenPocket",
          "description": "Nous recommandons d'épingler TokenPocket à votre barre des tâches pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec qui que ce soit."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour rafraîchir le navigateur et charger l'extension."
        }
      }
    },
    "trust": {
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application Trust Wallet",
          "description": "Placez Trust Wallet sur votre écran d'accueil pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un portefeuille",
          "description": "Créer un nouveau portefeuille ou en importer un existant."
        },
        "step3": {
          "title": "Appuyez sur WalletConnect dans les paramètres",
          "description": "Choisissez Nouvelle Connexion, puis scannez le code QR et confirmez l'invite pour vous connecter."
        }
      },
      "extension": {
        "step1": {
          "title": "Installez l'extension Trust Wallet",
          "description": "Cliquez en haut à droite de votre navigateur et épinglez Trust Wallet pour un accès facile."
        },
        "step2": {
          "title": "Créer ou importer un portefeuille",
          "description": "Créer un nouveau portefeuille ou en importer un existant."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré Trust Wallet, cliquez ci-dessous pour rafraîchir le navigateur et charger l'extension."
        }
      }
    },
    "uniswap": {
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application Uniswap",
          "description": "Ajoutez Uniswap Wallet à votre écran d'accueil pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créez ou importez un portefeuille",
          "description": "Créez un nouveau portefeuille ou importez-en un existant."
        },
        "step3": {
          "title": "Tapez sur l'icône QR et scannez",
          "description": "Touchez l'icône QR sur votre écran d'accueil, scannez le code et confirmez l'invite pour vous connecter."
        }
      }
    },
    "zerion": {
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application Zerion",
          "description": "Nous vous recommandons de mettre Zerion sur votre écran d'accueil pour un accès plus rapide."
        },
        "step2": {
          "title": "Créer ou Importer un portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec personne."
        },
        "step3": {
          "title": "Appuyez sur le bouton de scan",
          "description": "Une fois que vous avez scanné, une invite de connexion apparaîtra pour que vous puissiez connecter votre portefeuille."
        }
      },
      "extension": {
        "step1": {
          "title": "Installer l'extension Zerion",
          "description": "Nous recommandons d'épingler Zerion à votre barre des tâches pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créez ou Importez un portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quiconque."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour rafraîchir le navigateur et charger l'extension."
        }
      }
    },
    "rainbow": {
      "qr_code": {
        "step1": {
          "title": "Ouvre l'application Rainbow",
          "description": "Nous vous recommandons de mettre Rainbow sur votre écran d'accueil pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créez ou Importez un portefeuille",
          "description": "Vous pouvez facilement sauvegarder votre portefeuille en utilisant notre fonction de sauvegarde sur votre téléphone."
        },
        "step3": {
          "title": "Appuyez sur le bouton de scan",
          "description": "Après avoir scanné, une invite de connexion apparaîtra pour que vous connectiez votre portefeuille."
        }
      }
    },
    "enkrypt": {
      "extension": {
        "step1": {
          "description": "Nous vous recommandons d'épingler Enkrypt Wallet à votre barre des tâches pour un accès plus rapide à votre portefeuille.",
          "title": "Installez l'extension Enkrypt Wallet"
        },
        "step2": {
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quelqu'un.",
          "title": "Créer ou Importer un portefeuille"
        },
        "step3": {
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour rafraîchir le navigateur et charger l’extension.",
          "title": "Rafraîchissez votre navigateur"
        }
      }
    },
    "frame": {
      "extension": {
        "step1": {
          "description": "Nous vous recommandons d'épingler Frame à votre barre des tâches pour un accès plus rapide à votre portefeuille.",
          "title": "Installez Frame & l'extension complémentaire"
        },
        "step2": {
          "description": "Assurez-vous de sauvegarder votre portefeuille à l'aide d'une méthode sécurisée. Ne partagez jamais votre phrase secrète avec personne.",
          "title": "Créer ou Importer un portefeuille"
        },
        "step3": {
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour rafraîchir le navigateur et charger l'extension.",
          "title": "Rafraîchissez votre navigateur"
        }
      }
    },
    "one_key": {
      "extension": {
        "step1": {
          "title": "Installez l'extension OneKey Wallet",
          "description": "Nous vous recommandons d'épingler OneKey Wallet à votre barre des tâches pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec personne."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour rafraîchir le navigateur et charger l'extension."
        }
      }
    },
    "phantom": {
      "extension": {
        "step1": {
          "title": "Installez l'extension Phantom",
          "description": "Nous vous recommandons d'épingler Phantom à votre barre des tâches pour un accès plus facile à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase de récupération secrète avec personne."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour rafraîchir le navigateur et charger l'extension."
        }
      }
    },
    "rabby": {
      "extension": {
        "step1": {
          "title": "Installez l'extension Rabby",
          "description": "Nous recommandons d'épingler Rabby à votre barre des tâches pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec qui que ce soit."
        },
        "step3": {
          "title": "Actualisez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour actualiser le navigateur et charger l'extension."
        }
      }
    },
    "ronin": {
      "qr_code": {
        "step1": {
          "description": "Nous recommandons de placer Ronin Wallet sur votre écran d'accueil pour un accès plus rapide.",
          "title": "Ouvrez l'application Ronin Wallet"
        },
        "step2": {
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quiconque.",
          "title": "Créer ou Importer un Portefeuille"
        },
        "step3": {
          "description": "Après avoir numérisé, une invite de connexion apparaîtra pour vous permettre de connecter votre portefeuille.",
          "title": "Appuyez sur le bouton de scan"
        }
      },
      "extension": {
        "step1": {
          "description": "Nous recommandons d'épingler Ronin Wallet à votre barre des tâches pour un accès plus rapide à votre portefeuille.",
          "title": "Installez l'extension Ronin Wallet"
        },
        "step2": {
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quiconque.",
          "title": "Créer ou Importer un Portefeuille"
        },
        "step3": {
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour actualiser le navigateur et charger l'extension.",
          "title": "Rafraîchissez votre navigateur"
        }
      }
    },
    "ramper": {
      "extension": {
        "step1": {
          "title": "Installez l'extension Ramper",
          "description": "Nous recommandons d'épingler Ramper à votre barre des tâches pour un accès plus facile à votre portefeuille."
        },
        "step2": {
          "title": "Créer un Portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quiconque."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour actualiser le navigateur et charger l'extension."
        }
      }
    },
    "safeheron": {
      "extension": {
        "step1": {
          "title": "Installez l'extension Core",
          "description": "Nous recommandons d'épingler Safeheron à votre barre des tâches pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quelqu'un."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour rafraîchir le navigateur et charger l'extension."
        }
      }
    },
    "taho": {
      "extension": {
        "step1": {
          "title": "Installez l'extension Taho",
          "description": "Nous vous recommandons d'épingler Taho à votre barre des tâches pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créez ou Importez un portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quelqu'un."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour rafraîchir le navigateur et charger l'extension."
        }
      }
    },
    "talisman": {
      "extension": {
        "step1": {
          "title": "Installez l'extension Talisman",
          "description": "Nous vous recommandons d'épingler Talisman à votre barre des tâches pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou importer un portefeuille Ethereum",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase de récupération avec personne."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour rafraîchir le navigateur et charger l'extension."
        }
      }
    },
    "xdefi": {
      "extension": {
        "step1": {
          "title": "Installez l'extension du portefeuille XDEFI",
          "description": "Nous vous recommandons d'épingler XDEFI Wallet à votre barre des tâches pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec qui que ce soit."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour rafraîchir le navigateur et charger l'extension."
        }
      }
    },
    "zeal": {
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application Zeal",
          "description": "Ajoutez Zeal Wallet à votre écran d'accueil pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un Portefeuille",
          "description": "Créez un nouveau portefeuille ou importez-en un existant."
        },
        "step3": {
          "title": "Touchez l'icône QR et scannez",
          "description": "Touchez l'icône QR sur votre écran d'accueil, scannez le code et confirmez l'invite pour vous connecter."
        }
      },
      "extension": {
        "step1": {
          "title": "Installez l'extension Zeal",
          "description": "Nous vous recommandons d'épingler Zeal à votre barre des tâches pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un Portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quiconque."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour actualiser le navigateur et charger l'extension."
        }
      }
    },
    "safepal": {
      "extension": {
        "step1": {
          "title": "Installez l'extension SafePal Wallet",
          "description": "Cliquez en haut à droite de votre navigateur et épinglez SafePal Wallet pour un accès facile."
        },
        "step2": {
          "title": "Créer ou Importer un portefeuille",
          "description": "Créez un nouveau portefeuille ou importez-en un existant."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré SafePal Wallet, cliquez ci-dessous pour rafraîchir le navigateur et charger l'extension."
        }
      },
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application SafePal Wallet",
          "description": "Mettez SafePal Wallet sur votre écran d'accueil pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un Portefeuille",
          "description": "Créez un nouveau portefeuille ou importez-en un existant."
        },
        "step3": {
          "title": "Appuyez sur WalletConnect dans les paramètres",
          "description": "Choisissez Nouvelle Connexion, puis scannez le code QR et confirmez l'invite pour vous connecter."
        }
      }
    },
    "desig": {
      "extension": {
        "step1": {
          "title": "Installez l'extension Desig",
          "description": "Nous vous recommandons d'épingler Desig à votre barre des tâches pour un accès plus facile à votre portefeuille."
        },
        "step2": {
          "title": "Créer un Portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quiconque."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour actualiser le navigateur et charger l'extension."
        }
      }
    },
    "subwallet": {
      "extension": {
        "step1": {
          "title": "Installez l'extension SubWallet",
          "description": "Nous vous recommandons d'épingler SubWallet à votre barre des tâches pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un Portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase de récupération avec personne."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour actualiser le navigateur et charger l'extension."
        }
      },
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application SubWallet",
          "description": "Nous vous recommandons de mettre SubWallet sur votre écran d'accueil pour un accès plus rapide."
        },
        "step2": {
          "title": "Créer ou Importer un Portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quiconque."
        },
        "step3": {
          "title": "Appuyez sur le bouton de scan",
          "description": "Après avoir numérisé, une invite de connexion apparaîtra pour vous permettre de connecter votre portefeuille."
        }
      }
    },
    "clv": {
      "extension": {
        "step1": {
          "title": "Installez l'extension CLV Wallet",
          "description": "Nous vous recommandons d'épingler CLV Wallet à votre barre des tâches pour un accès plus rapide à votre portefeuille."
        },
        "step2": {
          "title": "Créer ou Importer un Portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quiconque."
        },
        "step3": {
          "title": "Rafraîchissez votre navigateur",
          "description": "Une fois que vous avez configuré votre portefeuille, cliquez ci-dessous pour actualiser le navigateur et charger l'extension."
        }
      },
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application CLV Wallet",
          "description": "Nous vous recommandons de mettre CLV Wallet sur votre écran d'accueil pour un accès plus rapide."
        },
        "step2": {
          "title": "Créer ou Importer un Portefeuille",
          "description": "Assurez-vous de sauvegarder votre portefeuille en utilisant une méthode sécurisée. Ne partagez jamais votre phrase secrète avec quiconque."
        },
        "step3": {
          "title": "Appuyez sur le bouton de scan",
          "description": "Après avoir numérisé, une invite de connexion apparaîtra pour vous permettre de connecter votre portefeuille."
        }
      }
    },
    "okto": {
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application Okto",
          "description": "Ajoutez Okto à votre écran d'accueil pour un accès rapide"
        },
        "step2": {
          "title": "Créer un portefeuille MPC",
          "description": "Créez un compte et générez un portefeuille"
        },
        "step3": {
          "title": "Appuyez sur WalletConnect dans les paramètres",
          "description": "Touchez l'icône 'Scan QR' en haut à droite et confirmez l'invite pour vous connecter."
        }
      }
    },
    "ledger": {
      "desktop": {
        "step1": {
          "title": "Ouvrez l'application Ledger Live",
          "description": "Nous vous recommandons de mettre Ledger Live sur votre écran d'accueil pour un accès plus rapide."
        },
        "step2": {
          "title": "Configurez votre Ledger",
          "description": "Configurez un nouveau Ledger ou connectez-vous à un existant."
        },
        "step3": {
          "title": "Connecter",
          "description": "Une fois que vous avez scanné, une invite de connexion apparaîtra pour que vous puissiez connecter votre portefeuille."
        }
      },
      "qr_code": {
        "step1": {
          "title": "Ouvrez l'application Ledger Live",
          "description": "Nous vous recommandons de mettre Ledger Live sur votre écran d'accueil pour un accès plus rapide."
        },
        "step2": {
          "title": "Configurez votre Ledger",
          "description": "Vous pouvez soit synchroniser avec l'application de bureau, soit connecter votre Ledger."
        },
        "step3": {
          "title": "Scannez le code",
          "description": "Appuyez sur WalletConnect puis passez au Scanner. Une fois que vous avez scanné, une invite de connexion apparaîtra pour que vous puissiez connecter votre portefeuille."
        }
      }
    }
  }
}
`;export{e as default};
